(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    558957,      10883]
NotebookOptionsPosition[    551276,      10755]
NotebookOutlinePosition[    551668,      10771]
CellTagsIndexPosition[    551625,      10768]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
- The note and this notebook correspond to the material used in the ~2/3 of \
the first lecture on Computational Astrophysics at PSI 23, following an \
overview of topics in computational astrophysics by I. Milic
Aim of the lecture was an  introduction to numerical analysis and the most \
common issues that arise when one discretizes an analytical problem. These \
issues were illustrated on a specific example : elliptic BVP in spherical \
coordinates, solved using the finite difference approach
- Standard reference for computational physics is W. Press et al. \
\[OpenCurlyDoubleQuote]Numerical Recipes\[CloseCurlyDoubleQuote].
For an introduction to finite difference methods for ODE/PDE see R. LeVeque \
\[OpenCurlyDoubleQuote]Finite Difference Methods  for Ordinary and Partial  \
Differential Equations\[CloseCurlyDoubleQuote]

\
\>", "Text",
 CellChangeTimes->{{3.900149584978259*^9, 3.900149628871483*^9}, {
   3.90137000123225*^9, 3.901370019045951*^9}, {3.901370491603162*^9, 
   3.901370501957502*^9}, {3.901370906633601*^9, 3.901371008660508*^9}, {
   3.901371039706757*^9, 3.901371070719204*^9}, {3.901371100843615*^9, 
   3.9013711311634912`*^9}, {3.901373477477006*^9, 3.901373497894063*^9}, {
   3.9013735334567957`*^9, 3.901373597371499*^9}, {3.901373815303206*^9, 
   3.90137386236976*^9}, {3.901374014711851*^9, 3.901374027610086*^9}, 
   3.901374096850593*^9, {3.901374407530171*^9, 3.901374432724059*^9}, {
   3.901374475857726*^9, 3.9013744787470207`*^9}, {3.901374557742016*^9, 
   3.9013745757726517`*^9}, {3.901375549450055*^9, 
   3.901375551839457*^9}},ExpressionUUID->"7c274769-2da8-4b70-8347-\
057399a794c9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "formulating", " ", "nonlinear", " ", "Poisson", " ", "equation", " ", 
    "in", " ", "spherical", " ", "coordinates"}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
    "Kp", ",", "lhs", ",", "rhs", ",", "\[Epsilon]", ",", "\[Delta]", ",", 
     "a", ",", "Rmax", ",", "m1", ",", "m2", ",", "\[Sigma]", ",", 
     "\[CapitalOmega]"}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Kp", "=", 
     RowBox[{"1", "+", 
      RowBox[{"\[Delta]", " ", 
       RowBox[{
        RowBox[{
         TemplateBox[{"Grad"},
          "InactiveHead",
          BaseStyle->"Inactive",
          SyntaxForm->"Symbol",
          Tooltip->"Inactive[Grad]"], "[", 
         RowBox[{
          RowBox[{"u", "[", "r", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "}"}], ",", 
          "\"\<Spherical\>\""}], "]"}], ".", 
        RowBox[{
         TemplateBox[{"Grad"},
          "InactiveHead",
          BaseStyle->"Inactive",
          SyntaxForm->"Symbol",
          Tooltip->"Inactive[Grad]"], "[", 
         RowBox[{
          RowBox[{"u", "[", "r", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "}"}], ",", 
          "\"\<Spherical\>\""}], "]"}]}]}]}]}], ";"}], "\n", 
   RowBox[{"lhs", "=", 
    RowBox[{
     TemplateBox[{"Div"},
      "InactiveHead",
      BaseStyle->"Inactive",
      SyntaxForm->"Symbol",
      Tooltip->"Inactive[Div]"], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Kp", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "Kp", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "Kp"}], "}"}]}], "}"}], ".", 
       RowBox[{
        TemplateBox[{"Grad"},
         "InactiveHead",
         BaseStyle->"Inactive",
         SyntaxForm->"Symbol",
         Tooltip->"Inactive[Grad]"], "[", 
        RowBox[{
         RowBox[{"u", "[", "r", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "}"}], ",", 
         "\"\<Spherical\>\""}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "}"}], ",", 
      "\"\<Spherical\>\""}], "]"}]}], "\n", 
   RowBox[{"rhs", "=", 
    RowBox[{"PDF", "[", 
     RowBox[{
      RowBox[{"NormalDistribution", "[", 
       RowBox[{"0", ",", 
        FractionBox["1", "2"]}], "]"}], ",", "r"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.900149584978259*^9, 3.900149628871483*^9}, {
  3.90137000123225*^9, 3.901370022848062*^9}, {3.901371157836429*^9, 
  3.901371179653832*^9}, {3.901374599619276*^9, 3.901374601445437*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"f597ab79-b850-4665-b18d-132fe3bf4a51"],

Cell[BoxData[
 RowBox[{
  TemplateBox[{"Div"},
   "InactiveHead",
   BaseStyle->"Inactive",
   SyntaxForm->"Symbol",
   Tooltip->"Inactive[Div]"], "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "+", 
         RowBox[{"\[Delta]", " ", 
          RowBox[{
           RowBox[{
            TemplateBox[{"Grad"},
             "InactiveHead",
             BaseStyle->"Inactive",
             SyntaxForm->"Symbol",
             Tooltip->"Inactive[Grad]"], "[", 
            RowBox[{
             RowBox[{"u", "[", "r", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "}"}], 
             ",", "\<\"Spherical\"\>"}], "]"}], ".", 
           RowBox[{
            TemplateBox[{"Grad"},
             "InactiveHead",
             BaseStyle->"Inactive",
             SyntaxForm->"Symbol",
             Tooltip->"Inactive[Grad]"], "[", 
            RowBox[{
             RowBox[{"u", "[", "r", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "}"}], 
             ",", "\<\"Spherical\"\>"}], "]"}]}]}]}], ",", "0", ",", "0"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"1", "+", 
         RowBox[{"\[Delta]", " ", 
          RowBox[{
           RowBox[{
            TemplateBox[{"Grad"},
             "InactiveHead",
             BaseStyle->"Inactive",
             SyntaxForm->"Symbol",
             Tooltip->"Inactive[Grad]"], "[", 
            RowBox[{
             RowBox[{"u", "[", "r", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "}"}], 
             ",", "\<\"Spherical\"\>"}], "]"}], ".", 
           RowBox[{
            TemplateBox[{"Grad"},
             "InactiveHead",
             BaseStyle->"Inactive",
             SyntaxForm->"Symbol",
             Tooltip->"Inactive[Grad]"], "[", 
            RowBox[{
             RowBox[{"u", "[", "r", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "}"}], 
             ",", "\<\"Spherical\"\>"}], "]"}]}]}]}], ",", "0"}], "}"}], ",", 
      
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"1", "+", 
         RowBox[{"\[Delta]", " ", 
          RowBox[{
           RowBox[{
            TemplateBox[{"Grad"},
             "InactiveHead",
             BaseStyle->"Inactive",
             SyntaxForm->"Symbol",
             Tooltip->"Inactive[Grad]"], "[", 
            RowBox[{
             RowBox[{"u", "[", "r", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "}"}], 
             ",", "\<\"Spherical\"\>"}], "]"}], ".", 
           RowBox[{
            TemplateBox[{"Grad"},
             "InactiveHead",
             BaseStyle->"Inactive",
             SyntaxForm->"Symbol",
             Tooltip->"Inactive[Grad]"], "[", 
            RowBox[{
             RowBox[{"u", "[", "r", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "}"}], 
             ",", "\<\"Spherical\"\>"}], "]"}]}]}]}]}], "}"}]}], "}"}], ".", 
    RowBox[{
     TemplateBox[{"Grad"},
      "InactiveHead",
      BaseStyle->"Inactive",
      SyntaxForm->"Symbol",
      Tooltip->"Inactive[Grad]"], "[", 
     RowBox[{
      RowBox[{"u", "[", "r", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "}"}], 
      ",", "\<\"Spherical\"\>"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "}"}], 
   ",", "\<\"Spherical\"\>"}], "]"}]], "Output",
 CellChangeTimes->{3.900239447278154*^9, 3.9013752497190332`*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"48445fc3-0926-4091-87a3-749bf81f00f4"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["r", "2"]}]], " ", 
  SqrtBox[
   FractionBox["2", "\[Pi]"]]}]], "Output",
 CellChangeTimes->{3.900239447278154*^9, 3.901375249738943*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"e6560ffa-513b-4cdc-8002-acad693c8f7b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Al", "=", 
  RowBox[{"Activate", "[", "lhs", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{"\[Delta]", "\[Rule]", "0", " ", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "we", " ", "consider", " ", "just", " ", "a", " ", "linear", " ", 
      "case"}], ",", " ", 
     RowBox[{
      RowBox[{"see", " ", "LeVeque", " ", "for", " ", "the", " ", "non"}], 
      "-", "linear"}]}], " ", "*)"}]}]}]}], "Input",
 CellChangeTimes->{{3.900149568925824*^9, 3.900149577637331*^9}, 
   3.9001496370717907`*^9, {3.901373505547735*^9, 3.901373523959161*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"042740d1-8b9a-42b5-92a9-5eca6b9dc09f"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{
     SuperscriptBox["u", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"\[Delta]", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["u", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}]}], "r"], 
  "+", 
  RowBox[{"2", " ", "\[Delta]", " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["u", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["u", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"\[Delta]", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["u", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["u", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}]}]], "Output",
 CellChangeTimes->{3.9001496381439734`*^9, 3.900185052925969*^9, 
  3.900230592929389*^9, 3.9002394502707767`*^9, 3.901375250158819*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"fe6a9c61-4358-4097-ad02-74b7d4db9310"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{
     SuperscriptBox["u", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], "r"], "+", 
  RowBox[{
   SuperscriptBox["u", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "r", "]"}]}]], "Output",
 CellChangeTimes->{3.9001496381439734`*^9, 3.900185052925969*^9, 
  3.900230592929389*^9, 3.9002394502707767`*^9, 3.901375250163999*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"b4022646-f43c-4494-9571-8f7cb0c0ce12"]
}, Open  ]],

Cell[TextData[StyleBox["We are checking here whether we are consistent with \
the second - order scheme . You can skip this part.", "Text"]], "Text",
 CellChangeTimes->{
  3.900149761045475*^9, {3.901371191020801*^9, 3.901371209241992*^9}, {
   3.90137462539124*^9, 3.9013746271324987`*^9}, {3.9013746799361963`*^9, 
   3.901374713243936*^9}, {3.901374759549282*^9, 3.901374768201415*^9}},
 FormatType->
  "TextForm",ExpressionUUID->"ae40a229-b28b-43d3-814a-f7281a7d7af7"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"D1", ",", "D2"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"D1", "=", 
  FractionBox[
   RowBox[{
    RowBox[{"u", "[", 
     RowBox[{"r", "+", "dr"}], "]"}], "-", 
    RowBox[{"u", "[", 
     RowBox[{"r", "-", "dr"}], "]"}]}], 
   RowBox[{"2", " ", "dr"}]]}], "\[IndentingNewLine]", 
 RowBox[{"D2", "=", 
  FractionBox[
   RowBox[{
    RowBox[{"u", "[", 
     RowBox[{"r", "+", "dr"}], "]"}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"u", "[", "r", "]"}]}], "+", 
    RowBox[{"u", "[", 
     RowBox[{"r", "-", "dr"}], "]"}]}], 
   SuperscriptBox["dr", "2"]]}]}], "Input",
 CellChangeTimes->{{3.900149711080125*^9, 3.900149763195767*^9}, {
  3.900149903718858*^9, 3.9001499207296886`*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"f5a54782-928a-4e3c-ac4d-ab656cc688b0"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"u", "[", 
     RowBox[{
      RowBox[{"-", "dr"}], "+", "r"}], "]"}]}], "+", 
   RowBox[{"u", "[", 
    RowBox[{"dr", "+", "r"}], "]"}]}], 
  RowBox[{"2", " ", "dr"}]]], "Output",
 CellChangeTimes->{
  3.900149763836722*^9, {3.9001499086343184`*^9, 3.900149921171793*^9}, 
   3.900230594064062*^9, 3.900239483851078*^9, 3.901375255720961*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"44bdd760-916f-43ee-aec1-5b5c5725926f"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"u", "[", "r", "]"}]}], "+", 
   RowBox[{"u", "[", 
    RowBox[{
     RowBox[{"-", "dr"}], "+", "r"}], "]"}], "+", 
   RowBox[{"u", "[", 
    RowBox[{"dr", "+", "r"}], "]"}]}], 
  SuperscriptBox["dr", "2"]]], "Output",
 CellChangeTimes->{
  3.900149763836722*^9, {3.9001499086343184`*^9, 3.900149921171793*^9}, 
   3.900230594064062*^9, 3.900239483851078*^9, 3.901375255728855*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"edc5a785-e0f6-4a71-a62c-f031c97c3dc7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", "u", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u", "[", "r_", "]"}], "=", 
  RowBox[{"Normal", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"U", "[", "r", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "0", ",", "6"}], "}"}]}], "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.900149817172452*^9, 3.900149829286965*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"b8ed5947-c6d5-42a6-a879-98cd8e2a0181"],

Cell[BoxData[
 RowBox[{
  RowBox[{"U", "[", "0", "]"}], "+", 
  RowBox[{"r", " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "0", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["r", "2"], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "0", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox["r", "3"], " ", 
   RowBox[{
    SuperscriptBox["U", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "0", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "24"], " ", 
   SuperscriptBox["r", "4"], " ", 
   RowBox[{
    SuperscriptBox["U", 
     TagBox[
      RowBox[{"(", "4", ")"}],
      Derivative],
     MultilineFunction->None], "[", "0", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "120"], " ", 
   SuperscriptBox["r", "5"], " ", 
   RowBox[{
    SuperscriptBox["U", 
     TagBox[
      RowBox[{"(", "5", ")"}],
      Derivative],
     MultilineFunction->None], "[", "0", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "720"], " ", 
   SuperscriptBox["r", "6"], " ", 
   RowBox[{
    SuperscriptBox["U", 
     TagBox[
      RowBox[{"(", "6", ")"}],
      Derivative],
     MultilineFunction->None], "[", "0", "]"}]}]}]], "Output",
 CellChangeTimes->{3.900149829704279*^9, 3.900149925452623*^9, 
  3.900230596871356*^9, 3.900239496160956*^9, 3.901375257353771*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"b9933aad-609d-455c-ae60-17cc3793a965"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"D1s", "=", 
  RowBox[{
   RowBox[{"D1", "/.", 
    RowBox[{"r", "->", "0"}]}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"D2s", "=", 
  RowBox[{
   RowBox[{"D2", "/.", 
    RowBox[{"r", "->", "0"}]}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", "u", "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.9001498399677477`*^9, 3.9001498772607317`*^9}, {
   3.90014993789865*^9, 3.90014995227236*^9}, 3.9013711887710867`*^9},
 CellLabel->"In[12]:=",ExpressionUUID->"e56a042b-ad6b-44d3-8bac-d69d5a09123d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["U", "\[Prime]",
    MultilineFunction->None], "[", "0", "]"}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox["dr", "2"], " ", 
   RowBox[{
    SuperscriptBox["U", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "0", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "120"], " ", 
   SuperscriptBox["dr", "4"], " ", 
   RowBox[{
    SuperscriptBox["U", 
     TagBox[
      RowBox[{"(", "5", ")"}],
      Derivative],
     MultilineFunction->None], "[", "0", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.900149864325177*^9, 3.900149926290316*^9}, 
   3.90023059760114*^9, 3.900239498550909*^9, 3.901375258944065*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"79d37b7e-faf7-49d4-aac2-1f7675b197d5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["U", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "0", "]"}], "+", 
  RowBox[{
   FractionBox["1", "360"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"30", " ", 
      SuperscriptBox["dr", "2"], " ", 
      RowBox[{
       SuperscriptBox["U", 
        TagBox[
         RowBox[{"(", "4", ")"}],
         Derivative],
        MultilineFunction->None], "[", "0", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["dr", "4"], " ", 
      RowBox[{
       SuperscriptBox["U", 
        TagBox[
         RowBox[{"(", "6", ")"}],
         Derivative],
        MultilineFunction->None], "[", "0", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.900149864325177*^9, 3.900149926290316*^9}, 
   3.90023059760114*^9, 3.900239498550909*^9, 3.901375258949361*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"06673a48-4233-4370-ab1d-23868ab5763e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Al", "/.", 
    RowBox[{"\[Delta]", " ", "\[Rule]", "0"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"u", "[", "r", "]"}], ",", "r"}], "]"}], " ", "\[Rule]", 
      RowBox[{
       SuperscriptBox["U", 
        TagBox[
         RowBox[{"(", "1", ")"}],
         Derivative],
        MultilineFunction->None], "[", "0", "]"}]}], ",", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"u", "[", "r", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "2"}], "}"}]}], "]"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["U", 
        TagBox[
         RowBox[{"(", "2", ")"}],
         Derivative],
        MultilineFunction->None], "[", "0", "]"}]}]}], "}"}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"%", "==", "0"}], ",", 
   RowBox[{
    SuperscriptBox["U", 
     TagBox[
      RowBox[{"(", "2", ")"}],
      Derivative],
     MultilineFunction->None], "[", "0", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"odedef", "=", 
  RowBox[{
   RowBox[{"%", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.900149987304262*^9, 3.900150087242012*^9}, {
  3.9001512977616167`*^9, 3.900151301271696*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"7bd16797-090f-4bef-801c-3996f879bf85"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{
     SuperscriptBox["U", "\[Prime]",
      MultilineFunction->None], "[", "0", "]"}]}], "r"], "+", 
  RowBox[{
   SuperscriptBox["U", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "0", "]"}]}]], "Output",
 CellChangeTimes->{3.9001500876486187`*^9, 3.9001513034950867`*^9, 
  3.9002305989895573`*^9, 3.900239520615749*^9, 3.901375260882655*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"856407f5-bf24-4815-812f-53726f897763"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["U", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "0", "]"}]}], "r"]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.9001500876486187`*^9, 3.9001513034950867`*^9, 
  3.9002305989895573`*^9, 3.900239520615749*^9, 3.9013752608873377`*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"64735372-5137-488e-9caf-19f1d00738ec"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["U", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["U", "\[Prime]",
       MultilineFunction->None], "[", "0", "]"}]}], "r"]}]}]], "Output",
 CellChangeTimes->{3.9001500876486187`*^9, 3.9001513034950867`*^9, 
  3.9002305989895573`*^9, 3.900239520615749*^9, 3.901375260892488*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"952e0124-73f2-498c-980c-d92c08009640"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Al", "/.", 
       RowBox[{"\[Delta]", " ", "\[Rule]", "0"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"u", "[", "r", "]"}], ",", "r"}], "]"}], " ", "\[Rule]", 
         "D1s"}], ",", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"u", "[", "r", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "2"}], "}"}]}], "]"}], "\[Rule]", "D2s"}]}], 
       "}"}]}], "/.", "odedef"}], "/.", 
    RowBox[{"{", 
     RowBox[{"dr", "->", "h"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Collect", "[", 
  RowBox[{"%", ",", 
   SuperscriptBox["h", "2"]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"%", ",", "h", ",", "0"}], "]"}], "]"}], ",", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"%", ",", "h", ",", "1"}], "]"}], "]"}], ",", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"%", ",", "h", ",", "2"}], "]"}], "]"}]}], "}"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"First", " ", "non"}], "-", 
    RowBox[{"trivial", " ", "term", " ", "starts", " ", 
     RowBox[{"w", ".", " ", 
      RowBox[{"h", "^", "2"}]}], " ", "as", " ", "it", " ", "should"}]}], 
   "*)"}]}]}], "Input",
 CellChangeTimes->{{3.900149987304262*^9, 3.900150077575098*^9}, {
  3.9001513117309103`*^9, 3.900151333740493*^9}, {3.9001513642901077`*^9, 
  3.9001513836211*^9}, {3.901374640736898*^9, 3.9013746640164547`*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"0f4831b0-d16d-4677-a7fb-a4e47d94ec41"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["h", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "0", "]"}]}], "+", 
      RowBox[{"r", " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "4", ")"}],
          Derivative],
         MultilineFunction->None], "[", "0", "]"}]}]}], ")"}]}], 
   RowBox[{"12", " ", "r"}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["h", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "5", ")"}],
          Derivative],
         MultilineFunction->None], "[", "0", "]"}]}], "+", 
      RowBox[{"r", " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "6", ")"}],
          Derivative],
         MultilineFunction->None], "[", "0", "]"}]}]}], ")"}]}], 
   RowBox[{"360", " ", "r"}]]}]], "Output",
 CellChangeTimes->{{3.9001500083613997`*^9, 3.900150032267786*^9}, {
   3.900151320745575*^9, 3.900151334301011*^9}, {3.900151377247756*^9, 
   3.9001513842605677`*^9}, 3.900230601052836*^9, 3.900239563424754*^9, 
   3.901375263126009*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"ba4d292a-ae54-47ba-8c4c-e2cdbc86c6f6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    FractionBox["1", "12"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{
         SuperscriptBox["U", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "0", "]"}]}], "r"], "+", 
      RowBox[{
       SuperscriptBox["U", 
        TagBox[
         RowBox[{"(", "4", ")"}],
         Derivative],
        MultilineFunction->None], "[", "0", "]"}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.9001500083613997`*^9, 3.900150032267786*^9}, {
   3.900151320745575*^9, 3.900151334301011*^9}, {3.900151377247756*^9, 
   3.9001513842605677`*^9}, 3.900230601052836*^9, 3.900239563424754*^9, 
   3.901375263130477*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"4fb42ad7-0196-4d66-b101-8644ba207774"]
}, Open  ]],

Cell["Code", "Text",
 CellChangeTimes->{{3.900152793534724*^9, 3.900152868354184*^9}, {
  3.900177768822998*^9, 3.900177775300619*^9}, {3.901373125895042*^9, 
  3.901373146673709*^9}, {3.9013747759722433`*^9, 3.901374799222927*^9}},
 FormatType->
  "TextForm",ExpressionUUID->"bfe5eb1f-5652-4b3e-a2ce-4f1da09d6f12"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"discretize", " ", "for", " ", "integrator"}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"D1", ",", "D2"}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"D1", "=", 
    FractionBox[
     RowBox[{
      RowBox[{"U", "[", 
       RowBox[{"i", "+", "1"}], "]"}], "-", 
      RowBox[{"U", "[", 
       RowBox[{"i", "-", "1"}], "]"}]}], 
     RowBox[{"2", " ", "h"}]]}], "\[IndentingNewLine]", 
   RowBox[{"D2", "=", 
    FractionBox[
     RowBox[{
      RowBox[{"U", "[", 
       RowBox[{"i", "+", "1"}], "]"}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"U", "[", "i", "]"}]}], "+", 
      RowBox[{"U", "[", 
       RowBox[{"i", "-", "1"}], "]"}]}], 
     SuperscriptBox["h", "2"]]}]}]}]], "Input",
 CellChangeTimes->{{3.900152793534724*^9, 3.900152868354184*^9}, {
  3.900177768822998*^9, 3.900177775300619*^9}, {3.901373125895042*^9, 
  3.901373146673709*^9}, {3.9013747759722433`*^9, 3.901374779104397*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"359e39eb-1392-4ba6-ba48-a95e03fad35b"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"U", "[", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
   RowBox[{"U", "[", 
    RowBox[{"1", "+", "i"}], "]"}]}], 
  RowBox[{"2", " ", "h"}]]], "Output",
 CellChangeTimes->{3.9001528690567007`*^9, 3.900177869450327*^9, 
  3.900185060935272*^9, 3.900230602631997*^9, 3.900239589089362*^9, 
  3.901375268802841*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"71ead9ca-6c31-4e84-aed3-16cfe63f0e16"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"U", "[", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
   RowBox[{"2", " ", 
    RowBox[{"U", "[", "i", "]"}]}], "+", 
   RowBox[{"U", "[", 
    RowBox[{"1", "+", "i"}], "]"}]}], 
  SuperscriptBox["h", "2"]]], "Output",
 CellChangeTimes->{3.9001528690567007`*^9, 3.900177869450327*^9, 
  3.900185060935272*^9, 3.900230602631997*^9, 3.900239589089362*^9, 
  3.901375268811222*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"d41cd197-b749-4282-9268-9f66dd94fc9a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Al"], "Input",
 CellChangeTimes->{{3.900152793534724*^9, 3.900152876745523*^9}, {
  3.900152947337944*^9, 3.900152958539506*^9}, {3.900152999471055*^9, 
  3.900153023244876*^9}, {3.900153161338313*^9, 3.900153247518938*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"41204a16-40f1-4baa-ac98-a19831718f93"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{
     SuperscriptBox["u", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"\[Delta]", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["u", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}]}], "r"], 
  "+", 
  RowBox[{"2", " ", "\[Delta]", " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["u", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["u", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"\[Delta]", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["u", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["u", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}]}]], "Output",
 CellChangeTimes->{3.900153249184499*^9, 3.901375271461905*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"9a3cbe18-0852-4948-bc22-aa54c6993007"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"regularize", " ", "using", " ", 
    RowBox[{"L", "'"}], "Hopital"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"\[Delta]", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["u", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}]}], ",",
      "r"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Alsing", "=", 
    RowBox[{"%", "+", 
     RowBox[{"2", " ", "\[Delta]", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["u", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["u", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"\[Delta]", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["u", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["u", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.900152793534724*^9, 3.900152876745523*^9}, {
  3.900152947337944*^9, 3.900152958539506*^9}, {3.900152999471055*^9, 
  3.900153023244876*^9}, {3.900153161338313*^9, 3.900153247518938*^9}, {
  3.901375280990049*^9, 
  3.901375283327265*^9}},ExpressionUUID->"d478b7e0-802e-42ab-b195-\
7eeffcc4fdb9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"4", " ", "\[Delta]", " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["u", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["u", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"\[Delta]", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["u", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["u", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.900153016629962*^9, 3.900153023610648*^9}, {
   3.900153161795504*^9, 3.9001532503648653`*^9}, 3.900185066496472*^9, 
   3.900230604538044*^9, 3.900239637738007*^9, 3.901375274430518*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"f1c35505-b7d2-4d7d-9200-a07cf79ebad0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"6", " ", "\[Delta]", " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["u", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["u", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"\[Delta]", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["u", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["u", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.900153016629962*^9, 3.900153023610648*^9}, {
   3.900153161795504*^9, 3.9001532503648653`*^9}, 3.900185066496472*^9, 
   3.900230604538044*^9, 3.900239637738007*^9, 3.90137527443375*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"973927cf-a870-42f5-bff5-36f9f33afa6b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"odseing", " ", "is", " ", "for", " ", "i"}], "=", "0"}], ",", 
    " ", 
    RowBox[{
     RowBox[{"ode", " ", "for", " ", "i"}], ">", "0"}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"ode", ",", "odesing", ",", "r"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"ode", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Al", "/.", 
        RowBox[{"\[Delta]", " ", "\[Rule]", "0"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"u", "[", "r", "]"}], ",", "r"}], "]"}], " ", "\[Rule]", 
          "D1"}], ",", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"u", "[", "r", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"r", ",", "2"}], "}"}]}], "]"}], "\[Rule]", "D2"}]}], 
        "}"}]}], "/.", 
      RowBox[{"dr", "->", "h"}]}], "/.", 
     RowBox[{"r", "->", 
      RowBox[{"i", "*", "h"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{"odesing", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Alsing", "/.", 
        RowBox[{"\[Delta]", " ", "\[Rule]", "0"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"u", "[", "r", "]"}], ",", "r"}], "]"}], " ", "\[Rule]", 
          "D1"}], ",", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"u", "[", "r", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"r", ",", "2"}], "}"}]}], "]"}], "\[Rule]", "D2"}]}], 
        "}"}]}], "/.", 
      RowBox[{"dr", "->", "h"}]}], "/.", 
     RowBox[{"r", "->", 
      RowBox[{"i", "*", "h"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r", "[", "i_", "]"}], ":=", 
    RowBox[{"i", "*", "h"}]}]}]}]], "Input",
 CellChangeTimes->{{3.900152793534724*^9, 3.900152876745523*^9}, {
   3.900152947337944*^9, 3.900152958539506*^9}, {3.900152999471055*^9, 
   3.900153014546673*^9}, 3.900153255604561*^9, {3.900153348916534*^9, 
   3.900153354141836*^9}, {3.900177905223042*^9, 3.900177923058137*^9}, {
   3.90137326294277*^9, 3.90137327393146*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"7e44fe6a-f8ba-4e10-877f-2b0ef075c311"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"-", 
     RowBox[{"U", "[", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "i"}], "]"}]}], "+", 
    RowBox[{"U", "[", 
     RowBox[{"1", "+", "i"}], "]"}]}], 
   RowBox[{
    SuperscriptBox["h", "2"], " ", "i"}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"U", "[", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"U", "[", "i", "]"}]}], "+", 
    RowBox[{"U", "[", 
     RowBox[{"1", "+", "i"}], "]"}]}], 
   SuperscriptBox["h", "2"]]}]], "Output",
 CellChangeTimes->{{3.9001527715482388`*^9, 3.9001528317527246`*^9}, 
   3.900152877829894*^9, {3.900152948978005*^9, 3.9001529591260643`*^9}, {
   3.90015300140338*^9, 3.900153011340951*^9}, {3.900153340386385*^9, 
   3.900153354660358*^9}, 3.9001778739862623`*^9, 3.9001779239113903`*^9, 
   3.900185071960094*^9, 3.900230605613727*^9, 3.90023964004599*^9, 
   3.901375293477227*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"3e24d35f-a05a-42fb-8a11-98f2aed64ea2"],

Cell[BoxData[
 FractionBox[
  RowBox[{"3", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"U", "[", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "i"}], "]"}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"U", "[", "i", "]"}]}], "+", 
     RowBox[{"U", "[", 
      RowBox[{"1", "+", "i"}], "]"}]}], ")"}]}], 
  SuperscriptBox["h", "2"]]], "Output",
 CellChangeTimes->{{3.9001527715482388`*^9, 3.9001528317527246`*^9}, 
   3.900152877829894*^9, {3.900152948978005*^9, 3.9001529591260643`*^9}, {
   3.90015300140338*^9, 3.900153011340951*^9}, {3.900153340386385*^9, 
   3.900153354660358*^9}, 3.9001778739862623`*^9, 3.9001779239113903`*^9, 
   3.900185071960094*^9, 3.900230605613727*^9, 3.90023964004599*^9, 
   3.901375293480483*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"85f3e8b1-d7d4-4448-8ec9-6b6670502cb6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "parameters", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"m", ",", "n"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"afin", "=", "4"}], "\[IndentingNewLine]", 
   RowBox[{"Mv", "=", "1"}], "\[IndentingNewLine]", 
   RowBox[{"\[Sigma]v", "=", 
    RowBox[{"afin", "/", "20"}]}]}]}]], "Input",
 CellChangeTimes->{{3.900152895425816*^9, 3.900152910887936*^9}, {
   3.900153361402034*^9, 3.900153377348687*^9}, {3.900177745320692*^9, 
   3.900177748087084*^9}, {3.900177883573493*^9, 3.9001778868135357`*^9}, {
   3.900177980090839*^9, 3.900178013378158*^9}, 3.9001824651323843`*^9, {
   3.900182768985468*^9, 3.9001827835213614`*^9}, {3.9001829642348013`*^9, 
   3.9001830102444477`*^9}, {3.900183088341742*^9, 3.900183104817584*^9}, {
   3.9001831358231087`*^9, 3.900183140287343*^9}, 3.900183173040492*^9, 
   3.900183217276322*^9, {3.900183535104847*^9, 3.900183549198915*^9}, {
   3.900184250212237*^9, 3.9001842563563004`*^9}, {3.9001850825943937`*^9, 
   3.900185112976268*^9}, {3.900231332418886*^9, 3.900231413244527*^9}, {
   3.900232442860035*^9, 3.90023244344599*^9}, {3.9002325932993*^9, 
   3.9002325955547037`*^9}, {3.901373293211804*^9, 3.901373299059436*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"b6cb5134-c5e4-41f8-add7-547e217fa511"],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{{3.9001829909066668`*^9, 3.9001830119493628`*^9}, {
   3.900183093670738*^9, 3.90018310667166*^9}, 3.900183140774661*^9, 
   3.900183173916904*^9, 3.9001832178480988`*^9, {3.900183535557996*^9, 
   3.9001835499137297`*^9}, 3.9001842569564857`*^9, {3.900185086346909*^9, 
   3.9001851134358797`*^9}, 3.900230609696559*^9, {3.9002313484168253`*^9, 
   3.9002314170281477`*^9}, 3.900232443971365*^9, 3.900232601181943*^9, 
   3.900239705267741*^9, 3.9013752965687532`*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"313703d5-ec90-4a3a-b40a-0259dd49c6da"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.9001829909066668`*^9, 3.9001830119493628`*^9}, {
   3.900183093670738*^9, 3.90018310667166*^9}, 3.900183140774661*^9, 
   3.900183173916904*^9, 3.9001832178480988`*^9, {3.900183535557996*^9, 
   3.9001835499137297`*^9}, 3.9001842569564857`*^9, {3.900185086346909*^9, 
   3.9001851134358797`*^9}, 3.900230609696559*^9, {3.9002313484168253`*^9, 
   3.9002314170281477`*^9}, 3.900232443971365*^9, 3.900232601181943*^9, 
   3.900239705267741*^9, 3.9013752965736723`*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"66b5542c-e719-4692-833f-f73ee67c0044"],

Cell[BoxData[
 FractionBox["1", "5"]], "Output",
 CellChangeTimes->{{3.9001829909066668`*^9, 3.9001830119493628`*^9}, {
   3.900183093670738*^9, 3.90018310667166*^9}, 3.900183140774661*^9, 
   3.900183173916904*^9, 3.9001832178480988`*^9, {3.900183535557996*^9, 
   3.9001835499137297`*^9}, 3.9001842569564857`*^9, {3.900185086346909*^9, 
   3.9001851134358797`*^9}, 3.900230609696559*^9, {3.9002313484168253`*^9, 
   3.9002314170281477`*^9}, 3.900232443971365*^9, 3.900232601181943*^9, 
   3.900239705267741*^9, 3.901375296579438*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"038ccc12-9ad5-43a6-8b88-bf115811a0dd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"skip", " ", "-", " ", 
    RowBox[{
    "just", " ", "an", " ", "example", " ", "to", " ", "see", " ", "the", " ",
      "form", " ", "of", " ", "the", " ", "system"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"SysEq", ",", "varsu"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"n", "=", "5"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SysEq", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"AppendTo", "[", 
      RowBox[{"SysEq", ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"i", "===", "0"}], ",", 
         RowBox[{"odesing", "-", 
          RowBox[{"4", "*", "Pi", "*", "M", 
           FractionBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"-", 
              FractionBox[
               SuperscriptBox[
                RowBox[{"r", "[", "i", "]"}], "2"], 
               RowBox[{"2", " ", 
                SuperscriptBox["\[Sigma]", "2"]}]]}]], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Sigma]", " ", 
               SqrtBox[
                RowBox[{"2", " ", "\[Pi]"}]]}], ")"}], "^", "3"}]]}]}], ",", 
         RowBox[{"ode", "-", 
          RowBox[{"4", "*", "Pi", "*", "M", 
           FractionBox[
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"-", 
              FractionBox[
               SuperscriptBox[
                RowBox[{"r", "[", "i", "]"}], "2"], 
               RowBox[{"2", " ", 
                SuperscriptBox["\[Sigma]", "2"]}]]}]], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Sigma]", " ", 
               SqrtBox[
                RowBox[{"2", " ", "\[Pi]"}]]}], ")"}], "^", "3"}]]}]}]}], 
        "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "n"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.900152895425816*^9, 3.900152910887936*^9}, {
   3.900153361402034*^9, 3.900153377348687*^9}, {3.900177745320692*^9, 
   3.900177748087084*^9}, {3.900177883573493*^9, 3.9001778868135357`*^9}, {
   3.900177980090839*^9, 3.900178013378158*^9}, 3.9001824651323843`*^9, {
   3.900182768985468*^9, 3.9001827835213614`*^9}, {3.9001829642348013`*^9, 
   3.9001829968468924`*^9}, 3.90018314261628*^9, {3.900230617702031*^9, 
   3.90023062310534*^9}, {3.900239721855567*^9, 3.90023972568801*^9}, {
   3.901373303748519*^9, 3.901373327073142*^9}, 
   3.901375313618352*^9},ExpressionUUID->"1ef26d31-0151-408e-9451-\
760affdf6cc1"],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{3.900239727764242*^9, 3.901375302768989*^9},
 CellLabel->"Out[36]=",ExpressionUUID->"03e5d08f-b53a-4a3a-9d41-e48e81af6aea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "skip", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"SysEq", "//", "MatrixForm"}], "\[IndentingNewLine]", 
   RowBox[{"varsu", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"U", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "n"}], "}"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.900153385181307*^9, 3.900153404037286*^9}, {
   3.900181206117731*^9, 3.900181225373584*^9}, {3.900182470837923*^9, 
   3.900182472777875*^9}, {3.900230626548464*^9, 3.900230627079615*^9}, 
   3.9002397198001842`*^9},
 CellLabel->"In[39]:=",ExpressionUUID->"71f7de12-4150-4bbc-a5b6-927c14831f20"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"M", " ", 
           SqrtBox[
            FractionBox["2", "\[Pi]"]]}], 
          SuperscriptBox["\[Sigma]", "3"]]}], "+", 
        FractionBox[
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"U", "[", 
             RowBox[{"-", "1"}], "]"}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"U", "[", "0", "]"}]}], "+", 
            RowBox[{"U", "[", "1", "]"}]}], ")"}]}], 
         SuperscriptBox["h", "2"]]}]},
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox["h", "2"], 
              RowBox[{"2", " ", 
               SuperscriptBox["\[Sigma]", "2"]}]]}]], " ", "M", " ", 
           SqrtBox[
            FractionBox["2", "\[Pi]"]]}], 
          SuperscriptBox["\[Sigma]", "3"]]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           RowBox[{"U", "[", "0", "]"}]}], "+", 
          RowBox[{"U", "[", "2", "]"}]}], 
         SuperscriptBox["h", "2"]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"U", "[", "0", "]"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"U", "[", "1", "]"}]}], "+", 
          RowBox[{"U", "[", "2", "]"}]}], 
         SuperscriptBox["h", "2"]]}]},
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", 
             FractionBox[
              RowBox[{"2", " ", 
               SuperscriptBox["h", "2"]}], 
              SuperscriptBox["\[Sigma]", "2"]]}]], " ", "M", " ", 
           SqrtBox[
            FractionBox["2", "\[Pi]"]]}], 
          SuperscriptBox["\[Sigma]", "3"]]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           RowBox[{"U", "[", "1", "]"}]}], "+", 
          RowBox[{"U", "[", "3", "]"}]}], 
         RowBox[{"2", " ", 
          SuperscriptBox["h", "2"]}]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"U", "[", "1", "]"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"U", "[", "2", "]"}]}], "+", 
          RowBox[{"U", "[", "3", "]"}]}], 
         SuperscriptBox["h", "2"]]}]},
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", 
             FractionBox[
              RowBox[{"9", " ", 
               SuperscriptBox["h", "2"]}], 
              RowBox[{"2", " ", 
               SuperscriptBox["\[Sigma]", "2"]}]]}]], " ", "M", " ", 
           SqrtBox[
            FractionBox["2", "\[Pi]"]]}], 
          SuperscriptBox["\[Sigma]", "3"]]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           RowBox[{"U", "[", "2", "]"}]}], "+", 
          RowBox[{"U", "[", "4", "]"}]}], 
         RowBox[{"3", " ", 
          SuperscriptBox["h", "2"]}]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"U", "[", "2", "]"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"U", "[", "3", "]"}]}], "+", 
          RowBox[{"U", "[", "4", "]"}]}], 
         SuperscriptBox["h", "2"]]}]},
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", 
             FractionBox[
              RowBox[{"8", " ", 
               SuperscriptBox["h", "2"]}], 
              SuperscriptBox["\[Sigma]", "2"]]}]], " ", "M", " ", 
           SqrtBox[
            FractionBox["2", "\[Pi]"]]}], 
          SuperscriptBox["\[Sigma]", "3"]]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           RowBox[{"U", "[", "3", "]"}]}], "+", 
          RowBox[{"U", "[", "5", "]"}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["h", "2"]}]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"U", "[", "3", "]"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"U", "[", "4", "]"}]}], "+", 
          RowBox[{"U", "[", "5", "]"}]}], 
         SuperscriptBox["h", "2"]]}]},
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", 
             FractionBox[
              RowBox[{"25", " ", 
               SuperscriptBox["h", "2"]}], 
              RowBox[{"2", " ", 
               SuperscriptBox["\[Sigma]", "2"]}]]}]], " ", "M", " ", 
           SqrtBox[
            FractionBox["2", "\[Pi]"]]}], 
          SuperscriptBox["\[Sigma]", "3"]]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           RowBox[{"U", "[", "4", "]"}]}], "+", 
          RowBox[{"U", "[", "6", "]"}]}], 
         RowBox[{"5", " ", 
          SuperscriptBox["h", "2"]}]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"U", "[", "4", "]"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"U", "[", "5", "]"}]}], "+", 
          RowBox[{"U", "[", "6", "]"}]}], 
         SuperscriptBox["h", "2"]]}]}
     },
     GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.900182473343025*^9, 3.90018278496847*^9, 3.900183015852529*^9, 
   3.900183144924923*^9, 3.900183176458849*^9, 3.900183220735263*^9, {
   3.900183539256962*^9, 3.9001835522410994`*^9}, 3.9002397333218184`*^9, 
   3.901375306743552*^9},
 CellLabel->
  "Out[39]//MatrixForm=",ExpressionUUID->"ede16302-0630-4750-8e1c-\
8fef4bd573d9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"U", "[", "0", "]"}], ",", 
   RowBox[{"U", "[", "1", "]"}], ",", 
   RowBox[{"U", "[", "2", "]"}], ",", 
   RowBox[{"U", "[", "3", "]"}], ",", 
   RowBox[{"U", "[", "4", "]"}], ",", 
   RowBox[{"U", "[", "5", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.900182473343025*^9, 3.90018278496847*^9, 3.900183015852529*^9, 
   3.900183144924923*^9, 3.900183176458849*^9, 3.900183220735263*^9, {
   3.900183539256962*^9, 3.9001835522410994`*^9}, 3.9002397333218184`*^9, 
   3.901375306751593*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"97785aaf-8baa-46c1-b91c-24334aee3e01"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.900179871150332*^9, 3.900179883577916*^9}, {
   3.900179939995693*^9, 3.900179999798925*^9}, 3.9001824394076157`*^9, 
   3.900182480157792*^9, {3.90018307831032*^9, 3.90018308123944*^9}, {
   3.900183111618273*^9, 3.9001831260954943`*^9}, 
   3.9001843259864264`*^9},ExpressionUUID->"e5d06b8c-6300-4160-a859-\
0eef66c85c83"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["11", "2"], ",", 
   RowBox[{"-", 
    FractionBox["2", "11"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.90017988423286*^9, {3.900179986906673*^9, 3.900180000142465*^9}, 
   3.9001824406762114`*^9, {3.900182476382526*^9, 3.900182480516883*^9}, 
   3.9001827870552597`*^9, 3.900183016877347*^9, {3.90018312653563*^9, 
   3.9001831458868093`*^9}, 3.900183177904706*^9, 3.9001832217610703`*^9, {
   3.900183540193797*^9, 3.9001835537757473`*^9}},
 CellLabel->
  "Out[360]=",ExpressionUUID->"b8621d4c-d7a8-41d8-a1fc-721682410724"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "n", ",", "SysEq", ",", "varsu", ",", "solution", ",", "soltab", ",", 
    "ntab"}], "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ntab", "=", 
    RowBox[{"{", 
     RowBox[{"10", ",", "20", ",", "30", ",", "40", ",", "80"}], "}"}]}], 
   ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"number", " ", "of", " ", "pts"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"soltab", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "solution", "]"}], ";", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "hV", ",", "nV", ",", "upval", ",", "solU", ",", "SysEq", ",", 
        "varsu"}], "}"}], ",", 
      RowBox[{
       RowBox[{"nV", "=", 
        RowBox[{"ntab", "[", 
         RowBox[{"[", "jt", "]"}], "]"}]}], ";", 
       RowBox[{"hV", "=", 
        RowBox[{"afin", "/", "nV"}]}], ";", 
       RowBox[{"SysEq", "=", 
        RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"AppendTo", "[", 
          RowBox[{"SysEq", ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"i", "===", "0"}], ",", 
             RowBox[{"odesing", "-", 
              RowBox[{"4", "*", "Pi", "*", "Mv", 
               FractionBox[
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{"-", 
                  FractionBox[
                   SuperscriptBox[
                    RowBox[{"r", "[", "i", "]"}], "2"], 
                   RowBox[{"2", " ", 
                    SuperscriptBox["\[Sigma]v", "2"]}]]}]], 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"\[Sigma]v", " ", 
                   SqrtBox[
                    RowBox[{"2", " ", "\[Pi]"}]]}], ")"}], "^", "3"}]]}]}], 
             ",", 
             RowBox[{"ode", "-", 
              RowBox[{"4", "*", "Pi", "*", "Mv", 
               FractionBox[
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{"-", 
                  FractionBox[
                   SuperscriptBox[
                    RowBox[{"r", "[", "i", "]"}], "2"], 
                   RowBox[{"2", " ", 
                    SuperscriptBox["\[Sigma]v", "2"]}]]}]], 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"\[Sigma]v", " ", 
                   SqrtBox[
                    RowBox[{"2", " ", "\[Pi]"}]]}], ")"}], "^", "3"}]]}]}]}], 
            "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", "nV"}], "}"}]}], "]"}], ";", 
       RowBox[{"varsu", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"U", "[", "i", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "nV"}], "}"}]}], "]"}]}], ";", 
       RowBox[{"upval", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"afin", "+", "hV"}], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"Mv", " "}], 
            RowBox[{"afin", "+", "hV"}]]}]}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "hV", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"solU", "=", 
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"SysEq", "==", "0"}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"U", "[", 
                RowBox[{"-", "1"}], "]"}], "->", 
               RowBox[{"U", "[", "1", "]"}]}], ",", 
              RowBox[{
               RowBox[{"U", "[", 
                RowBox[{"nV", "+", "1"}], "]"}], "->", 
               RowBox[{"upval", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"h", "->", "hV"}], ",", 
             RowBox[{"M", "->", "Mv"}], ",", 
             RowBox[{"\[Sigma]", "->", "\[Sigma]v"}]}], "}"}]}], ",", 
          "varsu"}], "]"}]}], ";", 
       RowBox[{"solution", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"r", "[", "i", "]"}], "/.", 
              RowBox[{"h", "->", "hV"}]}], ",", 
             RowBox[{"U", "[", "i", "]"}]}], "}"}], "/.", "solU"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "nV"}], "}"}]}], "]"}]}]}]}], "]"}], 
    ";", 
    RowBox[{"AppendTo", "[", 
     RowBox[{"soltab", ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"solution", ",", "1"}], "]"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"jt", ",", "1", ",", 
     RowBox[{"Length", "[", "ntab", "]"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{
  3.900181199486636*^9, 3.900181294636446*^9, {3.900181515453239*^9, 
   3.9001816193493557`*^9}, {3.900182260218853*^9, 3.900182276855341*^9}, {
   3.900182449192021*^9, 3.900182450090847*^9}, {3.900182684676261*^9, 
   3.900182766856009*^9}, {3.900183002847578*^9, 3.900183019002041*^9}, {
   3.900183161879367*^9, 3.900183198765443*^9}, {3.900183938213665*^9, 
   3.9001839663684587`*^9}, {3.900184224401553*^9, 3.900184336670652*^9}, {
   3.900184402828113*^9, 3.900184430113606*^9}, {3.9001844631278687`*^9, 
   3.90018452425249*^9}, {3.900184581989581*^9, 3.900184605523693*^9}, {
   3.900184808279533*^9, 3.900184852243635*^9}, {3.900185139234729*^9, 
   3.9001851767632027`*^9}, {3.900185250182062*^9, 3.900185264290505*^9}, {
   3.900185336069673*^9, 3.900185357695059*^9}, {3.900230669987966*^9, 
   3.900230682461701*^9}, {3.900231428750072*^9, 3.900231444691553*^9}, {
   3.900232452188567*^9, 3.900232453614613*^9}, 3.900232606708255*^9, {
   3.900232960701598*^9, 3.900232968414607*^9}, {3.900239834235969*^9, 
   3.9002398509269953`*^9}, {3.901373337276126*^9, 3.9013733532782803`*^9}, {
   3.901375319507114*^9, 3.901375332962359*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"59fba8db-d6dc-4492-b22e-b4c425400962"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox["2", "5"]], "Print",
 CellChangeTimes->{
  3.90023068337747*^9, {3.900231429643149*^9, 3.900231445475863*^9}, 
   3.900232454446954*^9, 3.900232608307366*^9, 3.900232970352991*^9, 
   3.9002399599025297`*^9, 3.901375335744933*^9},
 CellLabel->
  "During evaluation of \
In[41]:=",ExpressionUUID->"ed0a16fc-e649-43be-86dd-19829596c5c4"],

Cell[BoxData[
 FractionBox["1", "5"]], "Print",
 CellChangeTimes->{
  3.90023068337747*^9, {3.900231429643149*^9, 3.900231445475863*^9}, 
   3.900232454446954*^9, 3.900232608307366*^9, 3.900232970352991*^9, 
   3.9002399599025297`*^9, 3.901375335846266*^9},
 CellLabel->
  "During evaluation of \
In[41]:=",ExpressionUUID->"4ef69d17-4a1f-4b1c-a680-06f3f426d2ba"],

Cell[BoxData[
 FractionBox["2", "15"]], "Print",
 CellChangeTimes->{
  3.90023068337747*^9, {3.900231429643149*^9, 3.900231445475863*^9}, 
   3.900232454446954*^9, 3.900232608307366*^9, 3.900232970352991*^9, 
   3.9002399599025297`*^9, 3.9013753363451757`*^9},
 CellLabel->
  "During evaluation of \
In[41]:=",ExpressionUUID->"0b82a288-7bc5-43a2-a05b-31020cf3fbcb"],

Cell[BoxData[
 FractionBox["1", "10"]], "Print",
 CellChangeTimes->{
  3.90023068337747*^9, {3.900231429643149*^9, 3.900231445475863*^9}, 
   3.900232454446954*^9, 3.900232608307366*^9, 3.900232970352991*^9, 
   3.9002399599025297`*^9, 3.901375337686187*^9},
 CellLabel->
  "During evaluation of \
In[41]:=",ExpressionUUID->"f5a5a397-2b72-4804-b464-66c1ab7c160e"],

Cell[BoxData[
 FractionBox["1", "20"]], "Print",
 CellChangeTimes->{
  3.90023068337747*^9, {3.900231429643149*^9, 3.900231445475863*^9}, 
   3.900232454446954*^9, 3.900232608307366*^9, 3.900232970352991*^9, 
   3.9002399599025297`*^9, 3.9013753407005053`*^9},
 CellLabel->
  "During evaluation of \
In[41]:=",ExpressionUUID->"35736e0c-050c-4d50-bde5-58e737025235"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Length", "[", "soltab", "]"}], "\[IndentingNewLine]", 
 RowBox[{"N", "[", 
  RowBox[{"soltab", "[", 
   RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{
  3.900181199486636*^9, 3.900181294636446*^9, {3.900181515453239*^9, 
   3.900181627789894*^9}, {3.90018231609656*^9, 3.900182419240582*^9}, {
   3.9001826889204473`*^9, 3.900182717863311*^9}, 3.900182790719*^9, {
   3.9001839305974092`*^9, 3.900183930885297*^9}, {3.9001845346228657`*^9, 
   3.9001846303031263`*^9}, {3.900185280912643*^9, 3.90018528104852*^9}, {
   3.900185321511834*^9, 3.9001853295970173`*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"d3789a48-1c62-4be6-a623-6ab0f7c38245"],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{{3.9001845415997562`*^9, 3.90018454624286*^9}, {
   3.900184577178652*^9, 3.900184630632599*^9}, 3.900184814993258*^9, {
   3.900185277675699*^9, 3.90018528159447*^9}, {3.900185324572461*^9, 
   3.900185329951125*^9}, 3.900185371464346*^9, 3.90023064284121*^9, 
   3.900231484413993*^9, 3.9002318750342407`*^9, 3.900232718986804*^9, 
   3.900239992475254*^9, 3.901375374685495*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"7e6dd689-a6e7-4a6b-aa26-56ca1444378d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"-", "4.858956130010686`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.4`", ",", 
     RowBox[{"-", "2.199340927334467`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.8`", ",", 
     RowBox[{"-", "1.1195215970707058`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.2`", ",", 
     RowBox[{"-", "0.7560130142957218`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.6`", ",", 
     RowBox[{"-", "0.5742585406317441`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.`", ",", 
     RowBox[{"-", "0.465205856433196`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.4`", ",", 
     RowBox[{"-", "0.39250406696749723`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.8`", ",", 
     RowBox[{"-", "0.34057421734914095`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.2`", ",", 
     RowBox[{"-", "0.3016268301353737`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.6`", ",", 
     RowBox[{"-", "0.2713344178579993`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.`", ",", 
     RowBox[{"-", "0.24710048803609966`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.9001845415997562`*^9, 3.90018454624286*^9}, {
   3.900184577178652*^9, 3.900184630632599*^9}, 3.900184814993258*^9, {
   3.900185277675699*^9, 3.90018528159447*^9}, {3.900185324572461*^9, 
   3.900185329951125*^9}, 3.900185371464346*^9, 3.90023064284121*^9, 
   3.900231484413993*^9, 3.9002318750342407`*^9, 3.900232718986804*^9, 
   3.900239992475254*^9, 3.901375374703559*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"7abe05c8-2853-4a4c-a49c-060a66b2641d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "fAr", "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"interpolation", " ", "function"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"fAr", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Interpolation", "[", 
     RowBox[{
      RowBox[{"soltab", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{"InterpolationOrder", "->", "1"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "ntab", "]"}]}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{
  3.900181199486636*^9, 3.900181294636446*^9, {3.900181515453239*^9, 
   3.900181627789894*^9}, {3.90018231609656*^9, 3.900182419240582*^9}, {
   3.9001826889204473`*^9, 3.900182717863311*^9}, 3.900182790719*^9, {
   3.9001839305974092`*^9, 3.900183930885297*^9}, {3.9001845346228657`*^9, 
   3.9001845515016937`*^9}, {3.900184611244976*^9, 3.900184611862217*^9}, {
   3.900184880892869*^9, 3.9001849407303047`*^9}, {3.900185375843753*^9, 
   3.9001853761073*^9}, {3.901373360231608*^9, 3.9013733672667847`*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"b214c22e-fc3c-4bff-b343-3afdcc122801"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     TagBox["InterpolatingFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]],
                 ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                None, BaseStyle -> {}, Evaluator -> Automatic, Method -> 
                "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}]], 
              GraphicsBox[{{
                 GrayLevel[0.6], 
                 AbsolutePointSize[5], 
                 PointBox[{1, 1}], 
                 PointBox[{2, 4}], 
                 PointBox[{3, 2}], 
                 PointBox[{4, 3}]}, {{}, {}, {
                  AbsoluteThickness[1], 
                  Opacity[1.], 
                  LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                   "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
               GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                 GrayLevel[0.7], 
                 Thickness[Tiny]], FrameTicks -> None, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}], PlotRange -> {{0, 5}, {0, 5}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "4"}], "}"}], "}"}], "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
            AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]],
                 ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, BaseStyle -> {}, Evaluator -> Automatic, Method -> 
                "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}]], 
              GraphicsBox[{{
                 GrayLevel[0.6], 
                 AbsolutePointSize[5], 
                 PointBox[{1, 1}], 
                 PointBox[{2, 4}], 
                 PointBox[{3, 2}], 
                 PointBox[{4, 3}]}, {{}, {}, {
                  AbsoluteThickness[1], 
                  Opacity[1.], 
                  LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                   "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
               GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                 GrayLevel[0.7], 
                 Thickness[Tiny]], FrameTicks -> None, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}], PlotRange -> {{0, 5}, {0, 5}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "4"}], "}"}], "}"}], "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["1", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
            AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    InterpolatingFunction[{{0, 4}}, {
     5, 3, 0, {11}, {2}, 0, 0, 0, 0, Automatic, {}, {}, False}, {{0, 
       Rational[2, 5], 
       Rational[4, 5], 
       Rational[6, 5], 
       Rational[8, 5], 2, 
       Rational[12, 5], 
       Rational[14, 5], 
       Rational[16, 5], 
       Rational[18, 5], 4}}, {{
      Rational[-5, 66] 
       E^(-200) (3 E^200 + 240 (2/Pi)^Rational[1, 2] + 
        432 E^38 (2/Pi)^Rational[1, 2] + 576 E^72 (2/Pi)^Rational[1, 2] + 
        672 E^102 (2/Pi)^Rational[1, 2] + 720 E^128 (2/Pi)^Rational[1, 2] + 
        720 E^150 (2/Pi)^Rational[1, 2] + 672 E^168 (2/Pi)^Rational[1, 2] + 
        576 E^182 (2/Pi)^Rational[1, 2] + 432 E^192 (2/Pi)^Rational[1, 2] + 
        240 E^198 (2/Pi)^Rational[1, 2] + 44 E^200 (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 22] 
       E^(-200) (E^200 + 80 (2/Pi)^Rational[1, 2] + 
        144 E^38 (2/Pi)^Rational[1, 2] + 192 E^72 (2/Pi)^Rational[1, 2] + 
        224 E^102 (2/Pi)^Rational[1, 2] + 240 E^128 (2/Pi)^Rational[1, 2] + 
        240 E^150 (2/Pi)^Rational[1, 2] + 224 E^168 (2/Pi)^Rational[1, 2] + 
        192 E^182 (2/Pi)^Rational[1, 2] + 144 E^192 (2/Pi)^Rational[1, 2] + 
        80 E^198 (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 22] 
       E^(-200) (E^200 + 80 (2/Pi)^Rational[1, 2] + 
        144 E^38 (2/Pi)^Rational[1, 2] + 192 E^72 (2/Pi)^Rational[1, 2] + 
        224 E^102 (2/Pi)^Rational[1, 2] + 240 E^128 (2/Pi)^Rational[1, 2] + 
        240 E^150 (2/Pi)^Rational[1, 2] + 224 E^168 (2/Pi)^Rational[1, 2] + 
        192 E^182 (2/Pi)^Rational[1, 2] + 144 E^192 (2/Pi)^Rational[1, 2] + 
        36 E^198 (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 66] 
       E^(-200) (3 E^200 + 240 (2/Pi)^Rational[1, 2] + 
        432 E^38 (2/Pi)^Rational[1, 2] + 576 E^72 (2/Pi)^Rational[1, 2] + 
        672 E^102 (2/Pi)^Rational[1, 2] + 720 E^128 (2/Pi)^Rational[1, 2] + 
        720 E^150 (2/Pi)^Rational[1, 2] + 672 E^168 (2/Pi)^Rational[1, 2] + 
        576 E^182 (2/Pi)^Rational[1, 2] + 256 E^192 (2/Pi)^Rational[1, 2] + 
        64 E^198 (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 22] 
       E^(-200) (E^200 + 80 (2/Pi)^Rational[1, 2] + 
        144 E^38 (2/Pi)^Rational[1, 2] + 192 E^72 (2/Pi)^Rational[1, 2] + 
        224 E^102 (2/Pi)^Rational[1, 2] + 240 E^128 (2/Pi)^Rational[1, 2] + 
        240 E^150 (2/Pi)^Rational[1, 2] + 224 E^168 (2/Pi)^Rational[1, 2] + 
        126 E^182 (2/Pi)^Rational[1, 2] + 56 E^192 (2/Pi)^Rational[1, 2] + 
        14 E^198 (2/Pi)^Rational[1, 2])}, {
      Rational[-1, 22] 
       E^(-200) (5 E^200 + 400 (2/Pi)^Rational[1, 2] + 
        720 E^38 (2/Pi)^Rational[1, 2] + 960 E^72 (2/Pi)^Rational[1, 2] + 
        1120 E^102 (2/Pi)^Rational[1, 2] + 1200 E^128 (2/Pi)^Rational[1, 2] + 
        1200 E^150 (2/Pi)^Rational[1, 2] + 768 E^168 (2/Pi)^Rational[1, 2] + 
        432 E^182 (2/Pi)^Rational[1, 2] + 192 E^192 (2/Pi)^Rational[1, 2] + 
        48 E^198 (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 66] 
       E^(-200) (3 E^200 + 240 (2/Pi)^Rational[1, 2] + 
        432 E^38 (2/Pi)^Rational[1, 2] + 576 E^72 (2/Pi)^Rational[1, 2] + 
        672 E^102 (2/Pi)^Rational[1, 2] + 720 E^128 (2/Pi)^Rational[1, 2] + 
        500 E^150 (2/Pi)^Rational[1, 2] + 320 E^168 (2/Pi)^Rational[1, 2] + 
        180 E^182 (2/Pi)^Rational[1, 2] + 80 E^192 (2/Pi)^Rational[1, 2] + 
        20 E^198 (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 154] 
       E^(-200) (7 E^200 + 560 (2/Pi)^Rational[1, 2] + 
        1008 E^38 (2/Pi)^Rational[1, 2] + 1344 E^72 (2/Pi)^Rational[1, 2] + 
        1568 E^102 (2/Pi)^Rational[1, 2] + 1152 E^128 (2/Pi)^Rational[1, 2] + 
        800 E^150 (2/Pi)^Rational[1, 2] + 512 E^168 (2/Pi)^Rational[1, 2] + 
        288 E^182 (2/Pi)^Rational[1, 2] + 128 E^192 (2/Pi)^Rational[1, 2] + 
        32 E^198 (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 22] 
       E^(-200) (80 2^Rational[1, 2] + 144 2^Rational[1, 2] E^38 + 
        192 2^Rational[1, 2] E^72 + 147 2^Rational[1, 2] E^102 + 
        108 2^Rational[1, 2] E^128 + 75 2^Rational[1, 2] E^150 + 
        48 2^Rational[1, 2] E^168 + 27 2^Rational[1, 2] E^182 + 
        12 2^Rational[1, 2] E^192 + 3 2^Rational[1, 2] E^198 + 
        E^200 Pi^Rational[1, 2]) Pi^Rational[-1, 2]}, {
      Rational[-5, 198] 
       E^(-200) (9 E^200 + 720 (2/Pi)^Rational[1, 2] + 
        1296 E^38 (2/Pi)^Rational[1, 2] + 1024 E^72 (2/Pi)^Rational[1, 2] + 
        784 E^102 (2/Pi)^Rational[1, 2] + 576 E^128 (2/Pi)^Rational[1, 2] + 
        400 E^150 (2/Pi)^Rational[1, 2] + 256 E^168 (2/Pi)^Rational[1, 2] + 
        144 E^182 (2/Pi)^Rational[1, 2] + 64 E^192 (2/Pi)^Rational[1, 2] + 
        16 E^198 (2/Pi)^Rational[1, 2])}, {
      Rational[-1, 22] 
       E^(-200) (5 E^200 + 400 (2/Pi)^Rational[1, 2] + 
        324 E^38 (2/Pi)^Rational[1, 2] + 256 E^72 (2/Pi)^Rational[1, 2] + 
        196 E^102 (2/Pi)^Rational[1, 2] + 144 E^128 (2/Pi)^Rational[1, 2] + 
        100 E^150 (2/Pi)^Rational[1, 2] + 64 E^168 (2/Pi)^Rational[1, 2] + 
        36 E^182 (2/Pi)^Rational[1, 2] + 16 E^192 (2/Pi)^Rational[1, 2] + 
        4 E^198 (2/Pi)^Rational[1, 2])}}, {Automatic}],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["InterpolatingFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]],
                 ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                None, BaseStyle -> {}, Evaluator -> Automatic, Method -> 
                "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}]], 
              GraphicsBox[{{
                 GrayLevel[0.6], 
                 AbsolutePointSize[5], 
                 PointBox[{1, 1}], 
                 PointBox[{2, 4}], 
                 PointBox[{3, 2}], 
                 PointBox[{4, 3}]}, {{}, {}, {
                  AbsoluteThickness[1], 
                  Opacity[1.], 
                  LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                   "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
               GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                 GrayLevel[0.7], 
                 Thickness[Tiny]], FrameTicks -> None, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}], PlotRange -> {{0, 5}, {0, 5}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "4"}], "}"}], "}"}], "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
            AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]],
                 ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, BaseStyle -> {}, Evaluator -> Automatic, Method -> 
                "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}]], 
              GraphicsBox[{{
                 GrayLevel[0.6], 
                 AbsolutePointSize[5], 
                 PointBox[{1, 1}], 
                 PointBox[{2, 4}], 
                 PointBox[{3, 2}], 
                 PointBox[{4, 3}]}, {{}, {}, {
                  AbsoluteThickness[1], 
                  Opacity[1.], 
                  LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                   "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
               GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                 GrayLevel[0.7], 
                 Thickness[Tiny]], FrameTicks -> None, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}], PlotRange -> {{0, 5}, {0, 5}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "4"}], "}"}], "}"}], "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["1", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
            AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    InterpolatingFunction[{{0, 4}}, {
     5, 3, 0, {21}, {2}, 0, 0, 0, 0, Automatic, {}, {}, False}, {{0, 
       Rational[1, 5], 
       Rational[2, 5], 
       Rational[3, 5], 
       Rational[4, 5], 1, 
       Rational[6, 5], 
       Rational[7, 5], 
       Rational[8, 5], 
       Rational[9, 5], 2, 
       Rational[11, 5], 
       Rational[12, 5], 
       Rational[13, 5], 
       Rational[14, 5], 3, 
       Rational[16, 5], 
       Rational[17, 5], 
       Rational[18, 5], 
       Rational[19, 5], 4}}, {{
      Rational[-5, 42] 
       E^(-200) (40 2^Rational[1, 2] + 76 2^Rational[1, 2] E^Rational[39, 2] + 
        108 2^Rational[1, 2] E^38 + 136 2^Rational[1, 2] E^Rational[111, 2] + 
        160 2^Rational[1, 2] E^72 + 180 2^Rational[1, 2] E^Rational[175, 2] + 
        196 2^Rational[1, 2] E^102 + 208 2^Rational[1, 2] E^Rational[231, 2] + 
        216 2^Rational[1, 2] E^128 + 220 2^Rational[1, 2] E^Rational[279, 2] + 
        220 2^Rational[1, 2] E^150 + 216 2^Rational[1, 2] E^Rational[319, 2] + 
        208 2^Rational[1, 2] E^168 + 196 2^Rational[1, 2] E^Rational[351, 2] + 
        180 2^Rational[1, 2] E^182 + 160 2^Rational[1, 2] E^Rational[375, 2] + 
        136 2^Rational[1, 2] E^192 + 108 2^Rational[1, 2] E^Rational[391, 2] + 
        76 2^Rational[1, 2] E^198 + 40 2^Rational[1, 2] E^Rational[399, 2] + 
        7 2^Rational[1, 2] E^200 + 2 E^200 Pi^Rational[1, 2]) 
       Pi^Rational[-1, 2]}, {
      Rational[-5, 21] 
       E^(-200) (20 2^Rational[1, 2] + 38 2^Rational[1, 2] E^Rational[39, 2] + 
        54 2^Rational[1, 2] E^38 + 68 2^Rational[1, 2] E^Rational[111, 2] + 
        80 2^Rational[1, 2] E^72 + 90 2^Rational[1, 2] E^Rational[175, 2] + 
        98 2^Rational[1, 2] E^102 + 104 2^Rational[1, 2] E^Rational[231, 2] + 
        108 2^Rational[1, 2] E^128 + 110 2^Rational[1, 2] E^Rational[279, 2] + 
        110 2^Rational[1, 2] E^150 + 108 2^Rational[1, 2] E^Rational[319, 2] + 
        104 2^Rational[1, 2] E^168 + 98 2^Rational[1, 2] E^Rational[351, 2] + 
        90 2^Rational[1, 2] E^182 + 80 2^Rational[1, 2] E^Rational[375, 2] + 
        68 2^Rational[1, 2] E^192 + 54 2^Rational[1, 2] E^Rational[391, 2] + 
        38 2^Rational[1, 2] E^198 + 20 2^Rational[1, 2] E^Rational[399, 2] + 
        E^200 Pi^Rational[1, 2]) Pi^Rational[-1, 2]}, {
      Rational[-5, 42] E^Rational[-401, 2] 
       Pi^(-1) (2 E^Rational[401, 2] Pi + 76 E^20 (2 Pi)^Rational[1, 2] + 
        108 E^Rational[77, 2] (2 Pi)^Rational[1, 2] + 
        136 E^56 (2 Pi)^Rational[1, 2] + 
        160 E^Rational[145, 2] (2 Pi)^Rational[1, 2] + 
        180 E^88 (2 Pi)^Rational[1, 2] + 
        196 E^Rational[205, 2] (2 Pi)^Rational[1, 2] + 
        208 E^116 (2 Pi)^Rational[1, 2] + 
        216 E^Rational[257, 2] (2 Pi)^Rational[1, 2] + 
        220 E^140 (2 Pi)^Rational[1, 2] + 
        220 E^Rational[301, 2] (2 Pi)^Rational[1, 2] + 
        216 E^160 (2 Pi)^Rational[1, 2] + 
        208 E^Rational[337, 2] (2 Pi)^Rational[1, 2] + 
        196 E^176 (2 Pi)^Rational[1, 2] + 
        180 E^Rational[365, 2] (2 Pi)^Rational[1, 2] + 
        160 E^188 (2 Pi)^Rational[1, 2] + 
        136 E^Rational[385, 2] (2 Pi)^Rational[1, 2] + 
        108 E^196 (2 Pi)^Rational[1, 2] + 
        76 E^Rational[397, 2] (2 Pi)^Rational[1, 2] + 
        19 E^200 (2 Pi)^Rational[1, 2] + 40 (2 E Pi)^Rational[1, 2])}, {
      Rational[-5, 21] 
       E^(-200) (20 2^Rational[1, 2] + 38 2^Rational[1, 2] E^Rational[39, 2] + 
        54 2^Rational[1, 2] E^38 + 68 2^Rational[1, 2] E^Rational[111, 2] + 
        80 2^Rational[1, 2] E^72 + 90 2^Rational[1, 2] E^Rational[175, 2] + 
        98 2^Rational[1, 2] E^102 + 104 2^Rational[1, 2] E^Rational[231, 2] + 
        108 2^Rational[1, 2] E^128 + 110 2^Rational[1, 2] E^Rational[279, 2] + 
        110 2^Rational[1, 2] E^150 + 108 2^Rational[1, 2] E^Rational[319, 2] + 
        104 2^Rational[1, 2] E^168 + 98 2^Rational[1, 2] E^Rational[351, 2] + 
        90 2^Rational[1, 2] E^182 + 80 2^Rational[1, 2] E^Rational[375, 2] + 
        68 2^Rational[1, 2] E^192 + 54 2^Rational[1, 2] E^Rational[391, 2] + 
        24 2^Rational[1, 2] E^198 + 6 2^Rational[1, 2] E^Rational[399, 2] + 
        E^200 Pi^Rational[1, 2]) Pi^Rational[-1, 2]}, {
      Rational[-5, 84] E^Rational[-401, 2] 
       Pi^(-1) (4 E^Rational[401, 2] Pi + 152 E^20 (2 Pi)^Rational[1, 2] + 
        216 E^Rational[77, 2] (2 Pi)^Rational[1, 2] + 
        272 E^56 (2 Pi)^Rational[1, 2] + 
        320 E^Rational[145, 2] (2 Pi)^Rational[1, 2] + 
        360 E^88 (2 Pi)^Rational[1, 2] + 
        392 E^Rational[205, 2] (2 Pi)^Rational[1, 2] + 
        416 E^116 (2 Pi)^Rational[1, 2] + 
        432 E^Rational[257, 2] (2 Pi)^Rational[1, 2] + 
        440 E^140 (2 Pi)^Rational[1, 2] + 
        440 E^Rational[301, 2] (2 Pi)^Rational[1, 2] + 
        432 E^160 (2 Pi)^Rational[1, 2] + 
        416 E^Rational[337, 2] (2 Pi)^Rational[1, 2] + 
        392 E^176 (2 Pi)^Rational[1, 2] + 
        360 E^Rational[365, 2] (2 Pi)^Rational[1, 2] + 
        320 E^188 (2 Pi)^Rational[1, 2] + 
        272 E^Rational[385, 2] (2 Pi)^Rational[1, 2] + 
        153 E^196 (2 Pi)^Rational[1, 2] + 
        68 E^Rational[397, 2] (2 Pi)^Rational[1, 2] + 
        17 E^200 (2 Pi)^Rational[1, 2] + 80 (2 E Pi)^Rational[1, 2])}, {
      Rational[-1, 21] 
       E^(-200) (100 2^Rational[1, 2] + 
        190 2^Rational[1, 2] E^Rational[39, 2] + 270 2^Rational[1, 2] E^38 + 
        340 2^Rational[1, 2] E^Rational[111, 2] + 400 2^Rational[1, 2] E^72 + 
        450 2^Rational[1, 2] E^Rational[175, 2] + 490 2^Rational[1, 2] E^102 + 
        520 2^Rational[1, 2] E^Rational[231, 2] + 540 2^Rational[1, 2] E^128 + 
        550 2^Rational[1, 2] E^Rational[279, 2] + 550 2^Rational[1, 2] E^150 + 
        540 2^Rational[1, 2] E^Rational[319, 2] + 520 2^Rational[1, 2] E^168 + 
        490 2^Rational[1, 2] E^Rational[351, 2] + 450 2^Rational[1, 2] E^182 + 
        400 2^Rational[1, 2] E^Rational[375, 2] + 256 2^Rational[1, 2] E^192 + 
        144 2^Rational[1, 2] E^Rational[391, 2] + 64 2^Rational[1, 2] E^198 + 
        16 2^Rational[1, 2] E^Rational[399, 2] + 5 E^200 Pi^Rational[1, 2]) 
       Pi^Rational[-1, 2]}, {
      Rational[-5, 42] E^Rational[-401, 2] 
       Pi^(-1) (2 E^Rational[401, 2] Pi + 76 E^20 (2 Pi)^Rational[1, 2] + 
        108 E^Rational[77, 2] (2 Pi)^Rational[1, 2] + 
        136 E^56 (2 Pi)^Rational[1, 2] + 
        160 E^Rational[145, 2] (2 Pi)^Rational[1, 2] + 
        180 E^88 (2 Pi)^Rational[1, 2] + 
        196 E^Rational[205, 2] (2 Pi)^Rational[1, 2] + 
        208 E^116 (2 Pi)^Rational[1, 2] + 
        216 E^Rational[257, 2] (2 Pi)^Rational[1, 2] + 
        220 E^140 (2 Pi)^Rational[1, 2] + 
        220 E^Rational[301, 2] (2 Pi)^Rational[1, 2] + 
        216 E^160 (2 Pi)^Rational[1, 2] + 
        208 E^Rational[337, 2] (2 Pi)^Rational[1, 2] + 
        196 E^176 (2 Pi)^Rational[1, 2] + 
        180 E^Rational[365, 2] (2 Pi)^Rational[1, 2] + 
        125 E^188 (2 Pi)^Rational[1, 2] + 
        80 E^Rational[385, 2] (2 Pi)^Rational[1, 2] + 
        45 E^196 (2 Pi)^Rational[1, 2] + 
        20 E^Rational[397, 2] (2 Pi)^Rational[1, 2] + 
        5 E^200 (2 Pi)^Rational[1, 2] + 40 (2 E Pi)^Rational[1, 2])}, {
      Rational[5, 21] 
       E^(-200) ((-20) 2^Rational[1, 2] - 38 2^Rational[1, 2] 
        E^Rational[39, 2] - 54 2^Rational[1, 2] E^38 - 68 2^Rational[1, 2] 
        E^Rational[111, 2] - 80 2^Rational[1, 2] E^72 - 90 2^Rational[1, 2] 
        E^Rational[175, 2] - 98 2^Rational[1, 2] E^102 - 104 2^Rational[1, 2] 
        E^Rational[231, 2] - 108 2^Rational[1, 2] E^128 - 110 
        2^Rational[1, 2] E^Rational[279, 2] - 110 2^Rational[1, 2] E^150 - 
        108 2^Rational[1, 2] E^Rational[319, 2] - 104 2^Rational[1, 2] E^168 - 
        98 2^Rational[1, 2] E^Rational[351, 2] - 72 2^Rational[1, 2] E^182 - 
        50 2^Rational[1, 2] E^Rational[375, 2] - 32 2^Rational[1, 2] E^192 - 
        18 2^Rational[1, 2] E^Rational[391, 2] - 8 2^Rational[1, 2] E^198 - 2 
        2^Rational[1, 2] E^Rational[399, 2] - E^200 Pi^Rational[1, 2]) 
       Pi^Rational[-1, 2]}, {
      Rational[-5, 168] E^Rational[-401, 2] 
       Pi^(-1) (8 E^Rational[401, 2] Pi + 304 E^20 (2 Pi)^Rational[1, 2] + 
        432 E^Rational[77, 2] (2 Pi)^Rational[1, 2] + 
        544 E^56 (2 Pi)^Rational[1, 2] + 
        640 E^Rational[145, 2] (2 Pi)^Rational[1, 2] + 
        720 E^88 (2 Pi)^Rational[1, 2] + 
        784 E^Rational[205, 2] (2 Pi)^Rational[1, 2] + 
        832 E^116 (2 Pi)^Rational[1, 2] + 
        864 E^Rational[257, 2] (2 Pi)^Rational[1, 2] + 
        880 E^140 (2 Pi)^Rational[1, 2] + 
        880 E^Rational[301, 2] (2 Pi)^Rational[1, 2] + 
        864 E^160 (2 Pi)^Rational[1, 2] + 
        832 E^Rational[337, 2] (2 Pi)^Rational[1, 2] + 
        637 E^176 (2 Pi)^Rational[1, 2] + 
        468 E^Rational[365, 2] (2 Pi)^Rational[1, 2] + 
        325 E^188 (2 Pi)^Rational[1, 2] + 
        208 E^Rational[385, 2] (2 Pi)^Rational[1, 2] + 
        117 E^196 (2 Pi)^Rational[1, 2] + 
        52 E^Rational[397, 2] (2 Pi)^Rational[1, 2] + 
        13 E^200 (2 Pi)^Rational[1, 2] + 160 (2 E Pi)^Rational[1, 2])}, {
      Rational[5, 63] 
       E^(-200) ((-60) 2^Rational[1, 2] - 114 2^Rational[1, 2] 
        E^Rational[39, 2] - 162 2^Rational[1, 2] E^38 - 204 2^Rational[1, 2] 
        E^Rational[111, 2] - 240 2^Rational[1, 2] E^72 - 270 2^Rational[1, 2] 
        E^Rational[175, 2] - 294 2^Rational[1, 2] E^102 - 312 
        2^Rational[1, 2] E^Rational[231, 2] - 324 2^Rational[1, 2] E^128 - 
        330 2^Rational[1, 2] E^Rational[279, 2] - 330 2^Rational[1, 2] E^150 - 
        324 2^Rational[1, 2] E^Rational[319, 2] - 256 2^Rational[1, 2] E^168 - 
        196 2^Rational[1, 2] E^Rational[351, 2] - 144 2^Rational[1, 2] E^182 - 
        100 2^Rational[1, 2] E^Rational[375, 2] - 64 2^Rational[1, 2] E^192 - 
        36 2^Rational[1, 2] E^Rational[391, 2] - 16 2^Rational[1, 2] E^198 - 
        4 2^Rational[1, 2] E^Rational[399, 2] - 3 E^200 Pi^Rational[1, 2]) 
       Pi^Rational[-1, 2]}, {
      Rational[-1, 42] E^Rational[-401, 2] 
       Pi^(-1) (10 E^Rational[401, 2] Pi + 380 E^20 (2 Pi)^Rational[1, 2] + 
        540 E^Rational[77, 2] (2 Pi)^Rational[1, 2] + 
        680 E^56 (2 Pi)^Rational[1, 2] + 
        800 E^Rational[145, 2] (2 Pi)^Rational[1, 2] + 
        900 E^88 (2 Pi)^Rational[1, 2] + 
        980 E^Rational[205, 2] (2 Pi)^Rational[1, 2] + 
        1040 E^116 (2 Pi)^Rational[1, 2] + 
        1080 E^Rational[257, 2] (2 Pi)^Rational[1, 2] + 
        1100 E^140 (2 Pi)^Rational[1, 2] + 
        1100 E^Rational[301, 2] (2 Pi)^Rational[1, 2] + 
        891 E^160 (2 Pi)^Rational[1, 2] + 
        704 E^Rational[337, 2] (2 Pi)^Rational[1, 2] + 
        539 E^176 (2 Pi)^Rational[1, 2] + 
        396 E^Rational[365, 2] (2 Pi)^Rational[1, 2] + 
        275 E^188 (2 Pi)^Rational[1, 2] + 
        176 E^Rational[385, 2] (2 Pi)^Rational[1, 2] + 
        99 E^196 (2 Pi)^Rational[1, 2] + 
        44 E^Rational[397, 2] (2 Pi)^Rational[1, 2] + 
        11 E^200 (2 Pi)^Rational[1, 2] + 200 (2 E Pi)^Rational[1, 2])}, {
      Rational[-5, 231] 
       E^(-200) (11 E^200 + 220 (2/Pi)^Rational[1, 2] + 
        418 E^Rational[39, 2] (2/Pi)^Rational[1, 2] + 
        594 E^38 (2/Pi)^Rational[1, 2] + 
        748 E^Rational[111, 2] (2/Pi)^Rational[1, 2] + 
        880 E^72 (2/Pi)^Rational[1, 2] + 
        990 E^Rational[175, 2] (2/Pi)^Rational[1, 2] + 
        1078 E^102 (2/Pi)^Rational[1, 2] + 
        1144 E^Rational[231, 2] (2/Pi)^Rational[1, 2] + 
        1188 E^128 (2/Pi)^Rational[1, 2] + 
        1210 E^Rational[279, 2] (2/Pi)^Rational[1, 2] + 
        1000 E^150 (2/Pi)^Rational[1, 2] + 
        810 E^Rational[319, 2] (2/Pi)^Rational[1, 2] + 
        640 E^168 (2/Pi)^Rational[1, 2] + 
        490 E^Rational[351, 2] (2/Pi)^Rational[1, 2] + 
        360 E^182 (2/Pi)^Rational[1, 2] + 
        250 E^Rational[375, 2] (2/Pi)^Rational[1, 2] + 
        160 E^192 (2/Pi)^Rational[1, 2] + 
        90 E^Rational[391, 2] (2/Pi)^Rational[1, 2] + 
        40 E^198 (2/Pi)^Rational[1, 2] + 
        10 E^Rational[399, 2] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 84] E^Rational[-401, 2] 
       Pi^(-1) (4 E^Rational[401, 2] Pi + 152 E^20 (2 Pi)^Rational[1, 2] + 
        216 E^Rational[77, 2] (2 Pi)^Rational[1, 2] + 
        272 E^56 (2 Pi)^Rational[1, 2] + 
        320 E^Rational[145, 2] (2 Pi)^Rational[1, 2] + 
        360 E^88 (2 Pi)^Rational[1, 2] + 
        392 E^Rational[205, 2] (2 Pi)^Rational[1, 2] + 
        416 E^116 (2 Pi)^Rational[1, 2] + 
        432 E^Rational[257, 2] (2 Pi)^Rational[1, 2] + 
        363 E^140 (2 Pi)^Rational[1, 2] + 
        300 E^Rational[301, 2] (2 Pi)^Rational[1, 2] + 
        243 E^160 (2 Pi)^Rational[1, 2] + 
        192 E^Rational[337, 2] (2 Pi)^Rational[1, 2] + 
        147 E^176 (2 Pi)^Rational[1, 2] + 
        108 E^Rational[365, 2] (2 Pi)^Rational[1, 2] + 
        75 E^188 (2 Pi)^Rational[1, 2] + 
        48 E^Rational[385, 2] (2 Pi)^Rational[1, 2] + 
        27 E^196 (2 Pi)^Rational[1, 2] + 
        12 E^Rational[397, 2] (2 Pi)^Rational[1, 2] + 
        3 E^200 (2 Pi)^Rational[1, 2] + 80 (2 E Pi)^Rational[1, 2])}, {
      Rational[-5, 273] 
       E^(-200) (13 E^200 + 260 (2/Pi)^Rational[1, 2] + 
        494 E^Rational[39, 2] (2/Pi)^Rational[1, 2] + 
        702 E^38 (2/Pi)^Rational[1, 2] + 
        884 E^Rational[111, 2] (2/Pi)^Rational[1, 2] + 
        1040 E^72 (2/Pi)^Rational[1, 2] + 
        1170 E^Rational[175, 2] (2/Pi)^Rational[1, 2] + 
        1274 E^102 (2/Pi)^Rational[1, 2] + 
        1352 E^Rational[231, 2] (2/Pi)^Rational[1, 2] + 
        1152 E^128 (2/Pi)^Rational[1, 2] + 
        968 E^Rational[279, 2] (2/Pi)^Rational[1, 2] + 
        800 E^150 (2/Pi)^Rational[1, 2] + 
        648 E^Rational[319, 2] (2/Pi)^Rational[1, 2] + 
        512 E^168 (2/Pi)^Rational[1, 2] + 
        392 E^Rational[351, 2] (2/Pi)^Rational[1, 2] + 
        288 E^182 (2/Pi)^Rational[1, 2] + 
        200 E^Rational[375, 2] (2/Pi)^Rational[1, 2] + 
        128 E^192 (2/Pi)^Rational[1, 2] + 
        72 E^Rational[391, 2] (2/Pi)^Rational[1, 2] + 
        32 E^198 (2/Pi)^Rational[1, 2] + 
        8 E^Rational[399, 2] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 42] E^Rational[-401, 2] 
       Pi^(-1) (2 E^Rational[401, 2] Pi + 76 E^20 (2 Pi)^Rational[1, 2] + 
        108 E^Rational[77, 2] (2 Pi)^Rational[1, 2] + 
        136 E^56 (2 Pi)^Rational[1, 2] + 
        160 E^Rational[145, 2] (2 Pi)^Rational[1, 2] + 
        180 E^88 (2 Pi)^Rational[1, 2] + 
        196 E^Rational[205, 2] (2 Pi)^Rational[1, 2] + 
        169 E^116 (2 Pi)^Rational[1, 2] + 
        144 E^Rational[257, 2] (2 Pi)^Rational[1, 2] + 
        121 E^140 (2 Pi)^Rational[1, 2] + 
        100 E^Rational[301, 2] (2 Pi)^Rational[1, 2] + 
        81 E^160 (2 Pi)^Rational[1, 2] + 
        64 E^Rational[337, 2] (2 Pi)^Rational[1, 2] + 
        49 E^176 (2 Pi)^Rational[1, 2] + 
        36 E^Rational[365, 2] (2 Pi)^Rational[1, 2] + 
        25 E^188 (2 Pi)^Rational[1, 2] + 
        16 E^Rational[385, 2] (2 Pi)^Rational[1, 2] + 
        9 E^196 (2 Pi)^Rational[1, 2] + 
        4 E^Rational[397, 2] (2 Pi)^Rational[1, 2] + 
        E^200 (2 Pi)^Rational[1, 2] + 40 (2 E Pi)^Rational[1, 2])}, {
      Rational[-1, 21] 
       E^(-200) (5 E^200 + 100 (2/Pi)^Rational[1, 2] + 
        190 E^Rational[39, 2] (2/Pi)^Rational[1, 2] + 
        270 E^38 (2/Pi)^Rational[1, 2] + 
        340 E^Rational[111, 2] (2/Pi)^Rational[1, 2] + 
        400 E^72 (2/Pi)^Rational[1, 2] + 
        450 E^Rational[175, 2] (2/Pi)^Rational[1, 2] + 
        392 E^102 (2/Pi)^Rational[1, 2] + 
        338 E^Rational[231, 2] (2/Pi)^Rational[1, 2] + 
        288 E^128 (2/Pi)^Rational[1, 2] + 
        242 E^Rational[279, 2] (2/Pi)^Rational[1, 2] + 
        200 E^150 (2/Pi)^Rational[1, 2] + 
        162 E^Rational[319, 2] (2/Pi)^Rational[1, 2] + 
        128 E^168 (2/Pi)^Rational[1, 2] + 
        98 E^Rational[351, 2] (2/Pi)^Rational[1, 2] + 
        72 E^182 (2/Pi)^Rational[1, 2] + 
        50 E^Rational[375, 2] (2/Pi)^Rational[1, 2] + 
        32 E^192 (2/Pi)^Rational[1, 2] + 
        18 E^Rational[391, 2] (2/Pi)^Rational[1, 2] + 
        8 E^198 (2/Pi)^Rational[1, 2] + 
        2 E^Rational[399, 2] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 336] E^Rational[-401, 2] 
       Pi^(-1) (16 E^Rational[401, 2] Pi + 608 E^20 (2 Pi)^Rational[1, 2] + 
        864 E^Rational[77, 2] (2 Pi)^Rational[1, 2] + 
        1088 E^56 (2 Pi)^Rational[1, 2] + 
        1280 E^Rational[145, 2] (2 Pi)^Rational[1, 2] + 
        1125 E^88 (2 Pi)^Rational[1, 2] + 
        980 E^Rational[205, 2] (2 Pi)^Rational[1, 2] + 
        845 E^116 (2 Pi)^Rational[1, 2] + 
        720 E^Rational[257, 2] (2 Pi)^Rational[1, 2] + 
        605 E^140 (2 Pi)^Rational[1, 2] + 
        500 E^Rational[301, 2] (2 Pi)^Rational[1, 2] + 
        405 E^160 (2 Pi)^Rational[1, 2] + 
        320 E^Rational[337, 2] (2 Pi)^Rational[1, 2] + 
        245 E^176 (2 Pi)^Rational[1, 2] + 
        180 E^Rational[365, 2] (2 Pi)^Rational[1, 2] + 
        125 E^188 (2 Pi)^Rational[1, 2] + 
        80 E^Rational[385, 2] (2 Pi)^Rational[1, 2] + 
        45 E^196 (2 Pi)^Rational[1, 2] + 
        20 E^Rational[397, 2] (2 Pi)^Rational[1, 2] + 
        5 E^200 (2 Pi)^Rational[1, 2] + 320 (2 E Pi)^Rational[1, 2])}, {
      Rational[-5, 357] 
       E^(-200) (17 E^200 + 340 (2/Pi)^Rational[1, 2] + 
        646 E^Rational[39, 2] (2/Pi)^Rational[1, 2] + 
        918 E^38 (2/Pi)^Rational[1, 2] + 
        1156 E^Rational[111, 2] (2/Pi)^Rational[1, 2] + 
        1024 E^72 (2/Pi)^Rational[1, 2] + 
        900 E^Rational[175, 2] (2/Pi)^Rational[1, 2] + 
        784 E^102 (2/Pi)^Rational[1, 2] + 
        676 E^Rational[231, 2] (2/Pi)^Rational[1, 2] + 
        576 E^128 (2/Pi)^Rational[1, 2] + 
        484 E^Rational[279, 2] (2/Pi)^Rational[1, 2] + 
        400 E^150 (2/Pi)^Rational[1, 2] + 
        324 E^Rational[319, 2] (2/Pi)^Rational[1, 2] + 
        256 E^168 (2/Pi)^Rational[1, 2] + 
        196 E^Rational[351, 2] (2/Pi)^Rational[1, 2] + 
        144 E^182 (2/Pi)^Rational[1, 2] + 
        100 E^Rational[375, 2] (2/Pi)^Rational[1, 2] + 
        64 E^192 (2/Pi)^Rational[1, 2] + 
        36 E^Rational[391, 2] (2/Pi)^Rational[1, 2] + 
        16 E^198 (2/Pi)^Rational[1, 2] + 
        4 E^Rational[399, 2] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 126] E^Rational[-401, 2] 
       Pi^(-1) (6 E^Rational[401, 2] Pi + 228 E^20 (2 Pi)^Rational[1, 2] + 
        324 E^Rational[77, 2] (2 Pi)^Rational[1, 2] + 
        289 E^56 (2 Pi)^Rational[1, 2] + 
        256 E^Rational[145, 2] (2 Pi)^Rational[1, 2] + 
        225 E^88 (2 Pi)^Rational[1, 2] + 
        196 E^Rational[205, 2] (2 Pi)^Rational[1, 2] + 
        169 E^116 (2 Pi)^Rational[1, 2] + 
        144 E^Rational[257, 2] (2 Pi)^Rational[1, 2] + 
        121 E^140 (2 Pi)^Rational[1, 2] + 
        100 E^Rational[301, 2] (2 Pi)^Rational[1, 2] + 
        81 E^160 (2 Pi)^Rational[1, 2] + 
        64 E^Rational[337, 2] (2 Pi)^Rational[1, 2] + 
        49 E^176 (2 Pi)^Rational[1, 2] + 
        36 E^Rational[365, 2] (2 Pi)^Rational[1, 2] + 
        25 E^188 (2 Pi)^Rational[1, 2] + 
        16 E^Rational[385, 2] (2 Pi)^Rational[1, 2] + 
        9 E^196 (2 Pi)^Rational[1, 2] + 
        4 E^Rational[397, 2] (2 Pi)^Rational[1, 2] + 
        E^200 (2 Pi)^Rational[1, 2] + 120 (2 E Pi)^Rational[1, 2])}, {
      Rational[-5, 399] 
       E^(-200) (19 E^200 + 380 (2/Pi)^Rational[1, 2] + 
        722 E^Rational[39, 2] (2/Pi)^Rational[1, 2] + 
        648 E^38 (2/Pi)^Rational[1, 2] + 
        578 E^Rational[111, 2] (2/Pi)^Rational[1, 2] + 
        512 E^72 (2/Pi)^Rational[1, 2] + 
        450 E^Rational[175, 2] (2/Pi)^Rational[1, 2] + 
        392 E^102 (2/Pi)^Rational[1, 2] + 
        338 E^Rational[231, 2] (2/Pi)^Rational[1, 2] + 
        288 E^128 (2/Pi)^Rational[1, 2] + 
        242 E^Rational[279, 2] (2/Pi)^Rational[1, 2] + 
        200 E^150 (2/Pi)^Rational[1, 2] + 
        162 E^Rational[319, 2] (2/Pi)^Rational[1, 2] + 
        128 E^168 (2/Pi)^Rational[1, 2] + 
        98 E^Rational[351, 2] (2/Pi)^Rational[1, 2] + 
        72 E^182 (2/Pi)^Rational[1, 2] + 
        50 E^Rational[375, 2] (2/Pi)^Rational[1, 2] + 
        32 E^192 (2/Pi)^Rational[1, 2] + 
        18 E^Rational[391, 2] (2/Pi)^Rational[1, 2] + 
        8 E^198 (2/Pi)^Rational[1, 2] + 
        2 E^Rational[399, 2] (2/Pi)^Rational[1, 2])}, {
      Rational[-1, 84] E^Rational[-401, 2] 
       Pi^(-1) (20 E^Rational[401, 2] Pi + 361 E^20 (2 Pi)^Rational[1, 2] + 
        324 E^Rational[77, 2] (2 Pi)^Rational[1, 2] + 
        289 E^56 (2 Pi)^Rational[1, 2] + 
        256 E^Rational[145, 2] (2 Pi)^Rational[1, 2] + 
        225 E^88 (2 Pi)^Rational[1, 2] + 
        196 E^Rational[205, 2] (2 Pi)^Rational[1, 2] + 
        169 E^116 (2 Pi)^Rational[1, 2] + 
        144 E^Rational[257, 2] (2 Pi)^Rational[1, 2] + 
        121 E^140 (2 Pi)^Rational[1, 2] + 
        100 E^Rational[301, 2] (2 Pi)^Rational[1, 2] + 
        81 E^160 (2 Pi)^Rational[1, 2] + 
        64 E^Rational[337, 2] (2 Pi)^Rational[1, 2] + 
        49 E^176 (2 Pi)^Rational[1, 2] + 
        36 E^Rational[365, 2] (2 Pi)^Rational[1, 2] + 
        25 E^188 (2 Pi)^Rational[1, 2] + 
        16 E^Rational[385, 2] (2 Pi)^Rational[1, 2] + 
        9 E^196 (2 Pi)^Rational[1, 2] + 
        4 E^Rational[397, 2] (2 Pi)^Rational[1, 2] + 
        E^200 (2 Pi)^Rational[1, 2] + 400 (2 E Pi)^Rational[1, 2])}}, {
     Automatic}],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["InterpolatingFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]],
                 ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                None, BaseStyle -> {}, Evaluator -> Automatic, Method -> 
                "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}]], 
              GraphicsBox[{{
                 GrayLevel[0.6], 
                 AbsolutePointSize[5], 
                 PointBox[{1, 1}], 
                 PointBox[{2, 4}], 
                 PointBox[{3, 2}], 
                 PointBox[{4, 3}]}, {{}, {}, {
                  AbsoluteThickness[1], 
                  Opacity[1.], 
                  LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                   "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
               GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                 GrayLevel[0.7], 
                 Thickness[Tiny]], FrameTicks -> None, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}], PlotRange -> {{0, 5}, {0, 5}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "4"}], "}"}], "}"}], "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
            AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]],
                 ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, BaseStyle -> {}, Evaluator -> Automatic, Method -> 
                "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}]], 
              GraphicsBox[{{
                 GrayLevel[0.6], 
                 AbsolutePointSize[5], 
                 PointBox[{1, 1}], 
                 PointBox[{2, 4}], 
                 PointBox[{3, 2}], 
                 PointBox[{4, 3}]}, {{}, {}, {
                  AbsoluteThickness[1], 
                  Opacity[1.], 
                  LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                   "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
               GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                 GrayLevel[0.7], 
                 Thickness[Tiny]], FrameTicks -> None, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}], PlotRange -> {{0, 5}, {0, 5}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "4"}], "}"}], "}"}], "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["1", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
            AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    InterpolatingFunction[{{0, 4}}, {
     5, 3, 0, {31}, {2}, 0, 0, 0, 0, Automatic, {}, {}, False}, {{0, 
       Rational[2, 15], 
       Rational[4, 15], 
       Rational[2, 5], 
       Rational[8, 15], 
       Rational[2, 3], 
       Rational[4, 5], 
       Rational[14, 15], 
       Rational[16, 15], 
       Rational[6, 5], 
       Rational[4, 3], 
       Rational[22, 15], 
       Rational[8, 5], 
       Rational[26, 15], 
       Rational[28, 15], 2, 
       Rational[32, 15], 
       Rational[34, 15], 
       Rational[12, 5], 
       Rational[38, 15], 
       Rational[8, 3], 
       Rational[14, 5], 
       Rational[44, 15], 
       Rational[46, 15], 
       Rational[16, 5], 
       Rational[10, 3], 
       Rational[52, 15], 
       Rational[18, 5], 
       Rational[56, 15], 
       Rational[58, 15], 4}}, {{
      Rational[-5, 1674] 
       E^(-200) (81 E^200 + 720 (2/Pi)^Rational[1, 2] + 
        1392 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        2016 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        2592 E^38 (2/Pi)^Rational[1, 2] + 
        3120 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        3600 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        4032 E^72 (2/Pi)^Rational[1, 2] + 
        4416 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        4752 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        5040 E^102 (2/Pi)^Rational[1, 2] + 
        5280 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        5472 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        5616 E^128 (2/Pi)^Rational[1, 2] + 
        5712 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        5760 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        5760 E^150 (2/Pi)^Rational[1, 2] + 
        5712 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        5616 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        5472 E^168 (2/Pi)^Rational[1, 2] + 
        5280 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        5040 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        4752 E^182 (2/Pi)^Rational[1, 2] + 
        4416 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        4032 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        3600 E^192 (2/Pi)^Rational[1, 2] + 
        3120 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        2592 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        2016 E^198 (2/Pi)^Rational[1, 2] + 
        1392 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        720 E^Rational[1798, 9] (2/Pi)^Rational[1, 2] + 
        124 E^200 (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 558] 
       E^(-200) (27 E^200 + 240 (2/Pi)^Rational[1, 2] + 
        464 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        672 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        864 E^38 (2/Pi)^Rational[1, 2] + 
        1040 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        1200 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        1344 E^72 (2/Pi)^Rational[1, 2] + 
        1472 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        1584 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        1680 E^102 (2/Pi)^Rational[1, 2] + 
        1760 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        1824 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        1872 E^128 (2/Pi)^Rational[1, 2] + 
        1904 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        1920 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        1920 E^150 (2/Pi)^Rational[1, 2] + 
        1904 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        1872 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        1824 E^168 (2/Pi)^Rational[1, 2] + 
        1760 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        1680 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        1584 E^182 (2/Pi)^Rational[1, 2] + 
        1472 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        1344 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        1200 E^192 (2/Pi)^Rational[1, 2] + 
        1040 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        864 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        672 E^198 (2/Pi)^Rational[1, 2] + 
        464 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        240 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 558] 
       E^(-200) (27 E^200 + 240 (2/Pi)^Rational[1, 2] + 
        464 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        672 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        864 E^38 (2/Pi)^Rational[1, 2] + 
        1040 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        1200 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        1344 E^72 (2/Pi)^Rational[1, 2] + 
        1472 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        1584 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        1680 E^102 (2/Pi)^Rational[1, 2] + 
        1760 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        1824 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        1872 E^128 (2/Pi)^Rational[1, 2] + 
        1904 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        1920 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        1920 E^150 (2/Pi)^Rational[1, 2] + 
        1904 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        1872 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        1824 E^168 (2/Pi)^Rational[1, 2] + 
        1760 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        1680 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        1584 E^182 (2/Pi)^Rational[1, 2] + 
        1472 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        1344 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        1200 E^192 (2/Pi)^Rational[1, 2] + 
        1040 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        864 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        672 E^198 (2/Pi)^Rational[1, 2] + 
        464 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        116 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 1674] 
       E^(-200) (81 E^200 + 720 (2/Pi)^Rational[1, 2] + 
        1392 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        2016 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        2592 E^38 (2/Pi)^Rational[1, 2] + 
        3120 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        3600 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        4032 E^72 (2/Pi)^Rational[1, 2] + 
        4416 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        4752 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        5040 E^102 (2/Pi)^Rational[1, 2] + 
        5280 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        5472 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        5616 E^128 (2/Pi)^Rational[1, 2] + 
        5712 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        5760 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        5760 E^150 (2/Pi)^Rational[1, 2] + 
        5712 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        5616 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        5472 E^168 (2/Pi)^Rational[1, 2] + 
        5280 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        5040 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        4752 E^182 (2/Pi)^Rational[1, 2] + 
        4416 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        4032 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        3600 E^192 (2/Pi)^Rational[1, 2] + 
        3120 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        2592 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        2016 E^198 (2/Pi)^Rational[1, 2] + 
        896 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        224 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 558] 
       E^(-200) (27 E^200 + 240 (2/Pi)^Rational[1, 2] + 
        464 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        672 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        864 E^38 (2/Pi)^Rational[1, 2] + 
        1040 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        1200 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        1344 E^72 (2/Pi)^Rational[1, 2] + 
        1472 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        1584 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        1680 E^102 (2/Pi)^Rational[1, 2] + 
        1760 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        1824 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        1872 E^128 (2/Pi)^Rational[1, 2] + 
        1904 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        1920 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        1920 E^150 (2/Pi)^Rational[1, 2] + 
        1904 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        1872 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        1824 E^168 (2/Pi)^Rational[1, 2] + 
        1760 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        1680 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        1584 E^182 (2/Pi)^Rational[1, 2] + 
        1472 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        1344 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        1200 E^192 (2/Pi)^Rational[1, 2] + 
        1040 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        864 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        486 E^198 (2/Pi)^Rational[1, 2] + 
        216 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        54 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-1, 558] 
       E^(-200) (135 E^200 + 1200 (2/Pi)^Rational[1, 2] + 
        2320 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        3360 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        4320 E^38 (2/Pi)^Rational[1, 2] + 
        5200 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        6000 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        6720 E^72 (2/Pi)^Rational[1, 2] + 
        7360 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        7920 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        8400 E^102 (2/Pi)^Rational[1, 2] + 
        8800 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        9120 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        9360 E^128 (2/Pi)^Rational[1, 2] + 
        9520 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        9600 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        9600 E^150 (2/Pi)^Rational[1, 2] + 
        9520 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        9360 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        9120 E^168 (2/Pi)^Rational[1, 2] + 
        8800 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        8400 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        7920 E^182 (2/Pi)^Rational[1, 2] + 
        7360 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        6720 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        6000 E^192 (2/Pi)^Rational[1, 2] + 
        5200 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        3328 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        1872 E^198 (2/Pi)^Rational[1, 2] + 
        832 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        208 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 1674] 
       E^(-200) (81 E^200 + 720 (2/Pi)^Rational[1, 2] + 
        1392 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        2016 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        2592 E^38 (2/Pi)^Rational[1, 2] + 
        3120 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        3600 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        4032 E^72 (2/Pi)^Rational[1, 2] + 
        4416 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        4752 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        5040 E^102 (2/Pi)^Rational[1, 2] + 
        5280 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        5472 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        5616 E^128 (2/Pi)^Rational[1, 2] + 
        5712 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        5760 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        5760 E^150 (2/Pi)^Rational[1, 2] + 
        5712 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        5616 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        5472 E^168 (2/Pi)^Rational[1, 2] + 
        5280 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        5040 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        4752 E^182 (2/Pi)^Rational[1, 2] + 
        4416 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        4032 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        3600 E^192 (2/Pi)^Rational[1, 2] + 
        2500 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        1600 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        900 E^198 (2/Pi)^Rational[1, 2] + 
        400 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        100 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 3906] 
       E^(-200) (189 E^200 + 1680 (2/Pi)^Rational[1, 2] + 
        3248 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        4704 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        6048 E^38 (2/Pi)^Rational[1, 2] + 
        7280 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        8400 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        9408 E^72 (2/Pi)^Rational[1, 2] + 
        10304 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        11088 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        11760 E^102 (2/Pi)^Rational[1, 2] + 
        12320 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        12768 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        13104 E^128 (2/Pi)^Rational[1, 2] + 
        13328 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        13440 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        13440 E^150 (2/Pi)^Rational[1, 2] + 
        13328 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        13104 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        12768 E^168 (2/Pi)^Rational[1, 2] + 
        12320 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        11760 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        11088 E^182 (2/Pi)^Rational[1, 2] + 
        10304 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        9408 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        6912 E^192 (2/Pi)^Rational[1, 2] + 
        4800 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        3072 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        1728 E^198 (2/Pi)^Rational[1, 2] + 
        768 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        192 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 558] 
       E^(-200) (240 2^Rational[1, 2] + 
        464 2^Rational[1, 2] E^Rational[118, 9] + 
        672 2^Rational[1, 2] E^Rational[232, 9] + 864 2^Rational[1, 2] E^38 + 
        1040 2^Rational[1, 2] E^Rational[448, 9] + 
        1200 2^Rational[1, 2] E^Rational[550, 9] + 1344 2^Rational[1, 2] E^72 + 
        1472 2^Rational[1, 2] E^Rational[742, 9] + 
        1584 2^Rational[1, 2] E^Rational[832, 9] + 
        1680 2^Rational[1, 2] E^102 + 
        1760 2^Rational[1, 2] E^Rational[1000, 9] + 
        1824 2^Rational[1, 2] E^Rational[1078, 9] + 
        1872 2^Rational[1, 2] E^128 + 
        1904 2^Rational[1, 2] E^Rational[1222, 9] + 
        1920 2^Rational[1, 2] E^Rational[1288, 9] + 
        1920 2^Rational[1, 2] E^150 + 
        1904 2^Rational[1, 2] E^Rational[1408, 9] + 
        1872 2^Rational[1, 2] E^Rational[1462, 9] + 
        1824 2^Rational[1, 2] E^168 + 
        1760 2^Rational[1, 2] E^Rational[1558, 9] + 
        1680 2^Rational[1, 2] E^Rational[1600, 9] + 
        1584 2^Rational[1, 2] E^182 + 
        1472 2^Rational[1, 2] E^Rational[1672, 9] + 
        1127 2^Rational[1, 2] E^Rational[1702, 9] + 
        828 2^Rational[1, 2] E^192 + 575 2^Rational[1, 2] E^Rational[1750, 9] + 
        368 2^Rational[1, 2] E^Rational[1768, 9] + 207 2^Rational[1, 2] E^198 + 
        92 2^Rational[1, 2] E^Rational[1792, 9] + 
        23 2^Rational[1, 2] E^Rational[1798, 9] + 27 E^200 Pi^Rational[1, 2]) 
       Pi^Rational[-1, 2]}, {
      Rational[-5, 5022] 
       E^(-200) (243 E^200 + 2160 (2/Pi)^Rational[1, 2] + 
        4176 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        6048 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        7776 E^38 (2/Pi)^Rational[1, 2] + 
        9360 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        10800 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        12096 E^72 (2/Pi)^Rational[1, 2] + 
        13248 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        14256 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        15120 E^102 (2/Pi)^Rational[1, 2] + 
        15840 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        16416 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        16848 E^128 (2/Pi)^Rational[1, 2] + 
        17136 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        17280 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        17280 E^150 (2/Pi)^Rational[1, 2] + 
        17136 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        16848 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        16416 E^168 (2/Pi)^Rational[1, 2] + 
        15840 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        15120 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        14256 E^182 (2/Pi)^Rational[1, 2] + 
        11264 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        8624 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        6336 E^192 (2/Pi)^Rational[1, 2] + 
        4400 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        2816 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        1584 E^198 (2/Pi)^Rational[1, 2] + 
        704 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        176 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-1, 558] 
       E^(-200) (135 E^200 + 1200 (2/Pi)^Rational[1, 2] + 
        2320 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        3360 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        4320 E^38 (2/Pi)^Rational[1, 2] + 
        5200 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        6000 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        6720 E^72 (2/Pi)^Rational[1, 2] + 
        7360 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        7920 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        8400 E^102 (2/Pi)^Rational[1, 2] + 
        8800 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        9120 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        9360 E^128 (2/Pi)^Rational[1, 2] + 
        9520 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        9600 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        9600 E^150 (2/Pi)^Rational[1, 2] + 
        9520 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        9360 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        9120 E^168 (2/Pi)^Rational[1, 2] + 
        8800 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        8400 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        6804 E^182 (2/Pi)^Rational[1, 2] + 
        5376 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        4116 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        3024 E^192 (2/Pi)^Rational[1, 2] + 
        2100 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        1344 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        756 E^198 (2/Pi)^Rational[1, 2] + 
        336 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        84 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 6138] 
       E^(-200) (297 E^200 + 2640 (2/Pi)^Rational[1, 2] + 
        5104 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        7392 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        9504 E^38 (2/Pi)^Rational[1, 2] + 
        11440 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        13200 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        14784 E^72 (2/Pi)^Rational[1, 2] + 
        16192 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        17424 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        18480 E^102 (2/Pi)^Rational[1, 2] + 
        19360 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        20064 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        20592 E^128 (2/Pi)^Rational[1, 2] + 
        20944 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        21120 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        21120 E^150 (2/Pi)^Rational[1, 2] + 
        20944 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        20592 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        20064 E^168 (2/Pi)^Rational[1, 2] + 
        19360 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        16000 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        12960 E^182 (2/Pi)^Rational[1, 2] + 
        10240 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        7840 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        5760 E^192 (2/Pi)^Rational[1, 2] + 
        4000 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        2560 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        1440 E^198 (2/Pi)^Rational[1, 2] + 
        640 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        160 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 1674] 
       E^(-200) (81 E^200 + 720 (2/Pi)^Rational[1, 2] + 
        1392 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        2016 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        2592 E^38 (2/Pi)^Rational[1, 2] + 
        3120 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        3600 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        4032 E^72 (2/Pi)^Rational[1, 2] + 
        4416 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        4752 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        5040 E^102 (2/Pi)^Rational[1, 2] + 
        5280 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        5472 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        5616 E^128 (2/Pi)^Rational[1, 2] + 
        5712 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        5760 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        5760 E^150 (2/Pi)^Rational[1, 2] + 
        5712 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        5616 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        5472 E^168 (2/Pi)^Rational[1, 2] + 
        4598 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        3800 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        3078 E^182 (2/Pi)^Rational[1, 2] + 
        2432 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        1862 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        1368 E^192 (2/Pi)^Rational[1, 2] + 
        950 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        608 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        342 E^198 (2/Pi)^Rational[1, 2] + 
        152 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        38 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 7254] 
       E^(-200) (351 E^200 + 3120 (2/Pi)^Rational[1, 2] + 
        6032 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        8736 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        11232 E^38 (2/Pi)^Rational[1, 2] + 
        13520 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        15600 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        17472 E^72 (2/Pi)^Rational[1, 2] + 
        19136 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        20592 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        21840 E^102 (2/Pi)^Rational[1, 2] + 
        22880 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        23712 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        24336 E^128 (2/Pi)^Rational[1, 2] + 
        24752 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        24960 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        24960 E^150 (2/Pi)^Rational[1, 2] + 
        24752 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        24336 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        20736 E^168 (2/Pi)^Rational[1, 2] + 
        17424 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        14400 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        11664 E^182 (2/Pi)^Rational[1, 2] + 
        9216 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        7056 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        5184 E^192 (2/Pi)^Rational[1, 2] + 
        3600 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        2304 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        1296 E^198 (2/Pi)^Rational[1, 2] + 
        576 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        144 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 3906] 
       E^(-200) (189 E^200 + 1680 (2/Pi)^Rational[1, 2] + 
        3248 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        4704 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        6048 E^38 (2/Pi)^Rational[1, 2] + 
        7280 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        8400 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        9408 E^72 (2/Pi)^Rational[1, 2] + 
        10304 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        11088 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        11760 E^102 (2/Pi)^Rational[1, 2] + 
        12320 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        12768 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        13104 E^128 (2/Pi)^Rational[1, 2] + 
        13328 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        13440 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        13440 E^150 (2/Pi)^Rational[1, 2] + 
        13328 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        11492 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        9792 E^168 (2/Pi)^Rational[1, 2] + 
        8228 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        6800 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        5508 E^182 (2/Pi)^Rational[1, 2] + 
        4352 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        3332 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        2448 E^192 (2/Pi)^Rational[1, 2] + 
        1700 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        1088 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        612 E^198 (2/Pi)^Rational[1, 2] + 
        272 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        68 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-1, 1674] 
       E^(-200) (405 E^200 + 3600 (2/Pi)^Rational[1, 2] + 
        6960 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        10080 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        12960 E^38 (2/Pi)^Rational[1, 2] + 
        15600 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        18000 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        20160 E^72 (2/Pi)^Rational[1, 2] + 
        22080 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        23760 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        25200 E^102 (2/Pi)^Rational[1, 2] + 
        26400 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        27360 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        28080 E^128 (2/Pi)^Rational[1, 2] + 
        28560 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        28800 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        28800 E^150 (2/Pi)^Rational[1, 2] + 
        25088 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        21632 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        18432 E^168 (2/Pi)^Rational[1, 2] + 
        15488 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        12800 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        10368 E^182 (2/Pi)^Rational[1, 2] + 
        8192 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        6272 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        4608 E^192 (2/Pi)^Rational[1, 2] + 
        3200 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        2048 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        1152 E^198 (2/Pi)^Rational[1, 2] + 
        512 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        128 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 1116] 
       E^(-200) (480 2^Rational[1, 2] + 
        928 2^Rational[1, 2] E^Rational[118, 9] + 
        1344 2^Rational[1, 2] E^Rational[232, 9] + 1728 2^Rational[1, 2] E^38 + 
        2080 2^Rational[1, 2] E^Rational[448, 9] + 
        2400 2^Rational[1, 2] E^Rational[550, 9] + 2688 2^Rational[1, 2] E^72 + 
        2944 2^Rational[1, 2] E^Rational[742, 9] + 
        3168 2^Rational[1, 2] E^Rational[832, 9] + 
        3360 2^Rational[1, 2] E^102 + 
        3520 2^Rational[1, 2] E^Rational[1000, 9] + 
        3648 2^Rational[1, 2] E^Rational[1078, 9] + 
        3744 2^Rational[1, 2] E^128 + 
        3808 2^Rational[1, 2] E^Rational[1222, 9] + 
        3840 2^Rational[1, 2] E^Rational[1288, 9] + 
        3375 2^Rational[1, 2] E^150 + 
        2940 2^Rational[1, 2] E^Rational[1408, 9] + 
        2535 2^Rational[1, 2] E^Rational[1462, 9] + 
        2160 2^Rational[1, 2] E^168 + 
        1815 2^Rational[1, 2] E^Rational[1558, 9] + 
        1500 2^Rational[1, 2] E^Rational[1600, 9] + 
        1215 2^Rational[1, 2] E^182 + 
        960 2^Rational[1, 2] E^Rational[1672, 9] + 
        735 2^Rational[1, 2] E^Rational[1702, 9] + 540 2^Rational[1, 2] E^192 + 
        375 2^Rational[1, 2] E^Rational[1750, 9] + 
        240 2^Rational[1, 2] E^Rational[1768, 9] + 135 2^Rational[1, 2] E^198 + 
        60 2^Rational[1, 2] E^Rational[1792, 9] + 
        15 2^Rational[1, 2] E^Rational[1798, 9] + 54 E^200 Pi^Rational[1, 2]) 
       Pi^Rational[-1, 2]}, {
      Rational[-5, 9486] 
       E^(-200) (459 E^200 + 4080 (2/Pi)^Rational[1, 2] + 
        7888 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        11424 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        14688 E^38 (2/Pi)^Rational[1, 2] + 
        17680 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        20400 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        22848 E^72 (2/Pi)^Rational[1, 2] + 
        25024 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        26928 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        28560 E^102 (2/Pi)^Rational[1, 2] + 
        29920 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        31008 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        31824 E^128 (2/Pi)^Rational[1, 2] + 
        32368 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        28672 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        25200 E^150 (2/Pi)^Rational[1, 2] + 
        21952 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        18928 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        16128 E^168 (2/Pi)^Rational[1, 2] + 
        13552 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        11200 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        9072 E^182 (2/Pi)^Rational[1, 2] + 
        7168 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        5488 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        4032 E^192 (2/Pi)^Rational[1, 2] + 
        2800 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        1792 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        1008 E^198 (2/Pi)^Rational[1, 2] + 
        448 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        112 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 5022] 
       E^(-200) (243 E^200 + 2160 (2/Pi)^Rational[1, 2] + 
        4176 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        6048 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        7776 E^38 (2/Pi)^Rational[1, 2] + 
        9360 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        10800 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        12096 E^72 (2/Pi)^Rational[1, 2] + 
        13248 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        14256 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        15120 E^102 (2/Pi)^Rational[1, 2] + 
        15840 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        16416 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        16848 E^128 (2/Pi)^Rational[1, 2] + 
        15028 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        13312 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        11700 E^150 (2/Pi)^Rational[1, 2] + 
        10192 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        8788 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        7488 E^168 (2/Pi)^Rational[1, 2] + 
        6292 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        5200 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        4212 E^182 (2/Pi)^Rational[1, 2] + 
        3328 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        2548 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        1872 E^192 (2/Pi)^Rational[1, 2] + 
        1300 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        832 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        468 E^198 (2/Pi)^Rational[1, 2] + 
        208 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        52 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 10602] 
       E^(-200) (513 E^200 + 4560 (2/Pi)^Rational[1, 2] + 
        8816 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        12768 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        16416 E^38 (2/Pi)^Rational[1, 2] + 
        19760 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        22800 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        25536 E^72 (2/Pi)^Rational[1, 2] + 
        27968 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        30096 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        31920 E^102 (2/Pi)^Rational[1, 2] + 
        33440 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        34656 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        31104 E^128 (2/Pi)^Rational[1, 2] + 
        27744 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        24576 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        21600 E^150 (2/Pi)^Rational[1, 2] + 
        18816 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        16224 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        13824 E^168 (2/Pi)^Rational[1, 2] + 
        11616 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        9600 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        7776 E^182 (2/Pi)^Rational[1, 2] + 
        6144 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        4704 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        3456 E^192 (2/Pi)^Rational[1, 2] + 
        2400 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        1536 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        864 E^198 (2/Pi)^Rational[1, 2] + 
        384 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        96 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-1, 558] 
       E^(-200) (135 E^200 + 1200 (2/Pi)^Rational[1, 2] + 
        2320 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        3360 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        4320 E^38 (2/Pi)^Rational[1, 2] + 
        5200 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        6000 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        6720 E^72 (2/Pi)^Rational[1, 2] + 
        7360 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        7920 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        8400 E^102 (2/Pi)^Rational[1, 2] + 
        8800 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        7942 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        7128 E^128 (2/Pi)^Rational[1, 2] + 
        6358 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        5632 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        4950 E^150 (2/Pi)^Rational[1, 2] + 
        4312 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        3718 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        3168 E^168 (2/Pi)^Rational[1, 2] + 
        2662 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        2200 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        1782 E^182 (2/Pi)^Rational[1, 2] + 
        1408 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        1078 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        792 E^192 (2/Pi)^Rational[1, 2] + 
        550 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        352 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        198 E^198 (2/Pi)^Rational[1, 2] + 
        88 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        22 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 11718] 
       E^(-200) (567 E^200 + 5040 (2/Pi)^Rational[1, 2] + 
        9744 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        14112 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        18144 E^38 (2/Pi)^Rational[1, 2] + 
        21840 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        25200 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        28224 E^72 (2/Pi)^Rational[1, 2] + 
        30912 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        33264 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        35280 E^102 (2/Pi)^Rational[1, 2] + 
        32000 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        28880 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        25920 E^128 (2/Pi)^Rational[1, 2] + 
        23120 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        20480 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        18000 E^150 (2/Pi)^Rational[1, 2] + 
        15680 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        13520 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        11520 E^168 (2/Pi)^Rational[1, 2] + 
        9680 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        8000 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        6480 E^182 (2/Pi)^Rational[1, 2] + 
        5120 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        3920 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        2880 E^192 (2/Pi)^Rational[1, 2] + 
        2000 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        1280 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        720 E^198 (2/Pi)^Rational[1, 2] + 
        320 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        80 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 6138] 
       E^(-200) (297 E^200 + 2640 (2/Pi)^Rational[1, 2] + 
        5104 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        7392 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        9504 E^38 (2/Pi)^Rational[1, 2] + 
        11440 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        13200 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        14784 E^72 (2/Pi)^Rational[1, 2] + 
        16192 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        17424 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        15876 E^102 (2/Pi)^Rational[1, 2] + 
        14400 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        12996 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        11664 E^128 (2/Pi)^Rational[1, 2] + 
        10404 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        9216 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        8100 E^150 (2/Pi)^Rational[1, 2] + 
        7056 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        6084 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        5184 E^168 (2/Pi)^Rational[1, 2] + 
        4356 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        3600 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        2916 E^182 (2/Pi)^Rational[1, 2] + 
        2304 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        1764 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        1296 E^192 (2/Pi)^Rational[1, 2] + 
        900 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        576 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        324 E^198 (2/Pi)^Rational[1, 2] + 
        144 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        36 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 12834] 
       E^(-200) (621 E^200 + 5520 (2/Pi)^Rational[1, 2] + 
        10672 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        15456 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        19872 E^38 (2/Pi)^Rational[1, 2] + 
        23920 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        27600 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        30912 E^72 (2/Pi)^Rational[1, 2] + 
        33856 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        30976 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        28224 E^102 (2/Pi)^Rational[1, 2] + 
        25600 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        23104 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        20736 E^128 (2/Pi)^Rational[1, 2] + 
        18496 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        16384 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        14400 E^150 (2/Pi)^Rational[1, 2] + 
        12544 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        10816 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        9216 E^168 (2/Pi)^Rational[1, 2] + 
        7744 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        6400 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        5184 E^182 (2/Pi)^Rational[1, 2] + 
        4096 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        3136 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        2304 E^192 (2/Pi)^Rational[1, 2] + 
        1600 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        1024 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        576 E^198 (2/Pi)^Rational[1, 2] + 
        256 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        64 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 1674] 
       E^(-200) (720 2^Rational[1, 2] + 
        1392 2^Rational[1, 2] E^Rational[118, 9] + 
        2016 2^Rational[1, 2] E^Rational[232, 9] + 2592 2^Rational[1, 2] E^38 + 
        3120 2^Rational[1, 2] E^Rational[448, 9] + 
        3600 2^Rational[1, 2] E^Rational[550, 9] + 4032 2^Rational[1, 2] E^72 + 
        3703 2^Rational[1, 2] E^Rational[742, 9] + 
        3388 2^Rational[1, 2] E^Rational[832, 9] + 
        3087 2^Rational[1, 2] E^102 + 
        2800 2^Rational[1, 2] E^Rational[1000, 9] + 
        2527 2^Rational[1, 2] E^Rational[1078, 9] + 
        2268 2^Rational[1, 2] E^128 + 
        2023 2^Rational[1, 2] E^Rational[1222, 9] + 
        1792 2^Rational[1, 2] E^Rational[1288, 9] + 
        1575 2^Rational[1, 2] E^150 + 
        1372 2^Rational[1, 2] E^Rational[1408, 9] + 
        1183 2^Rational[1, 2] E^Rational[1462, 9] + 
        1008 2^Rational[1, 2] E^168 + 
        847 2^Rational[1, 2] E^Rational[1558, 9] + 
        700 2^Rational[1, 2] E^Rational[1600, 9] + 567 2^Rational[1, 2] E^182 + 
        448 2^Rational[1, 2] E^Rational[1672, 9] + 
        343 2^Rational[1, 2] E^Rational[1702, 9] + 252 2^Rational[1, 2] E^192 + 
        175 2^Rational[1, 2] E^Rational[1750, 9] + 
        112 2^Rational[1, 2] E^Rational[1768, 9] + 63 2^Rational[1, 2] E^198 + 
        28 2^Rational[1, 2] E^Rational[1792, 9] + 
        7 2^Rational[1, 2] E^Rational[1798, 9] + 81 E^200 Pi^Rational[1, 2]) 
       Pi^Rational[-1, 2]}, {
      Rational[-1, 2790] 
       E^(-200) (675 E^200 + 6000 (2/Pi)^Rational[1, 2] + 
        11600 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        16800 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        21600 E^38 (2/Pi)^Rational[1, 2] + 
        26000 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        30000 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        27648 E^72 (2/Pi)^Rational[1, 2] + 
        25392 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        23232 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        21168 E^102 (2/Pi)^Rational[1, 2] + 
        19200 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        17328 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        15552 E^128 (2/Pi)^Rational[1, 2] + 
        13872 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        12288 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        10800 E^150 (2/Pi)^Rational[1, 2] + 
        9408 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        8112 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        6912 E^168 (2/Pi)^Rational[1, 2] + 
        5808 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        4800 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        3888 E^182 (2/Pi)^Rational[1, 2] + 
        3072 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        2352 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        1728 E^192 (2/Pi)^Rational[1, 2] + 
        1200 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        768 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        432 E^198 (2/Pi)^Rational[1, 2] + 
        192 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        48 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 7254] 
       E^(-200) (351 E^200 + 3120 (2/Pi)^Rational[1, 2] + 
        6032 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        8736 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        11232 E^38 (2/Pi)^Rational[1, 2] + 
        13520 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        12500 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        11520 E^72 (2/Pi)^Rational[1, 2] + 
        10580 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        9680 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        8820 E^102 (2/Pi)^Rational[1, 2] + 
        8000 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        7220 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        6480 E^128 (2/Pi)^Rational[1, 2] + 
        5780 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        5120 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        4500 E^150 (2/Pi)^Rational[1, 2] + 
        3920 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        3380 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        2880 E^168 (2/Pi)^Rational[1, 2] + 
        2420 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        2000 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        1620 E^182 (2/Pi)^Rational[1, 2] + 
        1280 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        980 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        720 E^192 (2/Pi)^Rational[1, 2] + 
        500 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        320 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        180 E^198 (2/Pi)^Rational[1, 2] + 
        80 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        20 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 15066] 
       E^(-200) (729 E^200 + 6480 (2/Pi)^Rational[1, 2] + 
        12528 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        18144 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        23328 E^38 (2/Pi)^Rational[1, 2] + 
        21632 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        20000 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        18432 E^72 (2/Pi)^Rational[1, 2] + 
        16928 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        15488 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        14112 E^102 (2/Pi)^Rational[1, 2] + 
        12800 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        11552 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        10368 E^128 (2/Pi)^Rational[1, 2] + 
        9248 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        8192 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        7200 E^150 (2/Pi)^Rational[1, 2] + 
        6272 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        5408 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        4608 E^168 (2/Pi)^Rational[1, 2] + 
        3872 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        3200 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        2592 E^182 (2/Pi)^Rational[1, 2] + 
        2048 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        1568 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        1152 E^192 (2/Pi)^Rational[1, 2] + 
        800 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        512 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        288 E^198 (2/Pi)^Rational[1, 2] + 
        128 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        32 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 3906] 
       E^(-200) (189 E^200 + 1680 (2/Pi)^Rational[1, 2] + 
        3248 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        4704 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        4374 E^38 (2/Pi)^Rational[1, 2] + 
        4056 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        3750 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        3456 E^72 (2/Pi)^Rational[1, 2] + 
        3174 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        2904 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        2646 E^102 (2/Pi)^Rational[1, 2] + 
        2400 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        2166 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        1944 E^128 (2/Pi)^Rational[1, 2] + 
        1734 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        1536 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        1350 E^150 (2/Pi)^Rational[1, 2] + 
        1176 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        1014 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        864 E^168 (2/Pi)^Rational[1, 2] + 
        726 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        600 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        486 E^182 (2/Pi)^Rational[1, 2] + 
        384 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        294 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        216 E^192 (2/Pi)^Rational[1, 2] + 
        150 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        96 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        54 E^198 (2/Pi)^Rational[1, 2] + 
        24 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        6 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-5, 16182] 
       E^(-200) (783 E^200 + 6960 (2/Pi)^Rational[1, 2] + 
        13456 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        12544 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        11664 E^38 (2/Pi)^Rational[1, 2] + 
        10816 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        10000 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        9216 E^72 (2/Pi)^Rational[1, 2] + 
        8464 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        7744 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        7056 E^102 (2/Pi)^Rational[1, 2] + 
        6400 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        5776 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        5184 E^128 (2/Pi)^Rational[1, 2] + 
        4624 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        4096 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        3600 E^150 (2/Pi)^Rational[1, 2] + 
        3136 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        2704 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        2304 E^168 (2/Pi)^Rational[1, 2] + 
        1936 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        1600 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        1296 E^182 (2/Pi)^Rational[1, 2] + 
        1024 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        784 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        576 E^192 (2/Pi)^Rational[1, 2] + 
        400 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        256 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        144 E^198 (2/Pi)^Rational[1, 2] + 
        64 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        16 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}, {
      Rational[-1, 1674] 
       E^(-200) (405 E^200 + 3600 (2/Pi)^Rational[1, 2] + 
        3364 E^Rational[118, 9] (2/Pi)^Rational[1, 2] + 
        3136 E^Rational[232, 9] (2/Pi)^Rational[1, 2] + 
        2916 E^38 (2/Pi)^Rational[1, 2] + 
        2704 E^Rational[448, 9] (2/Pi)^Rational[1, 2] + 
        2500 E^Rational[550, 9] (2/Pi)^Rational[1, 2] + 
        2304 E^72 (2/Pi)^Rational[1, 2] + 
        2116 E^Rational[742, 9] (2/Pi)^Rational[1, 2] + 
        1936 E^Rational[832, 9] (2/Pi)^Rational[1, 2] + 
        1764 E^102 (2/Pi)^Rational[1, 2] + 
        1600 E^Rational[1000, 9] (2/Pi)^Rational[1, 2] + 
        1444 E^Rational[1078, 9] (2/Pi)^Rational[1, 2] + 
        1296 E^128 (2/Pi)^Rational[1, 2] + 
        1156 E^Rational[1222, 9] (2/Pi)^Rational[1, 2] + 
        1024 E^Rational[1288, 9] (2/Pi)^Rational[1, 2] + 
        900 E^150 (2/Pi)^Rational[1, 2] + 
        784 E^Rational[1408, 9] (2/Pi)^Rational[1, 2] + 
        676 E^Rational[1462, 9] (2/Pi)^Rational[1, 2] + 
        576 E^168 (2/Pi)^Rational[1, 2] + 
        484 E^Rational[1558, 9] (2/Pi)^Rational[1, 2] + 
        400 E^Rational[1600, 9] (2/Pi)^Rational[1, 2] + 
        324 E^182 (2/Pi)^Rational[1, 2] + 
        256 E^Rational[1672, 9] (2/Pi)^Rational[1, 2] + 
        196 E^Rational[1702, 9] (2/Pi)^Rational[1, 2] + 
        144 E^192 (2/Pi)^Rational[1, 2] + 
        100 E^Rational[1750, 9] (2/Pi)^Rational[1, 2] + 
        64 E^Rational[1768, 9] (2/Pi)^Rational[1, 2] + 
        36 E^198 (2/Pi)^Rational[1, 2] + 
        16 E^Rational[1792, 9] (2/Pi)^Rational[1, 2] + 
        4 E^Rational[1798, 9] (2/Pi)^Rational[1, 2])}}, {Automatic}],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   InterpretationBox[
    RowBox[{
     TagBox["InterpolatingFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]],
                 ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                None, BaseStyle -> {}, Evaluator -> Automatic, Method -> 
                "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}]], 
              GraphicsBox[{{
                 GrayLevel[0.6], 
                 AbsolutePointSize[5], 
                 PointBox[{1, 1}], 
                 PointBox[{2, 4}], 
                 PointBox[{3, 2}], 
                 PointBox[{4, 3}]}, {{}, {}, {
                  AbsoluteThickness[1], 
                  Opacity[1.], 
                  LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                   "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
               GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                 GrayLevel[0.7], 
                 Thickness[Tiny]], FrameTicks -> None, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}], PlotRange -> {{0, 5}, {0, 5}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "4"}], "}"}], "}"}], "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
            AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]],
                 ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, BaseStyle -> {}, Evaluator -> Automatic, Method -> 
                "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}]], 
              GraphicsBox[{{
                 GrayLevel[0.6], 
                 AbsolutePointSize[5], 
                 PointBox[{1, 1}], 
                 PointBox[{2, 4}], 
                 PointBox[{3, 2}], 
                 PointBox[{4, 3}]}, {{}, {}, {
                  AbsoluteThickness[1], 
                  Opacity[1.], 
                  LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                   "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
               GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                 GrayLevel[0.7], 
                 Thickness[Tiny]], FrameTicks -> None, ImageSize -> 
               Dynamic[{
                 Automatic, 
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}], PlotRange -> {{0, 5}, {0, 5}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "4"}], "}"}], "}"}], "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["1", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
            AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    InterpolatingFunction[{{0, 4}}, {
     5, 3, 0, {41}, {2}, 0, 0, 0, 0, Automatic, {}, {}, False}, {{0, 
       Rational[1, 10], 
       Rational[1, 5], 
       Rational[3, 10], 
       Rational[2, 5], 
       Rational[1, 2], 
       Rational[3, 5], 
       Rational[7, 10], 
       Rational[4, 5], 
       Rational[9, 10], 1, 
       Rational[11, 10], 
       Rational[6, 5], 
       Rational[13, 10], 
       Rational[7, 5], 
       Rational[3, 2], 
       Rational[8, 5], 
       Rational[17, 10], 
       Rational[9, 5], 
       Rational[19, 10], 2, 
       Rational[21, 10], 
       Rational[11, 5], 
       Rational[23, 10], 
       Rational[12, 5], 
       Rational[5, 2], 
       Rational[13, 5], 
       Rational[27, 10], 
       Rational[14, 5], 
       Rational[29, 10], 3, 
       Rational[31, 10], 
       Rational[16, 5], 
       Rational[33, 10], 
       Rational[17, 5], 
       Rational[7, 2], 
       Rational[18, 5], 
       Rational[37, 10], 
       Rational[19, 5], 
       Rational[39, 10], 4}}, {{
      Rational[-5, 984] E^Rational[-401, 2] 
       Pi^(-1) (48 E^Rational[401, 2] Pi + 
        468 E^Rational[83, 8] (2 Pi)^Rational[1, 2] + 
        684 E^20 (2 Pi)^Rational[1, 2] + 
        888 E^Rational[235, 8] (2 Pi)^Rational[1, 2] + 
        1080 E^Rational[77, 2] (2 Pi)^Rational[1, 2] + 
        1260 E^Rational[379, 8] (2 Pi)^Rational[1, 2] + 
        1428 E^56 (2 Pi)^Rational[1, 2] + 
        1584 E^Rational[515, 8] (2 Pi)^Rational[1, 2] + 
        1728 E^Rational[145, 2] (2 Pi)^Rational[1, 2] + 
        1860 E^Rational[643, 8] (2 Pi)^Rational[1, 2] + 
        1980 E^88 (2 Pi)^Rational[1, 2] + 
        2088 E^Rational[763, 8] (2 Pi)^Rational[1, 2] + 
        2184 E^Rational[205, 2] (2 Pi)^Rational[1, 2] + 
        2268 E^Rational[875, 8] (2 Pi)^Rational[1, 2] + 
        2340 E^116 (2 Pi)^Rational[1, 2] + 
        2400 E^Rational[979, 8] (2 Pi)^Rational[1, 2] + 
        2448 E^Rational[257, 2] (2 Pi)^Rational[1, 2] + 
        2484 E^Rational[1075, 8] (2 Pi)^Rational[1, 2] + 
        2508 E^140 (2 Pi)^Rational[1, 2] + 
        2520 E^Rational[1163, 8] (2 Pi)^Rational[1, 2] + 
        2520 E^Rational[301, 2] (2 Pi)^Rational[1, 2] + 
        2508 E^Rational[1243, 8] (2 Pi)^Rational[1, 2] + 
        2484 E^160 (2 Pi)^Rational[1, 2] + 
        2448 E^Rational[1315, 8] (2 Pi)^Rational[1, 2] + 
        2400 E^Rational[337, 2] (2 Pi)^Rational[1, 2] + 
        2340 E^Rational[1379, 8] (2 Pi)^Rational[1, 2] + 
        2268 E^176 (2 Pi)^Rational[1, 2] + 
        2184 E^Rational[1435, 8] (2 Pi)^Rational[1, 2] + 
        2088 E^Rational[365, 2] (2 Pi)^Rational[1, 2] + 
        1980 E^Rational[1483, 8] (2 Pi)^Rational[1, 2] + 
        1860 E^188 (2 Pi)^Rational[1, 2] + 
        1728 E^Rational[1523, 8] (2 Pi)^Rational[1, 2] + 
        1584 E^Rational[385, 2] (2 Pi)^Rational[1, 2] + 
        1428 E^Rational[1555, 8] (2 Pi)^Rational[1, 2] + 
        1260 E^196 (2 Pi)^Rational[1, 2] + 
        1080 E^Rational[1579, 8] (2 Pi)^Rational[1, 2] + 
        888 E^Rational[397, 2] (2 Pi)^Rational[1, 2] + 
        684 E^Rational[1595, 8] (2 Pi)^Rational[1, 2] + 
        468 E^200 (2 Pi)^Rational[1, 2] + 
        240 E^Rational[1603, 8] (2 Pi)^Rational[1, 2] + 
        41 E^Rational[401, 2] (2 Pi)^Rational[1, 2] + 
        240 (2 E Pi)^Rational[1, 2])}, {
      Rational[-5, 82] E^Rational[-401, 2] 
       Pi^Rational[-3, 2] (39 2^Rational[1, 2] E^Rational[83, 8] Pi + 
        57 2^Rational[1, 2] E^20 Pi + 
        74 2^Rational[1, 2] E^Rational[235, 8] Pi + 
        90 2^Rational[1, 2] E^Rational[77, 2] Pi + 
        105 2^Rational[1, 2] E^Rational[379, 8] Pi + 
        119 2^Rational[1, 2] E^56 Pi + 
        132 2^Rational[1, 2] E^Rational[515, 8] Pi + 
        144 2^Rational[1, 2] E^Rational[145, 2] Pi + 
        155 2^Rational[1, 2] E^Rational[643, 8] Pi + 
        165 2^Rational[1, 2] E^88 Pi + 
        174 2^Rational[1, 2] E^Rational[763, 8] Pi + 
        182 2^Rational[1, 2] E^Rational[205, 2] Pi + 
        189 2^Rational[1, 2] E^Rational[875, 8] Pi + 
        195 2^Rational[1, 2] E^116 Pi + 
        200 2^Rational[1, 2] E^Rational[979, 8] Pi + 
        204 2^Rational[1, 2] E^Rational[257, 2] Pi + 
        207 2^Rational[1, 2] E^Rational[1075, 8] Pi + 
        209 2^Rational[1, 2] E^140 Pi + 
        210 2^Rational[1, 2] E^Rational[1163, 8] Pi + 
        210 2^Rational[1, 2] E^Rational[301, 2] Pi + 
        209 2^Rational[1, 2] E^Rational[1243, 8] Pi + 
        207 2^Rational[1, 2] E^160 Pi + 
        204 2^Rational[1, 2] E^Rational[1315, 8] Pi + 
        200 2^Rational[1, 2] E^Rational[337, 2] Pi + 
        195 2^Rational[1, 2] E^Rational[1379, 8] Pi + 
        189 2^Rational[1, 2] E^176 Pi + 
        182 2^Rational[1, 2] E^Rational[1435, 8] Pi + 
        174 2^Rational[1, 2] E^Rational[365, 2] Pi + 
        165 2^Rational[1, 2] E^Rational[1483, 8] Pi + 
        155 2^Rational[1, 2] E^188 Pi + 
        144 2^Rational[1, 2] E^Rational[1523, 8] Pi + 
        132 2^Rational[1, 2] E^Rational[385, 2] Pi + 
        119 2^Rational[1, 2] E^Rational[1555, 8] Pi + 
        105 2^Rational[1, 2] E^196 Pi + 
        90 2^Rational[1, 2] E^Rational[1579, 8] Pi + 
        74 2^Rational[1, 2] E^Rational[397, 2] Pi + 
        57 2^Rational[1, 2] E^Rational[1595, 8] Pi + 
        39 2^Rational[1, 2] E^200 Pi + 
        20 2^Rational[1, 2] E^Rational[1603, 8] Pi + 
        20 (2 E)^Rational[1, 2] Pi + 
        4 E^Rational[401, 2] Pi^Rational[3, 2])}, {
      Rational[-5, 328] E^Rational[-401, 2] 
       Pi^Rational[-3, 2] (156 2^Rational[1, 2] E^Rational[83, 8] Pi + 
        228 2^Rational[1, 2] E^20 Pi + 
        296 2^Rational[1, 2] E^Rational[235, 8] Pi + 
        360 2^Rational[1, 2] E^Rational[77, 2] Pi + 
        420 2^Rational[1, 2] E^Rational[379, 8] Pi + 
        476 2^Rational[1, 2] E^56 Pi + 
        528 2^Rational[1, 2] E^Rational[515, 8] Pi + 
        576 2^Rational[1, 2] E^Rational[145, 2] Pi + 
        620 2^Rational[1, 2] E^Rational[643, 8] Pi + 
        660 2^Rational[1, 2] E^88 Pi + 
        696 2^Rational[1, 2] E^Rational[763, 8] Pi + 
        728 2^Rational[1, 2] E^Rational[205, 2] Pi + 
        756 2^Rational[1, 2] E^Rational[875, 8] Pi + 
        780 2^Rational[1, 2] E^116 Pi + 
        800 2^Rational[1, 2] E^Rational[979, 8] Pi + 
        816 2^Rational[1, 2] E^Rational[257, 2] Pi + 
        828 2^Rational[1, 2] E^Rational[1075, 8] Pi + 
        836 2^Rational[1, 2] E^140 Pi + 
        840 2^Rational[1, 2] E^Rational[1163, 8] Pi + 
        840 2^Rational[1, 2] E^Rational[301, 2] Pi + 
        836 2^Rational[1, 2] E^Rational[1243, 8] Pi + 
        828 2^Rational[1, 2] E^160 Pi + 
        816 2^Rational[1, 2] E^Rational[1315, 8] Pi + 
        800 2^Rational[1, 2] E^Rational[337, 2] Pi + 
        780 2^Rational[1, 2] E^Rational[1379, 8] Pi + 
        756 2^Rational[1, 2] E^176 Pi + 
        728 2^Rational[1, 2] E^Rational[1435, 8] Pi + 
        696 2^Rational[1, 2] E^Rational[365, 2] Pi + 
        660 2^Rational[1, 2] E^Rational[1483, 8] Pi + 
        620 2^Rational[1, 2] E^188 Pi + 
        576 2^Rational[1, 2] E^Rational[1523, 8] Pi + 
        528 2^Rational[1, 2] E^Rational[385, 2] Pi + 
        476 2^Rational[1, 2] E^Rational[1555, 8] Pi + 
        420 2^Rational[1, 2] E^196 Pi + 
        360 2^Rational[1, 2] E^Rational[1579, 8] Pi + 
        296 2^Rational[1, 2] E^Rational[397, 2] Pi + 
        228 2^Rational[1, 2] E^Rational[1595, 8] Pi + 
        156 2^Rational[1, 2] E^200 Pi + 
        39 2^Rational[1, 2] E^Rational[1603, 8] Pi + 
        80 (2 E)^Rational[1, 2] Pi + 
        16 E^Rational[401, 2] Pi^Rational[3, 2])}, {
      Rational[5, 246] E^(-200) 
       Pi^(-1) ((-12) E^200 Pi - 60 (2 Pi)^Rational[1, 2] - 117 
        E^Rational[79, 8] (2 Pi)^Rational[1, 2] - 171 
        E^Rational[39, 2] (2 Pi)^Rational[1, 2] - 222 
        E^Rational[231, 8] (2 Pi)^Rational[1, 2] - 270 
        E^38 (2 Pi)^Rational[1, 2] - 315 
        E^Rational[375, 8] (2 Pi)^Rational[1, 2] - 357 
        E^Rational[111, 2] (2 Pi)^Rational[1, 2] - 396 
        E^Rational[511, 8] (2 Pi)^Rational[1, 2] - 432 
        E^72 (2 Pi)^Rational[1, 2] - 465 
        E^Rational[639, 8] (2 Pi)^Rational[1, 2] - 495 
        E^Rational[175, 2] (2 Pi)^Rational[1, 2] - 522 
        E^Rational[759, 8] (2 Pi)^Rational[1, 2] - 546 
        E^102 (2 Pi)^Rational[1, 2] - 567 
        E^Rational[871, 8] (2 Pi)^Rational[1, 2] - 585 
        E^Rational[231, 2] (2 Pi)^Rational[1, 2] - 600 
        E^Rational[975, 8] (2 Pi)^Rational[1, 2] - 612 
        E^128 (2 Pi)^Rational[1, 2] - 621 
        E^Rational[1071, 8] (2 Pi)^Rational[1, 2] - 627 
        E^Rational[279, 2] (2 Pi)^Rational[1, 2] - 630 
        E^Rational[1159, 8] (2 Pi)^Rational[1, 2] - 630 
        E^150 (2 Pi)^Rational[1, 2] - 627 
        E^Rational[1239, 8] (2 Pi)^Rational[1, 2] - 621 
        E^Rational[319, 2] (2 Pi)^Rational[1, 2] - 612 
        E^Rational[1311, 8] (2 Pi)^Rational[1, 2] - 600 
        E^168 (2 Pi)^Rational[1, 2] - 585 
        E^Rational[1375, 8] (2 Pi)^Rational[1, 2] - 567 
        E^Rational[351, 2] (2 Pi)^Rational[1, 2] - 546 
        E^Rational[1431, 8] (2 Pi)^Rational[1, 2] - 522 
        E^182 (2 Pi)^Rational[1, 2] - 495 
        E^Rational[1479, 8] (2 Pi)^Rational[1, 2] - 465 
        E^Rational[375, 2] (2 Pi)^Rational[1, 2] - 432 
        E^Rational[1519, 8] (2 Pi)^Rational[1, 2] - 396 
        E^192 (2 Pi)^Rational[1, 2] - 357 
        E^Rational[1551, 8] (2 Pi)^Rational[1, 2] - 315 
        E^Rational[391, 2] (2 Pi)^Rational[1, 2] - 270 
        E^Rational[1575, 8] (2 Pi)^Rational[1, 2] - 222 
        E^198 (2 Pi)^Rational[1, 2] - 171 
        E^Rational[1591, 8] (2 Pi)^Rational[1, 2] - 76 
        E^Rational[399, 2] (2 Pi)^Rational[1, 2] - 19 
        E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[5, 656] E^(-200) 
       Pi^(-1) ((-32) E^200 Pi - 160 (2 Pi)^Rational[1, 2] - 312 
        E^Rational[79, 8] (2 Pi)^Rational[1, 2] - 456 
        E^Rational[39, 2] (2 Pi)^Rational[1, 2] - 592 
        E^Rational[231, 8] (2 Pi)^Rational[1, 2] - 720 
        E^38 (2 Pi)^Rational[1, 2] - 840 
        E^Rational[375, 8] (2 Pi)^Rational[1, 2] - 952 
        E^Rational[111, 2] (2 Pi)^Rational[1, 2] - 1056 
        E^Rational[511, 8] (2 Pi)^Rational[1, 2] - 1152 
        E^72 (2 Pi)^Rational[1, 2] - 1240 
        E^Rational[639, 8] (2 Pi)^Rational[1, 2] - 1320 
        E^Rational[175, 2] (2 Pi)^Rational[1, 2] - 1392 
        E^Rational[759, 8] (2 Pi)^Rational[1, 2] - 1456 
        E^102 (2 Pi)^Rational[1, 2] - 1512 
        E^Rational[871, 8] (2 Pi)^Rational[1, 2] - 1560 
        E^Rational[231, 2] (2 Pi)^Rational[1, 2] - 1600 
        E^Rational[975, 8] (2 Pi)^Rational[1, 2] - 1632 
        E^128 (2 Pi)^Rational[1, 2] - 1656 
        E^Rational[1071, 8] (2 Pi)^Rational[1, 2] - 1672 
        E^Rational[279, 2] (2 Pi)^Rational[1, 2] - 1680 
        E^Rational[1159, 8] (2 Pi)^Rational[1, 2] - 1680 
        E^150 (2 Pi)^Rational[1, 2] - 1672 
        E^Rational[1239, 8] (2 Pi)^Rational[1, 2] - 1656 
        E^Rational[319, 2] (2 Pi)^Rational[1, 2] - 1632 
        E^Rational[1311, 8] (2 Pi)^Rational[1, 2] - 1600 
        E^168 (2 Pi)^Rational[1, 2] - 1560 
        E^Rational[1375, 8] (2 Pi)^Rational[1, 2] - 1512 
        E^Rational[351, 2] (2 Pi)^Rational[1, 2] - 1456 
        E^Rational[1431, 8] (2 Pi)^Rational[1, 2] - 1392 
        E^182 (2 Pi)^Rational[1, 2] - 1320 
        E^Rational[1479, 8] (2 Pi)^Rational[1, 2] - 1240 
        E^Rational[375, 2] (2 Pi)^Rational[1, 2] - 1152 
        E^Rational[1519, 8] (2 Pi)^Rational[1, 2] - 1056 
        E^192 (2 Pi)^Rational[1, 2] - 952 
        E^Rational[1551, 8] (2 Pi)^Rational[1, 2] - 840 
        E^Rational[391, 2] (2 Pi)^Rational[1, 2] - 720 
        E^Rational[1575, 8] (2 Pi)^Rational[1, 2] - 592 
        E^198 (2 Pi)^Rational[1, 2] - 333 
        E^Rational[1591, 8] (2 Pi)^Rational[1, 2] - 148 
        E^Rational[399, 2] (2 Pi)^Rational[1, 2] - 37 
        E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[-1, 82] E^(-200) 
       Pi^(-1) (20 E^200 Pi + 100 (2 Pi)^Rational[1, 2] + 
        195 E^Rational[79, 8] (2 Pi)^Rational[1, 2] + 
        285 E^Rational[39, 2] (2 Pi)^Rational[1, 2] + 
        370 E^Rational[231, 8] (2 Pi)^Rational[1, 2] + 
        450 E^38 (2 Pi)^Rational[1, 2] + 
        525 E^Rational[375, 8] (2 Pi)^Rational[1, 2] + 
        595 E^Rational[111, 2] (2 Pi)^Rational[1, 2] + 
        660 E^Rational[511, 8] (2 Pi)^Rational[1, 2] + 
        720 E^72 (2 Pi)^Rational[1, 2] + 
        775 E^Rational[639, 8] (2 Pi)^Rational[1, 2] + 
        825 E^Rational[175, 2] (2 Pi)^Rational[1, 2] + 
        870 E^Rational[759, 8] (2 Pi)^Rational[1, 2] + 
        910 E^102 (2 Pi)^Rational[1, 2] + 
        945 E^Rational[871, 8] (2 Pi)^Rational[1, 2] + 
        975 E^Rational[231, 2] (2 Pi)^Rational[1, 2] + 
        1000 E^Rational[975, 8] (2 Pi)^Rational[1, 2] + 
        1020 E^128 (2 Pi)^Rational[1, 2] + 
        1035 E^Rational[1071, 8] (2 Pi)^Rational[1, 2] + 
        1045 E^Rational[279, 2] (2 Pi)^Rational[1, 2] + 
        1050 E^Rational[1159, 8] (2 Pi)^Rational[1, 2] + 
        1050 E^150 (2 Pi)^Rational[1, 2] + 
        1045 E^Rational[1239, 8] (2 Pi)^Rational[1, 2] + 
        1035 E^Rational[319, 2] (2 Pi)^Rational[1, 2] + 
        1020 E^Rational[1311, 8] (2 Pi)^Rational[1, 2] + 
        1000 E^168 (2 Pi)^Rational[1, 2] + 
        975 E^Rational[1375, 8] (2 Pi)^Rational[1, 2] + 
        945 E^Rational[351, 2] (2 Pi)^Rational[1, 2] + 
        910 E^Rational[1431, 8] (2 Pi)^Rational[1, 2] + 
        870 E^182 (2 Pi)^Rational[1, 2] + 
        825 E^Rational[1479, 8] (2 Pi)^Rational[1, 2] + 
        775 E^Rational[375, 2] (2 Pi)^Rational[1, 2] + 
        720 E^Rational[1519, 8] (2 Pi)^Rational[1, 2] + 
        660 E^192 (2 Pi)^Rational[1, 2] + 
        595 E^Rational[1551, 8] (2 Pi)^Rational[1, 2] + 
        525 E^Rational[391, 2] (2 Pi)^Rational[1, 2] + 
        450 E^Rational[1575, 8] (2 Pi)^Rational[1, 2] + 
        288 E^198 (2 Pi)^Rational[1, 2] + 
        162 E^Rational[1591, 8] (2 Pi)^Rational[1, 2] + 
        72 E^Rational[399, 2] (2 Pi)^Rational[1, 2] + 
        18 E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[-5, 984] E^Rational[-401, 2] 
       Pi^(-1) (48 E^Rational[401, 2] Pi + 
        468 E^Rational[83, 8] (2 Pi)^Rational[1, 2] + 
        684 E^20 (2 Pi)^Rational[1, 2] + 
        888 E^Rational[235, 8] (2 Pi)^Rational[1, 2] + 
        1080 E^Rational[77, 2] (2 Pi)^Rational[1, 2] + 
        1260 E^Rational[379, 8] (2 Pi)^Rational[1, 2] + 
        1428 E^56 (2 Pi)^Rational[1, 2] + 
        1584 E^Rational[515, 8] (2 Pi)^Rational[1, 2] + 
        1728 E^Rational[145, 2] (2 Pi)^Rational[1, 2] + 
        1860 E^Rational[643, 8] (2 Pi)^Rational[1, 2] + 
        1980 E^88 (2 Pi)^Rational[1, 2] + 
        2088 E^Rational[763, 8] (2 Pi)^Rational[1, 2] + 
        2184 E^Rational[205, 2] (2 Pi)^Rational[1, 2] + 
        2268 E^Rational[875, 8] (2 Pi)^Rational[1, 2] + 
        2340 E^116 (2 Pi)^Rational[1, 2] + 
        2400 E^Rational[979, 8] (2 Pi)^Rational[1, 2] + 
        2448 E^Rational[257, 2] (2 Pi)^Rational[1, 2] + 
        2484 E^Rational[1075, 8] (2 Pi)^Rational[1, 2] + 
        2508 E^140 (2 Pi)^Rational[1, 2] + 
        2520 E^Rational[1163, 8] (2 Pi)^Rational[1, 2] + 
        2520 E^Rational[301, 2] (2 Pi)^Rational[1, 2] + 
        2508 E^Rational[1243, 8] (2 Pi)^Rational[1, 2] + 
        2484 E^160 (2 Pi)^Rational[1, 2] + 
        2448 E^Rational[1315, 8] (2 Pi)^Rational[1, 2] + 
        2400 E^Rational[337, 2] (2 Pi)^Rational[1, 2] + 
        2340 E^Rational[1379, 8] (2 Pi)^Rational[1, 2] + 
        2268 E^176 (2 Pi)^Rational[1, 2] + 
        2184 E^Rational[1435, 8] (2 Pi)^Rational[1, 2] + 
        2088 E^Rational[365, 2] (2 Pi)^Rational[1, 2] + 
        1980 E^Rational[1483, 8] (2 Pi)^Rational[1, 2] + 
        1860 E^188 (2 Pi)^Rational[1, 2] + 
        1728 E^Rational[1523, 8] (2 Pi)^Rational[1, 2] + 
        1584 E^Rational[385, 2] (2 Pi)^Rational[1, 2] + 
        1428 E^Rational[1555, 8] (2 Pi)^Rational[1, 2] + 
        1260 E^196 (2 Pi)^Rational[1, 2] + 
        875 E^Rational[1579, 8] (2 Pi)^Rational[1, 2] + 
        560 E^Rational[397, 2] (2 Pi)^Rational[1, 2] + 
        315 E^Rational[1595, 8] (2 Pi)^Rational[1, 2] + 
        140 E^200 (2 Pi)^Rational[1, 2] + 
        35 E^Rational[1603, 8] (2 Pi)^Rational[1, 2] + 
        240 (2 E Pi)^Rational[1, 2])}, {
      Rational[5, 574] E^(-200) 
       Pi^(-1) ((-28) E^200 Pi - 140 (2 Pi)^Rational[1, 2] - 273 
        E^Rational[79, 8] (2 Pi)^Rational[1, 2] - 399 
        E^Rational[39, 2] (2 Pi)^Rational[1, 2] - 518 
        E^Rational[231, 8] (2 Pi)^Rational[1, 2] - 630 
        E^38 (2 Pi)^Rational[1, 2] - 735 
        E^Rational[375, 8] (2 Pi)^Rational[1, 2] - 833 
        E^Rational[111, 2] (2 Pi)^Rational[1, 2] - 924 
        E^Rational[511, 8] (2 Pi)^Rational[1, 2] - 1008 
        E^72 (2 Pi)^Rational[1, 2] - 1085 
        E^Rational[639, 8] (2 Pi)^Rational[1, 2] - 1155 
        E^Rational[175, 2] (2 Pi)^Rational[1, 2] - 1218 
        E^Rational[759, 8] (2 Pi)^Rational[1, 2] - 1274 
        E^102 (2 Pi)^Rational[1, 2] - 1323 
        E^Rational[871, 8] (2 Pi)^Rational[1, 2] - 1365 
        E^Rational[231, 2] (2 Pi)^Rational[1, 2] - 1400 
        E^Rational[975, 8] (2 Pi)^Rational[1, 2] - 1428 
        E^128 (2 Pi)^Rational[1, 2] - 1449 
        E^Rational[1071, 8] (2 Pi)^Rational[1, 2] - 1463 
        E^Rational[279, 2] (2 Pi)^Rational[1, 2] - 1470 
        E^Rational[1159, 8] (2 Pi)^Rational[1, 2] - 1470 
        E^150 (2 Pi)^Rational[1, 2] - 1463 
        E^Rational[1239, 8] (2 Pi)^Rational[1, 2] - 1449 
        E^Rational[319, 2] (2 Pi)^Rational[1, 2] - 1428 
        E^Rational[1311, 8] (2 Pi)^Rational[1, 2] - 1400 
        E^168 (2 Pi)^Rational[1, 2] - 1365 
        E^Rational[1375, 8] (2 Pi)^Rational[1, 2] - 1323 
        E^Rational[351, 2] (2 Pi)^Rational[1, 2] - 1274 
        E^Rational[1431, 8] (2 Pi)^Rational[1, 2] - 1218 
        E^182 (2 Pi)^Rational[1, 2] - 1155 
        E^Rational[1479, 8] (2 Pi)^Rational[1, 2] - 1085 
        E^Rational[375, 2] (2 Pi)^Rational[1, 2] - 1008 
        E^Rational[1519, 8] (2 Pi)^Rational[1, 2] - 924 
        E^192 (2 Pi)^Rational[1, 2] - 833 
        E^Rational[1551, 8] (2 Pi)^Rational[1, 2] - 612 
        E^Rational[391, 2] (2 Pi)^Rational[1, 2] - 425 
        E^Rational[1575, 8] (2 Pi)^Rational[1, 2] - 272 
        E^198 (2 Pi)^Rational[1, 2] - 153 
        E^Rational[1591, 8] (2 Pi)^Rational[1, 2] - 68 
        E^Rational[399, 2] (2 Pi)^Rational[1, 2] - 17 
        E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[5, 1312] E^(-200) 
       Pi^(-1) ((-64) E^200 Pi - 320 (2 Pi)^Rational[1, 2] - 624 
        E^Rational[79, 8] (2 Pi)^Rational[1, 2] - 912 
        E^Rational[39, 2] (2 Pi)^Rational[1, 2] - 1184 
        E^Rational[231, 8] (2 Pi)^Rational[1, 2] - 1440 
        E^38 (2 Pi)^Rational[1, 2] - 1680 
        E^Rational[375, 8] (2 Pi)^Rational[1, 2] - 1904 
        E^Rational[111, 2] (2 Pi)^Rational[1, 2] - 2112 
        E^Rational[511, 8] (2 Pi)^Rational[1, 2] - 2304 
        E^72 (2 Pi)^Rational[1, 2] - 2480 
        E^Rational[639, 8] (2 Pi)^Rational[1, 2] - 2640 
        E^Rational[175, 2] (2 Pi)^Rational[1, 2] - 2784 
        E^Rational[759, 8] (2 Pi)^Rational[1, 2] - 2912 
        E^102 (2 Pi)^Rational[1, 2] - 3024 
        E^Rational[871, 8] (2 Pi)^Rational[1, 2] - 3120 
        E^Rational[231, 2] (2 Pi)^Rational[1, 2] - 3200 
        E^Rational[975, 8] (2 Pi)^Rational[1, 2] - 3264 
        E^128 (2 Pi)^Rational[1, 2] - 3312 
        E^Rational[1071, 8] (2 Pi)^Rational[1, 2] - 3344 
        E^Rational[279, 2] (2 Pi)^Rational[1, 2] - 3360 
        E^Rational[1159, 8] (2 Pi)^Rational[1, 2] - 3360 
        E^150 (2 Pi)^Rational[1, 2] - 3344 
        E^Rational[1239, 8] (2 Pi)^Rational[1, 2] - 3312 
        E^Rational[319, 2] (2 Pi)^Rational[1, 2] - 3264 
        E^Rational[1311, 8] (2 Pi)^Rational[1, 2] - 3200 
        E^168 (2 Pi)^Rational[1, 2] - 3120 
        E^Rational[1375, 8] (2 Pi)^Rational[1, 2] - 3024 
        E^Rational[351, 2] (2 Pi)^Rational[1, 2] - 2912 
        E^Rational[1431, 8] (2 Pi)^Rational[1, 2] - 2784 
        E^182 (2 Pi)^Rational[1, 2] - 2640 
        E^Rational[1479, 8] (2 Pi)^Rational[1, 2] - 2480 
        E^Rational[375, 2] (2 Pi)^Rational[1, 2] - 2304 
        E^Rational[1519, 8] (2 Pi)^Rational[1, 2] - 2112 
        E^192 (2 Pi)^Rational[1, 2] - 1617 
        E^Rational[1551, 8] (2 Pi)^Rational[1, 2] - 1188 
        E^Rational[391, 2] (2 Pi)^Rational[1, 2] - 825 
        E^Rational[1575, 8] (2 Pi)^Rational[1, 2] - 528 
        E^198 (2 Pi)^Rational[1, 2] - 297 
        E^Rational[1591, 8] (2 Pi)^Rational[1, 2] - 132 
        E^Rational[399, 2] (2 Pi)^Rational[1, 2] - 33 
        E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[5, 738] E^(-200) 
       Pi^(-1) ((-36) E^200 Pi - 180 (2 Pi)^Rational[1, 2] - 351 
        E^Rational[79, 8] (2 Pi)^Rational[1, 2] - 513 
        E^Rational[39, 2] (2 Pi)^Rational[1, 2] - 666 
        E^Rational[231, 8] (2 Pi)^Rational[1, 2] - 810 
        E^38 (2 Pi)^Rational[1, 2] - 945 
        E^Rational[375, 8] (2 Pi)^Rational[1, 2] - 1071 
        E^Rational[111, 2] (2 Pi)^Rational[1, 2] - 1188 
        E^Rational[511, 8] (2 Pi)^Rational[1, 2] - 1296 
        E^72 (2 Pi)^Rational[1, 2] - 1395 
        E^Rational[639, 8] (2 Pi)^Rational[1, 2] - 1485 
        E^Rational[175, 2] (2 Pi)^Rational[1, 2] - 1566 
        E^Rational[759, 8] (2 Pi)^Rational[1, 2] - 1638 
        E^102 (2 Pi)^Rational[1, 2] - 1701 
        E^Rational[871, 8] (2 Pi)^Rational[1, 2] - 1755 
        E^Rational[231, 2] (2 Pi)^Rational[1, 2] - 1800 
        E^Rational[975, 8] (2 Pi)^Rational[1, 2] - 1836 
        E^128 (2 Pi)^Rational[1, 2] - 1863 
        E^Rational[1071, 8] (2 Pi)^Rational[1, 2] - 1881 
        E^Rational[279, 2] (2 Pi)^Rational[1, 2] - 1890 
        E^Rational[1159, 8] (2 Pi)^Rational[1, 2] - 1890 
        E^150 (2 Pi)^Rational[1, 2] - 1881 
        E^Rational[1239, 8] (2 Pi)^Rational[1, 2] - 1863 
        E^Rational[319, 2] (2 Pi)^Rational[1, 2] - 1836 
        E^Rational[1311, 8] (2 Pi)^Rational[1, 2] - 1800 
        E^168 (2 Pi)^Rational[1, 2] - 1755 
        E^Rational[1375, 8] (2 Pi)^Rational[1, 2] - 1701 
        E^Rational[351, 2] (2 Pi)^Rational[1, 2] - 1638 
        E^Rational[1431, 8] (2 Pi)^Rational[1, 2] - 1566 
        E^182 (2 Pi)^Rational[1, 2] - 1485 
        E^Rational[1479, 8] (2 Pi)^Rational[1, 2] - 1395 
        E^Rational[375, 2] (2 Pi)^Rational[1, 2] - 1296 
        E^Rational[1519, 8] (2 Pi)^Rational[1, 2] - 1024 
        E^192 (2 Pi)^Rational[1, 2] - 784 
        E^Rational[1551, 8] (2 Pi)^Rational[1, 2] - 576 
        E^Rational[391, 2] (2 Pi)^Rational[1, 2] - 400 
        E^Rational[1575, 8] (2 Pi)^Rational[1, 2] - 256 
        E^198 (2 Pi)^Rational[1, 2] - 144 
        E^Rational[1591, 8] (2 Pi)^Rational[1, 2] - 64 
        E^Rational[399, 2] (2 Pi)^Rational[1, 2] - 16 
        E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[-1, 328] E^Rational[-401, 2] 
       Pi^Rational[-3, 2] (780 2^Rational[1, 2] E^Rational[83, 8] Pi + 
        1140 2^Rational[1, 2] E^20 Pi + 
        1480 2^Rational[1, 2] E^Rational[235, 8] Pi + 
        1800 2^Rational[1, 2] E^Rational[77, 2] Pi + 
        2100 2^Rational[1, 2] E^Rational[379, 8] Pi + 
        2380 2^Rational[1, 2] E^56 Pi + 
        2640 2^Rational[1, 2] E^Rational[515, 8] Pi + 
        2880 2^Rational[1, 2] E^Rational[145, 2] Pi + 
        3100 2^Rational[1, 2] E^Rational[643, 8] Pi + 
        3300 2^Rational[1, 2] E^88 Pi + 
        3480 2^Rational[1, 2] E^Rational[763, 8] Pi + 
        3640 2^Rational[1, 2] E^Rational[205, 2] Pi + 
        3780 2^Rational[1, 2] E^Rational[875, 8] Pi + 
        3900 2^Rational[1, 2] E^116 Pi + 
        4000 2^Rational[1, 2] E^Rational[979, 8] Pi + 
        4080 2^Rational[1, 2] E^Rational[257, 2] Pi + 
        4140 2^Rational[1, 2] E^Rational[1075, 8] Pi + 
        4180 2^Rational[1, 2] E^140 Pi + 
        4200 2^Rational[1, 2] E^Rational[1163, 8] Pi + 
        4200 2^Rational[1, 2] E^Rational[301, 2] Pi + 
        4180 2^Rational[1, 2] E^Rational[1243, 8] Pi + 
        4140 2^Rational[1, 2] E^160 Pi + 
        4080 2^Rational[1, 2] E^Rational[1315, 8] Pi + 
        4000 2^Rational[1, 2] E^Rational[337, 2] Pi + 
        3900 2^Rational[1, 2] E^Rational[1379, 8] Pi + 
        3780 2^Rational[1, 2] E^176 Pi + 
        3640 2^Rational[1, 2] E^Rational[1435, 8] Pi + 
        3480 2^Rational[1, 2] E^Rational[365, 2] Pi + 
        3300 2^Rational[1, 2] E^Rational[1483, 8] Pi + 
        3100 2^Rational[1, 2] E^188 Pi + 
        2511 2^Rational[1, 2] E^Rational[1523, 8] Pi + 
        1984 2^Rational[1, 2] E^Rational[385, 2] Pi + 
        1519 2^Rational[1, 2] E^Rational[1555, 8] Pi + 
        1116 2^Rational[1, 2] E^196 Pi + 
        775 2^Rational[1, 2] E^Rational[1579, 8] Pi + 
        496 2^Rational[1, 2] E^Rational[397, 2] Pi + 
        279 2^Rational[1, 2] E^Rational[1595, 8] Pi + 
        124 2^Rational[1, 2] E^200 Pi + 
        31 2^Rational[1, 2] E^Rational[1603, 8] Pi + 
        400 (2 E)^Rational[1, 2] Pi + 
        80 E^Rational[401, 2] Pi^Rational[3, 2])}, {
      Rational[5, 902] E^(-200) 
       Pi^(-1) ((-44) E^200 Pi - 220 (2 Pi)^Rational[1, 2] - 429 
        E^Rational[79, 8] (2 Pi)^Rational[1, 2] - 627 
        E^Rational[39, 2] (2 Pi)^Rational[1, 2] - 814 
        E^Rational[231, 8] (2 Pi)^Rational[1, 2] - 990 
        E^38 (2 Pi)^Rational[1, 2] - 1155 
        E^Rational[375, 8] (2 Pi)^Rational[1, 2] - 1309 
        E^Rational[111, 2] (2 Pi)^Rational[1, 2] - 1452 
        E^Rational[511, 8] (2 Pi)^Rational[1, 2] - 1584 
        E^72 (2 Pi)^Rational[1, 2] - 1705 
        E^Rational[639, 8] (2 Pi)^Rational[1, 2] - 1815 
        E^Rational[175, 2] (2 Pi)^Rational[1, 2] - 1914 
        E^Rational[759, 8] (2 Pi)^Rational[1, 2] - 2002 
        E^102 (2 Pi)^Rational[1, 2] - 2079 
        E^Rational[871, 8] (2 Pi)^Rational[1, 2] - 2145 
        E^Rational[231, 2] (2 Pi)^Rational[1, 2] - 2200 
        E^Rational[975, 8] (2 Pi)^Rational[1, 2] - 2244 
        E^128 (2 Pi)^Rational[1, 2] - 2277 
        E^Rational[1071, 8] (2 Pi)^Rational[1, 2] - 2299 
        E^Rational[279, 2] (2 Pi)^Rational[1, 2] - 2310 
        E^Rational[1159, 8] (2 Pi)^Rational[1, 2] - 2310 
        E^150 (2 Pi)^Rational[1, 2] - 2299 
        E^Rational[1239, 8] (2 Pi)^Rational[1, 2] - 2277 
        E^Rational[319, 2] (2 Pi)^Rational[1, 2] - 2244 
        E^Rational[1311, 8] (2 Pi)^Rational[1, 2] - 2200 
        E^168 (2 Pi)^Rational[1, 2] - 2145 
        E^Rational[1375, 8] (2 Pi)^Rational[1, 2] - 2079 
        E^Rational[351, 2] (2 Pi)^Rational[1, 2] - 2002 
        E^Rational[1431, 8] (2 Pi)^Rational[1, 2] - 1914 
        E^182 (2 Pi)^Rational[1, 2] - 1815 
        E^Rational[1479, 8] (2 Pi)^Rational[1, 2] - 1500 
        E^Rational[375, 2] (2 Pi)^Rational[1, 2] - 1215 
        E^Rational[1519, 8] (2 Pi)^Rational[1, 2] - 960 
        E^192 (2 Pi)^Rational[1, 2] - 735 
        E^Rational[1551, 8] (2 Pi)^Rational[1, 2] - 540 
        E^Rational[391, 2] (2 Pi)^Rational[1, 2] - 375 
        E^Rational[1575, 8] (2 Pi)^Rational[1, 2] - 240 
        E^198 (2 Pi)^Rational[1, 2] - 135 
        E^Rational[1591, 8] (2 Pi)^Rational[1, 2] - 60 
        E^Rational[399, 2] (2 Pi)^Rational[1, 2] - 15 
        E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[5, 1968] E^(-200) 
       Pi^(-1) ((-96) E^200 Pi - 480 (2 Pi)^Rational[1, 2] - 936 
        E^Rational[79, 8] (2 Pi)^Rational[1, 2] - 1368 
        E^Rational[39, 2] (2 Pi)^Rational[1, 2] - 1776 
        E^Rational[231, 8] (2 Pi)^Rational[1, 2] - 2160 
        E^38 (2 Pi)^Rational[1, 2] - 2520 
        E^Rational[375, 8] (2 Pi)^Rational[1, 2] - 2856 
        E^Rational[111, 2] (2 Pi)^Rational[1, 2] - 3168 
        E^Rational[511, 8] (2 Pi)^Rational[1, 2] - 3456 
        E^72 (2 Pi)^Rational[1, 2] - 3720 
        E^Rational[639, 8] (2 Pi)^Rational[1, 2] - 3960 
        E^Rational[175, 2] (2 Pi)^Rational[1, 2] - 4176 
        E^Rational[759, 8] (2 Pi)^Rational[1, 2] - 4368 
        E^102 (2 Pi)^Rational[1, 2] - 4536 
        E^Rational[871, 8] (2 Pi)^Rational[1, 2] - 4680 
        E^Rational[231, 2] (2 Pi)^Rational[1, 2] - 4800 
        E^Rational[975, 8] (2 Pi)^Rational[1, 2] - 4896 
        E^128 (2 Pi)^Rational[1, 2] - 4968 
        E^Rational[1071, 8] (2 Pi)^Rational[1, 2] - 5016 
        E^Rational[279, 2] (2 Pi)^Rational[1, 2] - 5040 
        E^Rational[1159, 8] (2 Pi)^Rational[1, 2] - 5040 
        E^150 (2 Pi)^Rational[1, 2] - 5016 
        E^Rational[1239, 8] (2 Pi)^Rational[1, 2] - 4968 
        E^Rational[319, 2] (2 Pi)^Rational[1, 2] - 4896 
        E^Rational[1311, 8] (2 Pi)^Rational[1, 2] - 4800 
        E^168 (2 Pi)^Rational[1, 2] - 4680 
        E^Rational[1375, 8] (2 Pi)^Rational[1, 2] - 4536 
        E^Rational[351, 2] (2 Pi)^Rational[1, 2] - 4368 
        E^Rational[1431, 8] (2 Pi)^Rational[1, 2] - 4176 
        E^182 (2 Pi)^Rational[1, 2] - 3509 
        E^Rational[1479, 8] (2 Pi)^Rational[1, 2] - 2900 
        E^Rational[375, 2] (2 Pi)^Rational[1, 2] - 2349 
        E^Rational[1519, 8] (2 Pi)^Rational[1, 2] - 1856 
        E^192 (2 Pi)^Rational[1, 2] - 1421 
        E^Rational[1551, 8] (2 Pi)^Rational[1, 2] - 1044 
        E^Rational[391, 2] (2 Pi)^Rational[1, 2] - 725 
        E^Rational[1575, 8] (2 Pi)^Rational[1, 2] - 464 
        E^198 (2 Pi)^Rational[1, 2] - 261 
        E^Rational[1591, 8] (2 Pi)^Rational[1, 2] - 116 
        E^Rational[399, 2] (2 Pi)^Rational[1, 2] - 29 
        E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[-5, 1066] 
       E^(-200) (260 2^Rational[1, 2] + 
        507 2^Rational[1, 2] E^Rational[79, 8] + 
        741 2^Rational[1, 2] E^Rational[39, 2] + 
        962 2^Rational[1, 2] E^Rational[231, 8] + 1170 2^Rational[1, 2] E^38 + 
        1365 2^Rational[1, 2] E^Rational[375, 8] + 
        1547 2^Rational[1, 2] E^Rational[111, 2] + 
        1716 2^Rational[1, 2] E^Rational[511, 8] + 1872 2^Rational[1, 2] E^72 + 
        2015 2^Rational[1, 2] E^Rational[639, 8] + 
        2145 2^Rational[1, 2] E^Rational[175, 2] + 
        2262 2^Rational[1, 2] E^Rational[759, 8] + 
        2366 2^Rational[1, 2] E^102 + 
        2457 2^Rational[1, 2] E^Rational[871, 8] + 
        2535 2^Rational[1, 2] E^Rational[231, 2] + 
        2600 2^Rational[1, 2] E^Rational[975, 8] + 
        2652 2^Rational[1, 2] E^128 + 
        2691 2^Rational[1, 2] E^Rational[1071, 8] + 
        2717 2^Rational[1, 2] E^Rational[279, 2] + 
        2730 2^Rational[1, 2] E^Rational[1159, 8] + 
        2730 2^Rational[1, 2] E^150 + 
        2717 2^Rational[1, 2] E^Rational[1239, 8] + 
        2691 2^Rational[1, 2] E^Rational[319, 2] + 
        2652 2^Rational[1, 2] E^Rational[1311, 8] + 
        2600 2^Rational[1, 2] E^168 + 
        2535 2^Rational[1, 2] E^Rational[1375, 8] + 
        2457 2^Rational[1, 2] E^Rational[351, 2] + 
        2366 2^Rational[1, 2] E^Rational[1431, 8] + 
        2016 2^Rational[1, 2] E^182 + 
        1694 2^Rational[1, 2] E^Rational[1479, 8] + 
        1400 2^Rational[1, 2] E^Rational[375, 2] + 
        1134 2^Rational[1, 2] E^Rational[1519, 8] + 
        896 2^Rational[1, 2] E^192 + 686 2^Rational[1, 2] E^Rational[1551, 8] + 
        504 2^Rational[1, 2] E^Rational[391, 2] + 
        350 2^Rational[1, 2] E^Rational[1575, 8] + 224 2^Rational[1, 2] E^198 + 
        126 2^Rational[1, 2] E^Rational[1591, 8] + 
        56 2^Rational[1, 2] E^Rational[399, 2] + 
        14 2^Rational[1, 2] E^Rational[1599, 8] + 52 E^200 Pi^Rational[1, 2]) 
       Pi^Rational[-1, 2]}, {
      Rational[5, 2296] E^Rational[-401, 2] 
       Pi^Rational[-3, 2] ((-1092) 2^Rational[1, 2] E^Rational[83, 8] Pi - 
        1596 2^Rational[1, 2] E^20 Pi - 2072 2^Rational[1, 2] 
        E^Rational[235, 8] Pi - 2520 2^Rational[1, 2] E^Rational[77, 2] Pi - 
        2940 2^Rational[1, 2] E^Rational[379, 8] Pi - 3332 2^Rational[1, 2] 
        E^56 Pi - 3696 2^Rational[1, 2] E^Rational[515, 8] Pi - 4032 
        2^Rational[1, 2] E^Rational[145, 2] Pi - 4340 2^Rational[1, 2] 
        E^Rational[643, 8] Pi - 4620 2^Rational[1, 2] E^88 Pi - 4872 
        2^Rational[1, 2] E^Rational[763, 8] Pi - 5096 2^Rational[1, 2] 
        E^Rational[205, 2] Pi - 5292 2^Rational[1, 2] E^Rational[875, 8] Pi - 
        5460 2^Rational[1, 2] E^116 Pi - 5600 2^Rational[1, 2] 
        E^Rational[979, 8] Pi - 5712 2^Rational[1, 2] E^Rational[257, 2] Pi - 
        5796 2^Rational[1, 2] E^Rational[1075, 8] Pi - 5852 2^Rational[1, 2] 
        E^140 Pi - 5880 2^Rational[1, 2] E^Rational[1163, 8] Pi - 5880 
        2^Rational[1, 2] E^Rational[301, 2] Pi - 5852 2^Rational[1, 2] 
        E^Rational[1243, 8] Pi - 5796 2^Rational[1, 2] E^160 Pi - 5712 
        2^Rational[1, 2] E^Rational[1315, 8] Pi - 5600 2^Rational[1, 2] 
        E^Rational[337, 2] Pi - 5460 2^Rational[1, 2] E^Rational[1379, 8] Pi - 
        5292 2^Rational[1, 2] E^176 Pi - 4563 2^Rational[1, 2] 
        E^Rational[1435, 8] Pi - 3888 2^Rational[1, 2] E^Rational[365, 2] Pi - 
        3267 2^Rational[1, 2] E^Rational[1483, 8] Pi - 2700 2^Rational[1, 2] 
        E^188 Pi - 2187 2^Rational[1, 2] E^Rational[1523, 8] Pi - 1728 
        2^Rational[1, 2] E^Rational[385, 2] Pi - 1323 2^Rational[1, 2] 
        E^Rational[1555, 8] Pi - 972 2^Rational[1, 2] E^196 Pi - 675 
        2^Rational[1, 2] E^Rational[1579, 8] Pi - 432 2^Rational[1, 2] 
        E^Rational[397, 2] Pi - 243 2^Rational[1, 2] E^Rational[1595, 8] Pi - 
        108 2^Rational[1, 2] E^200 Pi - 27 2^Rational[1, 2] 
        E^Rational[1603, 8] Pi - 560 (2 E)^Rational[1, 2] Pi - 112 
        E^Rational[401, 2] Pi^Rational[3, 2])}, {
      Rational[-1, 246] E^(-200) 
       Pi^(-1) (60 E^200 Pi + 300 (2 Pi)^Rational[1, 2] + 
        585 E^Rational[79, 8] (2 Pi)^Rational[1, 2] + 
        855 E^Rational[39, 2] (2 Pi)^Rational[1, 2] + 
        1110 E^Rational[231, 8] (2 Pi)^Rational[1, 2] + 
        1350 E^38 (2 Pi)^Rational[1, 2] + 
        1575 E^Rational[375, 8] (2 Pi)^Rational[1, 2] + 
        1785 E^Rational[111, 2] (2 Pi)^Rational[1, 2] + 
        1980 E^Rational[511, 8] (2 Pi)^Rational[1, 2] + 
        2160 E^72 (2 Pi)^Rational[1, 2] + 
        2325 E^Rational[639, 8] (2 Pi)^Rational[1, 2] + 
        2475 E^Rational[175, 2] (2 Pi)^Rational[1, 2] + 
        2610 E^Rational[759, 8] (2 Pi)^Rational[1, 2] + 
        2730 E^102 (2 Pi)^Rational[1, 2] + 
        2835 E^Rational[871, 8] (2 Pi)^Rational[1, 2] + 
        2925 E^Rational[231, 2] (2 Pi)^Rational[1, 2] + 
        3000 E^Rational[975, 8] (2 Pi)^Rational[1, 2] + 
        3060 E^128 (2 Pi)^Rational[1, 2] + 
        3105 E^Rational[1071, 8] (2 Pi)^Rational[1, 2] + 
        3135 E^Rational[279, 2] (2 Pi)^Rational[1, 2] + 
        3150 E^Rational[1159, 8] (2 Pi)^Rational[1, 2] + 
        3150 E^150 (2 Pi)^Rational[1, 2] + 
        3135 E^Rational[1239, 8] (2 Pi)^Rational[1, 2] + 
        3105 E^Rational[319, 2] (2 Pi)^Rational[1, 2] + 
        3060 E^Rational[1311, 8] (2 Pi)^Rational[1, 2] + 
        3000 E^168 (2 Pi)^Rational[1, 2] + 
        2925 E^Rational[1375, 8] (2 Pi)^Rational[1, 2] + 
        2548 E^Rational[351, 2] (2 Pi)^Rational[1, 2] + 
        2197 E^Rational[1431, 8] (2 Pi)^Rational[1, 2] + 
        1872 E^182 (2 Pi)^Rational[1, 2] + 
        1573 E^Rational[1479, 8] (2 Pi)^Rational[1, 2] + 
        1300 E^Rational[375, 2] (2 Pi)^Rational[1, 2] + 
        1053 E^Rational[1519, 8] (2 Pi)^Rational[1, 2] + 
        832 E^192 (2 Pi)^Rational[1, 2] + 
        637 E^Rational[1551, 8] (2 Pi)^Rational[1, 2] + 
        468 E^Rational[391, 2] (2 Pi)^Rational[1, 2] + 
        325 E^Rational[1575, 8] (2 Pi)^Rational[1, 2] + 
        208 E^198 (2 Pi)^Rational[1, 2] + 
        117 E^Rational[1591, 8] (2 Pi)^Rational[1, 2] + 
        52 E^Rational[399, 2] (2 Pi)^Rational[1, 2] + 
        13 E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[5, 2624] E^(-200) 
       Pi^(-1) ((-128) E^200 Pi - 640 (2 Pi)^Rational[1, 2] - 1248 
        E^Rational[79, 8] (2 Pi)^Rational[1, 2] - 1824 
        E^Rational[39, 2] (2 Pi)^Rational[1, 2] - 2368 
        E^Rational[231, 8] (2 Pi)^Rational[1, 2] - 2880 
        E^38 (2 Pi)^Rational[1, 2] - 3360 
        E^Rational[375, 8] (2 Pi)^Rational[1, 2] - 3808 
        E^Rational[111, 2] (2 Pi)^Rational[1, 2] - 4224 
        E^Rational[511, 8] (2 Pi)^Rational[1, 2] - 4608 
        E^72 (2 Pi)^Rational[1, 2] - 4960 
        E^Rational[639, 8] (2 Pi)^Rational[1, 2] - 5280 
        E^Rational[175, 2] (2 Pi)^Rational[1, 2] - 5568 
        E^Rational[759, 8] (2 Pi)^Rational[1, 2] - 5824 
        E^102 (2 Pi)^Rational[1, 2] - 6048 
        E^Rational[871, 8] (2 Pi)^Rational[1, 2] - 6240 
        E^Rational[231, 2] (2 Pi)^Rational[1, 2] - 6400 
        E^Rational[975, 8] (2 Pi)^Rational[1, 2] - 6528 
        E^128 (2 Pi)^Rational[1, 2] - 6624 
        E^Rational[1071, 8] (2 Pi)^Rational[1, 2] - 6688 
        E^Rational[279, 2] (2 Pi)^Rational[1, 2] - 6720 
        E^Rational[1159, 8] (2 Pi)^Rational[1, 2] - 6720 
        E^150 (2 Pi)^Rational[1, 2] - 6688 
        E^Rational[1239, 8] (2 Pi)^Rational[1, 2] - 6624 
        E^Rational[319, 2] (2 Pi)^Rational[1, 2] - 6528 
        E^Rational[1311, 8] (2 Pi)^Rational[1, 2] - 6400 
        E^168 (2 Pi)^Rational[1, 2] - 5625 
        E^Rational[1375, 8] (2 Pi)^Rational[1, 2] - 4900 
        E^Rational[351, 2] (2 Pi)^Rational[1, 2] - 4225 
        E^Rational[1431, 8] (2 Pi)^Rational[1, 2] - 3600 
        E^182 (2 Pi)^Rational[1, 2] - 3025 
        E^Rational[1479, 8] (2 Pi)^Rational[1, 2] - 2500 
        E^Rational[375, 2] (2 Pi)^Rational[1, 2] - 2025 
        E^Rational[1519, 8] (2 Pi)^Rational[1, 2] - 1600 
        E^192 (2 Pi)^Rational[1, 2] - 1225 
        E^Rational[1551, 8] (2 Pi)^Rational[1, 2] - 900 
        E^Rational[391, 2] (2 Pi)^Rational[1, 2] - 625 
        E^Rational[1575, 8] (2 Pi)^Rational[1, 2] - 400 
        E^198 (2 Pi)^Rational[1, 2] - 225 
        E^Rational[1591, 8] (2 Pi)^Rational[1, 2] - 100 
        E^Rational[399, 2] (2 Pi)^Rational[1, 2] - 25 
        E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[-5, 1394] 
       E^(-200) (340 2^Rational[1, 2] + 
        663 2^Rational[1, 2] E^Rational[79, 8] + 
        969 2^Rational[1, 2] E^Rational[39, 2] + 
        1258 2^Rational[1, 2] E^Rational[231, 8] + 1530 2^Rational[1, 2] E^38 + 
        1785 2^Rational[1, 2] E^Rational[375, 8] + 
        2023 2^Rational[1, 2] E^Rational[111, 2] + 
        2244 2^Rational[1, 2] E^Rational[511, 8] + 2448 2^Rational[1, 2] E^72 + 
        2635 2^Rational[1, 2] E^Rational[639, 8] + 
        2805 2^Rational[1, 2] E^Rational[175, 2] + 
        2958 2^Rational[1, 2] E^Rational[759, 8] + 
        3094 2^Rational[1, 2] E^102 + 
        3213 2^Rational[1, 2] E^Rational[871, 8] + 
        3315 2^Rational[1, 2] E^Rational[231, 2] + 
        3400 2^Rational[1, 2] E^Rational[975, 8] + 
        3468 2^Rational[1, 2] E^128 + 
        3519 2^Rational[1, 2] E^Rational[1071, 8] + 
        3553 2^Rational[1, 2] E^Rational[279, 2] + 
        3570 2^Rational[1, 2] E^Rational[1159, 8] + 
        3570 2^Rational[1, 2] E^150 + 
        3553 2^Rational[1, 2] E^Rational[1239, 8] + 
        3519 2^Rational[1, 2] E^Rational[319, 2] + 
        3468 2^Rational[1, 2] E^Rational[1311, 8] + 
        3072 2^Rational[1, 2] E^168 + 
        2700 2^Rational[1, 2] E^Rational[1375, 8] + 
        2352 2^Rational[1, 2] E^Rational[351, 2] + 
        2028 2^Rational[1, 2] E^Rational[1431, 8] + 
        1728 2^Rational[1, 2] E^182 + 
        1452 2^Rational[1, 2] E^Rational[1479, 8] + 
        1200 2^Rational[1, 2] E^Rational[375, 2] + 
        972 2^Rational[1, 2] E^Rational[1519, 8] + 768 2^Rational[1, 2] E^192 + 
        588 2^Rational[1, 2] E^Rational[1551, 8] + 
        432 2^Rational[1, 2] E^Rational[391, 2] + 
        300 2^Rational[1, 2] E^Rational[1575, 8] + 192 2^Rational[1, 2] E^198 + 
        108 2^Rational[1, 2] E^Rational[1591, 8] + 
        48 2^Rational[1, 2] E^Rational[399, 2] + 
        12 2^Rational[1, 2] E^Rational[1599, 8] + 68 E^200 Pi^Rational[1, 2]) 
       Pi^Rational[-1, 2]}, {
      Rational[5, 2952] E^Rational[-401, 2] 
       Pi^Rational[-3, 2] ((-1404) 2^Rational[1, 2] E^Rational[83, 8] Pi - 
        2052 2^Rational[1, 2] E^20 Pi - 2664 2^Rational[1, 2] 
        E^Rational[235, 8] Pi - 3240 2^Rational[1, 2] E^Rational[77, 2] Pi - 
        3780 2^Rational[1, 2] E^Rational[379, 8] Pi - 4284 2^Rational[1, 2] 
        E^56 Pi - 4752 2^Rational[1, 2] E^Rational[515, 8] Pi - 5184 
        2^Rational[1, 2] E^Rational[145, 2] Pi - 5580 2^Rational[1, 2] 
        E^Rational[643, 8] Pi - 5940 2^Rational[1, 2] E^88 Pi - 6264 
        2^Rational[1, 2] E^Rational[763, 8] Pi - 6552 2^Rational[1, 2] 
        E^Rational[205, 2] Pi - 6804 2^Rational[1, 2] E^Rational[875, 8] Pi - 
        7020 2^Rational[1, 2] E^116 Pi - 7200 2^Rational[1, 2] 
        E^Rational[979, 8] Pi - 7344 2^Rational[1, 2] E^Rational[257, 2] Pi - 
        7452 2^Rational[1, 2] E^Rational[1075, 8] Pi - 7524 2^Rational[1, 2] 
        E^140 Pi - 7560 2^Rational[1, 2] E^Rational[1163, 8] Pi - 7560 
        2^Rational[1, 2] E^Rational[301, 2] Pi - 7524 2^Rational[1, 2] 
        E^Rational[1243, 8] Pi - 7452 2^Rational[1, 2] E^160 Pi - 6647 
        2^Rational[1, 2] E^Rational[1315, 8] Pi - 5888 2^Rational[1, 2] 
        E^Rational[337, 2] Pi - 5175 2^Rational[1, 2] E^Rational[1379, 8] Pi - 
        4508 2^Rational[1, 2] E^176 Pi - 3887 2^Rational[1, 2] 
        E^Rational[1435, 8] Pi - 3312 2^Rational[1, 2] E^Rational[365, 2] Pi - 
        2783 2^Rational[1, 2] E^Rational[1483, 8] Pi - 2300 2^Rational[1, 2] 
        E^188 Pi - 1863 2^Rational[1, 2] E^Rational[1523, 8] Pi - 1472 
        2^Rational[1, 2] E^Rational[385, 2] Pi - 1127 2^Rational[1, 2] 
        E^Rational[1555, 8] Pi - 828 2^Rational[1, 2] E^196 Pi - 575 
        2^Rational[1, 2] E^Rational[1579, 8] Pi - 368 2^Rational[1, 2] 
        E^Rational[397, 2] Pi - 207 2^Rational[1, 2] E^Rational[1595, 8] Pi - 
        92 2^Rational[1, 2] E^200 Pi - 23 2^Rational[1, 2] 
        E^Rational[1603, 8] Pi - 720 (2 E)^Rational[1, 2] Pi - 144 
        E^Rational[401, 2] Pi^Rational[3, 2])}, {
      Rational[5, 1558] E^(-200) 
       Pi^(-1) ((-76) E^200 Pi - 380 (2 Pi)^Rational[1, 2] - 741 
        E^Rational[79, 8] (2 Pi)^Rational[1, 2] - 1083 
        E^Rational[39, 2] (2 Pi)^Rational[1, 2] - 1406 
        E^Rational[231, 8] (2 Pi)^Rational[1, 2] - 1710 
        E^38 (2 Pi)^Rational[1, 2] - 1995 
        E^Rational[375, 8] (2 Pi)^Rational[1, 2] - 2261 
        E^Rational[111, 2] (2 Pi)^Rational[1, 2] - 2508 
        E^Rational[511, 8] (2 Pi)^Rational[1, 2] - 2736 
        E^72 (2 Pi)^Rational[1, 2] - 2945 
        E^Rational[639, 8] (2 Pi)^Rational[1, 2] - 3135 
        E^Rational[175, 2] (2 Pi)^Rational[1, 2] - 3306 
        E^Rational[759, 8] (2 Pi)^Rational[1, 2] - 3458 
        E^102 (2 Pi)^Rational[1, 2] - 3591 
        E^Rational[871, 8] (2 Pi)^Rational[1, 2] - 3705 
        E^Rational[231, 2] (2 Pi)^Rational[1, 2] - 3800 
        E^Rational[975, 8] (2 Pi)^Rational[1, 2] - 3876 
        E^128 (2 Pi)^Rational[1, 2] - 3933 
        E^Rational[1071, 8] (2 Pi)^Rational[1, 2] - 3971 
        E^Rational[279, 2] (2 Pi)^Rational[1, 2] - 3990 
        E^Rational[1159, 8] (2 Pi)^Rational[1, 2] - 3990 
        E^150 (2 Pi)^Rational[1, 2] - 3971 
        E^Rational[1239, 8] (2 Pi)^Rational[1, 2] - 3564 
        E^Rational[319, 2] (2 Pi)^Rational[1, 2] - 3179 
        E^Rational[1311, 8] (2 Pi)^Rational[1, 2] - 2816 
        E^168 (2 Pi)^Rational[1, 2] - 2475 
        E^Rational[1375, 8] (2 Pi)^Rational[1, 2] - 2156 
        E^Rational[351, 2] (2 Pi)^Rational[1, 2] - 1859 
        E^Rational[1431, 8] (2 Pi)^Rational[1, 2] - 1584 
        E^182 (2 Pi)^Rational[1, 2] - 1331 
        E^Rational[1479, 8] (2 Pi)^Rational[1, 2] - 1100 
        E^Rational[375, 2] (2 Pi)^Rational[1, 2] - 891 
        E^Rational[1519, 8] (2 Pi)^Rational[1, 2] - 704 
        E^192 (2 Pi)^Rational[1, 2] - 539 
        E^Rational[1551, 8] (2 Pi)^Rational[1, 2] - 396 
        E^Rational[391, 2] (2 Pi)^Rational[1, 2] - 275 
        E^Rational[1575, 8] (2 Pi)^Rational[1, 2] - 176 
        E^198 (2 Pi)^Rational[1, 2] - 99 
        E^Rational[1591, 8] (2 Pi)^Rational[1, 2] - 44 
        E^Rational[399, 2] (2 Pi)^Rational[1, 2] - 11 
        E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[-1, 656] E^(-200) 
       Pi^(-1) (160 E^200 Pi + 800 (2 Pi)^Rational[1, 2] + 
        1560 E^Rational[79, 8] (2 Pi)^Rational[1, 2] + 
        2280 E^Rational[39, 2] (2 Pi)^Rational[1, 2] + 
        2960 E^Rational[231, 8] (2 Pi)^Rational[1, 2] + 
        3600 E^38 (2 Pi)^Rational[1, 2] + 
        4200 E^Rational[375, 8] (2 Pi)^Rational[1, 2] + 
        4760 E^Rational[111, 2] (2 Pi)^Rational[1, 2] + 
        5280 E^Rational[511, 8] (2 Pi)^Rational[1, 2] + 
        5760 E^72 (2 Pi)^Rational[1, 2] + 
        6200 E^Rational[639, 8] (2 Pi)^Rational[1, 2] + 
        6600 E^Rational[175, 2] (2 Pi)^Rational[1, 2] + 
        6960 E^Rational[759, 8] (2 Pi)^Rational[1, 2] + 
        7280 E^102 (2 Pi)^Rational[1, 2] + 
        7560 E^Rational[871, 8] (2 Pi)^Rational[1, 2] + 
        7800 E^Rational[231, 2] (2 Pi)^Rational[1, 2] + 
        8000 E^Rational[975, 8] (2 Pi)^Rational[1, 2] + 
        8160 E^128 (2 Pi)^Rational[1, 2] + 
        8280 E^Rational[1071, 8] (2 Pi)^Rational[1, 2] + 
        8360 E^Rational[279, 2] (2 Pi)^Rational[1, 2] + 
        8400 E^Rational[1159, 8] (2 Pi)^Rational[1, 2] + 
        8400 E^150 (2 Pi)^Rational[1, 2] + 
        7581 E^Rational[1239, 8] (2 Pi)^Rational[1, 2] + 
        6804 E^Rational[319, 2] (2 Pi)^Rational[1, 2] + 
        6069 E^Rational[1311, 8] (2 Pi)^Rational[1, 2] + 
        5376 E^168 (2 Pi)^Rational[1, 2] + 
        4725 E^Rational[1375, 8] (2 Pi)^Rational[1, 2] + 
        4116 E^Rational[351, 2] (2 Pi)^Rational[1, 2] + 
        3549 E^Rational[1431, 8] (2 Pi)^Rational[1, 2] + 
        3024 E^182 (2 Pi)^Rational[1, 2] + 
        2541 E^Rational[1479, 8] (2 Pi)^Rational[1, 2] + 
        2100 E^Rational[375, 2] (2 Pi)^Rational[1, 2] + 
        1701 E^Rational[1519, 8] (2 Pi)^Rational[1, 2] + 
        1344 E^192 (2 Pi)^Rational[1, 2] + 
        1029 E^Rational[1551, 8] (2 Pi)^Rational[1, 2] + 
        756 E^Rational[391, 2] (2 Pi)^Rational[1, 2] + 
        525 E^Rational[1575, 8] (2 Pi)^Rational[1, 2] + 
        336 E^198 (2 Pi)^Rational[1, 2] + 
        189 E^Rational[1591, 8] (2 Pi)^Rational[1, 2] + 
        84 E^Rational[399, 2] (2 Pi)^Rational[1, 2] + 
        21 E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[-5, 1722] 
       E^(-200) (420 2^Rational[1, 2] + 
        819 2^Rational[1, 2] E^Rational[79, 8] + 
        1197 2^Rational[1, 2] E^Rational[39, 2] + 
        1554 2^Rational[1, 2] E^Rational[231, 8] + 1890 2^Rational[1, 2] E^38 + 
        2205 2^Rational[1, 2] E^Rational[375, 8] + 
        2499 2^Rational[1, 2] E^Rational[111, 2] + 
        2772 2^Rational[1, 2] E^Rational[511, 8] + 3024 2^Rational[1, 2] E^72 + 
        3255 2^Rational[1, 2] E^Rational[639, 8] + 
        3465 2^Rational[1, 2] E^Rational[175, 2] + 
        3654 2^Rational[1, 2] E^Rational[759, 8] + 
        3822 2^Rational[1, 2] E^102 + 
        3969 2^Rational[1, 2] E^Rational[871, 8] + 
        4095 2^Rational[1, 2] E^Rational[231, 2] + 
        4200 2^Rational[1, 2] E^Rational[975, 8] + 
        4284 2^Rational[1, 2] E^128 + 
        4347 2^Rational[1, 2] E^Rational[1071, 8] + 
        4389 2^Rational[1, 2] E^Rational[279, 2] + 
        4410 2^Rational[1, 2] E^Rational[1159, 8] + 
        4000 2^Rational[1, 2] E^150 + 
        3610 2^Rational[1, 2] E^Rational[1239, 8] + 
        3240 2^Rational[1, 2] E^Rational[319, 2] + 
        2890 2^Rational[1, 2] E^Rational[1311, 8] + 
        2560 2^Rational[1, 2] E^168 + 
        2250 2^Rational[1, 2] E^Rational[1375, 8] + 
        1960 2^Rational[1, 2] E^Rational[351, 2] + 
        1690 2^Rational[1, 2] E^Rational[1431, 8] + 
        1440 2^Rational[1, 2] E^182 + 
        1210 2^Rational[1, 2] E^Rational[1479, 8] + 
        1000 2^Rational[1, 2] E^Rational[375, 2] + 
        810 2^Rational[1, 2] E^Rational[1519, 8] + 640 2^Rational[1, 2] E^192 + 
        490 2^Rational[1, 2] E^Rational[1551, 8] + 
        360 2^Rational[1, 2] E^Rational[391, 2] + 
        250 2^Rational[1, 2] E^Rational[1575, 8] + 160 2^Rational[1, 2] E^198 + 
        90 2^Rational[1, 2] E^Rational[1591, 8] + 
        40 2^Rational[1, 2] E^Rational[399, 2] + 
        10 2^Rational[1, 2] E^Rational[1599, 8] + 84 E^200 Pi^Rational[1, 2]) 
       Pi^Rational[-1, 2]}, {
      Rational[5, 3608] E^Rational[-401, 2] 
       Pi^Rational[-3, 2] ((-1716) 2^Rational[1, 2] E^Rational[83, 8] Pi - 
        2508 2^Rational[1, 2] E^20 Pi - 3256 2^Rational[1, 2] 
        E^Rational[235, 8] Pi - 3960 2^Rational[1, 2] E^Rational[77, 2] Pi - 
        4620 2^Rational[1, 2] E^Rational[379, 8] Pi - 5236 2^Rational[1, 2] 
        E^56 Pi - 5808 2^Rational[1, 2] E^Rational[515, 8] Pi - 6336 
        2^Rational[1, 2] E^Rational[145, 2] Pi - 6820 2^Rational[1, 2] 
        E^Rational[643, 8] Pi - 7260 2^Rational[1, 2] E^88 Pi - 7656 
        2^Rational[1, 2] E^Rational[763, 8] Pi - 8008 2^Rational[1, 2] 
        E^Rational[205, 2] Pi - 8316 2^Rational[1, 2] E^Rational[875, 8] Pi - 
        8580 2^Rational[1, 2] E^116 Pi - 8800 2^Rational[1, 2] 
        E^Rational[979, 8] Pi - 8976 2^Rational[1, 2] E^Rational[257, 2] Pi - 
        9108 2^Rational[1, 2] E^Rational[1075, 8] Pi - 9196 2^Rational[1, 2] 
        E^140 Pi - 8379 2^Rational[1, 2] E^Rational[1163, 8] Pi - 7600 
        2^Rational[1, 2] E^Rational[301, 2] Pi - 6859 2^Rational[1, 2] 
        E^Rational[1243, 8] Pi - 6156 2^Rational[1, 2] E^160 Pi - 5491 
        2^Rational[1, 2] E^Rational[1315, 8] Pi - 4864 2^Rational[1, 2] 
        E^Rational[337, 2] Pi - 4275 2^Rational[1, 2] E^Rational[1379, 8] Pi - 
        3724 2^Rational[1, 2] E^176 Pi - 3211 2^Rational[1, 2] 
        E^Rational[1435, 8] Pi - 2736 2^Rational[1, 2] E^Rational[365, 2] Pi - 
        2299 2^Rational[1, 2] E^Rational[1483, 8] Pi - 1900 2^Rational[1, 2] 
        E^188 Pi - 1539 2^Rational[1, 2] E^Rational[1523, 8] Pi - 1216 
        2^Rational[1, 2] E^Rational[385, 2] Pi - 931 2^Rational[1, 2] 
        E^Rational[1555, 8] Pi - 684 2^Rational[1, 2] E^196 Pi - 475 
        2^Rational[1, 2] E^Rational[1579, 8] Pi - 304 2^Rational[1, 2] 
        E^Rational[397, 2] Pi - 171 2^Rational[1, 2] E^Rational[1595, 8] Pi - 
        76 2^Rational[1, 2] E^200 Pi - 19 2^Rational[1, 2] 
        E^Rational[1603, 8] Pi - 880 (2 E)^Rational[1, 2] Pi - 176 
        E^Rational[401, 2] Pi^Rational[3, 2])}, {
      Rational[5, 1886] E^(-200) 
       Pi^(-1) ((-92) E^200 Pi - 460 (2 Pi)^Rational[1, 2] - 897 
        E^Rational[79, 8] (2 Pi)^Rational[1, 2] - 1311 
        E^Rational[39, 2] (2 Pi)^Rational[1, 2] - 1702 
        E^Rational[231, 8] (2 Pi)^Rational[1, 2] - 2070 
        E^38 (2 Pi)^Rational[1, 2] - 2415 
        E^Rational[375, 8] (2 Pi)^Rational[1, 2] - 2737 
        E^Rational[111, 2] (2 Pi)^Rational[1, 2] - 3036 
        E^Rational[511, 8] (2 Pi)^Rational[1, 2] - 3312 
        E^72 (2 Pi)^Rational[1, 2] - 3565 
        E^Rational[639, 8] (2 Pi)^Rational[1, 2] - 3795 
        E^Rational[175, 2] (2 Pi)^Rational[1, 2] - 4002 
        E^Rational[759, 8] (2 Pi)^Rational[1, 2] - 4186 
        E^102 (2 Pi)^Rational[1, 2] - 4347 
        E^Rational[871, 8] (2 Pi)^Rational[1, 2] - 4485 
        E^Rational[231, 2] (2 Pi)^Rational[1, 2] - 4600 
        E^Rational[975, 8] (2 Pi)^Rational[1, 2] - 4692 
        E^128 (2 Pi)^Rational[1, 2] - 4761 
        E^Rational[1071, 8] (2 Pi)^Rational[1, 2] - 4356 
        E^Rational[279, 2] (2 Pi)^Rational[1, 2] - 3969 
        E^Rational[1159, 8] (2 Pi)^Rational[1, 2] - 3600 
        E^150 (2 Pi)^Rational[1, 2] - 3249 
        E^Rational[1239, 8] (2 Pi)^Rational[1, 2] - 2916 
        E^Rational[319, 2] (2 Pi)^Rational[1, 2] - 2601 
        E^Rational[1311, 8] (2 Pi)^Rational[1, 2] - 2304 
        E^168 (2 Pi)^Rational[1, 2] - 2025 
        E^Rational[1375, 8] (2 Pi)^Rational[1, 2] - 1764 
        E^Rational[351, 2] (2 Pi)^Rational[1, 2] - 1521 
        E^Rational[1431, 8] (2 Pi)^Rational[1, 2] - 1296 
        E^182 (2 Pi)^Rational[1, 2] - 1089 
        E^Rational[1479, 8] (2 Pi)^Rational[1, 2] - 900 
        E^Rational[375, 2] (2 Pi)^Rational[1, 2] - 729 
        E^Rational[1519, 8] (2 Pi)^Rational[1, 2] - 576 
        E^192 (2 Pi)^Rational[1, 2] - 441 
        E^Rational[1551, 8] (2 Pi)^Rational[1, 2] - 324 
        E^Rational[391, 2] (2 Pi)^Rational[1, 2] - 225 
        E^Rational[1575, 8] (2 Pi)^Rational[1, 2] - 144 
        E^198 (2 Pi)^Rational[1, 2] - 81 
        E^Rational[1591, 8] (2 Pi)^Rational[1, 2] - 36 
        E^Rational[399, 2] (2 Pi)^Rational[1, 2] - 9 
        E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[5, 3936] E^(-200) 
       Pi^(-1) ((-192) E^200 Pi - 960 (2 Pi)^Rational[1, 2] - 1872 
        E^Rational[79, 8] (2 Pi)^Rational[1, 2] - 2736 
        E^Rational[39, 2] (2 Pi)^Rational[1, 2] - 3552 
        E^Rational[231, 8] (2 Pi)^Rational[1, 2] - 4320 
        E^38 (2 Pi)^Rational[1, 2] - 5040 
        E^Rational[375, 8] (2 Pi)^Rational[1, 2] - 5712 
        E^Rational[111, 2] (2 Pi)^Rational[1, 2] - 6336 
        E^Rational[511, 8] (2 Pi)^Rational[1, 2] - 6912 
        E^72 (2 Pi)^Rational[1, 2] - 7440 
        E^Rational[639, 8] (2 Pi)^Rational[1, 2] - 7920 
        E^Rational[175, 2] (2 Pi)^Rational[1, 2] - 8352 
        E^Rational[759, 8] (2 Pi)^Rational[1, 2] - 8736 
        E^102 (2 Pi)^Rational[1, 2] - 9072 
        E^Rational[871, 8] (2 Pi)^Rational[1, 2] - 9360 
        E^Rational[231, 2] (2 Pi)^Rational[1, 2] - 9600 
        E^Rational[975, 8] (2 Pi)^Rational[1, 2] - 9792 
        E^128 (2 Pi)^Rational[1, 2] - 8993 
        E^Rational[1071, 8] (2 Pi)^Rational[1, 2] - 8228 
        E^Rational[279, 2] (2 Pi)^Rational[1, 2] - 7497 
        E^Rational[1159, 8] (2 Pi)^Rational[1, 2] - 6800 
        E^150 (2 Pi)^Rational[1, 2] - 6137 
        E^Rational[1239, 8] (2 Pi)^Rational[1, 2] - 5508 
        E^Rational[319, 2] (2 Pi)^Rational[1, 2] - 4913 
        E^Rational[1311, 8] (2 Pi)^Rational[1, 2] - 4352 
        E^168 (2 Pi)^Rational[1, 2] - 3825 
        E^Rational[1375, 8] (2 Pi)^Rational[1, 2] - 3332 
        E^Rational[351, 2] (2 Pi)^Rational[1, 2] - 2873 
        E^Rational[1431, 8] (2 Pi)^Rational[1, 2] - 2448 
        E^182 (2 Pi)^Rational[1, 2] - 2057 
        E^Rational[1479, 8] (2 Pi)^Rational[1, 2] - 1700 
        E^Rational[375, 2] (2 Pi)^Rational[1, 2] - 1377 
        E^Rational[1519, 8] (2 Pi)^Rational[1, 2] - 1088 
        E^192 (2 Pi)^Rational[1, 2] - 833 
        E^Rational[1551, 8] (2 Pi)^Rational[1, 2] - 612 
        E^Rational[391, 2] (2 Pi)^Rational[1, 2] - 425 
        E^Rational[1575, 8] (2 Pi)^Rational[1, 2] - 272 
        E^198 (2 Pi)^Rational[1, 2] - 153 
        E^Rational[1591, 8] (2 Pi)^Rational[1, 2] - 68 
        E^Rational[399, 2] (2 Pi)^Rational[1, 2] - 17 
        E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[-1, 410] 
       E^(-200) (500 2^Rational[1, 2] + 
        975 2^Rational[1, 2] E^Rational[79, 8] + 
        1425 2^Rational[1, 2] E^Rational[39, 2] + 
        1850 2^Rational[1, 2] E^Rational[231, 8] + 2250 2^Rational[1, 2] E^38 + 
        2625 2^Rational[1, 2] E^Rational[375, 8] + 
        2975 2^Rational[1, 2] E^Rational[111, 2] + 
        3300 2^Rational[1, 2] E^Rational[511, 8] + 3600 2^Rational[1, 2] E^72 + 
        3875 2^Rational[1, 2] E^Rational[639, 8] + 
        4125 2^Rational[1, 2] E^Rational[175, 2] + 
        4350 2^Rational[1, 2] E^Rational[759, 8] + 
        4550 2^Rational[1, 2] E^102 + 
        4725 2^Rational[1, 2] E^Rational[871, 8] + 
        4875 2^Rational[1, 2] E^Rational[231, 2] + 
        5000 2^Rational[1, 2] E^Rational[975, 8] + 
        4608 2^Rational[1, 2] E^128 + 
        4232 2^Rational[1, 2] E^Rational[1071, 8] + 
        3872 2^Rational[1, 2] E^Rational[279, 2] + 
        3528 2^Rational[1, 2] E^Rational[1159, 8] + 
        3200 2^Rational[1, 2] E^150 + 
        2888 2^Rational[1, 2] E^Rational[1239, 8] + 
        2592 2^Rational[1, 2] E^Rational[319, 2] + 
        2312 2^Rational[1, 2] E^Rational[1311, 8] + 
        2048 2^Rational[1, 2] E^168 + 
        1800 2^Rational[1, 2] E^Rational[1375, 8] + 
        1568 2^Rational[1, 2] E^Rational[351, 2] + 
        1352 2^Rational[1, 2] E^Rational[1431, 8] + 
        1152 2^Rational[1, 2] E^182 + 
        968 2^Rational[1, 2] E^Rational[1479, 8] + 
        800 2^Rational[1, 2] E^Rational[375, 2] + 
        648 2^Rational[1, 2] E^Rational[1519, 8] + 512 2^Rational[1, 2] E^192 + 
        392 2^Rational[1, 2] E^Rational[1551, 8] + 
        288 2^Rational[1, 2] E^Rational[391, 2] + 
        200 2^Rational[1, 2] E^Rational[1575, 8] + 128 2^Rational[1, 2] E^198 + 
        72 2^Rational[1, 2] E^Rational[1591, 8] + 
        32 2^Rational[1, 2] E^Rational[399, 2] + 
        8 2^Rational[1, 2] E^Rational[1599, 8] + 100 E^200 Pi^Rational[1, 2]) 
       Pi^Rational[-1, 2]}, {
      Rational[5, 4264] E^Rational[-401, 2] 
       Pi^Rational[-3, 2] ((-2028) 2^Rational[1, 2] E^Rational[83, 8] Pi - 
        2964 2^Rational[1, 2] E^20 Pi - 3848 2^Rational[1, 2] 
        E^Rational[235, 8] Pi - 4680 2^Rational[1, 2] E^Rational[77, 2] Pi - 
        5460 2^Rational[1, 2] E^Rational[379, 8] Pi - 6188 2^Rational[1, 2] 
        E^56 Pi - 6864 2^Rational[1, 2] E^Rational[515, 8] Pi - 7488 
        2^Rational[1, 2] E^Rational[145, 2] Pi - 8060 2^Rational[1, 2] 
        E^Rational[643, 8] Pi - 8580 2^Rational[1, 2] E^88 Pi - 9048 
        2^Rational[1, 2] E^Rational[763, 8] Pi - 9464 2^Rational[1, 2] 
        E^Rational[205, 2] Pi - 9828 2^Rational[1, 2] E^Rational[875, 8] Pi - 
        10140 2^Rational[1, 2] E^116 Pi - 9375 2^Rational[1, 2] 
        E^Rational[979, 8] Pi - 8640 2^Rational[1, 2] E^Rational[257, 2] Pi - 
        7935 2^Rational[1, 2] E^Rational[1075, 8] Pi - 7260 2^Rational[1, 2] 
        E^140 Pi - 6615 2^Rational[1, 2] E^Rational[1163, 8] Pi - 6000 
        2^Rational[1, 2] E^Rational[301, 2] Pi - 5415 2^Rational[1, 2] 
        E^Rational[1243, 8] Pi - 4860 2^Rational[1, 2] E^160 Pi - 4335 
        2^Rational[1, 2] E^Rational[1315, 8] Pi - 3840 2^Rational[1, 2] 
        E^Rational[337, 2] Pi - 3375 2^Rational[1, 2] E^Rational[1379, 8] Pi - 
        2940 2^Rational[1, 2] E^176 Pi - 2535 2^Rational[1, 2] 
        E^Rational[1435, 8] Pi - 2160 2^Rational[1, 2] E^Rational[365, 2] Pi - 
        1815 2^Rational[1, 2] E^Rational[1483, 8] Pi - 1500 2^Rational[1, 2] 
        E^188 Pi - 1215 2^Rational[1, 2] E^Rational[1523, 8] Pi - 960 
        2^Rational[1, 2] E^Rational[385, 2] Pi - 735 2^Rational[1, 2] 
        E^Rational[1555, 8] Pi - 540 2^Rational[1, 2] E^196 Pi - 375 
        2^Rational[1, 2] E^Rational[1579, 8] Pi - 240 2^Rational[1, 2] 
        E^Rational[397, 2] Pi - 135 2^Rational[1, 2] E^Rational[1595, 8] Pi - 
        60 2^Rational[1, 2] E^200 Pi - 15 2^Rational[1, 2] 
        E^Rational[1603, 8] Pi - 1040 (2 E)^Rational[1, 2] Pi - 208 
        E^Rational[401, 2] Pi^Rational[3, 2])}, {
      Rational[5, 2214] E^(-200) 
       Pi^(-1) ((-108) E^200 Pi - 540 (2 Pi)^Rational[1, 2] - 1053 
        E^Rational[79, 8] (2 Pi)^Rational[1, 2] - 1539 
        E^Rational[39, 2] (2 Pi)^Rational[1, 2] - 1998 
        E^Rational[231, 8] (2 Pi)^Rational[1, 2] - 2430 
        E^38 (2 Pi)^Rational[1, 2] - 2835 
        E^Rational[375, 8] (2 Pi)^Rational[1, 2] - 3213 
        E^Rational[111, 2] (2 Pi)^Rational[1, 2] - 3564 
        E^Rational[511, 8] (2 Pi)^Rational[1, 2] - 3888 
        E^72 (2 Pi)^Rational[1, 2] - 4185 
        E^Rational[639, 8] (2 Pi)^Rational[1, 2] - 4455 
        E^Rational[175, 2] (2 Pi)^Rational[1, 2] - 4698 
        E^Rational[759, 8] (2 Pi)^Rational[1, 2] - 4914 
        E^102 (2 Pi)^Rational[1, 2] - 5103 
        E^Rational[871, 8] (2 Pi)^Rational[1, 2] - 4732 
        E^Rational[231, 2] (2 Pi)^Rational[1, 2] - 4375 
        E^Rational[975, 8] (2 Pi)^Rational[1, 2] - 4032 
        E^128 (2 Pi)^Rational[1, 2] - 3703 
        E^Rational[1071, 8] (2 Pi)^Rational[1, 2] - 3388 
        E^Rational[279, 2] (2 Pi)^Rational[1, 2] - 3087 
        E^Rational[1159, 8] (2 Pi)^Rational[1, 2] - 2800 
        E^150 (2 Pi)^Rational[1, 2] - 2527 
        E^Rational[1239, 8] (2 Pi)^Rational[1, 2] - 2268 
        E^Rational[319, 2] (2 Pi)^Rational[1, 2] - 2023 
        E^Rational[1311, 8] (2 Pi)^Rational[1, 2] - 1792 
        E^168 (2 Pi)^Rational[1, 2] - 1575 
        E^Rational[1375, 8] (2 Pi)^Rational[1, 2] - 1372 
        E^Rational[351, 2] (2 Pi)^Rational[1, 2] - 1183 
        E^Rational[1431, 8] (2 Pi)^Rational[1, 2] - 1008 
        E^182 (2 Pi)^Rational[1, 2] - 847 
        E^Rational[1479, 8] (2 Pi)^Rational[1, 2] - 700 
        E^Rational[375, 2] (2 Pi)^Rational[1, 2] - 567 
        E^Rational[1519, 8] (2 Pi)^Rational[1, 2] - 448 
        E^192 (2 Pi)^Rational[1, 2] - 343 
        E^Rational[1551, 8] (2 Pi)^Rational[1, 2] - 252 
        E^Rational[391, 2] (2 Pi)^Rational[1, 2] - 175 
        E^Rational[1575, 8] (2 Pi)^Rational[1, 2] - 112 
        E^198 (2 Pi)^Rational[1, 2] - 63 
        E^Rational[1591, 8] (2 Pi)^Rational[1, 2] - 28 
        E^Rational[399, 2] (2 Pi)^Rational[1, 2] - 7 
        E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[-5, 4592] E^Rational[-401, 2] 
       Pi^(-1) (224 E^Rational[401, 2] Pi + 
        2184 E^Rational[83, 8] (2 Pi)^Rational[1, 2] + 
        3192 E^20 (2 Pi)^Rational[1, 2] + 
        4144 E^Rational[235, 8] (2 Pi)^Rational[1, 2] + 
        5040 E^Rational[77, 2] (2 Pi)^Rational[1, 2] + 
        5880 E^Rational[379, 8] (2 Pi)^Rational[1, 2] + 
        6664 E^56 (2 Pi)^Rational[1, 2] + 
        7392 E^Rational[515, 8] (2 Pi)^Rational[1, 2] + 
        8064 E^Rational[145, 2] (2 Pi)^Rational[1, 2] + 
        8680 E^Rational[643, 8] (2 Pi)^Rational[1, 2] + 
        9240 E^88 (2 Pi)^Rational[1, 2] + 
        9744 E^Rational[763, 8] (2 Pi)^Rational[1, 2] + 
        10192 E^Rational[205, 2] (2 Pi)^Rational[1, 2] + 
        9477 E^Rational[875, 8] (2 Pi)^Rational[1, 2] + 
        8788 E^116 (2 Pi)^Rational[1, 2] + 
        8125 E^Rational[979, 8] (2 Pi)^Rational[1, 2] + 
        7488 E^Rational[257, 2] (2 Pi)^Rational[1, 2] + 
        6877 E^Rational[1075, 8] (2 Pi)^Rational[1, 2] + 
        6292 E^140 (2 Pi)^Rational[1, 2] + 
        5733 E^Rational[1163, 8] (2 Pi)^Rational[1, 2] + 
        5200 E^Rational[301, 2] (2 Pi)^Rational[1, 2] + 
        4693 E^Rational[1243, 8] (2 Pi)^Rational[1, 2] + 
        4212 E^160 (2 Pi)^Rational[1, 2] + 
        3757 E^Rational[1315, 8] (2 Pi)^Rational[1, 2] + 
        3328 E^Rational[337, 2] (2 Pi)^Rational[1, 2] + 
        2925 E^Rational[1379, 8] (2 Pi)^Rational[1, 2] + 
        2548 E^176 (2 Pi)^Rational[1, 2] + 
        2197 E^Rational[1435, 8] (2 Pi)^Rational[1, 2] + 
        1872 E^Rational[365, 2] (2 Pi)^Rational[1, 2] + 
        1573 E^Rational[1483, 8] (2 Pi)^Rational[1, 2] + 
        1300 E^188 (2 Pi)^Rational[1, 2] + 
        1053 E^Rational[1523, 8] (2 Pi)^Rational[1, 2] + 
        832 E^Rational[385, 2] (2 Pi)^Rational[1, 2] + 
        637 E^Rational[1555, 8] (2 Pi)^Rational[1, 2] + 
        468 E^196 (2 Pi)^Rational[1, 2] + 
        325 E^Rational[1579, 8] (2 Pi)^Rational[1, 2] + 
        208 E^Rational[397, 2] (2 Pi)^Rational[1, 2] + 
        117 E^Rational[1595, 8] (2 Pi)^Rational[1, 2] + 
        52 E^200 (2 Pi)^Rational[1, 2] + 
        13 E^Rational[1603, 8] (2 Pi)^Rational[1, 2] + 
        1120 (2 E Pi)^Rational[1, 2])}, {
      Rational[-5, 2378] 
       E^(-200) (580 2^Rational[1, 2] + 
        1131 2^Rational[1, 2] E^Rational[79, 8] + 
        1653 2^Rational[1, 2] E^Rational[39, 2] + 
        2146 2^Rational[1, 2] E^Rational[231, 8] + 2610 2^Rational[1, 2] E^38 + 
        3045 2^Rational[1, 2] E^Rational[375, 8] + 
        3451 2^Rational[1, 2] E^Rational[111, 2] + 
        3828 2^Rational[1, 2] E^Rational[511, 8] + 4176 2^Rational[1, 2] E^72 + 
        4495 2^Rational[1, 2] E^Rational[639, 8] + 
        4785 2^Rational[1, 2] E^Rational[175, 2] + 
        5046 2^Rational[1, 2] E^Rational[759, 8] + 
        4704 2^Rational[1, 2] E^102 + 
        4374 2^Rational[1, 2] E^Rational[871, 8] + 
        4056 2^Rational[1, 2] E^Rational[231, 2] + 
        3750 2^Rational[1, 2] E^Rational[975, 8] + 
        3456 2^Rational[1, 2] E^128 + 
        3174 2^Rational[1, 2] E^Rational[1071, 8] + 
        2904 2^Rational[1, 2] E^Rational[279, 2] + 
        2646 2^Rational[1, 2] E^Rational[1159, 8] + 
        2400 2^Rational[1, 2] E^150 + 
        2166 2^Rational[1, 2] E^Rational[1239, 8] + 
        1944 2^Rational[1, 2] E^Rational[319, 2] + 
        1734 2^Rational[1, 2] E^Rational[1311, 8] + 
        1536 2^Rational[1, 2] E^168 + 
        1350 2^Rational[1, 2] E^Rational[1375, 8] + 
        1176 2^Rational[1, 2] E^Rational[351, 2] + 
        1014 2^Rational[1, 2] E^Rational[1431, 8] + 
        864 2^Rational[1, 2] E^182 + 726 2^Rational[1, 2] E^Rational[1479, 8] + 
        600 2^Rational[1, 2] E^Rational[375, 2] + 
        486 2^Rational[1, 2] E^Rational[1519, 8] + 384 2^Rational[1, 2] E^192 + 
        294 2^Rational[1, 2] E^Rational[1551, 8] + 
        216 2^Rational[1, 2] E^Rational[391, 2] + 
        150 2^Rational[1, 2] E^Rational[1575, 8] + 96 2^Rational[1, 2] E^198 + 
        54 2^Rational[1, 2] E^Rational[1591, 8] + 
        24 2^Rational[1, 2] E^Rational[399, 2] + 
        6 2^Rational[1, 2] E^Rational[1599, 8] + 116 E^200 Pi^Rational[1, 2]) 
       Pi^Rational[-1, 2]}, {
      Rational[-1, 984] E^Rational[-401, 2] 
       Pi^Rational[-3, 2] (2340 2^Rational[1, 2] E^Rational[83, 8] Pi + 
        3420 2^Rational[1, 2] E^20 Pi + 
        4440 2^Rational[1, 2] E^Rational[235, 8] Pi + 
        5400 2^Rational[1, 2] E^Rational[77, 2] Pi + 
        6300 2^Rational[1, 2] E^Rational[379, 8] Pi + 
        7140 2^Rational[1, 2] E^56 Pi + 
        7920 2^Rational[1, 2] E^Rational[515, 8] Pi + 
        8640 2^Rational[1, 2] E^Rational[145, 2] Pi + 
        9300 2^Rational[1, 2] E^Rational[643, 8] Pi + 
        9900 2^Rational[1, 2] E^88 Pi + 
        9251 2^Rational[1, 2] E^Rational[763, 8] Pi + 
        8624 2^Rational[1, 2] E^Rational[205, 2] Pi + 
        8019 2^Rational[1, 2] E^Rational[875, 8] Pi + 
        7436 2^Rational[1, 2] E^116 Pi + 
        6875 2^Rational[1, 2] E^Rational[979, 8] Pi + 
        6336 2^Rational[1, 2] E^Rational[257, 2] Pi + 
        5819 2^Rational[1, 2] E^Rational[1075, 8] Pi + 
        5324 2^Rational[1, 2] E^140 Pi + 
        4851 2^Rational[1, 2] E^Rational[1163, 8] Pi + 
        4400 2^Rational[1, 2] E^Rational[301, 2] Pi + 
        3971 2^Rational[1, 2] E^Rational[1243, 8] Pi + 
        3564 2^Rational[1, 2] E^160 Pi + 
        3179 2^Rational[1, 2] E^Rational[1315, 8] Pi + 
        2816 2^Rational[1, 2] E^Rational[337, 2] Pi + 
        2475 2^Rational[1, 2] E^Rational[1379, 8] Pi + 
        2156 2^Rational[1, 2] E^176 Pi + 
        1859 2^Rational[1, 2] E^Rational[1435, 8] Pi + 
        1584 2^Rational[1, 2] E^Rational[365, 2] Pi + 
        1331 2^Rational[1, 2] E^Rational[1483, 8] Pi + 
        1100 2^Rational[1, 2] E^188 Pi + 
        891 2^Rational[1, 2] E^Rational[1523, 8] Pi + 
        704 2^Rational[1, 2] E^Rational[385, 2] Pi + 
        539 2^Rational[1, 2] E^Rational[1555, 8] Pi + 
        396 2^Rational[1, 2] E^196 Pi + 
        275 2^Rational[1, 2] E^Rational[1579, 8] Pi + 
        176 2^Rational[1, 2] E^Rational[397, 2] Pi + 
        99 2^Rational[1, 2] E^Rational[1595, 8] Pi + 
        44 2^Rational[1, 2] E^200 Pi + 
        11 2^Rational[1, 2] E^Rational[1603, 8] Pi + 
        1200 (2 E)^Rational[1, 2] Pi + 
        240 E^Rational[401, 2] Pi^Rational[3, 2])}, {
      Rational[5, 2542] E^(-200) 
       Pi^(-1) ((-124) E^200 Pi - 620 (2 Pi)^Rational[1, 2] - 1209 
        E^Rational[79, 8] (2 Pi)^Rational[1, 2] - 1767 
        E^Rational[39, 2] (2 Pi)^Rational[1, 2] - 2294 
        E^Rational[231, 8] (2 Pi)^Rational[1, 2] - 2790 
        E^38 (2 Pi)^Rational[1, 2] - 3255 
        E^Rational[375, 8] (2 Pi)^Rational[1, 2] - 3689 
        E^Rational[111, 2] (2 Pi)^Rational[1, 2] - 4092 
        E^Rational[511, 8] (2 Pi)^Rational[1, 2] - 4464 
        E^72 (2 Pi)^Rational[1, 2] - 4805 
        E^Rational[639, 8] (2 Pi)^Rational[1, 2] - 4500 
        E^Rational[175, 2] (2 Pi)^Rational[1, 2] - 4205 
        E^Rational[759, 8] (2 Pi)^Rational[1, 2] - 3920 
        E^102 (2 Pi)^Rational[1, 2] - 3645 
        E^Rational[871, 8] (2 Pi)^Rational[1, 2] - 3380 
        E^Rational[231, 2] (2 Pi)^Rational[1, 2] - 3125 
        E^Rational[975, 8] (2 Pi)^Rational[1, 2] - 2880 
        E^128 (2 Pi)^Rational[1, 2] - 2645 
        E^Rational[1071, 8] (2 Pi)^Rational[1, 2] - 2420 
        E^Rational[279, 2] (2 Pi)^Rational[1, 2] - 2205 
        E^Rational[1159, 8] (2 Pi)^Rational[1, 2] - 2000 
        E^150 (2 Pi)^Rational[1, 2] - 1805 
        E^Rational[1239, 8] (2 Pi)^Rational[1, 2] - 1620 
        E^Rational[319, 2] (2 Pi)^Rational[1, 2] - 1445 
        E^Rational[1311, 8] (2 Pi)^Rational[1, 2] - 1280 
        E^168 (2 Pi)^Rational[1, 2] - 1125 
        E^Rational[1375, 8] (2 Pi)^Rational[1, 2] - 980 
        E^Rational[351, 2] (2 Pi)^Rational[1, 2] - 845 
        E^Rational[1431, 8] (2 Pi)^Rational[1, 2] - 720 
        E^182 (2 Pi)^Rational[1, 2] - 605 
        E^Rational[1479, 8] (2 Pi)^Rational[1, 2] - 500 
        E^Rational[375, 2] (2 Pi)^Rational[1, 2] - 405 
        E^Rational[1519, 8] (2 Pi)^Rational[1, 2] - 320 
        E^192 (2 Pi)^Rational[1, 2] - 245 
        E^Rational[1551, 8] (2 Pi)^Rational[1, 2] - 180 
        E^Rational[391, 2] (2 Pi)^Rational[1, 2] - 125 
        E^Rational[1575, 8] (2 Pi)^Rational[1, 2] - 80 
        E^198 (2 Pi)^Rational[1, 2] - 45 
        E^Rational[1591, 8] (2 Pi)^Rational[1, 2] - 20 
        E^Rational[399, 2] (2 Pi)^Rational[1, 2] - 5 
        E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[5, 5248] E^(-200) 
       Pi^(-1) ((-256) E^200 Pi - 1280 (2 Pi)^Rational[1, 2] - 2496 
        E^Rational[79, 8] (2 Pi)^Rational[1, 2] - 3648 
        E^Rational[39, 2] (2 Pi)^Rational[1, 2] - 4736 
        E^Rational[231, 8] (2 Pi)^Rational[1, 2] - 5760 
        E^38 (2 Pi)^Rational[1, 2] - 6720 
        E^Rational[375, 8] (2 Pi)^Rational[1, 2] - 7616 
        E^Rational[111, 2] (2 Pi)^Rational[1, 2] - 8448 
        E^Rational[511, 8] (2 Pi)^Rational[1, 2] - 9216 
        E^72 (2 Pi)^Rational[1, 2] - 8649 
        E^Rational[639, 8] (2 Pi)^Rational[1, 2] - 8100 
        E^Rational[175, 2] (2 Pi)^Rational[1, 2] - 7569 
        E^Rational[759, 8] (2 Pi)^Rational[1, 2] - 7056 
        E^102 (2 Pi)^Rational[1, 2] - 6561 
        E^Rational[871, 8] (2 Pi)^Rational[1, 2] - 6084 
        E^Rational[231, 2] (2 Pi)^Rational[1, 2] - 5625 
        E^Rational[975, 8] (2 Pi)^Rational[1, 2] - 5184 
        E^128 (2 Pi)^Rational[1, 2] - 4761 
        E^Rational[1071, 8] (2 Pi)^Rational[1, 2] - 4356 
        E^Rational[279, 2] (2 Pi)^Rational[1, 2] - 3969 
        E^Rational[1159, 8] (2 Pi)^Rational[1, 2] - 3600 
        E^150 (2 Pi)^Rational[1, 2] - 3249 
        E^Rational[1239, 8] (2 Pi)^Rational[1, 2] - 2916 
        E^Rational[319, 2] (2 Pi)^Rational[1, 2] - 2601 
        E^Rational[1311, 8] (2 Pi)^Rational[1, 2] - 2304 
        E^168 (2 Pi)^Rational[1, 2] - 2025 
        E^Rational[1375, 8] (2 Pi)^Rational[1, 2] - 1764 
        E^Rational[351, 2] (2 Pi)^Rational[1, 2] - 1521 
        E^Rational[1431, 8] (2 Pi)^Rational[1, 2] - 1296 
        E^182 (2 Pi)^Rational[1, 2] - 1089 
        E^Rational[1479, 8] (2 Pi)^Rational[1, 2] - 900 
        E^Rational[375, 2] (2 Pi)^Rational[1, 2] - 729 
        E^Rational[1519, 8] (2 Pi)^Rational[1, 2] - 576 
        E^192 (2 Pi)^Rational[1, 2] - 441 
        E^Rational[1551, 8] (2 Pi)^Rational[1, 2] - 324 
        E^Rational[391, 2] (2 Pi)^Rational[1, 2] - 225 
        E^Rational[1575, 8] (2 Pi)^Rational[1, 2] - 144 
        E^198 (2 Pi)^Rational[1, 2] - 81 
        E^Rational[1591, 8] (2 Pi)^Rational[1, 2] - 36 
        E^Rational[399, 2] (2 Pi)^Rational[1, 2] - 9 
        E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[-5, 2706] 
       E^(-200) (660 2^Rational[1, 2] + 
        1287 2^Rational[1, 2] E^Rational[79, 8] + 
        1881 2^Rational[1, 2] E^Rational[39, 2] + 
        2442 2^Rational[1, 2] E^Rational[231, 8] + 2970 2^Rational[1, 2] E^38 + 
        3465 2^Rational[1, 2] E^Rational[375, 8] + 
        3927 2^Rational[1, 2] E^Rational[111, 2] + 
        4356 2^Rational[1, 2] E^Rational[511, 8] + 4096 2^Rational[1, 2] E^72 + 
        3844 2^Rational[1, 2] E^Rational[639, 8] + 
        3600 2^Rational[1, 2] E^Rational[175, 2] + 
        3364 2^Rational[1, 2] E^Rational[759, 8] + 
        3136 2^Rational[1, 2] E^102 + 
        2916 2^Rational[1, 2] E^Rational[871, 8] + 
        2704 2^Rational[1, 2] E^Rational[231, 2] + 
        2500 2^Rational[1, 2] E^Rational[975, 8] + 
        2304 2^Rational[1, 2] E^128 + 
        2116 2^Rational[1, 2] E^Rational[1071, 8] + 
        1936 2^Rational[1, 2] E^Rational[279, 2] + 
        1764 2^Rational[1, 2] E^Rational[1159, 8] + 
        1600 2^Rational[1, 2] E^150 + 
        1444 2^Rational[1, 2] E^Rational[1239, 8] + 
        1296 2^Rational[1, 2] E^Rational[319, 2] + 
        1156 2^Rational[1, 2] E^Rational[1311, 8] + 
        1024 2^Rational[1, 2] E^168 + 
        900 2^Rational[1, 2] E^Rational[1375, 8] + 
        784 2^Rational[1, 2] E^Rational[351, 2] + 
        676 2^Rational[1, 2] E^Rational[1431, 8] + 576 2^Rational[1, 2] E^182 + 
        484 2^Rational[1, 2] E^Rational[1479, 8] + 
        400 2^Rational[1, 2] E^Rational[375, 2] + 
        324 2^Rational[1, 2] E^Rational[1519, 8] + 256 2^Rational[1, 2] E^192 + 
        196 2^Rational[1, 2] E^Rational[1551, 8] + 
        144 2^Rational[1, 2] E^Rational[391, 2] + 
        100 2^Rational[1, 2] E^Rational[1575, 8] + 64 2^Rational[1, 2] E^198 + 
        36 2^Rational[1, 2] E^Rational[1591, 8] + 
        16 2^Rational[1, 2] E^Rational[399, 2] + 
        4 2^Rational[1, 2] E^Rational[1599, 8] + 132 E^200 Pi^Rational[1, 2]) 
       Pi^Rational[-1, 2]}, {
      Rational[5, 5576] E^Rational[-401, 2] 
       Pi^Rational[-3, 2] ((-2652) 2^Rational[1, 2] E^Rational[83, 8] Pi - 
        3876 2^Rational[1, 2] E^20 Pi - 5032 2^Rational[1, 2] 
        E^Rational[235, 8] Pi - 6120 2^Rational[1, 2] E^Rational[77, 2] Pi - 
        7140 2^Rational[1, 2] E^Rational[379, 8] Pi - 8092 2^Rational[1, 2] 
        E^56 Pi - 7623 2^Rational[1, 2] E^Rational[515, 8] Pi - 7168 
        2^Rational[1, 2] E^Rational[145, 2] Pi - 6727 2^Rational[1, 2] 
        E^Rational[643, 8] Pi - 6300 2^Rational[1, 2] E^88 Pi - 5887 
        2^Rational[1, 2] E^Rational[763, 8] Pi - 5488 2^Rational[1, 2] 
        E^Rational[205, 2] Pi - 5103 2^Rational[1, 2] E^Rational[875, 8] Pi - 
        4732 2^Rational[1, 2] E^116 Pi - 4375 2^Rational[1, 2] 
        E^Rational[979, 8] Pi - 4032 2^Rational[1, 2] E^Rational[257, 2] Pi - 
        3703 2^Rational[1, 2] E^Rational[1075, 8] Pi - 3388 2^Rational[1, 2] 
        E^140 Pi - 3087 2^Rational[1, 2] E^Rational[1163, 8] Pi - 2800 
        2^Rational[1, 2] E^Rational[301, 2] Pi - 2527 2^Rational[1, 2] 
        E^Rational[1243, 8] Pi - 2268 2^Rational[1, 2] E^160 Pi - 2023 
        2^Rational[1, 2] E^Rational[1315, 8] Pi - 1792 2^Rational[1, 2] 
        E^Rational[337, 2] Pi - 1575 2^Rational[1, 2] E^Rational[1379, 8] Pi - 
        1372 2^Rational[1, 2] E^176 Pi - 1183 2^Rational[1, 2] 
        E^Rational[1435, 8] Pi - 1008 2^Rational[1, 2] E^Rational[365, 2] Pi - 
        847 2^Rational[1, 2] E^Rational[1483, 8] Pi - 700 2^Rational[1, 2] 
        E^188 Pi - 567 2^Rational[1, 2] E^Rational[1523, 8] Pi - 448 
        2^Rational[1, 2] E^Rational[385, 2] Pi - 343 2^Rational[1, 2] 
        E^Rational[1555, 8] Pi - 252 2^Rational[1, 2] E^196 Pi - 175 
        2^Rational[1, 2] E^Rational[1579, 8] Pi - 112 2^Rational[1, 2] 
        E^Rational[397, 2] Pi - 63 2^Rational[1, 2] E^Rational[1595, 8] Pi - 
        28 2^Rational[1, 2] E^200 Pi - 7 2^Rational[1, 2] E^Rational[1603, 8] 
        Pi - 1360 (2 E)^Rational[1, 2] Pi - 272 E^Rational[401, 2] 
        Pi^Rational[3, 2])}, {
      Rational[-1, 574] E^(-200) 
       Pi^(-1) (140 E^200 Pi + 700 (2 Pi)^Rational[1, 2] + 
        1365 E^Rational[79, 8] (2 Pi)^Rational[1, 2] + 
        1995 E^Rational[39, 2] (2 Pi)^Rational[1, 2] + 
        2590 E^Rational[231, 8] (2 Pi)^Rational[1, 2] + 
        3150 E^38 (2 Pi)^Rational[1, 2] + 
        3675 E^Rational[375, 8] (2 Pi)^Rational[1, 2] + 
        3468 E^Rational[111, 2] (2 Pi)^Rational[1, 2] + 
        3267 E^Rational[511, 8] (2 Pi)^Rational[1, 2] + 
        3072 E^72 (2 Pi)^Rational[1, 2] + 
        2883 E^Rational[639, 8] (2 Pi)^Rational[1, 2] + 
        2700 E^Rational[175, 2] (2 Pi)^Rational[1, 2] + 
        2523 E^Rational[759, 8] (2 Pi)^Rational[1, 2] + 
        2352 E^102 (2 Pi)^Rational[1, 2] + 
        2187 E^Rational[871, 8] (2 Pi)^Rational[1, 2] + 
        2028 E^Rational[231, 2] (2 Pi)^Rational[1, 2] + 
        1875 E^Rational[975, 8] (2 Pi)^Rational[1, 2] + 
        1728 E^128 (2 Pi)^Rational[1, 2] + 
        1587 E^Rational[1071, 8] (2 Pi)^Rational[1, 2] + 
        1452 E^Rational[279, 2] (2 Pi)^Rational[1, 2] + 
        1323 E^Rational[1159, 8] (2 Pi)^Rational[1, 2] + 
        1200 E^150 (2 Pi)^Rational[1, 2] + 
        1083 E^Rational[1239, 8] (2 Pi)^Rational[1, 2] + 
        972 E^Rational[319, 2] (2 Pi)^Rational[1, 2] + 
        867 E^Rational[1311, 8] (2 Pi)^Rational[1, 2] + 
        768 E^168 (2 Pi)^Rational[1, 2] + 
        675 E^Rational[1375, 8] (2 Pi)^Rational[1, 2] + 
        588 E^Rational[351, 2] (2 Pi)^Rational[1, 2] + 
        507 E^Rational[1431, 8] (2 Pi)^Rational[1, 2] + 
        432 E^182 (2 Pi)^Rational[1, 2] + 
        363 E^Rational[1479, 8] (2 Pi)^Rational[1, 2] + 
        300 E^Rational[375, 2] (2 Pi)^Rational[1, 2] + 
        243 E^Rational[1519, 8] (2 Pi)^Rational[1, 2] + 
        192 E^192 (2 Pi)^Rational[1, 2] + 
        147 E^Rational[1551, 8] (2 Pi)^Rational[1, 2] + 
        108 E^Rational[391, 2] (2 Pi)^Rational[1, 2] + 
        75 E^Rational[1575, 8] (2 Pi)^Rational[1, 2] + 
        48 E^198 (2 Pi)^Rational[1, 2] + 
        27 E^Rational[1591, 8] (2 Pi)^Rational[1, 2] + 
        12 E^Rational[399, 2] (2 Pi)^Rational[1, 2] + 
        3 E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[-5, 5904] E^Rational[-401, 2] 
       Pi^(-1) (288 E^Rational[401, 2] Pi + 
        2808 E^Rational[83, 8] (2 Pi)^Rational[1, 2] + 
        4104 E^20 (2 Pi)^Rational[1, 2] + 
        5328 E^Rational[235, 8] (2 Pi)^Rational[1, 2] + 
        6480 E^Rational[77, 2] (2 Pi)^Rational[1, 2] + 
        6125 E^Rational[379, 8] (2 Pi)^Rational[1, 2] + 
        5780 E^56 (2 Pi)^Rational[1, 2] + 
        5445 E^Rational[515, 8] (2 Pi)^Rational[1, 2] + 
        5120 E^Rational[145, 2] (2 Pi)^Rational[1, 2] + 
        4805 E^Rational[643, 8] (2 Pi)^Rational[1, 2] + 
        4500 E^88 (2 Pi)^Rational[1, 2] + 
        4205 E^Rational[763, 8] (2 Pi)^Rational[1, 2] + 
        3920 E^Rational[205, 2] (2 Pi)^Rational[1, 2] + 
        3645 E^Rational[875, 8] (2 Pi)^Rational[1, 2] + 
        3380 E^116 (2 Pi)^Rational[1, 2] + 
        3125 E^Rational[979, 8] (2 Pi)^Rational[1, 2] + 
        2880 E^Rational[257, 2] (2 Pi)^Rational[1, 2] + 
        2645 E^Rational[1075, 8] (2 Pi)^Rational[1, 2] + 
        2420 E^140 (2 Pi)^Rational[1, 2] + 
        2205 E^Rational[1163, 8] (2 Pi)^Rational[1, 2] + 
        2000 E^Rational[301, 2] (2 Pi)^Rational[1, 2] + 
        1805 E^Rational[1243, 8] (2 Pi)^Rational[1, 2] + 
        1620 E^160 (2 Pi)^Rational[1, 2] + 
        1445 E^Rational[1315, 8] (2 Pi)^Rational[1, 2] + 
        1280 E^Rational[337, 2] (2 Pi)^Rational[1, 2] + 
        1125 E^Rational[1379, 8] (2 Pi)^Rational[1, 2] + 
        980 E^176 (2 Pi)^Rational[1, 2] + 
        845 E^Rational[1435, 8] (2 Pi)^Rational[1, 2] + 
        720 E^Rational[365, 2] (2 Pi)^Rational[1, 2] + 
        605 E^Rational[1483, 8] (2 Pi)^Rational[1, 2] + 
        500 E^188 (2 Pi)^Rational[1, 2] + 
        405 E^Rational[1523, 8] (2 Pi)^Rational[1, 2] + 
        320 E^Rational[385, 2] (2 Pi)^Rational[1, 2] + 
        245 E^Rational[1555, 8] (2 Pi)^Rational[1, 2] + 
        180 E^196 (2 Pi)^Rational[1, 2] + 
        125 E^Rational[1579, 8] (2 Pi)^Rational[1, 2] + 
        80 E^Rational[397, 2] (2 Pi)^Rational[1, 2] + 
        45 E^Rational[1595, 8] (2 Pi)^Rational[1, 2] + 
        20 E^200 (2 Pi)^Rational[1, 2] + 
        5 E^Rational[1603, 8] (2 Pi)^Rational[1, 2] + 
        1440 (2 E Pi)^Rational[1, 2])}, {
      Rational[-5, 3034] 
       E^(-200) (740 2^Rational[1, 2] + 
        1443 2^Rational[1, 2] E^Rational[79, 8] + 
        2109 2^Rational[1, 2] E^Rational[39, 2] + 
        2738 2^Rational[1, 2] E^Rational[231, 8] + 2592 2^Rational[1, 2] E^38 + 
        2450 2^Rational[1, 2] E^Rational[375, 8] + 
        2312 2^Rational[1, 2] E^Rational[111, 2] + 
        2178 2^Rational[1, 2] E^Rational[511, 8] + 2048 2^Rational[1, 2] E^72 + 
        1922 2^Rational[1, 2] E^Rational[639, 8] + 
        1800 2^Rational[1, 2] E^Rational[175, 2] + 
        1682 2^Rational[1, 2] E^Rational[759, 8] + 
        1568 2^Rational[1, 2] E^102 + 
        1458 2^Rational[1, 2] E^Rational[871, 8] + 
        1352 2^Rational[1, 2] E^Rational[231, 2] + 
        1250 2^Rational[1, 2] E^Rational[975, 8] + 
        1152 2^Rational[1, 2] E^128 + 
        1058 2^Rational[1, 2] E^Rational[1071, 8] + 
        968 2^Rational[1, 2] E^Rational[279, 2] + 
        882 2^Rational[1, 2] E^Rational[1159, 8] + 800 2^Rational[1, 2] E^150 + 
        722 2^Rational[1, 2] E^Rational[1239, 8] + 
        648 2^Rational[1, 2] E^Rational[319, 2] + 
        578 2^Rational[1, 2] E^Rational[1311, 8] + 512 2^Rational[1, 2] E^168 + 
        450 2^Rational[1, 2] E^Rational[1375, 8] + 
        392 2^Rational[1, 2] E^Rational[351, 2] + 
        338 2^Rational[1, 2] E^Rational[1431, 8] + 288 2^Rational[1, 2] E^182 + 
        242 2^Rational[1, 2] E^Rational[1479, 8] + 
        200 2^Rational[1, 2] E^Rational[375, 2] + 
        162 2^Rational[1, 2] E^Rational[1519, 8] + 128 2^Rational[1, 2] E^192 + 
        98 2^Rational[1, 2] E^Rational[1551, 8] + 
        72 2^Rational[1, 2] E^Rational[391, 2] + 
        50 2^Rational[1, 2] E^Rational[1575, 8] + 32 2^Rational[1, 2] E^198 + 
        18 2^Rational[1, 2] E^Rational[1591, 8] + 
        8 2^Rational[1, 2] E^Rational[399, 2] + 
        2 2^Rational[1, 2] E^Rational[1599, 8] + 148 E^200 Pi^Rational[1, 2]) 
       Pi^Rational[-1, 2]}, {
      Rational[5, 6232] E^Rational[-401, 2] 
       Pi^Rational[-3, 2] ((-2964) 2^Rational[1, 2] E^Rational[83, 8] Pi - 
        4332 2^Rational[1, 2] E^20 Pi - 4107 2^Rational[1, 2] 
        E^Rational[235, 8] Pi - 3888 2^Rational[1, 2] E^Rational[77, 2] Pi - 
        3675 2^Rational[1, 2] E^Rational[379, 8] Pi - 3468 2^Rational[1, 2] 
        E^56 Pi - 3267 2^Rational[1, 2] E^Rational[515, 8] Pi - 3072 
        2^Rational[1, 2] E^Rational[145, 2] Pi - 2883 2^Rational[1, 2] 
        E^Rational[643, 8] Pi - 2700 2^Rational[1, 2] E^88 Pi - 2523 
        2^Rational[1, 2] E^Rational[763, 8] Pi - 2352 2^Rational[1, 2] 
        E^Rational[205, 2] Pi - 2187 2^Rational[1, 2] E^Rational[875, 8] Pi - 
        2028 2^Rational[1, 2] E^116 Pi - 1875 2^Rational[1, 2] 
        E^Rational[979, 8] Pi - 1728 2^Rational[1, 2] E^Rational[257, 2] Pi - 
        1587 2^Rational[1, 2] E^Rational[1075, 8] Pi - 1452 2^Rational[1, 2] 
        E^140 Pi - 1323 2^Rational[1, 2] E^Rational[1163, 8] Pi - 1200 
        2^Rational[1, 2] E^Rational[301, 2] Pi - 1083 2^Rational[1, 2] 
        E^Rational[1243, 8] Pi - 972 2^Rational[1, 2] E^160 Pi - 867 
        2^Rational[1, 2] E^Rational[1315, 8] Pi - 768 2^Rational[1, 2] 
        E^Rational[337, 2] Pi - 675 2^Rational[1, 2] E^Rational[1379, 8] Pi - 
        588 2^Rational[1, 2] E^176 Pi - 507 2^Rational[1, 2] 
        E^Rational[1435, 8] Pi - 432 2^Rational[1, 2] E^Rational[365, 2] Pi - 
        363 2^Rational[1, 2] E^Rational[1483, 8] Pi - 300 2^Rational[1, 2] 
        E^188 Pi - 243 2^Rational[1, 2] E^Rational[1523, 8] Pi - 192 
        2^Rational[1, 2] E^Rational[385, 2] Pi - 147 2^Rational[1, 2] 
        E^Rational[1555, 8] Pi - 108 2^Rational[1, 2] E^196 Pi - 75 
        2^Rational[1, 2] E^Rational[1579, 8] Pi - 48 2^Rational[1, 2] 
        E^Rational[397, 2] Pi - 27 2^Rational[1, 2] E^Rational[1595, 8] Pi - 
        12 2^Rational[1, 2] E^200 Pi - 3 2^Rational[1, 2] E^Rational[1603, 8] 
        Pi - 1520 (2 E)^Rational[1, 2] Pi - 304 E^Rational[401, 2] 
        Pi^Rational[3, 2])}, {
      Rational[5, 3198] E^(-200) 
       Pi^(-1) ((-156) E^200 Pi - 780 (2 Pi)^Rational[1, 2] - 1521 
        E^Rational[79, 8] (2 Pi)^Rational[1, 2] - 1444 
        E^Rational[39, 2] (2 Pi)^Rational[1, 2] - 1369 
        E^Rational[231, 8] (2 Pi)^Rational[1, 2] - 1296 
        E^38 (2 Pi)^Rational[1, 2] - 1225 
        E^Rational[375, 8] (2 Pi)^Rational[1, 2] - 1156 
        E^Rational[111, 2] (2 Pi)^Rational[1, 2] - 1089 
        E^Rational[511, 8] (2 Pi)^Rational[1, 2] - 1024 
        E^72 (2 Pi)^Rational[1, 2] - 961 
        E^Rational[639, 8] (2 Pi)^Rational[1, 2] - 900 
        E^Rational[175, 2] (2 Pi)^Rational[1, 2] - 841 
        E^Rational[759, 8] (2 Pi)^Rational[1, 2] - 784 
        E^102 (2 Pi)^Rational[1, 2] - 729 
        E^Rational[871, 8] (2 Pi)^Rational[1, 2] - 676 
        E^Rational[231, 2] (2 Pi)^Rational[1, 2] - 625 
        E^Rational[975, 8] (2 Pi)^Rational[1, 2] - 576 
        E^128 (2 Pi)^Rational[1, 2] - 529 
        E^Rational[1071, 8] (2 Pi)^Rational[1, 2] - 484 
        E^Rational[279, 2] (2 Pi)^Rational[1, 2] - 441 
        E^Rational[1159, 8] (2 Pi)^Rational[1, 2] - 400 
        E^150 (2 Pi)^Rational[1, 2] - 361 
        E^Rational[1239, 8] (2 Pi)^Rational[1, 2] - 324 
        E^Rational[319, 2] (2 Pi)^Rational[1, 2] - 289 
        E^Rational[1311, 8] (2 Pi)^Rational[1, 2] - 256 
        E^168 (2 Pi)^Rational[1, 2] - 225 
        E^Rational[1375, 8] (2 Pi)^Rational[1, 2] - 196 
        E^Rational[351, 2] (2 Pi)^Rational[1, 2] - 169 
        E^Rational[1431, 8] (2 Pi)^Rational[1, 2] - 144 
        E^182 (2 Pi)^Rational[1, 2] - 121 
        E^Rational[1479, 8] (2 Pi)^Rational[1, 2] - 100 
        E^Rational[375, 2] (2 Pi)^Rational[1, 2] - 81 
        E^Rational[1519, 8] (2 Pi)^Rational[1, 2] - 64 
        E^192 (2 Pi)^Rational[1, 2] - 49 
        E^Rational[1551, 8] (2 Pi)^Rational[1, 2] - 36 
        E^Rational[391, 2] (2 Pi)^Rational[1, 2] - 25 
        E^Rational[1575, 8] (2 Pi)^Rational[1, 2] - 16 
        E^198 (2 Pi)^Rational[1, 2] - 9 
        E^Rational[1591, 8] (2 Pi)^Rational[1, 2] - 4 
        E^Rational[399, 2] (2 Pi)^Rational[1, 2] - 
        E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}, {
      Rational[-1, 1312] E^(-200) 
       Pi^(-1) (320 E^200 Pi + 1600 (2 Pi)^Rational[1, 2] + 
        1521 E^Rational[79, 8] (2 Pi)^Rational[1, 2] + 
        1444 E^Rational[39, 2] (2 Pi)^Rational[1, 2] + 
        1369 E^Rational[231, 8] (2 Pi)^Rational[1, 2] + 
        1296 E^38 (2 Pi)^Rational[1, 2] + 
        1225 E^Rational[375, 8] (2 Pi)^Rational[1, 2] + 
        1156 E^Rational[111, 2] (2 Pi)^Rational[1, 2] + 
        1089 E^Rational[511, 8] (2 Pi)^Rational[1, 2] + 
        1024 E^72 (2 Pi)^Rational[1, 2] + 
        961 E^Rational[639, 8] (2 Pi)^Rational[1, 2] + 
        900 E^Rational[175, 2] (2 Pi)^Rational[1, 2] + 
        841 E^Rational[759, 8] (2 Pi)^Rational[1, 2] + 
        784 E^102 (2 Pi)^Rational[1, 2] + 
        729 E^Rational[871, 8] (2 Pi)^Rational[1, 2] + 
        676 E^Rational[231, 2] (2 Pi)^Rational[1, 2] + 
        625 E^Rational[975, 8] (2 Pi)^Rational[1, 2] + 
        576 E^128 (2 Pi)^Rational[1, 2] + 
        529 E^Rational[1071, 8] (2 Pi)^Rational[1, 2] + 
        484 E^Rational[279, 2] (2 Pi)^Rational[1, 2] + 
        441 E^Rational[1159, 8] (2 Pi)^Rational[1, 2] + 
        400 E^150 (2 Pi)^Rational[1, 2] + 
        361 E^Rational[1239, 8] (2 Pi)^Rational[1, 2] + 
        324 E^Rational[319, 2] (2 Pi)^Rational[1, 2] + 
        289 E^Rational[1311, 8] (2 Pi)^Rational[1, 2] + 
        256 E^168 (2 Pi)^Rational[1, 2] + 
        225 E^Rational[1375, 8] (2 Pi)^Rational[1, 2] + 
        196 E^Rational[351, 2] (2 Pi)^Rational[1, 2] + 
        169 E^Rational[1431, 8] (2 Pi)^Rational[1, 2] + 
        144 E^182 (2 Pi)^Rational[1, 2] + 
        121 E^Rational[1479, 8] (2 Pi)^Rational[1, 2] + 
        100 E^Rational[375, 2] (2 Pi)^Rational[1, 2] + 
        81 E^Rational[1519, 8] (2 Pi)^Rational[1, 2] + 
        64 E^192 (2 Pi)^Rational[1, 2] + 
        49 E^Rational[1551, 8] (2 Pi)^Rational[1, 2] + 
        36 E^Rational[391, 2] (2 Pi)^Rational[1, 2] + 
        25 E^Rational[1575, 8] (2 Pi)^Rational[1, 2] + 
        16 E^198 (2 Pi)^Rational[1, 2] + 
        9 E^Rational[1591, 8] (2 Pi)^Rational[1, 2] + 
        4 E^Rational[399, 2] (2 Pi)^Rational[1, 2] + 
        E^Rational[1599, 8] (2 Pi)^Rational[1, 2])}}, {Automatic}],
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   TagBox[
    TemplateBox[{
      RowBox[{
        StyleBox[
         TagBox["InterpolatingFunction", "SummaryHead"], 
         "NonInterpretableSummary"], 
        StyleBox["[", "NonInterpretableSummary"], 
        DynamicModuleBox[{
         Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
         TemplateBox[{
           TemplateBox[{
             PaneSelectorBox[{False -> GridBox[{{
                   PaneBox[
                    ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SummaryBoxOpener"]], 
                    ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                    None, BaseStyle -> {}, Evaluator -> Automatic, Method -> 
                    "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                   GraphicsBox[{{
                    GrayLevel[0.6], 
                    AbsolutePointSize[5], 
                    PointBox[{1, 1}], 
                    PointBox[{2, 4}], 
                    PointBox[{3, 2}], 
                    PointBox[{4, 3}]}, {{}, {}, {
                    AbsoluteThickness[1], 
                    Opacity[1.], 
                    LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                    "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
                    GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                    GrayLevel[0.7], 
                    Thickness[Tiny]], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRange -> {{0, 5}, {0, 5}}], 
                   GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "4"}], "}"}], "}"}], "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                    AutoDelete -> False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaselinePosition -> {1, 1}], True -> GridBox[{{
                   PaneBox[
                    ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SummaryBoxCloser"]], 
                    ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                    None, BaseStyle -> {}, Evaluator -> Automatic, Method -> 
                    "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                   GraphicsBox[{{
                    GrayLevel[0.6], 
                    AbsolutePointSize[5], 
                    PointBox[{1, 1}], 
                    PointBox[{2, 4}], 
                    PointBox[{3, 2}], 
                    PointBox[{4, 3}]}, {{}, {}, {
                    AbsoluteThickness[1], 
                    Opacity[1.], 
                    LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                    "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
                    GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                    GrayLevel[0.7], 
                    Thickness[Tiny]], FrameTicks -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], PlotRange -> {{0, 5}, {0, 5}}], 
                   GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "4"}], "}"}], "}"}], "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                    AutoDelete -> False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaselinePosition -> {1, 1}]}, 
              Dynamic[Typeset`open$$], ImageSize -> Automatic]}, 
            "SummaryPanel"], 
           ButtonBox[
            DynamicBox[
             ToBoxes[
              If[
               
               Or[$VersionNumber < 11.2, CurrentValue["RunningEvaluator"] =!= 
                "Local"], 
               Style["This object cannot be used as input.", "SummaryEmbed"], 
               
               BoxForm`EmbedSummaryLabel[InterpolatingFunction, 2340680, 
                Dynamic[Typeset`embedState$$], Automatic]], StandardForm]], 
            ButtonFunction :> 
            BoxForm`EmbedSummaryInterpretation[
             "Choose", InterpolatingFunction, 2340680, 
              5660660854482096352153235121796729905629399469336231805840, 
              EvaluationBox[], 
              Dynamic[Typeset`embedState$$], StandardForm, 
              ElisionsDump`embedSummaryBoxes], DefaultBaseStyle -> 
            "SummaryEmbedButton", ImageSize -> Inherited, 
            BaseStyle -> {"DialogStyle"}, Enabled -> Dynamic[
              
              And[$VersionNumber >= 11.2, CurrentValue["RunningEvaluator"] === 
               "Local", Typeset`embedState$$ === "Ready"]], Appearance -> 
            Inherited, Method -> Inherited, Evaluator -> Automatic]}, 
          "SummaryEmbedGrid"], DynamicModuleValues :> {}], 
        StyleBox["]", "NonInterpretableSummary"]}]},
     "CopyTag",
     DisplayFunction->(#& ),
     InterpretationFunction->("InterpolatingFunction[{{0, 4}}, <>]"& )],
    False,
    BoxID -> 5660660854482096352153235121796729905629399469336231805840,
    Editable->False,
    SelectWithContents->True,
    Selectable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.900181526805634*^9, 3.9001815369392433`*^9}, {
   3.900181570324953*^9, 3.900181597924633*^9}, 3.9001816283617277`*^9, 
   3.9001822822667027`*^9, 3.9001823174006157`*^9, {3.9001823567606087`*^9, 
   3.900182374863291*^9}, 3.9001824196866407`*^9, 3.9001824587769213`*^9, 
   3.900182718358657*^9, 3.900182791261917*^9, 3.900183022529275*^9, {
   3.9001832006151447`*^9, 3.900183228441175*^9}, {3.900183543753427*^9, 
   3.900183555706925*^9}, 3.90018455203522*^9, 3.900184612388008*^9, 
   3.900184817347617*^9, {3.90018489255787*^9, 3.900184898289254*^9}, 
   3.9001849416020403`*^9, 3.900185283456367*^9, 3.9001853767236433`*^9, 
   3.900230645254977*^9, 3.9002314865711317`*^9, 3.900232721383389*^9, 
   3.900233037349244*^9, 3.9002400033333273`*^9, 3.901375377313758*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"bb30d088-b0c2-4b63-8d6b-1f7eae9ff08b"]
}, Open  ]],

Cell["Tests of the code - compare w analytics  + convergence tests", "Text",
 CellChangeTimes->{{3.9001816297782173`*^9, 3.9001816390880947`*^9}, {
  3.900182377573483*^9, 3.9001823835235443`*^9}, {3.900182796811309*^9, 
  3.900182872269912*^9}, {3.900183043952875*^9, 3.900183044387998*^9}, {
  3.900183233379615*^9, 3.900183281741951*^9}, {3.900183369135285*^9, 
  3.900183382985553*^9}, {3.900183579016501*^9, 3.900183615355852*^9}, {
  3.901373370505085*^9, 3.901373376115464*^9}, {3.9013748063553553`*^9, 
  3.90137482731822*^9}, {3.9013751763556128`*^9, 3.9013751888732147`*^9}},
 FormatType->
  "TextForm",ExpressionUUID->"74b76087-a1db-4e30-9ddb-17ad47dc1311"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", "fAN", "]"}], "  ", 
   RowBox[{"(*", 
    RowBox[{"analytical", " ", "solution"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fAN", "[", 
     RowBox[{"r_", ",", "M_", ",", "\[Sigma]_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"-", "M"}], "*", 
     RowBox[{
      RowBox[{"Erf", "[", 
       RowBox[{"r", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], "\[Sigma]"}], ")"}]}], "]"}], "/", 
      "r"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.9001816297782173`*^9, 3.9001816390880947`*^9}, {
  3.900182377573483*^9, 3.9001823835235443`*^9}, {3.900182796811309*^9, 
  3.900182872269912*^9}, {3.900183043952875*^9, 3.900183044387998*^9}, {
  3.900183233379615*^9, 3.900183281741951*^9}, {3.900183369135285*^9, 
  3.900183382985553*^9}, {3.900183579016501*^9, 3.900183615355852*^9}, {
  3.901373370505085*^9, 3.901373376115464*^9}, {3.9013748063553553`*^9, 
  3.901374812704933*^9}},
 CellLabel->"In[49]:=",ExpressionUUID->"eeb55d4a-4805-44cc-b295-fd0f554c2dd0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"fAr", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "[", "r", "]"}], ",", 
     RowBox[{
      RowBox[{"fAr", "[", 
       RowBox[{"[", "5", "]"}], "]"}], "[", "r", "]"}], ",", 
     RowBox[{"fAN", "[", 
      RowBox[{"r", ",", "Mv", ",", "\[Sigma]v"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0", ",", "afin"}], "}"}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Darker", "[", "Cyan", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Darker", "[", "Red", "]"}], ",", "Dashed"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Dotted"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotRange", "->", "All"}], ",", 
   RowBox[{"PlotLegends", "->", 
    RowBox[{"{", 
     RowBox[{
     "\"\<num-coarsest\>\"", ",", "\"\<num-finest\>\"", ",", "\"\<an\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9001816297782173`*^9, 3.9001816390880947`*^9}, {
   3.900182377573483*^9, 3.9001823835235443`*^9}, {3.900182796811309*^9, 
   3.900182872269912*^9}, {3.900183043952875*^9, 3.900183044387998*^9}, {
   3.900183233379615*^9, 3.900183281741951*^9}, {3.900183369135285*^9, 
   3.900183382985553*^9}, {3.900183579016501*^9, 3.9001835958478947`*^9}, {
   3.900184949739677*^9, 3.90018499521607*^9}, 3.900185291685224*^9, {
   3.90018538363431*^9, 3.900185439301877*^9}, {3.9013753874769278`*^9, 
   3.901375460182473*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"448a080b-2992-4390-bbe5-a4d12850b489"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]]], 
         LineBox[CompressedData["
1:eJwVlnk41G8XxscMwzAZokUhFG2SivY8T1oQFSJUhJSlTWhRSrJUEoqEsrVI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          "]]}, Annotation[#, "Charting`Private`Tag$16440#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJwVxWk8lO0eAGDG0tjmQVJ2siSEJKK8/ycUiRaUFkmoREULiTpeaxIpSYRK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          "]]}, Annotation[#, "Charting`Private`Tag$16440#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          GrayLevel[0], 
          Dashing[{0, Small}]], 
         LineBox[CompressedData["
1:eJwV0nc81/sXB3B7+36MyEyIrkJdZZbO51LXbkiD5JIVIpKySuQrlVVXsio7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          "]]}, Annotation[#, "Charting`Private`Tag$16440#3"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, -4.858955587232073}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {All, All}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{Automatic, Automatic}, {
       Automatic, Automatic}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"num-coarsest\"", "\"num-finest\"", "\"an\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 
                    NCache[
                    Rational[2, 3], 0.6666666666666666]]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 
                    NCache[
                    Rational[2, 3], 0.6666666666666666]]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0], 
                    Dashing[{0, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0], 
                    Dashing[{0, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   TemplateBox[<|"color" -> RGBColor[0, 
                    Rational[2, 3], 
                    Rational[2, 3]]|>, "RGBColorSwatchTemplate"]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   TemplateBox[<|"color" -> RGBColor[
                    Rational[2, 3], 0, 0]|>, "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> GrayLevel[0]|>, 
                    "GrayLevelColorSwatchTemplate"], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.900181639996725*^9, {3.900182361320231*^9, 3.9001823844682007`*^9}, 
   3.90018242285686*^9, 3.900182460749279*^9, {3.9001827933039093`*^9, 
   3.900182797224806*^9}, 3.900182841702022*^9, 3.900182873259952*^9, {
   3.9001830236590147`*^9, 3.900183044948909*^9}, {3.900183201409631*^9, 
   3.900183282305389*^9}, {3.9001833726012774`*^9, 3.900183383870442*^9}, {
   3.900183545207741*^9, 3.900183556434338*^9}, 3.900183617382721*^9, 
   3.9001838339359417`*^9, {3.9001849537128696`*^9, 3.90018499563449*^9}, {
   3.900185288368322*^9, 3.900185292245466*^9}, {3.900185379724473*^9, 
   3.900185400033078*^9}, {3.900185432689745*^9, 3.9001854398720913`*^9}, 
   3.900230648608267*^9, 3.900231489708322*^9, 3.900232725137974*^9, 
   3.9002330394097013`*^9, 3.900240075130904*^9, 3.901375383946295*^9, {
   3.901375433429543*^9, 3.901375462004171*^9}},
 CellLabel->"Out[53]=",ExpressionUUID->"580bead5-8ec7-4dbf-805b-644efadcf791"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"analytics", " ", "vs", " ", "numerics"}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"LogLogPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"100", "*", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"fAr", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "[", "r", "]"}], "-", 
          RowBox[{"fAN", "[", 
           RowBox[{"r", ",", "Mv", ",", "\[Sigma]v"}], "]"}]}], "]"}], "/", 
        RowBox[{"Abs", "[", 
         RowBox[{"fAN", "[", 
          RowBox[{"r", ",", "Mv", ",", "\[Sigma]v"}], "]"}], "]"}]}]}], ",", 
      RowBox[{"100", "*", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"fAr", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "[", "r", "]"}], "-", 
          RowBox[{"fAN", "[", 
           RowBox[{"r", ",", "Mv", ",", "\[Sigma]v"}], "]"}]}], "]"}], "/", 
        RowBox[{"Abs", "[", 
         RowBox[{"fAN", "[", 
          RowBox[{"r", ",", "Mv", ",", "\[Sigma]v"}], "]"}], "]"}]}]}], ",", 
      RowBox[{"100", "*", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"fAr", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "[", "r", "]"}], "-", 
          RowBox[{"fAN", "[", 
           RowBox[{"r", ",", "Mv", ",", "\[Sigma]v"}], "]"}]}], "]"}], "/", 
        RowBox[{"Abs", "[", 
         RowBox[{"fAN", "[", 
          RowBox[{"r", ",", "Mv", ",", "\[Sigma]v"}], "]"}], "]"}]}]}], ",", 
      RowBox[{"100", "*", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"fAr", "[", 
            RowBox[{"[", "4", "]"}], "]"}], "[", "r", "]"}], "-", 
          RowBox[{"fAN", "[", 
           RowBox[{"r", ",", "Mv", ",", "\[Sigma]v"}], "]"}]}], "]"}], "/", 
        RowBox[{"Abs", "[", 
         RowBox[{"fAN", "[", 
          RowBox[{"r", ",", "Mv", ",", "\[Sigma]v"}], "]"}], "]"}]}]}], ",", 
      RowBox[{"100", "*", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"fAr", "[", 
            RowBox[{"[", "5", "]"}], "]"}], "[", "r", "]"}], "-", 
          RowBox[{"fAN", "[", 
           RowBox[{"r", ",", "Mv", ",", "\[Sigma]v"}], "]"}]}], "]"}], "/", 
        RowBox[{"Abs", "[", 
         RowBox[{"fAN", "[", 
          RowBox[{"r", ",", "Mv", ",", "\[Sigma]v"}], "]"}], "]"}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "0", ",", "afin"}], "}"}], ",", 
    RowBox[{"PlotLegends", "->", 
     RowBox[{"{", 
      RowBox[{
      "\"\<10\>\"", ",", "\"\<20\>\"", ",", "\"\<30\>\"", ",", "\"\<40\>\"", 
       ",", "\"\<50\>\""}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.900183525094119*^9, 3.900183527222065*^9}, {
  3.900183568145268*^9, 3.9001835745149107`*^9}, {3.9001838373004503`*^9, 
  3.9001838732080297`*^9}, {3.900185447496793*^9, 3.900185525900882*^9}, {
  3.900232478345518*^9, 3.900232494313527*^9}, {3.9002326241811666`*^9, 
  3.9002326285144577`*^9}, {3.9013733809659863`*^9, 3.90137338834055*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"12f328e7-1c41-4d17-a000-e54335ee9ce6"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVV3c81d8bvzZpGKWSBiEJDTvj+aS+RoQkRbKVzJRKVmYKkVWpjMyGCiFC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          "]]}, Annotation[#, "Charting`Private`Tag$16559#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVl3c81d8fx91rRCghES2rklCZkbe0rEqRUiTEt50kIpVREioqJauUVUoi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          "]], 
         LineBox[CompressedData["
1:eJw9Wnc0l+/7fxtvO7NUSkVSRIOMJJeKkpJR2YoSinwiIisrSlahVFZGiEpF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          "]]}, Annotation[#, "Charting`Private`Tag$16559#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwUl3c81d8fx61rJNlFqUS0zCJkHBERlWipqEhJykxWsqIUXyEZmdkrI3u8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          "]], 
         LineBox[CompressedData["
1:eJw9lX00lAkbxmfmmTEYykciSagmWz6qTWhbd63pxURaSghLakPTh430Iesr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          "]], 
         LineBox[CompressedData["
1:eJw9Vns01WkXRs5dx3HJcDA4lPt8dVDJcXaXRUUK1UlYDSUNqWRMDJEupKFE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          "]], 
         LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA18Cixq1F8z+1qSRSLNAawDybjxgm
TfM/hNwjkwwLE8AuESy+4FXzP9kA7eZ1sxDAIIfIY5te8z9uLZ+RT8kOwBL9
ZAlWZ/M/rOrzBzUUDcAEcwGvEHDzPyPxZio45gvA9uidVMt48z8cjmWK3hML
wOheOvqFgfM/55ikqb6GCsDa1NafQIrzP7VPnaCrMgrAzEpzRfuS8z/yYAql
ZREKwL7AD+u1m/M/xCxWecwgCsCwNqyQcKTzP1LbEDxSYgrAoqxINiut8z/Y
RnWOWtsKwJQi5dvltfM/Uu7I7b2WC8CGmIGBoL7zP1Qu1pJ0qAzAM5ffCl/I
8z+e1OMl/G8OwOCVPZQd0vM/DQZe4QioEMCNlJsd3NvzP/OKAZ3BfxPAOpP5
pprl8z8OWkStS34awOeRVzBZ7/M/GXwiF5+mEsCUkLW5F/nzP/iKBBF6bBDA
QY8TQ9YC9D9MCJ8Bp2EOwO6NccyUDPQ//kKR/UrQDMCbjM9VUxb0P03QTndJ
yAvASIst3xEg9D9TFcLH2CALwPWJi2jQKfQ/dUu/1xHGCsCiiOnxjjP0PzAW
eNjirgrAT4dHe0099D9oulW6etkKwPyFpQQMR/Q/axrEKKRKC8CphAOOylD0
P30mZRWGDwzAVoNhF4la9D/QyVQdU0MNwAOCv6BHZPQ/hMbkKFofD8CwgB0q
Bm70P6MMusVJGRHAXX97s8R39D/17n+qb1MUwAp+2TyDgfQ/uHyyZ4wfGMC3
fDfGQYv0P+1Ylq1LZhLAZHuVTwCV9D9QVLvNbGMQwBF689i+nvQ/mTPDFVt/
DsC+eFFifaj0P77b3LTlDA3Aa3ev6zuy9D8z+Iuj9B0MwBh2DXX6u/Q/crt5
VS2OC8DFdGv+uMX0P+H2bw1OTAvAcnPJh3fP9D868XKmnVELwB9yJxE22fQ/
WTs+0zKfC8DMcIWa9OL0P+qheR5fPgzAeW/jI7Ps9D/xZKY+n0QNwCZuQa1x
9vQ/AsQvZ0DfDsDTbJ82MAD1PydDW+1wvBDAgGv9v+4J9T8M70odAjYTwMUi
h5mfDPU/takkUizQGsBteY48
          "]], 
         LineBox[CompressedData["
1:eJwB8QEO/iFib1JlAgAAAB4AAAACAAAAgUv60Mwa9T+1qSRSLNAawNpoudJr
HfU/3H4w7Pd6E8CHZxdcKif1PzYAnD+aABHANGZ15egw9T8ng7ESlWUPwOFk
026nOvU/EVKfJOTJDcCOYzH4ZUT1P+0bJ4EaxAzAO2KPgSRO9T8OXt7HiicM
wOhg7QrjV/U/FxEYuZTfC8CVX0uUoWH1P+em8+g45AvAQl6pHWBr9T9ETebI
jzYMwO9cB6cedfU/2ezITT7hDMCcW2Uw3X71PxV7hLBc/Q3ASVrDuZuI9T9d
Xb2FlMEPwPZYIUNakvU/5Q/srVBbEcCjV3/MGJz1PzojTOb0cBTAUFbdVdel
9T9GoOsElPQYwP1UO9+Vr/U/IXqNAFzPEsCqU5loVLn1P4/h0BwnxRDAV1L3
8RLD9T8LycGjqEYPwARRVXvRzPU/ApNWQqXfDcCxT7MEkNb1PyNG8zjVAQ3A
Xk4Rjk7g9T9NzlHTIYkMwAtNbxcN6vU/IYTfLMllDMC4S82gy/P1P5ImUsT/
kwzAZUorKor99T/Dzv+ZNhoNwBJJibNIB/Y/Qina9xkMDsC/R+c8BxH2P7zS
M06+lQ/AbEZFxsUa9j8u25w4axARwBpFo0+EJPY/IlpymWCDE8Bi1nPTWyb2
P7WpJFIs0BrAfm3rkQ==
          "]]}, Annotation[#, "Charting`Private`Tag$16559#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVV3c8lu8Xtl9bSil8y06yEqFwFxJRWRWhjEiiJFFWRikjIzNZycjI3us8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          "]], 
         LineBox[CompressedData["
1:eJw9lflXzHsfwL8z065OKi33lqsIxajbo5TkvsOhDW2upk3KLbQKbSQipUVJ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          "]], 
         LineBox[CompressedData["
1:eJw9mHc4F+z3xz97IjskDRlJFLKS8zQelVIeT2VLKUnqiSh7P5XRh4ZKZSSU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          "]], 
         LineBox[CompressedData["
1:eJw9lXs0lYkaxiXX/e17UozrjtwbRAj7pUIUSTEGxVQqQsfO9RRpMSjXRJcV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          "]], 
         LineBox[{{1.2234575328191344`, -6.703294070708968}, {
          1.2255152875987245`, -5.364292473148651}, {
          1.2276464129712785`, -4.643900984958981}, {
          1.2297775383438325`, -4.291837447569763}, {
          1.2319086637163865`, -4.0831612439581875`}, {
          1.2340397890889405`, -3.956111035889851}, {
          1.2364187645666334`, -3.881169645380684}, {
          1.2387977400443262`, -3.8636874204516647`}, {
          1.241176715522019, -3.9010513486194083`}, {
          1.2435556909997119`, -4.000355403674035}, {
          1.2459346664774047`, -4.183322133930356}, {
          1.2483136419550975`, -4.507285763341744}, {
          1.2506926174327904`, -5.177403438551848}, {
          1.2526081752477893`, -6.703294070708968}}], 
         LineBox[CompressedData["
1:eJwB8QEO/iFib1JlAgAAAB4AAAACAAAAP2I740kc8j+1qSRSLNAawBbxxxlc
JPI/NwFDIm/DE8AIZ2S/Fi3yP6LQlH2PkhHA+twAZdE18j/OCDEJtV4QwOxS
nQqMPvI/ZoS0z408D8DeyDmwRkfyP1xy3F1cRw7A0D7WVQFQ8j+ghoEEP7YN
wMK0cvu7WPI/0GWCRdB2DcC0Kg+hdmHyP9KWzEQ3gg3ApqCrRjFq8j/LZPHe
O9oNwJgWSOzrcvI/gfqcgACKDsCKjOSRpnvyPwOg6FYXqw/AfAKBN2GE8j+f
jV3bc7oQwG54Hd0bjfI/7/79tRk5EsBg7rmC1pXyPyOyf9lVWhXAUmRWKJGe
8j++xKsY8JIZwEXa8s1Lp/I/O9Vvt+GWE8A4UI9zBrDyP4sWkYyPkBHAKsYr
GcG48j9YdJV1fW8QwBw8yL57wfI/emb5PzZ3D8AOsmRkNsryP8h4nu0xlw7A
ACgBCvHS8j+ckuk37xoOwPKdna+r2/I/eigWD2zyDcDkEzpVZuTyP7V8yuhD
GQ7A1onW+iDt8j9eKwiuvJQOwMj/cqDb9fI/Lai/WCJ2D8C6dQ9Glv7yPyIh
Xh8EchDArOur61AH8z8AgIaSApwRwJ5hSJELEPM/iP4TP+K/E8ApAG6jexjz
P7WpJFIs0BrA2e/uSQ==
          "]], 
         LineBox[CompressedData["
1:eJw9k2tM02cYxZmQEarS998il0YUYoMMcEM0ZVshT6jjZgNF7gFBQOqQIkwU
cIJcBAJY08nWugyKgoQxBihbnQJyeQxCpkLQsaByv6jzhgvhfTtiYFv3ZR9O
Ts6Hk9/5cpxTssKVG8zMzD4x6T9v7Vvnwqwp/NIiDvd4IMLa86NREbYUfO12
d79+J8Qg9a5ZzolCLN9eqx/jkFWp0x58QMFrz1uJ7AbBK5UvlzV7KExqRh7e
tiGoqAjMD/Gl8J67b91aGR/XypssNgVSMHfSrQ0l8LGlzFxzL8zE61DOXmjn
Y3Rpsl1VHIWtz/g8bxlB87P99YGppjz3z/Z0HocdxY5u72dS6LE+pb1yUoAJ
RfmGO3kUqHhrgly7BXmFT3xKSyi03ZW/TNvngDcLvIf81BSsrGPl5o1CTM3X
Kcx0FKQ1oplveznkTq887rtEYbhmel3RS7Dv1IGUMz9QCDNcbWr6iKAq79pr
6c8UAiIHjJtm+Gifuznn3S0KDrykhskpPg6eVP3dOWjap0gWeH9IMPvE3Yq8
UQpFT2/3JPcQ3J69k5M8oWCTGB0/ihwOf1FeQxco9IdFJYTcFOKXWYs7DG8o
bExfWsmwFqFLpl/7caOp/6hD06rfgmMZlyWeZgxKbkhCfm0XYLFqvf+tFYNL
E/7VdREc7kqPD24XMjDor7uOXiQ4kdb1m8qRQfeZ4vIYb4IVn9sddNvJ4LLW
x3p+G8G9R3KevfBkYO9adv9xEMH51LHM5k8ZdK5eb+3uI6g5vHtV+RmDar/5
BY96DqUpX5WIQxkcpce6CuRCfJG0xFuMYWBxRKza0GSHukNybUMyA8nzifFD
r2xRltjimKRiwMp0AxYfC/HPg5bN23IY6M+fcEm8yqE+Xuk5XcjAV+oknpsi
GBw30FVbySBqpvH4xWyCxljnfXFfM9jvZdWsjCTYGFM0bK9nkFUYWOlRQDAs
ejrqUZNp/46x8aMrBNcjpbO6awwaeET9+ySHP0Z8lxbZxcDzWMjzw3VCjAn/
a1kwwGDqG7XD1Dl7tDgQlf9wmEHMvbO2CaW2+JPCYHFhnEH0rYU32e5CTAzl
NKFzJt5yl+T7bg43hmTZbX7FAHLnngasEuyUj9TfX2GQspid619LULnf3e3c
OgPnvYnzA2qCguAqQ5ClEWSuFdreIYL9gX/4WHJGqO6VLQfEc5gR4D80KDLC
8sodL9FpAYr8GxVlYiMUts23yUdscEnh0WDlYvz/f/8CXpbB7w==
          "]], 
         LineBox[{{1.1936386326234274`, -6.703294070708968}, {
          1.1956795323829685`, -5.324208955922566}, {
          1.1978106577555225`, -4.606665606684835}, {
          1.1999417831280765`, -4.253150568152973}, {
          1.2020729085006305`, -4.041593577067705}, {
          1.2042040338731845`, -3.910543196943182}, {
          1.2063351592457385`, -3.835333634595274}, {
          1.2084662846182925`, -3.805088069315969}, {
          1.2105974099908465`, -3.8161155920439818`}, {
          1.2127285353634005`, -3.8701119341011214`}, {
          1.2148596607359545`, -3.9749592541051246`}, {
          1.2169907861085085`, -4.149052253701014}, {
          1.2191219114810625`, -4.435594205322599}, {
          1.2212530368536165`, -4.964690345004812}, {
          1.2233272044857793`, -6.703294070708968}}]}, 
        Annotation[#, "Charting`Private`Tag$16559#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwUV3c8lu8XfvHae6ao7GySkV2UlL6RFaWsKKKMoqyEspUIEalURgkVWZ3b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          "]], 
         LineBox[CompressedData["
1:eJwBEQPu/CFib1JlAgAAADAAAAACAAAAVLxdvYjnur+1qSRSLNAawFSqIgVF
Vbq/+dgD3mV9EcC8+cEAMb+5v/7esnV5Iw7AI0lh/Bwpub+5ETDvZmELwIqY
APgIk7i/KJaWGM+FCcDy55/z9Py3v+K0xKJwLQjAWjc/7+Bmt7/hhUI8disH
wMKG3urM0La/QPDesQZoBsAq1n3muDq2vwIb/mAv1QXAkiUd4qSktb8vkbKH
WGoFwPp0vN2QDrW/ZZTRliQiBcBhxFvZfHi0vzlxqppc+QTAyBP71Gjis7/7
SqNwYu4EwDBjmtBUTLO/HZ3W9+8ABcCYsjnMQLayv2SjG4YMMgXAAALZxywg
sr9tJKckNYQFwGhReMMYirG/gNGGNMX7BcDQoBe/BPSwv2on9L3GnwbAOPC2
uvBdsL95eMF3h3sHwD5/rGy5j6+/De1Mr9ihCMANHutjkWOuv0VpAJx+NArA
3LwpW2k3rb8Wk4y6Z3gMwKxbaFJBC6y/ag4yarAPEMB7+qZJGd+qv2q9L1Vq
KBTASpnlQPGyqb9esn6MDuEUwBo4JDjJhqi/QFC2f+aQEMDp1mIvoVqnvz0H
dqqKYQ3AuHWhJnkupr+WXkXdFxELwIgU4B1RAqW/Kc3YAqB2CcBXsx4VKdaj
v41tvMUZSwjAJlJdDAGqor9s+TcuCmwHwPbwmwPZfaG/0VzL0mbGBsARtauo
tWWgvw5Yj8+VVQbAWfJ2mySbnr8Fe5W0QAcGwJB6luXdapy/YMHoC+7XBcDG
ArYvlzqav8pfsy+7xQXA/IrVeVAKmL+IuL3nEdAFwDIT9cMJ2pW/2t1Rd5L3
BcBomxQOw6mTv1f4QwwrPgbAnyM0WHx5kb+KzFYbZKcGwKtXp0Rrko6/T9IC
Rvw4B8AYaObY3TGKv1+hM+sS/AfAhHglbVDRhb/bwQhLd/8IwPGIZAHDcIG/
FEtPkaRcCsC8MkcrayB6v05WmcwiRAzAlVPFU1Bfcb9vUYOzDiQPwN3ohvhq
PGG/sx+9EtsvEsA09TsL51BQv7WpJFIs0BrATM6DpA==
          "]], 
         LineBox[CompressedData["
1:eJw9k/k3FAgcwGdHzWFmzDSuxexOjid2Ub1Nbl9RLzaspJBbRrWOVtiEKJEj
DzWuMhGNM/cY9+jraAnZWW12tXmketmIPDbKte0v+8Pnfd7nD/io+59z5hEJ
BMKBz/znWyL9xfW6oyCu1HLWk6qihH+ZRxjwg+ZXpOnySDZu17WWVSsNA6Xw
TMUPQ0zUo/S9MAyMBruQgEtZS3SsXCrxrOBfgfnp4ffP5Gho/vLUgOFyEsRH
WyQTRVSUjmrt63VJg5FIp7Kaegqe6nld5CTOACOeuu7aPBnX3J5sX0i7AcY3
aJwkHzL2SUUdhh18+C5bKSHlIwkzbLPDYmdzQCNzmF7RQkI3jNjVq5YPKzu/
bBjJJaGG8fEJqv1t2Nu9Z6A4h4RzdYZ8p1gBUM9vDhxuIqF4l5JdXnUhfL/m
GBu6TMIHP8RshYbeBQsZ4xc33ckovB508ua1YjhwXbez9G8ypvZ7iMWFJTB0
95+MY7UUDJWxZ4033wOOiUi5sIWKzmAetD4iBE2B/mmBOg2NYvR+4b4phegt
4SVzTQZyWjjqNltlwEvhLHhyWUhYoscGKlfA6ThSBEFTHl8bbIyl7q6EEaNn
OkQbFRz88d3emsNVsMepZFKRxca6sol0qc99EGRdcxwtZGL29OM3SxeqYcNH
o2OcyMCor7uslbNqwJGRfHnDioZeJ2vvmFbUgkpRtK/MJhWtcwtXvbAO0vjT
1XQWFeXP9ldaBdeDgE6clvhSkJQMrs6r9aC1ov0t9yUZV4Ut2wISG6CoVZse
lEnGtz27GyNZjRDh+qhX1Y+ME1PlPsmCRmi4t//K0nEySje5jFs6IqBe3VdS
EELGHk5+e1WTCOJr/EVplWRsMmWd6bRqAjb34l8ODAqWu6Uojgw3gcRWt9i8
iIK3fyb0TrqJYWZlW83iWSqmZ0f9tPhKDBOKvz70jpfFuMb3X8mENYNfWlbc
H1s0DJOeGVLYaAY93Y9zJH05DJifitJObQF2Mv/T4BgLT9DdtY0VW2FEf4fX
bJkC2n7z2xO74lbYP2b5zh+U0NTW7oqHfhscLJjrImfvQL3AboOQtjZYCBeP
nXBgIjfR5HncoXbIa0uQL1ihY+LTHr7tRDusqluUWdvQ8K22/RF2ZAeo2Kn3
0Nmy6BT1lPic3gl/qvqjxISKzY+820uFnZBk1qdsI6QgR20m7Jy5BDxCfOtc
D1EwIThM1+R3CfBsBmuOKlFwRvJpihjcBVcnQ5QdFCjoyEzMH5Z5AGU8udQo
oGCTL8Mpt+BzmyUq7CygIMN9SKZeBYEZufAhxoCK+EXWZDYPQWpZd6SVJIvh
VS4dFxsQVEbb1wVmNNQ+ppLnvYEgJ7/cZ7lGx/G1ifM2dt3g6XKnn1XLxHRh
iaNOTjcwiy5kTDuyMXg2+PH9h93///8vM0jtBw==
          "]], 
         LineBox[{{0.22398825202880818`, -6.703294070708968}, {
          0.22537623989716674`, -4.81385943650393}, {
          0.22769234031210184`, -4.164559445360458}, {
          0.23000844072703694`, -3.819826195125537}, {
          0.23232454114197204`, -3.601072951836523}, {
          0.23464064155690714`, -3.454037263525845}, {
          0.23695674197184224`, -3.3554334416815217`}, {
          0.23927284238677735`, -3.293690267283896}, {
          0.24158894280171245`, -3.2628928431076916`}, {
          0.24390504321664755`, -3.260493167049028}, {
          0.24622114363158265`, -3.286484017847946}, {
          0.24853724404651775`, -3.3433967480922204`}, {
          0.25085334446145285`, -3.4371214250322657`}, {
          0.25312723207923116`, -3.576052151270815}, {
          0.2554011196970094, -3.7832639099228014`}, {
          0.25767500731478765`, -4.108223815213928}, {
          0.2599488949325659, -4.705593284984178}, {
          0.26158572848316136`, -6.703294070708968}}], 
         LineBox[CompressedData["
1:eJw9VGs01AkcnZSSZv7zMmHIpqJabDaylfKjJGFLemjoQR4rEdmKyiMz06jR
Q1btqkRWSiTaVQn1k0dZb7FmzOs/0WO0eUUOjlr7ZT/cc88995x7z7kfrun+
CK8gLQqFsmsK//H4Yq4Xq6kTSvIWeVm2cHE8MTG2RtMJbyVVk5dM9dCS/1Q+
ky4BgcVwdt4xJu7lT6xxtZVAt4k9RceAgSn8lRlneRI4V031TUsk8Dn/6ORf
8RJ46PlssechGg7zH+yh5kggdPZ4ENRS0VzQX/FjnQSMrUZLqT9TcZfA0uRi
nwRGAwTVEQepKBYciG9hSyHJPd+HfZ+K5YJcJXOVFIws7CaiXGjYL+h22LZX
Cj3a3OkXXAiM2Rc8Wy9RCpxL250GntCRYq951f67FMzH06vqpzHx7NywG5dr
pZAR/rH0H202sob6QnZqpFA/ORxR02SAVxsP2+hTu6B+r2XWoygOLswbnuz8
rgv0BB7b59izsEAY/fK3rVO6LB3jihho6zeeyjvSBWbPV+Yd5NOxwj5uD/fX
LnB5+yjmogeBLvqUJbLSqbwoplW+iIZNQ/yha/Iu0N1aNqY/l4beTdoVu792
wXFOnXVgHxXJvDNJ8xbI4JRWUW37HBqGnJ7jpXSWQTZPGDR2mIaDfheMM3+S
QUP0bsdZVgSeWMN8t08sA5NFQ7p23nTUMkgrnn9PBtHMLY/mpTEw+dPcWHWz
DLRbZ2xw57BQrzndJXtIBs6r39hY2nHw+l1jZgBHDmG64eKEJEM0E2XKFq6U
Q7bbgt6XJ9lY6L8gt8dHDp6BkRdLI5lot/ZW5K04OYzll+Y6uTPwmcES++As
OfTpr9fXNqOj6/Bd7cVVctio2v0+dRWBLc1WLe/eyCGhiWHtf5+GvPyiq3d0
FLA+ZW3l1qM0fC2yCTpgoYDCmjZXp9M0DN3/cNm3mxUQw9VdcVRNw09rV433
Riqg2CqoWXSZwFjD8ur8XxRAEd8Ivl9GxxkjDhfDHipAcpg8xKtl4LmWSp6V
VAFZxveIRncWcgqcF/VNKOBUQ7Bvp5CDN5Je9BWaKCFq5vz2wO8N0TzArTTC
SQmPPuQ9eCxi432HRoF1oBJeiWy/MRQzcSXXc/OgSAmtipzYjDAG4kibwYM8
JbiliD++OULHTa07uqMalMDxjQxNv0JgW4Hknk2/EkbnLUucZUSgzxnfmGGm
CjgDjMrwIRp2ByjXldiq4GbqQVaEAYFh4E875q0Cj9BDektTCRzm9nTanVBB
P3GOGh1Jx7jPwdmj11XwebV2R+hU/8w2TdjjZyqwTxz7IE1h4oV7YT8cf60C
5ZMTW4/dYuO56lFKhhYJI+zUNIoLFz2XrwqeZJOwwKhoV28CB/WyTtTvMSPh
1Nl4r1QhCyW0cuundiQsTcosq2My8frJycsmrlO+semKcFsG+mscJuJ5JGgK
+3OrdtDR3PuUnyqUhHhTaYfWQwJ7qytrIJaEP0vs6aFRBBYun26RdZ6EQkfH
CyV8AqOynFMomSQs/oNnJNIQaEeIRvyKSOidNladXkLHiZMvfCorSci84rPt
lXBqX40Omr4ioXr+YOWMa0wUeruZ8XtI8KvbEHf8Ehtda5LFr0dIWJKqTt64
1hCpNo3962apISdGUjz4hYPwwnMnl6uGBl7j2I2bLIzybS8ftFTDaeuJ2eJ5
TMzp915YB2qwEabkhzsysFMgO5vlpQYBM+L27QQ66hrsG4gOUkNPUsd5xVcC
1xS83rklRg3FClX9lw8ERjgGV5gnq2F7YcfH6050zG7XLPySoQaeIs58aBYD
O0LCxR1FanB3CFlRiQzUmRwYKKhSg+77co/maSxcfemIt/BvNZSbiBXrT+vh
8jvZm1pJ9f9/+y+PfbhC
          "]], 
         LineBox[CompressedData["
1:eJwBkQFu/iFib1JlAgAAABgAAAACAAAA4yNq1B1t5T+1qSRSLNAawPLuo/a+
ceU/ppVvw0b/FMAlgyddloTlP4jPe/Y5pBLAWBerw22X5T/tOixGoXsRwIqr
LipFquU/U84xkInbEMC9P7KQHL3lP3H9XluHkhDAnMFYrLPO5T+HM34wII4Q
wHpD/8dK4OU/vSecGKvGEMBYxaXj4fHlP7X9AprKRxHANkdM/3gD5j/GWOaF
fzISwBTJ8hoQFeY/QacjY4fmE8DySpk2pybmPyKRvnk4UBjA0Mw/Uj445j/Z
ucf7xngXwK5O5m3VSeY/1AlU82LIE8CM0IyJbFvmP0dD9oCNORLAalIzpQNt
5j+kQUpLG2ARwEjU2cCafuY/kn4z1NzqEMAmVoDcMZDmPyVFlr5zvRDABNgm
+Mih5j81fyYqJM8QwOJZzRNgs+Y/x6JKjNUjEcDA23Mv98TmP0nQdNIHzxHA
nl0aS47W5j+O9pOI4wYTwHzfwGYl6OY/bmvLDUGJFcAOV+wCHPHmP7WpJFIs
0BrAdmvERA==
          "]], 
         LineBox[CompressedData["
1:eJwBEQLu/SFib1JlAgAAACAAAAACAAAAuI1j9uNB6T+1qSRSLNAawNaghC7O
T+k/c8aGYH4vFcC0IitKZWHpPxJuv8CTLRPAkqTRZfxy6T+UPF6hhSwSwHAm
eIGThOk/bDFw5IqpEcBOqB6dKpbpP4BoBLUnfRHALCrFuMGn6T/6oQLY+pwR
wAqsa9RYuek/Y7lMBU0REsDoLRLw78rpPwHVIng5/RLAxq+4C4fc6T+1v/Ny
KdIUwKQxXyce7uk/z+pmMMZqGsCCswVDtf/pP7MVx9WnGBfAYDWsXkwR6j92
iVlIwgcUwD+3UnrjIuo/urGc2d2uEsAKjyYPIjTqP4WddD78/xHA1Gb6o2BF
6j/Ws1ypHrMRwJ4+zjifVuo/WZW2qaG0EcBoFqLN3WfqP/vyHJVmBRLAMu51
Yhx56j+5INAwqrsSwP3FSfdaiuo/sBYQwYcdFMDInR2MmZvqP1rg/In/URfA
knXxINis6j+GfJ5LAzkawFxNxbUWvuo/pwbrkJQLFcAmJZlKVc/qP2K6MizE
RBPA8Pxs35Pg6j/XmNzNcl8SwLvUQHTS8eo/pVIMpdnwEcCGrBQJEQPrP72X
JH1m2BHAUITonU8U6z9aWWJmcRASwBpcvDKOJes/ijNvvHCoEsDkM5DHzDbr
P6tn1TFl1hPArgtkXAtI6z8ktlkzEGQWwHIiGWxlUes/takkUizQGsCpHf8A

          "]], 
         LineBox[{{0.9367632509330573, -6.703294070708968}, {
          0.9388509733952075, -5.389875078158868}, {
          0.9409560098243583, -4.955628782878038}, {
          0.9430610462535092, -4.750037262840775}, {
          0.94516608268266, -4.669157969491129}, {
          0.9472711191118109, -4.6858976391104274`}, {
          0.9493761555409619, -4.806230743708625}, {
          0.9514811919701127, -5.077244752702997}, {
          0.9537650446775404, -5.772844193876546}, {
          0.9556144358520318, -6.703294070708968}}], 
         LineBox[{{1.0831047032988435`, -6.703294070708968}, {
          1.0839446490009181`, -5.770389436154667}, {
          1.0862285017083457`, -5.211032167989347}, {
          1.0885123544157733`, -4.996322507812312}, {
          1.090796207123201, -4.9573354660599716`}, {
          1.0930800598306287`, -5.074293607521234}, {
          1.0953639125380565`, -5.419990351043734}, {
          1.0976477652454841`, -6.476309809860361}, {
          1.0997788906180381`, -6.331390830050942}, {
          1.1019100159905921`, -5.439460016081673}, {
          1.1040411413631461`, -5.114456405479939}, {
          1.1061722667357001`, -4.994360724459153}, {
          1.1083033921082541`, -5.015175443014848}, {
          1.1104345174808081`, -5.187728189835337}, {
          1.1125656428533621`, -5.622705826370639}, {
          1.113994195671929, -6.703294070708968}}], 
         LineBox[{{1.2245857807629907`, -6.703294070708968}, {
          1.2255152875987245`, -6.108051005014027}, {
          1.2276464129712785`, -5.4874151296492615`}, {
          1.2297775383438325`, -5.268144997272079}, {
          1.2319086637163865`, -5.24705288347119}, {
          1.2340397890889405`, -5.412099915899546}, {
          1.2364187645666334`, -5.997230810611155}, {
          1.2375832206232065`, -6.703294070708968}}], 
         LineBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAAU7zlxjC/xL+1qSRSLNAawJr0Sbmc
fsS/1b7AFQpgEcBOnBm3kjPEv80dY7fAxw3AAkTptIjow79Nv8+79PUKwLXr
uLJ+ncO/lk/8KsEOCcBok4iwdFLDv3KGae4DrAfAHDtYrmoHw78k7zJ61p8G
wNDiJ6xgvMK/M5IDV9HRBcCEivepVnHCv86cVjefMwXAODLHp0wmwr9aW3No
UbwEwOzZlqVC28G/myG5PC9mBMCggWajOJDBv6HaffmWLQTAVCk2oS5Fwb90
U4Y3ZBAEwAjRBZ8k+sC/NxW0kJ8NBMC8eNWcGq/Av/6Rxt9cJQTAcCClmhBk
wL8+Y2HnvVgEwCPIdJgGGcC/Fl3CJhqqBMCu34gs+Zu/vzUFDP1XHQXAFi8o
KOUFv78w+DtklbgFwH5+xyPRb76/zkxJUGSFBsDlzWYfvdm9v8sYVBM7kwfA
TB0GG6lDvb+YDy0bv/wIwLRspRaVrby/6K2ZIBD1CsAcvEQSgRe8v1YAsU8G
8g3AhAvkDW2Bu7/5o8fRe78RwH8+DGlE77q/takkUizQGsAbf9IY
          "]], 
         LineBox[CompressedData["
1:eJwBYQKe/SFib1JlAgAAACUAAAACAAAARZoNUrz9wT+1qSRSLNAawPL1Kwby
LMI/GaFGwrbpEsClnvDh1njCPw90PMyoSxDAWEe1vbvEwj8T7/2fyMgNwAvw
eZmgEMM/1SkJpDj6C8C+mD51hVzDP2YitVYmvArAcUEDUWqowz/uQXPGT94J
wCTqxyxP9MM/omKmbjJICcDXkowINEDEP0IZH8WH7AjAijtR5BiMxD8BFPi8
YsQIwD3kFcD918Q/SR/ebCPNCMDwjNqb4iPFP3kKArPGBwnAozWfd8dvxT9a
EKcmJ3kJwFbeY1Osu8U/fJO9WlUrCsAJhygvkQfGP604bC3pMAvAvC/tCnZT
xj/a78bmFq0MwG/YseZan8Y/G5/exoPqDsAigXbCP+vGP5pk+0VbWRHA1Ck7
niQ3xz8rVs5G6gsWwIfS/3kJg8c/NUyBCd/4FMA6e8RV7s7HP2Td8JKHPBHA
7SOJMdMayD+QtpHUlBAPwKDMTQ24Zsg/8uUwQfv7DMBTdRLpnLLIP6Rml0NH
lwvABh7XxIH+yD/D/t5nSKIKwLnGm6BmSsk//6+zqBn+CcBsb2B8S5bJPywy
jEWFmgnAHxglWDDiyT9Zq91OPm8JwNLA6TMVLso/FP12yyZ5CcCFaa4P+nnK
PxAzXeJpuQnAOBJz697Fyj+1g+L6zzUKwOu6N8fDEcs/0+V3LoP6CsCeY/yi
qF3LP2rtwaSPHgzAUQzBfo2pyz/iyRyOes8NwAS1hVpy9cs/eHjKcp06EMC3
XUo2V0HMP8tD9CpmrBLALszf8SlwzD+1qSRSLNAawJH6KBw=
          "]], 
         LineBox[CompressedData["
1:eJwBIQPe/CFib1JlAgAAADEAAAACAAAAOvvPO3jT0D+1qSRSLNAawJR4EXGD
7dA/i+QdLb2WE8DGeE7RxBLRP1lnkKzJ8BDA+HiLMQY40T9zd9dsbhkPwCp5
yJFHXdE/4Ejuvn9YDcBceQXyiILRP1ZH5ofpLAzAjnlCUsqn0T9kshyONmYL
wMB5f7ILzdE/vVK6FYvsCsDyebwSTfLRP0DuL8zvswrAJHr5co4X0j9tHJSA
lrcKwFZ6NtPPPNI/Plnd5T74CsCJenMzEWLSP0HEG+BzfAvAvHqwk1KH0j/z
HxTszlIMwO567fOTrNI/wV5u6ieYDcAgeypU1dHSP57TV5G2iA/AUntntBb3
0j/NDTgaA14RwIR7pBRYHNM/oPeFvkTKFMC2e+F0mUHTP2yB6407pRfA6Hse
1dpm0z+ABg27QmsSwBp8WzUcjNM/udNa9Z92EMBMfJiVXbHTPzvPr8zLqw7A
fnzV9Z7W0z+zjPK1czcNwLB8Elbg+9M/5BYmifBBDMDifE+2ISHUPwx3qqKl
pwvAFH2MFmNG1D/UcJBwCVcLwEZ9yXaka9Q/7lcrllNIC8B4fQbX5ZDUP+Hg
+4yJegvAq31DNye21D/b6n2pJ/MLwN59gJdo29Q//UbXqh/ADMAQfr33qQDV
P5emtQTs/Q3AQn76V+sl1T8EFbj2uugPwHR+N7gsS9U/5v6+UHKMEcCmfnQY
bnDVP5iqatgP/BTA2H6xeK+V1T9JBEJ6UrcXwAp/7tjwutU/kTYKqS2OEsA8
fys5MuDVP+mwwLqmnhDAbn9omXMF1j+BYVlCjgQPwKB/pfm0KtY/2gJJ1WKZ
DcDSf+JZ9k/WP1cHMpBOrgzABIAfujd11j+oUga7YCAMwDaAXBp5mtY/17Y8
H+TeC8BogJl6ur/WP2/k0itF4wvAmoDW2vvk1j965nBTdi4MwM2AEzs9Ctc/
FmHNJ0vJDMAAgVCbfi/XP7Us0EYbyA3AMoGN+79U1z9gK7nSa1UPwGSBylsB
etc/Lk9mvcDpEMCWgQe8Qp/XP7+MwcIfOhPAkzTGfdW71z+1qSRSLNAawPdU
ifA=
          "]], 
         LineBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAAKBMV1sfx4T+1qSRSLNAawKC5eyQz
/OE/x5R/A8ZbFMDSTf+KCg/iPychY6Y5DRLABeKC8eEh4j9/VEfWHt4QwDh2
Bli5NOI/bC+lz3YvEMBrCoq+kEfiPy0SAGkBoQ/Anp4NJWha4j9Mq0cg3VwP
wNAykYs/beI/iAxf7nWHD8ADxxTyFoDiP/xJCJd5FBDANluYWO6S4j/ItaAH
A7EQwGjvG7/FpeI/o6UBtZ/DEcCbg58lnbjiP4wQEfdizhPAzhcjjHTL4j/n
mFbLUa8awAGspvJL3uI/qK8TAJt3FcA0QCpZI/HiPwCD+QhJmhLAZtStv/oD
4z9/nFPa+D4RwJloMSbSFuM/n+xYCGB7EMDM/LSMqSnjP9pdCNfMEBDA/pA4
84A84z8Tab12GtAPwDElvFlYT+M/6Y1MuvPzD8BkuT/AL2LjP5803IhEShDA
l03DJgd14z+CXZ5PCuoQwMrhRo3eh+M/2L4wmvUGEsD8dcrztZrjPzwQroVx
MxTAaJeDYauo4z+1qSRSLNAawNYuwk4=
          "]], 
         LineBox[{{0.7421859671537073, -6.703294070708968}, {
          0.7437523868099947, -5.546137906473078}, {
          0.7458996360363024, -4.867398138138087}, {
          0.7480468852626101, -4.548456408585791}, {
          0.7501941344889178, -4.376667511098614}, {
          0.7523413837152255, -4.294865877084846}, {
          0.7544886329415332, -4.283716027756579}, {
          0.756635882167841, -4.341269878965043}, {
          0.7587831313941487, -4.481322631582154}, {
          0.7609303806204564, -4.746656597487812}, {
          0.7630776298467641, -5.278383821369777}, {
          0.764476424007693, -6.703294070708968}}], 
         LineBox[CompressedData["
1:eJwBUQGu/iFib1JlAgAAABQAAAACAAAAcYmMUEoN7D+1qSRSLNAawCopUlb6
Fuw/7lASv+/aFcD1ACbrOCjsP+H9W/o1xBPAwNj5f3c57D9a2nnkhcMSwIqw
zRS2Suw/uCkrLcZJEsBUiKGp9FvsP/KOzuWyLhLAH2B1PjNt7D9XYStPWmsS
wOo3SdNxfuw/WlWPlx8SE8C0Dx1osI/sPx7ARmE2ZhTAfufw/O6g7D87sY9Q
U4YXwEi/xJEtsuw/ZyAqKUKjGsASl5gmbMPsP7xoWJ19XRXA3W5su6rU7D/d
3tGVzpsTwKhGQFDp5ew/w64hzS3BEsByHhTlJ/fsP1In48CMYhLAPPbneWYI
7T/kue6U02ESwAbOuw6lGe0/cS3hK2y/EsDQpY+j4yrtP+/W+WLAmhPAm31j
OCI87T9fVgN6l2MVwCnL3KrgTO0/takkUizQGsDC26N+
          "]], 
         LineBox[{{0.9926469343542921, -6.703294070708968}, {
          0.9948743934112386, -5.916842799769384}, {
          0.9971582461186663, -5.182777480484007}, {
          0.999442098826094, -4.892274893321199}, {
          1.0017259515335217`, -4.784007713535176}, {
          1.0040098042409493`, -4.806119631669417}, {
          1.0062936569483771`, -4.969224075217507}, {
          1.008577509655805, -5.368262793387527}, {
          1.0108613623632325`, -6.635163116956809}, {
          1.0131452150706601`, -5.981425334953935}, {
          1.0154290677780877`, -5.220567102585202}, {
          1.0177129204855153`, -4.925890467777765}, {
          1.0199967731929431`, -4.819088990617111}, {
          1.022280625900371, -4.847142685741951}, {
          1.0245644786077985`, -5.023869411050235}, {
          1.0268483313152261`, -5.4604426609981145`}, {
          1.0286264000518819`, -6.703294070708968}}], 
         LineBox[{{1.1642946756548047`, -6.703294070708968}, {
          1.1658437771672123`, -5.6744273780391365`}, {
          1.1679749025397665`, -5.271258351004903}, {
          1.1701060279123205`, -5.1258293776071335`}, {
          1.1722371532848745`, -5.143146306972404}, {
          1.1743682786574285`, -5.3338753741220035`}, {
          1.1764994040299825`, -5.845259634909304}, {
          1.1769218798860894`, -6.703294070708968}}], 
         LineBox[{{1.308970697735574, -6.703294070708968}, {
          1.3101670043751112`, -6.158569683169667}, {
          1.312545979852804, -5.554346776702081}, {
          1.314924955330497, -5.403124426991007}, {
          1.3173039308081897`, -5.5207340164285235`}, {
          1.3196829062858826`, -6.047506023195793}, {
          1.3205530544496982`, -6.703294070708968}}], 
         LineBox[{{0.9754491392781973, -6.703294070708968}, {
          0.9766035717518172, -5.690453323000475}, {
          0.9788874244592449, -5.085544195425948}, {
          0.9811712771666726, -4.832643357066817}, {
          0.9834551298741003, -4.743199469954643}, {
          0.9857389825815279, -4.77782491515193}, {
          0.9880228352889556, -4.952046719035365}, {
          0.9903066879963833, -5.367138094134652}, {
          0.9925570071748323, -6.703294070708968}}], 
         LineBox[{{1.2684666102677407`, -6.703294070708968}, {
          1.269724421254333, -5.776490662929085}, {
          1.2721033967320259`, -5.393846526631502}, {
          1.2744823722097187`, -5.325957970709223}, {
          1.2768613476874116`, -5.5092363501758745`}, {
          1.2792403231651044`, -6.169216607088446}, {
          1.2807319548773786`, -6.703294070708968}}], 
         LineBox[CompressedData["
1:eJwBkQFu/iFib1JlAgAAABgAAAACAAAAVhPlGQ2z4z+1qSRSLNAawGKe0cBk
wOM/qgizo4UzFcCUMlUnPNPjP4haltQxkxLAx8bYjRPm4z+dWXffk00RwPpa
XPTq+OM/xD1oOwiYEMAt799awgvkP20/oaHZORDAYINjwZke5D/xdi2Rbh4Q
wJIX5ydxMeQ/rzi5letAEMDFq2qOSETkP+Wa5bGPqBDA+D/u9B9X5D8p3QO2
SW4RwCrUcVv3aeQ/sKsM6q7XEsBdaPXBznzkP9O7FUUZ/BXAkPx4KKaP5D+d
ovYsrIAZwMOQ/I59ouQ/fPLHuob4E8D2JID1VLXkP/2VrTuSGBLAKLkDXCzI
5D9iNT9SrhwRwFtNh8ID2+Q/yBhgIMuTEMCO4Qop2+3kP+6FCEASWRDAwHWO
j7IA5T9t7G05ZGAQwPMJEvaJE+U/zUFBa7erEMAmnpVcYSblP4e0oVihTBHA
WTIZwzg55T+jfoCPWXUSwIzGnCkQTOU/KnD7B2rRFMBovhOgzFDlP7WpJFIs
0BrA7QnB4w==
          "]], 
         LineBox[{{0.7660694149131547, -6.703294070708968}, {
          0.7673721282993795, -5.527232057050023}, {
          0.7695193775256872, -4.87750247182825}, {
          0.7716666267519949, -4.570442592313847}, {
          0.7738138759783026, -4.4076953389033635`}, {
          0.7759611252046104, -4.3351679975785204`}, {
          0.7781083744309181, -4.335386441673064}, {
          0.7802556236572258, -4.408888243079637}, {
          0.7824028728835335, -4.574702592076966}, {
          0.7845501221098412, -4.891146093016436}, {
          0.7866973713361489, -5.579886019874111}, {
          0.7883108905256732, -6.703294070708968}}], 
         LineBox[{{0.9157967163426063, -6.703294070708968}, {
          0.9178006091036988, -5.900184618039391}, {
          0.9199056455328496, -5.147294800885312}, {
          0.9220106819620005, -4.8256065541555095`}, {
          0.9241157183911515, -4.672044513487223}, {
          0.9262207548203023, -4.62497702021368}, {
          0.9283257912494531, -4.670416965923279}, {
          0.930430827678604, -4.823206434781068}, {
          0.9325358641077548, -5.147135057944175}, {
          0.9346409005369057, -5.9189809030785865`}, {
          0.9367171028083722, -6.703294070708968}}], 
         LineBox[{{1.0489314668611374`, -6.703294070708968}, {
          1.049686858389503, -5.645029569583206}, {
          1.0519707110969305`, -5.132391820044387}, {
          1.0542545638043581`, -4.928238400875529}, {
          1.056538416511786, -4.887745232767317}, {
          1.0588222692192137`, -4.9918984145427325`}, {
          1.0611061219266413`, -5.299290289360105}, {
          1.063389974634069, -6.14773013162775}, {
          1.0656738273414967`, -6.474757518034131}, {
          1.0679576800489246`, -5.409814250288178}, {
          1.0702415327563521`, -5.0551527575084}, {
          1.0725253854637797`, -4.927228459618097}, {
          1.0748092381712073`, -4.9510669212659195`}, {
          1.077093090878635, -5.140096223480567}, {
          1.0793769435860627`, -5.631504932953631}, {
          1.0802918422057208`, -6.703294070708968}}], 
         LineBox[{{1.1947228487597106`, -6.703294070708968}, {
          1.1956795323829685`, -6.066130189369017}, {
          1.1978106577555225`, -5.444610219554535}, {
          1.1999417831280765`, -5.217576712667414}, {
          1.2020729085006305`, -5.181933132947803}, {
          1.2042040338731845`, -5.317747302868207}, {
          1.2063351592457385`, -5.721568538360676}, {
          1.2077210136706662`, -6.703294070708968}}], 
         LineBox[{{0.9563754531510238, -6.703294070708968}, {
          0.9583327500923957, -5.393162557645201}, {
          0.9606166027998234, -4.949518510718879}, {
          0.9629004555072511, -4.756379456236092}, {
          0.9651843082146787, -4.702777728610762}, {
          0.9674681609221064, -4.767712648155984}, {
          0.9697520136295341, -4.979316169115589}, {
          0.9720358663369618, -5.472733773394015}, {
          0.9733009905378233, -6.703294070708968}}], 
         LineBox[{{1.0298096355955528`, -6.703294070708968}, {
          1.0314160367300818`, -5.864970896628866}, {
          1.0336998894375093`, -5.197414960518287}, {
          1.035983742144937, -4.934193094521823}, {
          1.0382675948523645`, -4.850267449304512}, {
          1.0405514475597921`, -4.904415549167426}, {
          1.04283530026722, -5.12409952876509}, {
          1.0451191529746477`, -5.674472010761061}, {
          1.0458603489305647`, -6.703294070708968}}], 
         LineBox[{{1.1803584426429865`, -6.703294070708968}, {
          1.1807616547750905`, -5.8935132813484135`}, {
          1.1828927801476445`, -5.369099485888468}, {
          1.1850239055201985`, -5.174282200367477}, {
          1.1871550308927525`, -5.157276407546293}, {
          1.1892861562653065`, -5.309628771628878}, {
          1.1914172816378605`, -5.74034709801529}, {
          1.1925932102072516`, -6.703294070708968}}], 
         LineBox[{{1.3234344326931686`, -6.703294070708968}, {
          1.3244408572412683`, -5.869492749020945}, {
          1.326819832718961, -5.487896888113575}, {
          1.329198808196654, -5.443999338858728}, {
          1.3315777836743468`, -5.691917449923566}, {
          1.3339567591520396`, -6.659890464272243}, {
          1.3363357346297324`, -6.464071946016169}, {
          1.3387147101074253`, -5.664866692275009}, {
          1.341093685585118, -5.460730264346393}, {
          1.343472661062811, -5.545520003710131}, {
          1.3458516365405038`, -6.023615199481715}, {
          1.346499355373863, -6.703294070708968}}], 
         LineBox[{{0.7190085030123241, -6.703294070708968}, {
          0.7201326453206098, -5.308154218851464}, {
          0.7222798945469175, -4.7487985004861315`}, {
          0.7244271437732253, -4.467852353177022}, {
          0.726574392999533, -4.314390523218858}, {
          0.7287216422258407, -4.2429932024985915`}, {
          0.7308688914521484, -4.238063669664678}, {
          0.7330161406784561, -4.299030834375394}, {
          0.7351633899047638, -4.439896502832493}, {
          0.7373106391310715, -4.702138263581496}, {
          0.7394578883573792, -5.219181287537568}, {
          0.7411235696424631, -6.703294070708968}}], 
         LineBox[{{0.8555435512256333, -6.703294070708968}, {
          0.8567545526583236, -5.439411790249152}, {
          0.8588595890874744, -4.914843268925506}, {
          0.8609646255166252, -4.660517271716436}, {
          0.8630696619457761, -4.53652109875691}, {
          0.8651746983749269, -4.502756456591474}, {
          0.8672797348040778, -4.550736555324752}, {
          0.8693847712332288, -4.6942189534638725`}, {
          0.8714898076623796, -4.985182006426403}, {
          0.8735948440915304, -5.619811030900672}, {
          0.8747072228363132, -6.703294070708968}}], 
         LineBox[{{1.1469579334598354`, -6.703294070708968}, {
          1.14879477418678, -6.221670717031773}, {
          1.150925899559334, -5.451768973079982}, {
          1.153057024931888, -5.168170087366447}, {
          1.155188150304442, -5.083372240807774}, {
          1.157319275676996, -5.150779511716559}, {
          1.15945040104955, -5.408822322915026}, {
          1.161581526422104, -6.1016407393523355`}, {
          1.1628790145773205`, -6.703294070708968}}], 
         LineBox[{{1.2822008674981857`, -6.703294070708968}, {
          1.28399827412049, -5.721365846420188}, {
          1.286377249598183, -5.395133145771764}, {
          1.2887562250758757`, -5.365517020904019}, {
          1.2911352005535686`, -5.605810265955067}, {
          1.2935141760312614`, -6.479425843959939}, {
          1.2958931515089542`, -6.541515007104881}, {
          1.298272126986647, -5.639430777088662}, {
          1.30065110246434, -5.393371326086692}, {
          1.3030300779420327`, -5.424006155740407}, {
          1.3054090534197256`, -5.765034218233927}, {
          1.306920521348102, -6.703294070708968}}], 
         LineBox[{{1.2095017384820788`, -6.703294070708968}, {
          1.2105974099908465`, -6.1446486017365105`}, {
          1.2127285353634005`, -5.485229887627784}, {
          1.2148596607359545`, -5.2491858941567635`}, {
          1.2169907861085085`, -5.211811468510485}, {
          1.2191219114810625`, -5.351344662641553}, {
          1.2212530368536165`, -5.771235047798762}, {
          1.2224203987368425`, -6.703294070708968}}], 
         LineBox[{{1.360946851214531, -6.703294070708968}, {
          1.3625044648843536`, -6.374369095511541}, {
          1.3648834403620465`, -5.671660983403974}, {
          1.3672624158397393`, -5.507547134517277}, {
          1.3696413913174321`, -5.644096614900109}, {
          1.372020366795125, -6.275982571889247}, {
          1.3732248528806166`, -6.703294070708968}}], 
         LineBox[{{1.239825072477298, -6.703294070708968}, {
          1.241176715522019, -5.734400691173824}, {
          1.2435556909997119`, -5.347267564924941}, {
          1.2459346664774047`, -5.265965158992073}, {
          1.2483136419550975`, -5.418329888639779}, {
          1.2506926174327904`, -5.966398690112893}, {
          1.251668605419889, -6.703294070708968}}], 
         LineBox[{{1.1327145212281327`, -6.703294070708968}, {
          1.1338768965789021`, -5.705123368748012}, {
          1.1360080219514561`, -5.253263259853879}, {
          1.1381391473240101`, -5.077917047650153}, {
          1.1402702726965641`, -5.062382557369671}, {
          1.1424013980691181`, -5.1998559149385635`}, {
          1.1445325234416721`, -5.575984112566549}, {
          1.1465271226350269`, -6.703294070708968}}], 
         LineBox[{{1.3499089247991778`, -6.703294070708968}, {
          1.3506095874958894`, -5.944865312914974}, {
          1.3529885629735823`, -5.541557691285129}, {
          1.3553675384512751`, -5.498013507503385}, {
          1.357746513928968, -5.765243802254242}, {
          1.3597542514101997`, -6.703294070708968}}], 
         LineBox[{{1.1156252907319695`, -6.703294070708968}, {
          1.1168278935984701`, -6.014982744367852}, {
          1.1189590189710241`, -5.353903504770459}, {
          1.1210901443435781`, -5.096062975372411}, {
          1.1232212697161321`, -5.019238236880911}, {
          1.1253523950886861`, -5.084796142116851}, {
          1.1274835204612401`, -5.327387162552801}, {
          1.1296146458337941`, -5.950901273843862}, {
          1.130626734803593, -6.703294070708968}}], 
         LineBox[{{1.2543452449639967`, -6.703294070708968}, {
          1.255450568388176, -5.7840015341991835`}, {
          1.2578295438658689`, -5.379439439701164}, {
          1.2602085193435617`, -5.294442252095127}, {
          1.2625874948212545`, -5.450224423375801}, {
          1.2649664702989474`, -6.019830876923712}, {
          1.2660435526275455`, -6.703294070708968}}], 
         LineBox[{{1.3751745475594719`, -6.703294070708968}, {
          1.3767783177505106`, -5.84127414973337}, {
          1.3791572932282035`, -5.5517885172498245`}, {
          1.3815362687058963`, -5.592185987482308}, {
          1.3839152441835894`, -6.017341240446664}, {
          1.384086690870447, -6.703294070708968}}]}, 
        Annotation[#, "Charting`Private`Tag$16559#5"]& ]}}, {}}, {
    DisplayFunction -> Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
       None}, DisplayFunction -> Identity, DisplayFunction -> Identity, Ticks -> {
       Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
        MachinePrecision, RotateLabel -> 0], 
       Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
        MachinePrecision, RotateLabel -> 0]}, 
     AxesOrigin -> {-5.6895831070962055`, -7.245241751611114}, FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
         MachinePrecision, RotateLabel -> 0], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
         MachinePrecision, RotateLabel -> 0], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, GridLines -> {None, None}, 
     DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "ClippingRange" -> {{{-5.545177303020954, 
        1.3862942196612822`}, {-15.535547698428484`, 
        3.0517641855299504`}}, {{-5.545177303020954, 
        1.3862942196612822`}, {-6.703294070708968, 3.0517641855299504`}}}}, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
       None}, PlotRange -> NCache[{{-Log[256], 
         Log[4]}, {-6.703294070708968, 
        3.0517641855299504`}}, {{-5.545177444479562, 
       1.3862943611198906`}, {-6.703294070708968, 3.0517641855299504`}}], 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"10\"", "\"20\"", "\"30\"", "\"40\"", "\"50\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.560181, 0.691569, 0.194885]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.922526, 0.385626, 0.209179]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.528488, 0.470624, 0.701351]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.900183850169009*^9, 3.900183873959669*^9}, {
   3.9001854763052607`*^9, 3.900185529446487*^9}, 3.9002306531763268`*^9, 
   3.900231499336194*^9, 3.900232734489543*^9, 3.900233045137652*^9, 
   3.900240127479947*^9, 3.901375483348469*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"0967e3e9-715d-4c9a-a2ba-a007a11de1a5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"convergence", " ", 
     RowBox[{"test", ":", " ", 
      RowBox[{
      "are", " ", "results", " ", "consistent", " ", "w", " ", "R"}]}]}], "=",
     "5"}], "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"LogLogPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Abs", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fAr", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "[", "r", "]"}], "-", 
        RowBox[{
         RowBox[{"fAr", "[", 
          RowBox[{"[", "5", "]"}], "]"}], "[", "r", "]"}]}], "]"}], ",", 
      RowBox[{"5", 
       RowBox[{"Abs", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"fAr", "[", 
           RowBox[{"[", "4", "]"}], "]"}], "[", "r", "]"}], "-", 
         RowBox[{
          RowBox[{"fAr", "[", 
           RowBox[{"[", "5", "]"}], "]"}], "[", "r", "]"}]}], "]"}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "0", ",", "afin"}], "}"}], ",", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Darker", "[", "Cyan", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Darker", "[", "Red", "]"}], ",", "Dashed"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Dotted"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotRange", "->", "All"}], ",", 
    RowBox[{"PlotLegends", "->", 
     RowBox[{"{", 
      RowBox[{"\"\<h/4-h\>\"", ",", "\"\<h/2-h/4\>\""}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.9002307039022913`*^9, 3.900230737790288*^9}, {
   3.900230769698357*^9, 3.900230772082981*^9}, {3.900230860500969*^9, 
   3.900230882486162*^9}, {3.900231528949086*^9, 3.900231530345808*^9}, {
   3.900231701939259*^9, 3.900231704377894*^9}, {3.900231778762762*^9, 
   3.9002317789550734`*^9}, 3.900233059333186*^9, {3.901373397129817*^9, 
   3.9013734156614513`*^9}},
 CellLabel->"In[55]:=",ExpressionUUID->"2598ba5d-4d17-44f9-97e9-4bf5b0513b54"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 
           NCache[
            Rational[2, 3], 0.6666666666666666], 
           NCache[
            Rational[2, 3], 0.6666666666666666]]], 
         LineBox[CompressedData["
1:eJwUV3c81d8bv8a1996bhDTMSk5JQopSolTGl1SKSkgIKYVERhKSokhWWRnn
kT2zN9l7731/9/fXfZ17zvOc55zP+zzv91vcyuGCDSWBQEiiJhD+/2uz/WRF
S5EHXpjEZZ5TWsa68Tw/uBV44K6rve8H8lhON+O/8b08kBTi6z1OHs+Gjja/
luaBB1E7Oz7Ky9hV/nxmhxAPDFN2Uv5WWcb+V2Qc7jHygNZk5IUD6ss4Nbdh
/P04N+gVJ4DmsWW85iTdMx/PDX31P2H89DLm/l2YO8rIDXEvdgtqLJdxZ4jm
dJ8nF5w1STbv8ljGR39fNPmwzAl5LTRdH2KW8d40s+yP1zmhxqjtb0zZMi5U
PX03sYkDwvqOvGBfWMa9/pICK0c4YLjB1J1WdgV/2B++Q5vIDgvXp9ju3lzB
JNs5NWFBdlAOkgqJSFnBc7fV7dx82eBJR0jDN+pVTE/V0vdzjhV46crWIm1W
sUOj5ZWtbhboCd06p9O6ipmeknLOtbOAUn2x8sX2VZysEMMd38QCxysWQ6w7
V/GoX0eDbhULdD58mfOidxVf1zQ8HZHNAgf3PGrqG1nF575rKB8MYYH420bW
7aurWPE5L8tNHRaI0ZnkX+Jfw7PqdcVN6cygzElFLWmzhsXlJQ45pzDD49go
BYeba/iisEs8/zdmcGLemCy4tYbzKcSfWXxkhhO+JorX7q3hl9VO2rOvmSHM
ZG053YUcby5UQX+HGSRXMzIS/cnxT+/UHpdmBoV07pyWjDWcV0bfnvqeCexi
vvwIIq5jI0UWv+UwJnhFk/HpBd06Ho/gUDsSzAQa6yvDXozrmM9O8F3ZCyZ4
e43Hyp19HTsz7Lvc85AJHuDqR2+E1/EhQ6N2+nNM8Hn8IlFWdR1/74ho/4+S
Ccpnzjgr3VrHMVOSHQJ3GOGe5c2Vk+3r+PduT5KzLSPMdlbrNHWt4zb2iCdN
lowQ7MLnZN23jlnU6UT9TRmBQlb9XtDIOvbynbbZOMUIt/Q7lGiX1/F/wllL
7WKMMJ9flfKCfQMrGOqwhrcxgGy5hXvzuQ1ckGmnw6rFAAxccs9tmjfwPYZO
ufxjDCB8kvXc4/YNLGqlx3rzMAPITNhdDu7ewD7sch1FBxiAWKtyuHJoA+s5
Tt26J8oAnTUPom4sb+C2ffde123TQ778ntn9PJt44dvDloAcepANPlPlaL6J
ZT56WtHto4eAsPuyJsubWONu7AsTWXr4U5VsWLaxiS8cLUr+IkkPTgOrPodJ
m9izfWfxuAA98DY+3XOQYQu3sXo8e0xLD1z/DYhcF9vCfl5PvkwO0IGsiWz8
r7NbeNzSdbQ2gg7Uzt21e56yhXf3RzIIvqUDuiCle58ztzDXbo7irdd0YMBT
ZFORu4WPR605E33pYCDtsb542RaObHKm1bxPBz65dg3CfVtY9+Qj2bQzdJCz
vHjwBPs2vs4ebrCjQwdTF2PQH95t7PTvl+MZLTrQTqqt0BPZxnFPlnPH1OmA
N/WEvb38Nl7/+VBPTIYOPjIeo6fQ2cYsPqF374nTwcYr/dlsg20sZfQzpECI
Du6V1Uc+NN7GRtOLnaacdKCpIGpDYbmNbX9z7Cay0MHVoqCoppvb2P3lIYkV
ejoI1ykoSL63jZOkHtwOIdABvHWec3DfxhfV9D7t36aFXIU3eaM+25igL9ZR
t0YLj1IrUq1fbePv5mss9ku00FbKu3QqcBubONSfYpijhcyzJ60Sg7YxhU+C
+7dJWniZXvGYLmQbp4S5/9QZpYUT15mO2oduY8rfcuLPemkhn8kd1CO38Y9a
ClPxTlpYSfDw+xS1jU3/dQThFlpYLpreYYzZxmnUfttbNbRg1NG4O/JpG5sb
DrU7/aaFCw9PPU79vo3Z3C6eMnWihQcUm1LjzdvY9a+qmOg4DawgR8PpvTv4
pWlhxI0hGsi8kiSyobCD3w2cZI7rowFXNWNjugM7OHvJaFOslQZoXl9d3ae6
g1d477RI/KEBT+73NhFaO/iBxceXMtE0wAOVxL6rO9h+gXZhnxENjKhU9ZkF
72ALzs5ijVwikNgN2aIpdvGyDteV0J9E+Fk6dvMUcRe/cjNcnEglQiT+k7dA
t4szB8ok3iUQ4RrbT1Njtl1MnZ75bOEtEbp2P3QfEd3FSQaBpxLvEiFD2KAs
5tguXnyOqlgliaC26hFT7b6Ln60nNAy+pgYFSR6G10QSTnGMfPLqFTWkX/o5
/IeehNvG/WUOPKcGomO2zDYzCct1Orh7uFNDcvLbOVceEm7IOyzLd4cansec
3/6wh4RFntQ9PatLDfQtn84H6JPw751lxVxKatC+yh8tF0rCi5Tar1+7UMHo
FNOh/XwE8FoYcWl7QAV0Hw7cIgkQgKXfz0r0HhW802443SRMALnCGrWM/6iA
9pIxvZckAaxdjAdbzlOBjPxj0pYiAVqmrNSEFKhA8cu+PlcdAlh1UUvY7KGC
Tz2N6o/0CDBfmciUKkEF2mZyj5wMCMCUODmA+KnAb8gl/skFApyyeBBoTUMF
7Hfjjv24ToDsFu+B5H5KqJJeJ8W5EEC7RLJ2qZsSzOrcTercCNCUUZat0U4J
4sb7GrY9CDAbRB9YX0cJOx/9NW18CbBHL0R18Tcl2FHdfGYeQs6npiR+NJsS
rucdd4gPI+eTaWX0zaCEewKC8VPvCGBBxT/A/Y0SxORvzvnFEiCyMC7gcDgl
JFx+mjL+nQAyKVrOPsGUcDb0xEW9NAL8ihq2qAmgBF0JmVs/MgnQ4CKres2H
HF8sNvs0jwDXbavFEj0oYdJRxW62gADTF+0Z51wpQXjqlrUFEMDtJMuqmhMl
XDRrH24tIQD9ofR+LwdKuOnwaeFcBXl/sQs1Vbcp4dNxiVONVeT9WZezOGzJ
60NpLdUryfvvhMddtaSEO8zevbHlBNCaVgv4Yk4JBBfH39Rl5Hq6Oh/NXKYE
0+85a7fI+a9XPbFQNaaEqUj18Ppi8v6JWKVSjxIW8xzmw4sIENPJp2R5ihJI
Yz1CXIUEAKYHBzaPU0LY/IfCkHwC0D6UkldQp4SthdSrAbkECEOvxIJlKEHr
ox+tK/n8aR0XGE2pKCHPT4FeLZEAwwyj/WMFFHC48hfbmdcEOOvAFEh7gAKs
fxTplpsRYNVA4Hu2PAXInrwivNeUALFystU2eyjg1REL2wAT8vccOUlXKkIB
1Vk3Lp0zJkCQ+RNfL2YKOHBeNKGOjJ8GvUn3jUkCOF65s5WBCHBRqvLuVAIB
1nxI1OzSBNimaAuM+kSAvQ4vTlqR8frl39B3vRgC5O45upwpToCVKNLEVzIO
pucnv18QIUAEu5rtf88IUGD39kEALwE6dhOu91oQwPl92rlBegJc7Xxm+FeQ
nO/4u0S9HhK223ciVYy87pnnMS33DhJ28t5lesBBAHnj+wE/Wkg4aO/jai5y
HM/4jDRTHQl7LfX4/5om4cAjR13yCklYXznTufoTCcsLtd1piSVh6x4F5buR
JPzt+72/C1Ek7O77dYH1DXn+wLU+5ncknNYSbX/JnYTv3s7aOUH+n+uRn1W/
CQkPvkvTjHpKwr1Z5udWGUlYptnqB4MFCa9ea2d8T0nCvk8pcjjMSZiN5kLV
0Y1dbFOzdIvflIS1TE5re4/u4lqeKzUSRiScuHrwCFPxLr57ZsJV+jgJ49iU
tdScXexx6l+VhAYJd+jsyTqfuosJQholIuokzPhO6MC7D7uYyJmbynGAhKXQ
u5nDb3fxrcjYOAYFEtYcY//e83IXi5e6HaGQJWFHNVoZCeddfOhIgs2kKAm/
+uc9VGq/i/MTClZ7BEk43m877qb1Ll7ZuLq/npeEC/a7XGe4sovD95YbKHKS
cGv7guAPI3K9SvKkCnJ/nH1q32l4ehfzsvez2azvYjrZsYhFcl+9d++oJ3Fq
Fx9x7WFXl9/FZ9SvXjNq2MXGYpf/donvYsvfYxWbf3axfWVjoAffLjZvTn76
LWsXf+SroC0h93W1L7GVzORzUedl7Jzt38F6HweukWx2se5kVH9w+w6OuGhF
lWi2iwMEfUua63fwqaftjoZndzGHp8krs8IdjH+GRiYrk899covLJmoHR3I3
1ntT7WLNOm0F94s72HRLwDPj0w52GWi/kly5jUNrN7uo+rfxb47iYzN4Gz+2
pLXbJfPd7slksQM529hH/NSdrYpt/CLRfTQrYRtfClyq3k7bxmF3xB8Uk3n8
o6hIqpDXNk5fuf2qQ4OsK15rE/+KbeNJ+t0cmowt/Oi4ccSs9RZe3aMjEPR1
C7PJUG+rXd7CVDpB7tyxW9glbnLpmf4WFvIROSEVsIXrQyWCJQ9u4bObmtUn
bLbw11UvJe/dTZw++bTHnX8LT5YVb/58v4kL6Co1qdm2MGuSvqn0601cJcP2
KYBmC3MafBd777WJB63ibKKWNnHWQf9xv5ubmLMbZnPqNvFtpmecPiqb2LmG
gmLJexMvF8i2jTaS9eOEnrWb6yb+7T1R61G2gd/Qvi2jcNjEf6YUGXjzNvC3
kxL+bGSdqNIWbmgUt4E787U4FVU38WHvoKreext4tNP/UZbCJr73WTD3hdUG
XlxrateQ3MRnfFl7DppsYAZl6+gzbJu49Wd9ftCxDayR8kz61uQGlhbIiLNi
2sC61TV+8/0beFzBjiBM2MCXxjknXcg6N7KA5Xnn0jq2ojE3INVt4HXFTwqR
Y+v4ntSX1BelGzj5hsiKafc6dtOaZmPJ38BJm03urZ3r+IWF8sPwjA0sfE99
U2pgHb/1dG8V+raBjUONZd3H1/HH6FIy1MjnIFRxdM+t45TfTFHy4RtY0Mmk
7MTaOs7tuLidGbCBO/ibz6TvruMGrhEodt3ALeEu1AnMG5jyNVH/34UNnNJ9
7PGs/AbmI+TMvdXbwKFMffr3lTaw4kO7cJ3jG5h7PIxm+8gGvmpW0/9j3wbe
S19qv1d/A/+SDnFxpyOvi3Y8O2K3gW2KhBL4i9ax9oT18+mvG7hyTolwcS/Z
13AWC0SS7/XNBavsStIq7iPO32ow3sIN53y8hdZW8Znz30u5r5FxdSbewHF2
FRuYzb62sd3Cb08ODvKSfRxX7pefUo+3cJiyFevN36u4LqdbX/IjWU/zWNkR
H61iz6DaI4dmtnB8l6WA1uQKblykf8FNxvVgm/dI+MAK7p3L+5Dpv40lmz+l
T3SsYINrF2nNyHrzS82ATkjFCvYjHRX+82Ubfy2wfNj/ZQVT5zis0pDfVUqs
Za3njRWcniHrcIttB2dZWXrmtyxjyUVZK4akHVx0pr/SuGYZF1yku1b1cwdX
Kt/gnC5exhUD+TPhRTu4i+baN6G0Zay6HH3EtGUHE76bNnm8WsaxpG5XXwK5
rywZyhzXXMYr7AStsKu7+GJPvWMH2ddrOFokHb65i6+Xnc13lF/G3v+EHs4+
2MWO784YfeIj+/LzJSkv/HdxxNHTbpRLS1ib9PP0o9+7eOCZZn3p1yXcQ8CD
dsIkPGlfyHctdgk3uI1Kc8mR8PIlDeuVsCWslvtxtUGVhGlkj6xL+yzhmvXN
rqfk/s3GnqdV5LqEidMzGg+ukTD/ptprE4clPJDNV+V8m4QValUk/MyX8HiP
JmWOLwmrZv2yFzVewjNhHyiWQkgYxSrl5Ogt4VHHtb8nPpLwBceDBuOqS/hh
vrmCQREJu3Dtc9ZjX8Jxn2F+hEDWizvfYYB2CYtos065knnOf1SO0W13Ea+e
TlYSIPNgdK5sXPLUInZlNDv3ksy/f8ylqhnLF7H+VJ0k72kCMCcIitS7LeIj
1k9spcn67DgvfRDNg0WsJvt3P0sUAZxere5o3lrEYR3mvcTPBOi529ibdnkR
H7i1FiiRRYBkVb+YEOVFfCdyYou7iwC6lYtCl2YX8COC0RNmso5wP9If+Hpk
AefTKORtkHVHekrddlnPAs6rLGtaO0IBvCHfelRrFvDNn2KP5AwpYNTsejTf
twWsus2Z6eBKAb5TVYI9lgs4x2DbJa2eAnKv5QRwmS3g00q09q2dFDD998uW
gdECDuXyl2cfoQDjX0+7CzUX8MVWokrNFgVIeKh8+Ci4gKUoB3rPy1GCyZwE
YwfHAo5AQsGKqpTgb8n2hI1hAQ9u7D6X1KKEhVNTV7zX5zGF67nIy1coQSq3
ozpvbh73OHDefEfWfaZy5UcWR+fxdLh+3/wDSgiM/pks1zePaW0mr/73lBKA
5ZOAdes8tlGbQYtkXbrsFeT/oXYeL4hbTEdFUoLs0pPN5pJ5vAZ/LzcmU4K5
za3bTPnkfCFHPN4VUsKbdpMu7cx5rLVQGRTWQNbJcUxRMm/msXgt/9syESrY
PujKP6k7jzssfHtXy6ngyEZ97bnj89hOet6ptIcKXEDa66faPDaoDGToWqSC
xXPNo+4y8/jCGSGZYVFqGL+j+IuVmny+xWzfbx7UcMaW4e/46hy2uS/JNhlO
DeXLOSqZI+TxR6pLz1KpoZCdk+pUyRz2Ty+zL+8n+5wzVTG3Peew1fVHVG16
RJDucqZWvjuHC82urAnaECHOTurOztU5/GE3W/KvFxEinj9VDz48h8MoK9X8
84jwDKs0Zy3P4geJzvdzDtCAuVI8HcWdWVzwdyAw9TAttBcbOlSbzeJbkrNN
6dfIPtRopzVUdxbP2D0k3fGhBd27pp9lZGZxp6ohv1w9Lah8ZdE0GJjBryiN
bJId6CBdpeALd8MMvvuENtQkig4USm8x/iuawbUezguU5XQgMVDacT96BkfN
rGwHiNFDjMMDdDRgBlMfjvruY0gPfLuiidRuM7j5CV3ej6f0EBpYx1RvN4Nd
XZJShTLogUXwycN3l2ewsz6Xfv8QPbxKku2y0JnBN57KS7sN0gO1ettxOZUZ
Mt/G+jhW0YNX+bOvS5IzeJmKjflrOj1sXTzIUsgxg8/8OHdNKJIenIf6nF5Q
zGD5Q+W8f8n7Ld4P7Dacn8Yl2xTThTfpYTxo7Ntg3TQ+w1zeoq9OD8WUF/v2
aU/j2fzv2qs+dFB/G5/0OjiNpXd5hy/doYOuJrmkJpFpfLPMa3ramA6W4ymc
XDam8OMwrsICaTqQOZlGX5w6hQ2knjWXkX1/4DMGlYv8U/jNpGh1khgtvJ96
FJVIM4WleLA5PRMtJBoPkNaXJnHtXcgOWaMBLJlbHVM/iYvXc8f5/9LAYomN
xdizSbzRG2G+8pQGSPKNZYfvT+IWtC7y0p4GmMI05AOvT2L1E2Z3NM1oQPo/
ztUDhyexaa68EacSDZhSFwe4zU7gRvmTjefGiWBjr7BQ2z2BJ7JmDGdbifCg
5Z2JaNUEFq9uZPpRQgRPDaqC+9kTONM2INA/gwgBX+6Jl36ewD61L0xefCRC
JFPXC56QCfyrdHL542sifHE6NW3nOYH/u0brUPyS7Pt70s/n35nAp+49/cDv
R4QibaEcZrMJLHTimOz950SoTvETstCZwFp10tyVz4jQzrXknak0gbNFRKxE
fIgwP1xlcJllAp/52iRY5UkEyecug3El45h34gYjrysRDswMnl5KH8fmyV0r
ds5E0Lh07sep2HEc9SgY/XYigom0tOuk6zgevaw9f+U+EV6WNTErK47jD7LL
JWG3iTBLVDxcETmGS7/PC0+aE8HIy3nCzG8M/0zWum94lVz/ZtH76Udj2Onz
MbVfZkRwmjPcZDcew+d+9Qq4mxBhs+N+vjnzGA40DtMkGhHB3Pj3nbmtUZyS
uiVle44IhXWUQj6To7iU396j3IAIXn9C3b9WjOJjd/h9n5PfMzEl69ii9yg2
LvEZ3dYigq3M7oyv4yhWmWe5anaCCJVxOrG8N0ax6VO6E1mICHsF35xLPjuK
DXTNI9k0ieAf3r6roTGKaZTXLO5oEGGaVSztr9wotqvtcek9RoSz/nY3rPhH
MS/N3KHJM0RIpc5gXaEdxVp7Xz3jvUIEtqcb2G91BD+6sTFnY0f+/hsnHAVG
RnDsWB1FG/k+mx/6i/1oHsEf98yfsiN/rwg7Qe+m9BEcbKmSvBJPBKELx7SE
74zg2hvF4aX/yHipfb6YZjaCz9T9aTWZI8I/nfp4Ld0RnNF4U5WNRIT4ozeo
7KRHMNfxdbEtERqQlfYuzfw3jAsGGUXLLWhAab1UR/fiMC7jed8wOk0DYQ+Y
17q0hnHq9YlneiQaWJ2+9PXuwWF8aPEg1QA7LeQOjNKGsgzj0ue8fzLVaEGz
hq6qt3II+/u8LqB4QQtxp84/dswZwia//bnko2iBAt7vpUocwg4JL0beptJC
6S85f9lnQ3jdXipEsoMWZPY/PJJ/fwi3vs81M5yhBb+k/MmzFkPYcJ+RK6ak
g3FJ6g/954Zw/zO+54/46EA/1uDMw2Pk+ZBvMg8V6eDY4oXNILkhHN9f1hat
QwcHdMySknmH8NG6p+ES9nQgGXXDtJx6CHsXdrvVxdIBz6wN7eDCIA6TmXjZ
30QH9Fr22Tt9g3hfiucdBzp62A5/YMNfO4hLZa84v0H0MHjsaYlR4iBe0L5R
OZBJD60hzx/Yhw7i1eWOHt05eqgcCRB/6TWIJ9zljn/fxwCpryOf4iuDOKeN
1DiRzgBuvRlHFVkHcRBxpKK3lRHuHsyd1NsewGVyZzrjZJjA4nnRe5uJARz1
fjdwzI0JdPbVrEWXDGDrNZZh3f3McNi7MTE3fQA7DM4WSQczg0Jr+6WWmAFs
KsHowbrKDBwewz8ZXQdws0+NhUEzCxAbJ6322AzgC1Y3YigMWGFdaoH95IUB
LDz6nj+8lhWmXNfgOhrAG+9qeJnl2aCvdsfBTWEAq3GH2M87sUGjGLVoBP8A
PiD27GFpKRuUOjHUZ9AMYEK5Ng4SZIecSjaPuqV+vKBZXBbrxg7JQrwKE/39
mPVkz8eUIXaIcRTupq7vx8rpXt/ozTgguFTSXyy/H3+1Oyq40MsBz/jkDmt8
68cCwdRd3C6c4Gx/YPxyeD/2FD4nlSbPBbdA9d1Dn34s6RFG952WG8y5jum8
cejHCV/TslbFeMDQ7uRKsnk/tvK49GPfV17QKtD7Uq7Xjz/ZT5npmfGCCpuR
8aBqPz56cczd7x0PyP5nQrkr2Y8n4gQenF/mBsFc8wx+9n48JrP+U+cmNwjx
lcPt7X+Y/vNpJ9YpLqCEJpH4tn94af1sNLM7F4zf/Ofemf4Pp63ZLKfzckE9
63QXW8A/fKtC35u3gBN+5ayr69r8wyEsqLHlJidE3SC+e4r+4Zc/sz7W83OC
Fy3HSjb/P3xsyaRDupEDDC7LZ0jX92HLKsR+/CwHHCKpsV771oe7mCbT1tg4
gO+r9t0wnz5sVZxcPd7ODsOr1/ZSqfVh69QaJcV77FAde9vvCHsfTpAgsm9p
sEO6jsvI/ale7FTLbjzLzA7uEcGf+j/2YnHfeoqQLDbgVC3hL6Lrxdo5RZK9
vGwQT+nP7DzSg78PMRw/PM0Kh/4aUSj+6cF1fZGHCpJZwciubzzmSQ8+8kVi
8+I+VuhXTui5ZNqDc/Mc8pUXWMCBwr6BWaUH25oXFX7PZoGgqI0cj9lufDA0
jMCgwwIiN+G7Sk03XrL0D69mZYEfSn4fZ7524/jmvcUtXcygQTgXmuDbjdP2
vc0bz2KG2louv2uW3fjlE5nGviRmMH/f7cat2Y2Lcjwu9ccww5RN/L06gW7s
Y1AqNxPCDAyk/SbHWrqwShFckXVjhqiaVb2V9C5s+DLvqck9ZtgbWXjsx+su
TFiV9H9jxQy6B89IC5/uwv9+t4+Jn2GGF9a2y9t5nXhEcptYJsQMlJXRbws+
duAwt6Pdc8VM8DbM+oWTewfWYpUeh2wmELeUc1Mw68DMO7ZWH74zwfHNHMto
jg4cz3/mjH04EzSUe166ONeO90f8CbbyZ4Iboaf0mGrb8UN8ZMHyKRN4KjQf
cH/ejnl2kn4+ucUELBvvpZSt2rGwuOds+HUmiCmz4JvWbMciawyrucZMoPB2
D9MXQXK+ZdOcYV0mKLg+S7q63oZ3z6WI8msywRn5rCXO1jb8jegrZKLEBF1r
T8ZqMtowt2XVzUVtJrhdqtX9LKgNX/2g5tp7mQk2gun/Hr3Tho1lQ3QId5jg
5bWGP0un2/BKz3XSVU8m4JN7l/1dqg270OV1LIQwgWqJVKxgXyseiSlYa8hj
AqcVdHfLqBXLJt1568PEDPNmzoz5qi3YsYSxhR4zw1e3QSYprhZMPD/36Hgb
M1z/cI7l9UIzDuvlI1TOMENNjwz7jZRmnD8dLtAkzAI+O285Kl8141SWc0Qz
VRZQFyFxHrzZjC2WtN4cNmSBxBvtPFQSzVhpNuIguw8LXPM6yWdPasJ9lduW
zNEswPUpjb+1pwkffej9310y/mqKBQU1fzfhwoUbjMqN5PyDfkJf3zVheoem
0/9Ns8BhqmVhtkdNmDjRJ09Bxwrzkhaijy804ZBex9BiDVZI1K4VG9zfhIUm
vtpye7HCNRt1iTPMTZj95aRbZxkrcL34IvlrshGHmBjEC9OyQXUim7RwZSNu
8LFMy1ZgA/Xx8T1zPo24GL/vDndngzm6S3tNLRrxha7sV6Jf2SBxb7Fc8bFG
HFZxqv59Mxtw3Xm/L3S9AX80U50RVWKHmgDi/u3WBqyom0UXa8sOPin3D9j8
bMBpH1ptl6PZQb2u92B9cAPmfp1m59zGDnMzekpq9xow78r5uBecHJDIkq0c
d6YB16RPF0Vd5ADz/RKq9HsbcN4U9b/jURwQNrB8P7viLxaZeswqpcoJlJJ1
Ti99/mKrHIZq3SBOcPgvweXKsb94PyMLx9IsJ/QkeLgprNfjoT1FwvNmXKA/
dsljN7Mev/E81JfeyAW5sopeDXfrcVWOHm28GTfI3KZ5Fi9bjzOqR0IrV7kh
7Hvfc6ehOsx7+dLP2XQeoJjJfqkTW4dHEywIMuG8cE/xTQCfWR0+e1OrbSuf
D3ocbgZNctbh4IA7AiXmAqCfgUIK6muxHasTr+deYchd5A0LelWLWT+pdhX8
kAAZ5fkIC+1aXGp/v4i2SARCH1W+P0SqwSrPOqvRdSEg5MRFU/+uwRPavAbl
gwJwb931Y5tTDV7qnWShrueHnsPn47/tr8HNMmLqS0t8oPdkb4LbZDUe/id3
awrxQXYBxTeDhGqcpv0gPyiRF6R2O5NFLKrx+/w/P+fEeOEtyvwxL1CNz+Nf
As+TeYDk5Z/+p7UKz3pzEvcd5wH7P1Y/w4Kr8B9LLfPEf9zQRXU02/ZMFe63
ebBy0o8bdE9x5qnTVGEVLZv1QhVuyHoxlc9QXIkTrnzW55rkgmD66OJU1Uq8
6rhX56wlF+zqO5V6LVTgcTbFeCpJLrAPNKi4kFKBnQQ+ZOwb54TTrDu1q+IV
eNSNLeH+E07YzK6tnm4rxz+a9+zWaHNC6vXoysGAcmwjGBJUx8YJPKlHS+tX
ynCAxC2q+jQOqL7E+Kc0uQx/mKqhsPHhAM+dLvz7RhlW/fomt8GEzE8JyYXp
XGX4a0VH75QCB4wauOUnVpXiFYuWZhYaDoha1suL9izFm/TJqQ1b7HAumj/n
rVIp7jpwNTxxgR2ypnIzPWNKsLm0huTrXnbw9V9LMrn/B//2WaTVyCbj+1DF
VwOZP1jwtM9aWAo7THdGJGh1F2OKN7f/I8Wzw8W9qp8UTxXj8feKYbTB7CBZ
6RRJww+4u+FUQe9tdkj991Jh4wPGfvHGm78t2YFnv6zsCBFjuyjt6K+m7DBS
Zyta2FmIk2fLBVN12MFAmEYw6WQh1vvy07fiGDv8sk/gCf9RQI6XtptTZgeh
Am0OMrFj1+7tIGkFcr2Mw8x3vfNx3VXDkluS5PquPKM3m/qNvzrutscKketL
liCeuvSbjAdu/kVZdijYKCYcxHn47t9l2Ycq5Hr1LLeF9ubhS5SCpyS12ME/
krBOF5qLicHsuVSG7LA49nFpeTsHGzZLdXGbs8OfF32TtQ3ZOLPWpK3FmR3k
2jxGc49k42cE0R++vuzwVlp48MuXLCxxa7+i/Vt2sCy92unu+gtXi+2ZHE9l
BwJlZ4WCWCYWY1wdrZ1kB7vzriV8/hnYNcj/8N1NdmiI48XUy+n4VNXG9EUG
DtB8mmKf9yYNs/O0n6KW5wBmkSnrEOtU/O2MkXTjUQ7oKdh79ZbaDyyXcadv
zoADUq7aXTjBmIJnUxzvWF/ngCebiXr8/5LxVszKvKIjB+i/Hzm+kJmE97bF
ZKq84QABdSn1qhffsGerIHdvIQdMtFnt/3TlK2YUZOfumeWA3EefZB4rJmI3
0xkvRwlOeMnVL3yeMgGvCAUfGTTlhMs/Rbj3tn3GZ1NMXz5/ywmr8x+oOj0+
4bBlX1Yqdi5gz/r+LcsmDnOc71fgvMAFZovOH6Q+xGIbNwPlrHfk9+QWMdJ7
Oxqf8BsaiRjkgnLK7P3vjkTh+tqzbW+UuGHbv/WxEUMk/jX5mCE9gBsOca6U
0HeFY5My85BL09xg94GLpSQpFF/aV/X67GUe+CipbOr+OARPpGc30/3lge+X
v2rfeRuEvc6oTiyZ8AKf3WhH70F/3H0Gu3Mu84Kvq/Rdo8bn+E7pkNLBVD5Y
ePkfRYmjN/542j782lt+KDh0Wv6OmBuOoP3lLJknAOHGZcZGN+7jYy2J4vVm
QtA7/mL9toYlVs2aun5YRhQI5ioffzygQNWHwtsbi2ShMNTLhlBpiSotZijf
+ooBca8Wg2DCfaQ5VrmVoi8CCnSlAyq2bqh00klB+YcQJC3Fm38L9UaHC8ZU
514IgsaQdaXK8nOkSiUhciBeABqapJRLLvqjUsXszpVRfrD+M/LRKCsICfIU
Lt3W5Yct02binH8I6hdsMhwq4oPShp/5KvmhiEbw/rfbp/ggSDfsvvtUOHp0
85hRbAcvmILTnhLBSERxzjaH05kXJNQv9dIbRKERt5BxCiFemE5TCTVyj0a5
91TzmKt4IGsPj967lFjUf0tPZa87D3wJuHPl7YtPaHBNxMJigRteVVzNyoqN
R4Ednw9rZXLDPSoDts7sz2iOxbc91ZkbLiCNO9v1X1BV959D2prcoPZEoVx0
LAERRl+ZpdGR9X6OkPhJUiLyKQrwSGrlAsISk7st7zckdrkwY+ULF4wo7rS9
2p+Ebj2nm44i6//q2zMHf5xORrk3vJCsIxekJfYGNtz4jnKd82VarbkgbLBu
bMklBamWXVqMu8wF166kxhz5looYgwnhbxEXrH/Jof7PNwO9rlYoqmXjgsk/
+zMfsWUiubCqSzeIXNDb//WGX3QmimcuYWHa5IQ/QpG/k3/9RBzUOu0ZQ2R/
cYTNruD4L6RFGzGR1MEJX01fctfX/kLfJn0lftdxQmCYq+PCcBZyuJOqLJ7L
CZ6Z88JU97MRzegZBZcfnHC/wa6GaycbKR9h8xuK54T/ZvtdZV7loMKUv902
kZxgwmQmo86di4RSD5fuvOYEXbnGZr1PuSi1R/x+CXl8RFfP++q+PKTW5KAS
8oETFGyLFe/m5aEj9CObEUmcIOp7uMfz1G/EeEveoS2HE3xb/4Tq9v5GaQtK
av4VnDApY3CG41E+YvgcKvminROyq67/TvhSgIIYqi0t1jnhHKtvZC0VRmk3
3s5NHeOCXxbMRhEfMIqxOvVunxEXMJvVUKXzA7r07bb6XysueJh8Mf9xBqD3
tMWVJ15xgYwx/7vrO4DoL/SSBGK4oHOr98FJvWKUTHG9+r8MLgj8En9ONrwY
uRRtbEqWcwE6e1OOeaAYsQzfzLrWzQWLK/I0iwp/0H5S5C01Dm5IiJ0faHP9
gwbF069Hn+UG09NZhfmlfxBl9YJTQyA3MM4/fh/HVoKGfR7HmTRwQ1Gk5qPn
5iWI6V2JSD0fD9w/QXX+9rcSpCuliLZseUBqskLBcLkEbSwq9TXn80D720A6
5eOlSFOKPTaEjxf8j54f5gssRf+Mo6/UefLCsWFu2GkvRee9UvmS53lhPrDr
w6BkGRKpeqsteJ8PPqt8dKlwKEMB/AXy16n5waTP2jglvwwxqN016iZfFL2f
7P4Q2nLEfXQ1YN5LAAr2zzA4G5ejDJrGKnY/QXDoyBi98rEcvchu/u/khBBI
eDv/QVPl6GYNqXWISRRa9h6NlVKrQGG2DzsJu+Lg10R6TP+sAgm3Rgq9EpSA
I09KL83WV6C7/w0fSxARgxnJVwebBSpR9tXlcildEYirPcuca1uJPq+un32y
LgTGjzgmojMrUVXS0JmILUGgEWkv9d6tRASpX8a+BwQhr/xDnK1+FdqGH5Gl
LwTA3sHC/UxEFUr0DmYfXOYHUT5p0wODVahz5YLTnBM/NMGEErdiNbolnVq+
SskPz2+lsm4+rkb3ijX+HIjmA3WOh1N9ZdXoMKO+wjtNPoi13o7/dq0GHdfz
i9j3nhfOMxV7vk6qQUJNpe2nDHmBOuv5lQcrNchOU+LdAQZeyLmmr3r5RC1S
/6J96CK5H92mYeXQeF2L7iZI0h0K5AHhtOYZsc5alBP53wlGNx5ouBxZRZSu
Q1Xj/CVfb/GAapK499+COqSydmLypR4PTJwfNf9FV49mRruvVR/mgejNZPX3
F+vR3levc5AcD1AaKM9bTdcj/Xs/7gEjD9x0+bx/i7kBdRw7p7VCxleUS/8b
DaUGdBr2bi3+4YZaF+F5D9MGNJ1bIMCfxQ27LleMsEcDElTr/2z7lRsOuL5L
J3xuQJOu4fFd77nByrWFTauyAX1WjpB3IuM3zJX9/rOZBrS5/oHq1QduKHc9
11jK0YhKv96mbkzhhnXXgIM06o1oPx+jgUMRN8g9rgw5fa0RSQ1Pcd4k12P+
mLj40qcRPT8SWpo/yA3w+GkmY10jmiyg9/Wn44FXbg+V2K2aUMcdk5UDZjxQ
4JYeesGvCblf+qbnc48HZt1mlkJTmtDem+B60ZcHxJ7IXWxtbEJr3p/u/oji
gQtPbv7iWWtC4+4MnqEZPOD75AuXqVAzmv/22+n//JD9ZMDp/YlmVLdnWMhn
lgfGn4i0dtk2o6OnM88uH+AFAferKkKBzUjoqaCaoisvGLhHhl/LaEanio0P
TZbygqd760psWzO6jufS2fj4IN2dw6R/qxm18NxsrHzAB4Puhtni4i2omFlT
JqSND7g8AnmsdVrQUQdGXttT/KDjUeX85U4Lkto7Oksq5gdXD5r2keAWNPTS
76OGkQB89ziptie7BalqZBn2rwhAn4fXO7vuFuTzT0mXs0AQ2DwL15IIrchV
6XDlr0wh0PLcvDwl3YrkZcZYRTaEwclTLVfhTCsypeOd9ewRhURPJ757jq0o
mfYIvUWVOHR4ZrimhbcituaXp5XLJIHh6WzH/O9WdHRHpMCcWRw0nsofPtTf
il4Llmz97heFe0/t3j8ktqGT5aEBRCfy+3yasPFLrg354sFrgjeFoenpoNmq
YRuqXAy/PRQiBNReor/VHrWhxEMu+yQHBEHVy1zgcVQbCrKU6xfXFwQ7r/du
v3Eb0rxV7366XACivNq6tobbkImAk/PR8wJQ58V59BhDOwpY7f+0McYPBG+j
D57725GuqZXIxZf8cMj79Ra+2I58ht5lJx/gh/+8q69SuLWjDO5zn4r+8UGE
N22B1sd2tCecUj8ijA8qvbWFfEvb0abTQtztc3yw6e3tXjZBnvf66TijygcK
PkU9NKwdSOtqR32fJB9c99nS0FXuQHZe13xE2Pkg2Ec95pVZB/K8QT+atMsL
f3we7VR7diCe8QvOntO8IPNsrvBsVQcKXKdP3qjkhblnQ5rG1ztRyHcmvW1f
XnC9YUvP5d2JdCd7bFMe8QLh6ERzy+dOxCZ/WDzIlhde8djHhpd3oq6ZIrG4
y7zAsThrZzLRiQ4/+iM4oMsLUXX3lXiZutDjoWH8/TwvSCYt77QrdqGplD9P
N6x5IcXXpTLyfBeqZbpdnEjWR8oWm2/NnLoQy8Wjp3Ne8ULhUY9rAu+6EM+I
B/P+GF7Q4SXIdud1ofxsYUOODF64XE8sNCd1If7Yi6/2dfFCf9JLP2GJbqQ9
t2rlMMcLds8ZL/Rpd6NDtrF+B4h84KbBPnbDvxvxNQuY6B7iA0q+sAyxH93I
xkC6/7seHwQs8bgP/O1GgoP5/t8syfj/+14nfrEb1QzMEnXc+CA6WYjdmrsH
RUV+bX8dywfSLz52S6r3oIrjn9pDR/gg1VIicfhKD+KyG4tmO8QPqscSHBM8
ehB7356MCV+yceOTPWob14N8Ji4pa/3jB93lZOKekh6Ue3KSM1SLrD//7msY
G+lB5ea+rg3pAmD2PT3qG10vemxcK5GoIAiDL5Rsbsn3IqXU2LXePEG4bZW9
X+5cL/rwdM8iP9n/Lx07vDnp2Iuu67ZsakkIgzt/Qen30F5EJZfJ9ItbBKhX
NN/YZ/ci57Sb2e4mohDYUGy2r7MXxSfTbeZGiAF3irbU7FYvmqcb7NA0k4BY
v4rZVJE+xH9gK4AFpEDGWj/P4UQf2vh8dnW0VBzSNOueHfivD4Xfv72YHSsG
6gJG5xZe9KH7aSHCLlWiACtNfJlJfah1vIk3I1cE9BovDT2o7UNLzTEmfAPk
95fS8UNprg8dJHXeKFIUhisvr7ous/9DVxNcmiMjhGDIuk8rS/kf+hLffm6E
XQjskSWz8+V/6OEpR16laEFYFhhuV3X7hwRGWpUcDgmCx6pt/Fr0P2Q0FHXA
qkkAaJom7HPxP7Q/yd7Sxk0Agn7Yqz0e/IfkZBRdVPYKQGDpGiGGsh9N0E9H
tfbyg9Ghw7Y7nP3ItSv3xL9CfuCKc6u5Jt2PJlsvVesk8UMHc8GBItV+dDpg
7hZjOD9EP9kJF9HtRx0v0rL2evOD5YTmlqdZPyrbS/Eg9i4/TJYWlyF38nyt
v8zT0/yQeohKPu51P+p5puYyoswPD+K0gwkf+9GFIuJwhAQZLywvVizS+1GG
48h8MBvZbzypuFJc3I/uF1ceb9zlA5igA/HmfuSg9y300gwf+F7Wl/YZ7kfS
emmlgj18oFsW4D+40o9uCgVWitfwAZNS3ZwW7QBiOtXsG9/CB6jCyERAYABp
jZdbb07ywYOrLQULCgNocj3O9R8FP7Q/634Vd2EAdUUlrtkf5AcGvhvzLjYD
SOzWY38pfX7QSBk0MXQlr69SBz9rfohvmZDcjRlAi1YhN50j+aHV7q5/a/oA
emdm78rzix/odubnU0oG0KEZhvcBDfxwJMTpsm/bAArPovMYnOGHu9LrhVcn
BpCoct3gPxYBiMt7IqW0PYBoM1+FGtoIQNNZkj8D6yBaGJwhLpUIAHHQZ2FA
fBBxm7bedye/B3VnGtM85UH0bOKuo/InQbjD4F8UfHoQlTUfeq8rLQSxsczS
dlcG0Zv6oguXCoWg4VBIALo7iNRXknZuOQoDVQXXIo/XIDqQ/DFIhuwXVa9G
ms6+HURXvllGVdwQBbs5QVyWMIiufWK89thBDD48+ygdkzuIfjua6QgmikM9
r2SgU80gaot7ui9FWxooUhIXz/QNordn3rEeJEmA8nE5M8mFQbQ32Nv/rYU4
2Lb8wJtUQ6hHM+0gv6cYvLc7KNPEM4TcjPf5f/wjCrXbvwKT9g4hOt1YHrsm
EdgNVl/y0hhCkXfkjYJZReCgdIGZqeEQCn0cLxJxRxj+y0Ow32oIhVPOR2/0
CsG7syUytI+G0HStb8d5SyGoHtB53ec3hHQlZN+uLgjC9qPqpayoIeT7TlP+
/GtB2M9w7srrH0NoSOG0/ZODgmAV2wj/wRDiuzkZQccuCGGHLu3RaB5CNtIc
Wp1rArB5xXx5cn0IPZd9m8xfIQD75v5d+cM4jCgOXNbwSBMAi2fWxe9FhpG4
anzE1UgBeMs7tuf+wWF0JaM7JM1bAMq+3w7S1R5GEY6Fl53uCMA6ml0WvTyM
Nl+UmydcEgC5lvtX124NI6aIi1c0jwvANbuV4nr3YUREhnpH5QUgeNtVNvHN
MIo+x368TVIASoK3gzzih1HNPp0YRw0BWJXyWrmYNYwOLx7jziLnu3rW7w9V
9zASPXNTxtKf/P4HGPZ2zwwjq9svuXoTBAAeBb3JJIwgp6xXy/J/BEAmNtzc
UmYE1ZzayHu0Q+6/h/hL1A+PIDPWucOvhQQhsDx6L5vBCHp/qPFAhoYg4Cti
wWPXR1DqWR0lvuuCsDj7ebXo/ghybXOyeVwkCNLP9lyL8B1BBzWWAiT2CoEp
7/eSu+9GUCdJMsArTgj8vyvKnUoeQd/eXsrb2CMMhSgzWKhwBCn7eDu9LBWG
6GLTlJ/1I+jh+aIgV0cRcDtJqtDvH0FY2Gw3G4mCaVnC0MDCCLq22OF5VEIM
VE8bkFypRtEKq0cyXZMYcFUtCrBxj6JvEebbyf3isKj/XvWrzCgKa2ifKjgl
BQ216IKm+ijq7Mm853tEClLPjd5t1RtFr+dp750/KEHmh8BX9ldH0bP4Hg6i
sjjcvqCUQHV3FPUPGq5SBoiBbksnRHmOoiRm5ugpRjGQMfHqORg8isTEWWHj
jChQd8isV34aRda6BPmfn0Rg0KyO0+LnKGIa6j35kIxn6H64f610FP209jyu
+UYYYq8JnAlqG0X2pLpf3MJk/voHttLjo+j2I36BfdlCcMXypk/BxiiKny74
mm8uBOpDzLHGjGPo4lm5gokTQsBj8ytvUmgMSbsv9eTuEYLl0Sut3opjSPVJ
8SVxFiFosqNY4Ds+hgYdrbcFVwQhyP6c7GnrMRQS1v/2R6kg2M8un+xzGkP7
C12d1X8Igr7jhxuPXowhR1Y382MRgiC7eOIJU+QY2qzu3JvzlOznnMYjPieN
oYCkTs5PtwRheCUo80j+GLLD4e9XjQXhj4tKfWPtGKLMSs/4YyMIcRvdE3Z9
YyhhV1b7Gjne84kPkTA/hg6R/oSmvhcE8x1Z8XcU4yjdty4VfgnCkad/NRQ5
x5Gg0bZHbIMgrPoIOZmrjqOmyYn8GQYhaKEuebN0ehwJvItRdyPjK/PFre/+
ZuPo4mutejo9IQimY6sQvzOOrjtkeCbfEoJ7/tmDue7jiGU0ju5BgBAYMF3b
NQwaR/l7iSuTo0IgF0QlMPZxHJVfIFj/NRYGOrZkFc+McdQSGci9XCcMoyFG
57lLxlHhpcaxLVMRKOVcs09pGUe63VcydTZFID485uXJ0XGULcWcdvK3KHjx
an/pWhtH1X1StknGYnD9/SS+Tz+BFqakPYNmxUBDMKSbTnAC6Ra0vz5XLw4C
MWprHxUm0JuOqwpnbCVhXaSPQ01zAj1wnuI4NSQDbXG+ivWGE+h4sn0yo6gk
/JKQ17exnEDD/VOm0sPi8PZLo832gwlUxVqwdEJCHBxlXL1DfSdQTL2BaGa4
GJz7JhIjFzGBbkff+Wy0RwwU5Mpyi79OIL6+h1KlkaLAkHKnxTRvAv2qfMrA
uSsC4/s45ueqJ1AylbvFfRcRKE/LZfTrmUBcBnv1jhJE4MvBG3tEZidQvVrk
F81wYfD5STyZRZpACQ3XuvWthcFCJeW6AfskEhtWc5bUEQaUc8FtSGIS1ZbN
GuTvFQaGNzKsEsqTSPCqusxbFmFosd38bHFqEn18diSMZZnMX5r16h9NJtHU
nuk3sl1CYMcTX9d7cxJd3+D70gFCcGj2kZXQ40mk8mH0H+83Idgp01u74j+J
WLz/Vf97IwSVMcKB7z9MorlxwytyrkLw9tGCWEfKJMqQz9Q9cF8IzM+WZfEU
TaJPn8y09gcKgYz0e/1LfydRdl34q/WvQpDfctypaWES+b2ZIggMCsGLFC56
dqopRKGtuhRIEAYj3/EYQ64ptOc7LYkkKgzDSsEVtapTyLFx/YK8lTCkMv5n
zqg7hcSyuyMYngvD4yG1BT2zKTT4k/jFOV0YtPMZX7y8PYWY2OY/BwqJAEvo
P4GKJ1NIcnRgISVcBDpu/0wjvp5CdYWM1VaiohCv5aetHTuF9mkf0hotEgV7
gaudPmlTaPIN0OzXFAO1RcV7xTCFhC98kanJFAPKakoqQtMUKtHo97ytLw61
n9reaQ5NodyZJ3RXJCUg4nGygsfyFFLgu/fW74skWJz3LM4nTqNYRxTz6IQs
yO29YLLJM41OKhq9ux0jCSsEmSl12Wk0V6kxVGssAdCx8dTl8DRS+NKTGRwo
Dv7pdVzZ+tNoMjKXUXNHDC6+/JS0fHUaOZjrxe97LQaiFo80le5OI8HpyvPC
B8VgUk2v+b7nNLp86WbrRJko/GIVtkt/M42wuPo0q6YoeI7Nb8/GTaODlEP8
Y2UioItLQ/ZlTqPTtkcdfpP5gONdpIx9yTT6Jt5RyHteBHrv2ecnt0yjELUj
zpcPicA3neNGEyPTKMPauN2eSwQeiHCN7FmbRhdszisYrAmDxurYY1u6GfTG
iDp9sksYaOrzWRL4Z1Cb89ZDTSwMDQlvPg/JzaDex5X6ml+E4YOHtbqExgya
U1z4NfBKGGwvqdVZnJ1BQLuvQYyspw7sY7T6eH0GvZD+OvXZQxg2qf+t9jrM
ID8BB6/jH4ShrCczQMh7Bm3Gf371N4+s9wOvZL3/PIOmaqtMqTeFQeo/Rf2O
XzOIw0y4tU5QBGaPUv7jKZ9B9lE+iY2aIpDL2fbwUvsMSj1BWy5jLQLPppLo
wsZnkPv3kqrRlyJwrsQjpmljBq3H57d4l4sA34fzh9gZZ9H+XD+V02S+HHwg
XWEoNIssVwQq/CpFIUV/42rQvlnES7VfOEdJDJwl6uZrNWdR+e8KF+q3YnBi
M+45o9Esaqv8brVBFAemJicBfctZVBTRpuMZLQ5tSbppLx/Mohe2fw3lHkoA
67frpzSfz6KmUp+tZREp0E106l56N4s4dw6E3e2VAa8v/veTkmdRVG7RjQJ/
SciLj6O9UTiLvvMq8VpfkYDFuOwYroZZNPV6yO8BOb/cx1ql6sFZtOAR9nOe
XRysYwarnq7MIvsrLnl/v4hB9If1Gyp0c+jgURWPHH0xaH3PsjopMIc09vCH
zW6JAkukVGDcvjlk3vpwVdFZFE5HHJEwOT6Hqhhk3107Te7PYUa5jMZz6Nrh
lcBBCVHIe2t7rthmDpl8XX4VRhKBxWD3YWfXOeThICNu0SsC1q+/sQ3GzCE1
yQgD0gcRiA4oSnyXPofMDrPr/nIXgZZXLRpnS+YQj3z2hVPXRYD55WQTZdsc
ikme7Q++KwI6Lwi3csfn0B4D6jLjYBF46stDurs1h3pLqVv/+yUC5iciqtlp
59GyXrV+b6cIhKMUiwr+eYQbOj657hWFTM0ceQnJebL+UunoMxaF+mN/Vt0V
5lFkTre9spcoTGrUFberzCNrs3iuzQlRoNHoCDyE5pFXN31443ExkDg6dPm1
7jx62P0xgCdKDNCRWYnx8/MoqG5s+TWNOJgf3pjRujqP+qTFCrODxcFVnTov
5r951LS/1IbRUALC1Fh91+/Oo0veR79c8pGEDFUBQ2OXeaTWJfAKb8tAvYq0
QKrXPBoYH80r+S0Fk8oHRuj859EZGsuyFW5JoFE+mm4dOo9IC6FLv8n6SkJJ
50lRNDm+Ue2ZcJg4aB46r8OfOI82BY9//V/DVR5Pdd6FI41GIhRa5Pe796JI
paRCjiXZBk1FktdEwtBIF2FkchHKyDLXmxnZ8kqLhmpUV8VpZMlWQ3hLlqQS
Jb9N0Ta/P7+f7/qc7/Oc85yUpSTuNfFRi6ychK7zGcdaZATGrA162nFzEkKS
ptRzgwiUrhGXr/x7EtoHypq/4/1f1ep4cXLrJCxxeCj+RoXANuO0LYOPJoGb
K+/Isbo4uuq3ueYDk1CxdVht0wNdnLOqsEv6ahIKtQ773rmoiwKjC4XvJieh
6Lmk4lCqLloZ/vWj88wkvA4qyrQ4oIveK+tMy2ZTkHAn8ifVrboYvaLl61dl
CmRjdvIx1rooNehu8dakoP+8eY4vv75Kfyi3WpeC8sexenfS+f5Gb3zfgpUU
ROVr01eu8e8RTRmFrqOg2EM47dvP+0WR3PsGCwo+FJJeUQoEkkLlvwl7Ctb5
a/xovZRAK4FWRpwbBU8zAqtW8nr1JgVePbv5cavly+FYXr+EsdDEj4L6RHn5
Dw8IzNHdNJEeQsGcNfvCGjaS+OdyO9nLCAoM56q0R9SQ2KrjlmwTT8GXx+YO
vSECHF22x/1MCgUdWoz2u5+FqLAsYMn7TAoUitO8jozq4VT2LLySR8GFytnX
qT49HFUsOHCwhIK73iLvr41CfBK/eZ7BRQoklYOKek0CbGP4bvgqBcPNpk5z
dARY+6PY88wtCpbmWgvcCkisGlT55HmPgnRJzLFpMxLPelwqUWunYOz5seuZ
z/j/bXVwaOumgAl9ZWqZR2CKzciblAEKylzi5k7zeGNuJOTYvKKgqWhvjEkg
gSHGOps+vaPA5q6q6jLeb/mUyvqvf6DAJeaWVwXPf7fFnkmH5Wj4GhYs6l1N
oHUmvWKVEg0Ki3r25OgQuG5OZsdLdRq+q+O6HykTKIoziixZSkOTFdopyROo
STUt9hHR0LnN9+z6hQTODQqo0zSmYQL3HVXn/dTM01kH/tlAw4471mS1OYFv
dhQo/WpFQ/euhFIjdwIHmjdXbXOgYfWi53ppAQQ+tOrxkNtOwzQztnnwZwL/
/kv88ZYXDT2yiF2OfP79y1C15IgfDTYbFttW3yfwXPGlbSYhNMwUFs4R8/rI
03R8My6mwf8SBn06ytffX0eyz8XRYKse+maII/GovGSjXzJ/fknbWLdUgGEx
Ov1LM2hQ/u2++cZ4vt5PyBJ7cmkgK5+0q5jq4Y4AzxXZhTQk1aRmbsgxQPsn
dLtLOQ0Jn8vVI8NEuGl7ZsQ3VTTIohO7dtoJ0bDRaPHdmzSEDlr5haYKcJll
c23cXf4+r/QsuS8kqlwNCDBroaGSu3M7O5vEWSvklKhOGhY24yqO5yNdUFB5
qY+GQIG3W/Y4gSMa5h6BIzRY6VzJt+gmsOdEzwzxlsfX5JPgigQ2fxUX93E0
lJv3LTKoILAmSnXbf7/QYJLfWSzj+VExfml8uyIDl194fXh/nMBCP8fseQsY
0Jssd+uJIDCrd8SsUZuBWNtZs539CUx0lTxNIBlgy8d/UjxEYGS9TqKFIQOu
g4v/eJpIYODmGoOpdQzcsHk9cuI0gV6Vnu1VFgwEV1yfJbhMoLMeIw7dyoDx
FoWVNfW8n8/P1NZ3ZUD7VXhBSB+Bq9VW1Q55MDC+ztbCnSWQSG3en+/LwKOI
+XXtG0hU/xzwrWcQA3kOyoa5mSQqRMhVLghnYOfHV+HNn0icGi3Y1RrDwMTt
5D3L0nh9+prPHJcw0E1lQKkjr7dHPUXWJxmwHSlpkElE2OYcYf8xh4GUs6/t
t1iuwFpUHa/OZyAzW6Fo60k9rDKryAr/HwO5tl8tl08K8WyFo5nRZQacT0bE
TKkIUSp40feimgHfi5vMu8QCTMmTSIprGRBLhet1PpK4/vSg0g/NDGDASOA9
/r1DuVukOp0MxFwLKaWtScyQ5us87WNAIjXX9DMg0fy36XN/vODxbNQ4+EGF
xFfZu9fuecdAofSsbeF7Xt9Z1TKtaQb+aS7IteD1bpOpYdcjz0LvoOK6260E
TmQcbpMqszC0oaM39zaB+b8+8NipyUKcUbl2dBfff6cbD6oRLLw+89YzlucP
dyI9+OFKFjpFLk0yBT6fpL2mTq1nQe4HPUdvXRLdUx3iXLew4FijHZZoQeKn
42UKyg78vNPYx7f+JF5Inn2qZTsL+39vUhu4R6Jnkp/WCW8Wzl3MOh1kJcDZ
iXXFDgEsCHxMSlIGBFiVoGP4TRgLjbYdeb/cF+J/jsVduxfNQq5YTcuGj7fS
L48tkyQs2Nu1PLMvNsAbRzc22qSzwGo4lh4tFmFAXK77rFwWOsShE+WxQlT7
mfl/bSELlt0alX51fL6M+d4//jyPh0x+0GEmwNDoynGLq/z++TIYaCFR+8j8
qJlbLCi8X6jWl0FiQ2Tol5sNLOx96OxkEkGiOOJ+avQDFpwn5/m27CFRV2yg
ZvaYhUVmktg0G74fCD/+BzvMwvU/78q+NyQx9tBz4bU3LEjJ34+rLiRRP8zm
8uEpFpYW/RSXQJLYdbDIbO0sDkIUF7VGm5OYEPq5buJbDmrZhs1Nu0g0Dtnr
dFmDA8Pens/ScBKfBMs6Q3U4+LaVU1I5RWJqkJaPoQEHIz3hAfrVJJoGRr0Y
XctBY8ujfdnLBPgsoCus3JwDb60jaeWFAjy13+TDga0c9B+/VDrjKkQL/0yJ
yI2DYd8tYxl7RTi6763S890cSCW3nKZr9DH3BxdpiR8HkadVt+ol6KOt7wWd
faEcNC8UvomKEOE7H8Xy5VEc1I8pxO2JEuKZvQfW9v/CgUbZYBLTKkAn73pZ
fhoHCa9H/Au+E+CUF2nnncNBfGzs8htjJJbuPtamfYYDn5tah5h2Erd79nv0
lnEwU2TpU36VxM+7LAZzKzlIS19w8XIeiRd3/h68S8bBGYUV+18eI3H3jveU
ej0Hvi+fjWwI5vX+vUfcP20c3L99cPFCPl5X3K8pZPVwMPoFNOEkib5uaqfc
hjjQv3LTdqSMxHmuh7Tmj3GQ5ODfuaaexJsu7cWtDAfBQ/KmnsMkHnA2Mjz5
mQP2lqh+i6YA1Z1OXHNUnIJAX23nYT4/1zm8slRUm4LZLw4Lc5YI8eA2+8aG
JVPgGNkblfVaiEvsS92TRVMQv0buSp+LHvbRwju2q6fArdpw/HylKf4L4sNp
oA==
          "]]}, Annotation[#, "Charting`Private`Tag$17116#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          RGBColor[
           NCache[
            Rational[2, 3], 0.6666666666666666], 0, 0], 
          Dashing[{Small, Small}]], 
         LineBox[CompressedData["
1:eJwUW3c8le8bPufYe++dUUbSkkpeX1SaSggpoaFSUkhWVsmsUEYlyUoSyki4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          "]]}, Annotation[#, "Charting`Private`Tag$17116#2"]& ]}}, {}}, {
    DisplayFunction -> Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
       None}, DisplayFunction -> Identity, DisplayFunction -> Identity, Ticks -> {
       Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
        MachinePrecision, RotateLabel -> 0], 
       Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
        MachinePrecision, RotateLabel -> 0]}, 
     AxesOrigin -> {-5.689582957580917, -20.68617124359776}, FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
         MachinePrecision, RotateLabel -> 0], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}, {Log, Exp}, "Nice", WorkingPrecision -> 
         MachinePrecision, RotateLabel -> 0], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, GridLines -> {None, None}, 
     DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "ClippingRange" -> {{{-5.545177303020954, 
        1.3862941158578714`}, {-20.686171243597805`, -1.2364566869005622`}}, \
{{-5.545177303020954, 
        1.3862941158578714`}, {-20.686171243597805`, -1.2364566869005622`}}}},
      DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, -20.686171243597805`}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
       None}, PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"h/4-h\"", "\"h/2-h/4\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 
                    NCache[
                    Rational[2, 3], 0.6666666666666666]]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 
                    NCache[
                    Rational[2, 3], 0.6666666666666666]]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[
                    NCache[
                    Rational[2, 3], 0.6666666666666666], 0, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   TemplateBox[<|"color" -> RGBColor[0, 
                    Rational[2, 3], 
                    Rational[2, 3]]|>, "RGBColorSwatchTemplate"]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   TemplateBox[<|"color" -> RGBColor[
                    Rational[2, 3], 0, 0]|>, "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.9002307212479773`*^9, 3.900230738704392*^9}, 
   3.900230772960168*^9, 3.900230885990045*^9, {3.900231511439036*^9, 
   3.90023153231063*^9}, 3.90023170581546*^9, 3.900231783124535*^9, 
   3.900232757769047*^9, {3.900233046591181*^9, 3.9002330612590513`*^9}, 
   3.901375491057407*^9},
 CellLabel->"Out[55]=",ExpressionUUID->"5a417731-9ec1-4be7-9fd7-c69a91401651"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "estimate", " ", "of", " ", "global", " ", "R", " ", "using", " ", "L2", 
    " ", "norm"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "4"}], ")"}], 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"soltab", "[", 
             RowBox[{"[", "4", "]"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"jt", "+", "1"}], "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "-", 
          RowBox[{
           RowBox[{
            RowBox[{"soltab", "[", 
             RowBox[{"[", "5", "]"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"2", "jt"}], "+", "1"}], "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "^", "2"}], ",", 
       RowBox[{"{", 
        RowBox[{"jt", ",", "0", ",", 
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"soltab", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "]"}], "-", "1"}]}], "}"}]}], 
      "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}], 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"soltab", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"jt", "+", "1"}], "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "-", 
          RowBox[{
           RowBox[{
            RowBox[{"soltab", "[", 
             RowBox[{"[", "5", "]"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"4", "jt"}], "+", "1"}], "]"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "^", "2"}], ",", 
       RowBox[{"{", 
        RowBox[{"jt", ",", "0", ",", 
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"soltab", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "]"}], "-", "1"}]}], "}"}]}], 
      "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"%", "/", "%%"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.900231997793199*^9, 3.900232113034052*^9}, {
  3.900232279227407*^9, 3.900232315799191*^9}, {3.900232346487875*^9, 
  3.900232348746105*^9}, {3.900232787058375*^9, 3.900232788258482*^9}, {
  3.900232887151203*^9, 3.900232888908626*^9}, {3.90023293257161*^9, 
  3.9002329505182047`*^9}, {3.9002330702793217`*^9, 3.900233071618588*^9}, {
  3.901373429435687*^9, 3.901373435612618*^9}, {3.9013754999508038`*^9, 
  3.901375502172535*^9}},ExpressionUUID->"ee769423-85b9-456c-8d8c-\
7a54ebfa21b0"],

Cell[BoxData["0.0022711395570014746`"], "Output",
 CellChangeTimes->{{3.900232075713868*^9, 3.900232114917109*^9}, 
   3.9002322818930483`*^9, 3.9002323175995607`*^9, 3.9002323490798283`*^9, {
   3.9002327621530724`*^9, 3.900232788788258*^9}, 3.900232950967215*^9, 
   3.90023307274292*^9, 3.900240266027113*^9, 3.901375495428681*^9},
 CellLabel->"Out[56]=",ExpressionUUID->"6b342583-521f-4540-8c85-b42885f7fc9d"],

Cell[BoxData["0.06601937862020506`"], "Output",
 CellChangeTimes->{{3.900232075713868*^9, 3.900232114917109*^9}, 
   3.9002322818930483`*^9, 3.9002323175995607`*^9, 3.9002323490798283`*^9, {
   3.9002327621530724`*^9, 3.900232788788258*^9}, 3.900232950967215*^9, 
   3.90023307274292*^9, 3.900240266027113*^9, 3.901375495434374*^9},
 CellLabel->"Out[57]=",ExpressionUUID->"220c6d44-7b8e-4701-9b16-54b7d60cad8a"],

Cell[BoxData["5.391552089388267`"], "Output",
 CellChangeTimes->{{3.900232075713868*^9, 3.900232114917109*^9}, 
   3.9002322818930483`*^9, 3.9002323175995607`*^9, 3.9002323490798283`*^9, {
   3.9002327621530724`*^9, 3.900232788788258*^9}, 3.900232950967215*^9, 
   3.90023307274292*^9, 3.900240266027113*^9, 3.901375495440318*^9},
 CellLabel->"Out[58]=",ExpressionUUID->"85e52528-3d3f-4803-b60d-1b3faaa7f51f"]
}, Open  ]]
},
WindowSize->{1440, 762},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"13.2 for Linux x86 (64-bit) (December 7, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"c8170292-3e2f-4f8f-9028-591033a5a9bf"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 1651, 27, 173, "Text",ExpressionUUID->"7c274769-2da8-4b70-8347-057399a794c9"],
Cell[CellGroupData[{
Cell[2234, 51, 2881, 80, 149, "Input",ExpressionUUID->"f597ab79-b850-4665-b18d-132fe3bf4a51"],
Cell[5118, 133, 3828, 109, 60, "Output",ExpressionUUID->"48445fc3-0926-4091-87a3-749bf81f00f4"],
Cell[8949, 244, 338, 9, 56, "Output",ExpressionUUID->"e6560ffa-513b-4cdc-8002-acad693c8f7b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9324, 258, 672, 15, 51, "Input",ExpressionUUID->"042740d1-8b9a-42b5-92a9-5eca6b9dc09f"],
Cell[9999, 275, 1256, 36, 54, "Output",ExpressionUUID->"fe6a9c61-4358-4097-ad02-74b7d4db9310"],
Cell[11258, 313, 502, 12, 52, "Output",ExpressionUUID->"b4022646-f43c-4494-9571-8f7cb0c0ce12"]
}, Open  ]],
Cell[11775, 328, 472, 7, 35, "Text",ExpressionUUID->"ae40a229-b28b-43d3-814a-f7281a7d7af7"],
Cell[CellGroupData[{
Cell[12272, 339, 857, 25, 141, "Input",ExpressionUUID->"f5a54782-928a-4e3c-ac4d-ab656cc688b0"],
Cell[13132, 366, 489, 13, 55, "Output",ExpressionUUID->"44bdd760-916f-43ee-aec1-5b5c5725926f"],
Cell[13624, 381, 552, 15, 54, "Output",ExpressionUUID->"edc5a785-e0f6-4a71-a62c-f031c97c3dc7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14213, 401, 470, 11, 51, "Input",ExpressionUUID->"b8ed5947-c6d5-42a6-a879-98cd8e2a0181"],
Cell[14686, 414, 1536, 51, 48, "Output",ExpressionUUID->"b9933aad-609d-455c-ae60-17cc3793a965"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16259, 470, 574, 12, 92, "Input",ExpressionUUID->"e56a042b-ad6b-44d3-8bac-d69d5a09123d"],
Cell[16836, 484, 815, 25, 48, "Output",ExpressionUUID->"79d37b7e-faf7-49d4-aac2-1f7675b197d5"],
Cell[17654, 511, 902, 27, 48, "Output",ExpressionUUID->"06673a48-4233-4370-ab1d-23868ab5763e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18593, 543, 1455, 47, 76, "Input",ExpressionUUID->"7bd16797-090f-4bef-801c-3996f879bf85"],
Cell[20051, 592, 505, 12, 52, "Output",ExpressionUUID->"856407f5-bf24-4815-812f-53726f897763"],
Cell[20559, 606, 604, 16, 52, "Output",ExpressionUUID->"64735372-5137-488e-9caf-19f1d00738ec"],
Cell[21166, 624, 534, 13, 52, "Output",ExpressionUUID->"952e0124-73f2-498c-980c-d92c08009640"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21737, 642, 1882, 52, 118, "Input",ExpressionUUID->"0f4831b0-d16d-4677-a7fb-a4e47d94ec41"],
Cell[23622, 696, 1444, 46, 61, "Output",ExpressionUUID->"ba4d292a-ae54-47ba-8c4c-e2cdbc86c6f6"],
Cell[25069, 744, 893, 26, 58, "Output",ExpressionUUID->"4fb42ad7-0196-4d66-b101-8644ba207774"]
}, Open  ]],
Cell[25977, 773, 315, 5, 35, "Text",ExpressionUUID->"bfe5eb1f-5652-4b3e-a2ce-4f1da09d6f12"],
Cell[CellGroupData[{
Cell[26317, 782, 1158, 30, 203, "Input",ExpressionUUID->"359e39eb-1392-4ba6-ba48-a95e03fad35b"],
Cell[27478, 814, 484, 13, 55, "Output",ExpressionUUID->"71ead9ca-6c31-4e84-aed3-16cfe63f0e16"],
Cell[27965, 829, 527, 14, 53, "Output",ExpressionUUID->"d41cd197-b749-4282-9268-9f66dd94fc9a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28529, 848, 317, 4, 29, "Input",ExpressionUUID->"41204a16-40f1-4baa-ac98-a19831718f93"],
Cell[28849, 854, 1184, 35, 54, "Output",ExpressionUUID->"9a3cbe18-0852-4948-bc22-aa54c6993007"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30070, 894, 1690, 46, 77, "Input",ExpressionUUID->"d478b7e0-802e-42ab-b195-7eeffcc4fdb9"],
Cell[31763, 942, 956, 24, 37, "Output",ExpressionUUID->"f1c35505-b7d2-4d7d-9200-a07cf79ebad0"],
Cell[32722, 968, 955, 24, 37, "Output",ExpressionUUID->"973927cf-a870-42f5-bff5-36f9f33afa6b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33714, 997, 2374, 67, 139, "Input",ExpressionUUID->"7e44fe6a-f8ba-4e10-877f-2b0ef075c311"],
Cell[36091, 1066, 1037, 28, 60, "Output",ExpressionUUID->"3e24d35f-a05a-42fb-8a11-98f2aed64ea2"],
Cell[37131, 1096, 816, 19, 55, "Output",ExpressionUUID->"85f3e8b1-d7d4-4448-8ec9-6b6670502cb6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37984, 1120, 1329, 22, 114, "Input",ExpressionUUID->"b6cb5134-c5e4-41f8-add7-547e217fa511"],
Cell[39316, 1144, 596, 8, 33, "Output",ExpressionUUID->"313703d5-ec90-4a3a-b40a-0259dd49c6da"],
Cell[39915, 1154, 596, 8, 33, "Output",ExpressionUUID->"66b5542c-e719-4692-833f-f73ee67c0044"],
Cell[40514, 1164, 614, 9, 48, "Output",ExpressionUUID->"038ccc12-9ad5-43a6-8b88-bf115811a0dd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41165, 1178, 2585, 64, 171, "Input",ExpressionUUID->"1ef26d31-0151-408e-9451-760affdf6cc1"],
Cell[43753, 1244, 171, 2, 33, "Output",ExpressionUUID->"03e5d08f-b53a-4a3a-9d41-e48e81af6aea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43961, 1251, 678, 15, 71, "Input",ExpressionUUID->"71f7de12-4150-4bbc-a5b6-927c14831f20"],
Cell[44642, 1268, 6036, 182, 347, "Output",ExpressionUUID->"ede16302-0630-4750-8e1c-8fef4bd573d9"],
Cell[50681, 1452, 626, 14, 33, "Output",ExpressionUUID->"97785aaf-8baa-46c1-b91c-24334aee3e01"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51344, 1471, 373, 6, 29, "Input",ExpressionUUID->"e5d06b8c-6300-4160-a859-0eef66c85c83"],
Cell[51720, 1479, 585, 13, 48, "Output",ExpressionUUID->"b8621d4c-d7a8-41d8-a1fc-721682410724"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52342, 1497, 6111, 152, 363, "Input",ExpressionUUID->"59fba8db-d6dc-4492-b22e-b4c425400962"],
Cell[CellGroupData[{
Cell[58478, 1653, 362, 8, 38, "Print",ExpressionUUID->"ed0a16fc-e649-43be-86dd-19829596c5c4"],
Cell[58843, 1663, 362, 8, 38, "Print",ExpressionUUID->"4ef69d17-4a1f-4b1c-a680-06f3f426d2ba"],
Cell[59208, 1673, 365, 8, 38, "Print",ExpressionUUID->"0b82a288-7bc5-43a2-a05b-31020cf3fbcb"],
Cell[59576, 1683, 363, 8, 38, "Print",ExpressionUUID->"f5a5a397-2b72-4804-b464-66c1ab7c160e"],
Cell[59942, 1693, 365, 8, 38, "Print",ExpressionUUID->"35736e0c-050c-4d50-bde5-58e737025235"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[60356, 1707, 693, 12, 51, "Input",ExpressionUUID->"d3789a48-1c62-4be6-a623-6ab0f7c38245"],
Cell[61052, 1721, 508, 7, 33, "Output",ExpressionUUID->"7e6dd689-a6e7-4a6b-aa26-56ca1444378d"],
Cell[61563, 1730, 1641, 42, 55, "Output",ExpressionUUID->"7abe05c8-2853-4a4c-a49c-060a66b2641d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63241, 1777, 1156, 25, 52, "Input",ExpressionUUID->"b214c22e-fc3c-4bff-b343-3afdcc122801"],
Cell[64400, 1804, 212311, 4022, 155, "Output",ExpressionUUID->"bb30d088-b0c2-4b63-8d6b-1f7eae9ff08b"]
}, Open  ]],
Cell[276726, 5829, 668, 9, 35, "Text",ExpressionUUID->"74b76087-a1db-4e30-9ddb-17ad47dc1311"],
Cell[277397, 5840, 1099, 25, 74, "Input",ExpressionUUID->"eeb55d4a-4805-44cc-b295-fd0f554c2dd0"],
Cell[CellGroupData[{
Cell[278521, 5869, 1600, 38, 51, "Input",ExpressionUUID->"448a080b-2992-4390-bbe5-a4d12850b489"],
Cell[280124, 5909, 26291, 501, 238, "Output",ExpressionUUID->"580bead5-8ec7-4dbf-805b-644efadcf791"]
}, Open  ]],
Cell[CellGroupData[{
Cell[306452, 6415, 3228, 82, 120, "Input",ExpressionUUID->"12f328e7-1c41-4d17-a000-e54335ee9ce6"],
Cell[309683, 6499, 172294, 2991, 239, "Output",ExpressionUUID->"0967e3e9-715d-4c9a-a2ba-a007a11de1a5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[482014, 9495, 2000, 53, 97, "Input",ExpressionUUID->"2598ba5d-4d17-44f9-97e9-4bf5b0513b54"],
Cell[484017, 9550, 63127, 1098, 234, "Output",ExpressionUUID->"5a417731-9ec1-4be7-9fd7-c69a91401651"]
}, Open  ]],
Cell[CellGroupData[{
Cell[547181, 10653, 2837, 78, 98, "Input",ExpressionUUID->"ee769423-85b9-456c-8d8c-7a54ebfa21b0"],
Cell[550021, 10733, 413, 5, 33, "Output",ExpressionUUID->"6b342583-521f-4540-8c85-b42885f7fc9d"],
Cell[550437, 10740, 411, 5, 33, "Output",ExpressionUUID->"220c6d44-7b8e-4701-9b16-54b7d60cad8a"],
Cell[550851, 10747, 409, 5, 33, "Output",ExpressionUUID->"85e52528-3d3f-4803-b60d-1b3faaa7f51f"]
}, Open  ]]
}
]
*)

